Module: Aws::BedrockAgentRuntime

Defined in:
lib/aws-sdk-bedrockagentruntime/endpoint_parameters.rb,
lib/aws-sdk-bedrockagentruntime/plugins/endpoints.rb,
lib/aws-sdk-bedrockagentruntime/endpoint_provider.rb,
lib/aws-sdk-bedrockagentruntime/event_streams.rb,
lib/aws-sdk-bedrockagentruntime/client_api.rb,
lib/aws-sdk-bedrockagentruntime/endpoints.rb,
lib/aws-sdk-bedrockagentruntime/resource.rb,
lib/aws-sdk-bedrockagentruntime/waiters.rb,
lib/aws-sdk-bedrockagentruntime/errors.rb,
lib/aws-sdk-bedrockagentruntime/client.rb,
lib/aws-sdk-bedrockagentruntime/types.rb,
lib/aws-sdk-bedrockagentruntime.rb

Overview

This module provides support for Agents for Amazon Bedrock Runtime. This module is available in the ‘aws-sdk-bedrockagentruntime` gem.

# Client

The Client class provides one method for each API operation. Operation methods each accept a hash of request parameters and return a response structure.

bedrock_agent_runtime = Aws::BedrockAgentRuntime::Client.new
resp = bedrock_agent_runtime.create_invocation(params)

See Client for more information.

# Errors

Errors returned from Agents for Amazon Bedrock Runtime are defined in the Errors module and all extend Errors::ServiceError.

begin
  # do stuff
rescue Aws::BedrockAgentRuntime::Errors::ServiceError
  # rescues all Agents for Amazon Bedrock Runtime API errors
end

See Errors for more information.

Defined Under Namespace

Modules: ClientApi, Endpoints, Errors, EventStreams, Plugins, Types, Waiters Classes: Client, EndpointParameters, EndpointProvider, Resource

service collapse

GEM_VERSION =
'1.74.0'