Module: Aws::BedrockAgentRuntime::Errors
- Extended by:
- Errors::DynamicErrors
- Defined in:
- lib/aws-sdk-bedrockagentruntime/errors.rb
Overview
When BedrockAgentRuntime returns an error response, the Ruby SDK constructs and raises an error. These errors all extend Aws::BedrockAgentRuntime::Errors::ServiceError < Errors::ServiceError
You can rescue all BedrockAgentRuntime errors using ServiceError:
begin
# do stuff
rescue Aws::BedrockAgentRuntime::Errors::ServiceError
# rescues all BedrockAgentRuntime API errors
end
## Request Context ServiceError objects have a #context method that returns information about the request that generated the error. See Seahorse::Client::RequestContext for more information.
## Error Classes
Additionally, error classes are dynamically generated for service errors based on the error code if they are not defined above.
Defined Under Namespace
Classes: AccessDeniedException, BadGatewayException, ConflictException, DependencyFailedException, InternalServerException, ModelNotReadyException, ResourceNotFoundException, ServiceQuotaExceededException, ThrottlingException, ValidationException