Class: Aws::BedrockAgentRuntime::Types::APISchema

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Note:

APISchema is a union - when making an API calls you must set exactly one of the members.

Contains details about the OpenAPI schema for the action group. For more information, see [Action group OpenAPI schemas]. You can either include the schema directly in the payload field or you can upload it to an S3 bucket and specify the S3 bucket location in the s3 field.

[1]: docs.aws.amazon.com/bedrock/latest/userguide/agents-api-schema.html

Direct Known Subclasses

Payload, S3, Unknown

Defined Under Namespace

Classes: Payload, S3, Unknown

Constant Summary collapse

SENSITIVE =
[:payload]

Instance Attribute Summary collapse

Instance Attribute Details

#payloadString

The JSON or YAML-formatted payload defining the OpenAPI schema for the action group.

Returns:

  • (String)


37
38
39
40
41
42
43
44
45
46
47
48
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 37

class APISchema < Struct.new(
  :payload,
  :s3,
  :unknown)
  SENSITIVE = [:payload]
  include Aws::Structure
  include Aws::Structure::Union

  class Payload < APISchema; end
  class S3 < APISchema; end
  class Unknown < APISchema; end
end

#s3Types::S3Identifier

Contains details about the S3 object containing the OpenAPI schema for the action group.

Returns:



37
38
39
40
41
42
43
44
45
46
47
48
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 37

class APISchema < Struct.new(
  :payload,
  :s3,
  :unknown)
  SENSITIVE = [:payload]
  include Aws::Structure
  include Aws::Structure::Union

  class Payload < APISchema; end
  class S3 < APISchema; end
  class Unknown < APISchema; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



37
38
39
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 37

def unknown
  @unknown
end