Class: Aws::BedrockAgentRuntime::Types::ActionGroupInvocationInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains information about the action group being invoked. For more information about the possible structures, see the InvocationInput tab in [OrchestrationTrace] in the [Amazon Bedrock User Guide].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/trace-orchestration.html [2]: docs.aws.amazon.com/bedrock/latest/userguide/what-is-service.html

Constant Summary collapse

SENSITIVE =
[:action_group_name, :api_path, :function, :verb]

Instance Attribute Summary collapse

Instance Attribute Details

#action_group_nameString

The name of the action group.

Returns:

  • (String)


145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 145

class ActionGroupInvocationInput < Struct.new(
  :action_group_name,
  :api_path,
  :execution_type,
  :function,
  :invocation_id,
  :parameters,
  :request_body,
  :verb)
  SENSITIVE = [:action_group_name, :api_path, :function, :verb]
  include Aws::Structure
end

#api_pathString

The path to the API to call, based off the action group.

Returns:

  • (String)


145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 145

class ActionGroupInvocationInput < Struct.new(
  :action_group_name,
  :api_path,
  :execution_type,
  :function,
  :invocation_id,
  :parameters,
  :request_body,
  :verb)
  SENSITIVE = [:action_group_name, :api_path, :function, :verb]
  include Aws::Structure
end

#execution_typeString

How fulfillment of the action is handled. For more information, see [Handling fulfillment of the action].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/action-handle.html

Returns:

  • (String)


145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 145

class ActionGroupInvocationInput < Struct.new(
  :action_group_name,
  :api_path,
  :execution_type,
  :function,
  :invocation_id,
  :parameters,
  :request_body,
  :verb)
  SENSITIVE = [:action_group_name, :api_path, :function, :verb]
  include Aws::Structure
end

#functionString

The function in the action group to call.

Returns:

  • (String)


145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 145

class ActionGroupInvocationInput < Struct.new(
  :action_group_name,
  :api_path,
  :execution_type,
  :function,
  :invocation_id,
  :parameters,
  :request_body,
  :verb)
  SENSITIVE = [:action_group_name, :api_path, :function, :verb]
  include Aws::Structure
end

#invocation_idString

The unique identifier of the invocation. Only returned if the executionType is RETURN_CONTROL.

Returns:

  • (String)


145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 145

class ActionGroupInvocationInput < Struct.new(
  :action_group_name,
  :api_path,
  :execution_type,
  :function,
  :invocation_id,
  :parameters,
  :request_body,
  :verb)
  SENSITIVE = [:action_group_name, :api_path, :function, :verb]
  include Aws::Structure
end

#parametersArray<Types::Parameter>

The parameters in the Lambda input event.

Returns:



145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 145

class ActionGroupInvocationInput < Struct.new(
  :action_group_name,
  :api_path,
  :execution_type,
  :function,
  :invocation_id,
  :parameters,
  :request_body,
  :verb)
  SENSITIVE = [:action_group_name, :api_path, :function, :verb]
  include Aws::Structure
end

#request_bodyTypes::RequestBody

The parameters in the request body for the Lambda input event.

Returns:



145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 145

class ActionGroupInvocationInput < Struct.new(
  :action_group_name,
  :api_path,
  :execution_type,
  :function,
  :invocation_id,
  :parameters,
  :request_body,
  :verb)
  SENSITIVE = [:action_group_name, :api_path, :function, :verb]
  include Aws::Structure
end

#verbString

The API method being used, based off the action group.

Returns:

  • (String)


145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 145

class ActionGroupInvocationInput < Struct.new(
  :action_group_name,
  :api_path,
  :execution_type,
  :function,
  :invocation_id,
  :parameters,
  :request_body,
  :verb)
  SENSITIVE = [:action_group_name, :api_path, :function, :verb]
  include Aws::Structure
end