Class: Aws::BedrockAgentRuntime::Types::AgenticRetrieveCitationReference
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::AgenticRetrieveCitationReference
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
A reference to a specific result item.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#result_index ⇒ Integer
Index into the results array on the same event.
Instance Attribute Details
#result_index ⇒ Integer
Index into the results array on the same event.
501 502 503 504 505 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 501 class AgenticRetrieveCitationReference < Struct.new( :result_index) SENSITIVE = [] include Aws::Structure end |