Class: Aws::BedrockAgentRuntime::Types::AgenticRetrieveMemoryMetadataValue
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::AgenticRetrieveMemoryMetadataValue
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Note:
AgenticRetrieveMemoryMetadataValue is a union - when making an API calls you must set exactly one of the members.
A metadata value that a filter expression compares against. Set exactly one member.
Defined Under Namespace
Classes: DateTimeValue, NumberValue, StringListValue, StringValue, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#date_time_value ⇒ Time
A timestamp value in ISO 8601 UTC format.
-
#number_value ⇒ Float
A numeric value.
-
#string_list_value ⇒ Array<String>
A list of string values.
-
#string_value ⇒ String
A string value.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#date_time_value ⇒ Time
A timestamp value in ISO 8601 UTC format.
778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 778 class AgenticRetrieveMemoryMetadataValue < Struct.new( :date_time_value, :number_value, :string_list_value, :string_value, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DateTimeValue < AgenticRetrieveMemoryMetadataValue; end class NumberValue < AgenticRetrieveMemoryMetadataValue; end class StringListValue < AgenticRetrieveMemoryMetadataValue; end class StringValue < AgenticRetrieveMemoryMetadataValue; end class Unknown < AgenticRetrieveMemoryMetadataValue; end end |
#number_value ⇒ Float
A numeric value.
778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 778 class AgenticRetrieveMemoryMetadataValue < Struct.new( :date_time_value, :number_value, :string_list_value, :string_value, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DateTimeValue < AgenticRetrieveMemoryMetadataValue; end class NumberValue < AgenticRetrieveMemoryMetadataValue; end class StringListValue < AgenticRetrieveMemoryMetadataValue; end class StringValue < AgenticRetrieveMemoryMetadataValue; end class Unknown < AgenticRetrieveMemoryMetadataValue; end end |
#string_list_value ⇒ Array<String>
A list of string values.
778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 778 class AgenticRetrieveMemoryMetadataValue < Struct.new( :date_time_value, :number_value, :string_list_value, :string_value, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DateTimeValue < AgenticRetrieveMemoryMetadataValue; end class NumberValue < AgenticRetrieveMemoryMetadataValue; end class StringListValue < AgenticRetrieveMemoryMetadataValue; end class StringValue < AgenticRetrieveMemoryMetadataValue; end class Unknown < AgenticRetrieveMemoryMetadataValue; end end |
#string_value ⇒ String
A string value.
778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 778 class AgenticRetrieveMemoryMetadataValue < Struct.new( :date_time_value, :number_value, :string_list_value, :string_value, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DateTimeValue < AgenticRetrieveMemoryMetadataValue; end class NumberValue < AgenticRetrieveMemoryMetadataValue; end class StringListValue < AgenticRetrieveMemoryMetadataValue; end class StringValue < AgenticRetrieveMemoryMetadataValue; end class Unknown < AgenticRetrieveMemoryMetadataValue; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
778 779 780 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 778 def unknown @unknown end |