Class: Aws::BedrockAgentRuntime::Types::AgenticRetrieveMemoryRetrieveDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

A long-term memory retrieval that the agent chose to perform. The record reports the query and the namespace. The corresponding Retrieval step reports the results.

Constant Summary collapse

SENSITIVE =
[:input_query]

Instance Attribute Summary collapse

Instance Attribute Details

#input_queryTypes::AgenticRetrieveMessageContent

The query that the agent composed.



864
865
866
867
868
869
870
871
872
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 864

class AgenticRetrieveMemoryRetrieveDetails < Struct.new(
  :input_query,
  :memory_id,
  :namespace,
  :namespace_path,
  :strategy_id)
  SENSITIVE = [:input_query]
  include Aws::Structure
end

#memory_idString

The identifier of the AgentCore Memory resource retrieved from.

Returns:

  • (String)


864
865
866
867
868
869
870
871
872
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 864

class AgenticRetrieveMemoryRetrieveDetails < Struct.new(
  :input_query,
  :memory_id,
  :namespace,
  :namespace_path,
  :strategy_id)
  SENSITIVE = [:input_query]
  include Aws::Structure
end

#namespaceString

The namespace prefix retrieved from, as supplied in the request. This field is present when the request specified namespace.

Returns:

  • (String)


864
865
866
867
868
869
870
871
872
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 864

class AgenticRetrieveMemoryRetrieveDetails < Struct.new(
  :input_query,
  :memory_id,
  :namespace,
  :namespace_path,
  :strategy_id)
  SENSITIVE = [:input_query]
  include Aws::Structure
end

#namespace_pathString

The parent namespace retrieved from hierarchically, as supplied in the request. This field is present when the request specified namespacePath.

Returns:

  • (String)


864
865
866
867
868
869
870
871
872
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 864

class AgenticRetrieveMemoryRetrieveDetails < Struct.new(
  :input_query,
  :memory_id,
  :namespace,
  :namespace_path,
  :strategy_id)
  SENSITIVE = [:input_query]
  include Aws::Structure
end

#strategy_idString

The extraction strategy that restricted retrieval, if the request specified one.

Returns:

  • (String)


864
865
866
867
868
869
870
871
872
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 864

class AgenticRetrieveMemoryRetrieveDetails < Struct.new(
  :input_query,
  :memory_id,
  :namespace,
  :namespace_path,
  :strategy_id)
  SENSITIVE = [:input_query]
  include Aws::Structure
end