Class: Aws::BedrockAgentRuntime::Types::AgenticRetrieveMemorySessionBinding

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

The short-term memory session that this retrieval reads from and writes to.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actor_idString

The identifier of the end user or agent that the session belongs to. This identifier scopes session history so that one actor's history is never returned for another. You are responsible for sending the correct actor value.

Returns:

  • (String)


891
892
893
894
895
896
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 891

class AgenticRetrieveMemorySessionBinding < Struct.new(
  :actor_id,
  :session_id)
  SENSITIVE = []
  include Aws::Structure
end

#session_idString

The identifier of the session to restore and continue. You are responsible for sending the correct session value.

Returns:

  • (String)


891
892
893
894
895
896
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 891

class AgenticRetrieveMemorySessionBinding < Struct.new(
  :actor_id,
  :session_id)
  SENSITIVE = []
  include Aws::Structure
end