Class: Aws::BedrockAgentRuntime::Types::AgenticRetrieveStreamResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::AgenticRetrieveStreamResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Response structure for the agentic retrieve stream operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#stream ⇒ Types::AgenticRetrieveStreamResponseOutput
The output stream containing retrieval results and trace events.
Instance Attribute Details
#stream ⇒ Types::AgenticRetrieveStreamResponseOutput
The output stream containing retrieval results and trace events.
845 846 847 848 849 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 845 class AgenticRetrieveStreamResponse < Struct.new( :stream) SENSITIVE = [] include Aws::Structure end |