Class: Aws::BedrockAgentRuntime::Types::AgenticRetrieveStreamResponseOutput
- Inherits:
-
Enumerator
- Object
- Enumerator
- Aws::BedrockAgentRuntime::Types::AgenticRetrieveStreamResponseOutput
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
The streaming output for agentic retrieval, containing results, traces, and errors.
EventStream is an Enumerator of Events. #event_types #=> Array, returns all modeled event types in the stream
Instance Method Summary collapse
Instance Method Details
#event_types ⇒ Object
10656 10657 10658 10659 10660 10661 10662 10663 10664 10665 10666 10667 10668 10669 10670 10671 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10656 def event_types [ :access_denied_exception, :bad_gateway_exception, :conflict_exception, :dependency_failed_exception, :internal_server_exception, :resource_not_found_exception, :response_event, :result, :service_quota_exceeded_exception, :throttling_exception, :trace_event, :validation_exception ] end |