Class: Aws::BedrockAgentRuntime::Types::ApiInvocationInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains information about the API operation that the agent predicts should be called.

This data type is used in the following API operations:

  • In the returnControl field of the [InvokeAgent response]

^

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_InvokeAgent.html#API_agent-runtime_InvokeAgent_ResponseSyntax

Constant Summary collapse

SENSITIVE =
[:api_path, :collaborator_name]

Instance Attribute Summary collapse

Instance Attribute Details

#action_groupString

The action group that the API operation belongs to.

Returns:

  • (String)


406
407
408
409
410
411
412
413
414
415
416
417
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 406

class ApiInvocationInput < Struct.new(
  :action_group,
  :action_invocation_type,
  :agent_id,
  :api_path,
  :collaborator_name,
  :http_method,
  :parameters,
  :request_body)
  SENSITIVE = [:api_path, :collaborator_name]
  include Aws::Structure
end

#action_invocation_typeString

Contains information about the API operation to invoke.

Returns:

  • (String)


406
407
408
409
410
411
412
413
414
415
416
417
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 406

class ApiInvocationInput < Struct.new(
  :action_group,
  :action_invocation_type,
  :agent_id,
  :api_path,
  :collaborator_name,
  :http_method,
  :parameters,
  :request_body)
  SENSITIVE = [:api_path, :collaborator_name]
  include Aws::Structure
end

#agent_idString

The agent’s ID.

Returns:

  • (String)


406
407
408
409
410
411
412
413
414
415
416
417
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 406

class ApiInvocationInput < Struct.new(
  :action_group,
  :action_invocation_type,
  :agent_id,
  :api_path,
  :collaborator_name,
  :http_method,
  :parameters,
  :request_body)
  SENSITIVE = [:api_path, :collaborator_name]
  include Aws::Structure
end

#api_pathString

The path to the API operation.

Returns:

  • (String)


406
407
408
409
410
411
412
413
414
415
416
417
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 406

class ApiInvocationInput < Struct.new(
  :action_group,
  :action_invocation_type,
  :agent_id,
  :api_path,
  :collaborator_name,
  :http_method,
  :parameters,
  :request_body)
  SENSITIVE = [:api_path, :collaborator_name]
  include Aws::Structure
end

#collaborator_nameString

The agent collaborator’s name.

Returns:

  • (String)


406
407
408
409
410
411
412
413
414
415
416
417
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 406

class ApiInvocationInput < Struct.new(
  :action_group,
  :action_invocation_type,
  :agent_id,
  :api_path,
  :collaborator_name,
  :http_method,
  :parameters,
  :request_body)
  SENSITIVE = [:api_path, :collaborator_name]
  include Aws::Structure
end

#http_methodString

The HTTP method of the API operation.

Returns:

  • (String)


406
407
408
409
410
411
412
413
414
415
416
417
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 406

class ApiInvocationInput < Struct.new(
  :action_group,
  :action_invocation_type,
  :agent_id,
  :api_path,
  :collaborator_name,
  :http_method,
  :parameters,
  :request_body)
  SENSITIVE = [:api_path, :collaborator_name]
  include Aws::Structure
end

#parametersArray<Types::ApiParameter>

The parameters to provide for the API request, as the agent elicited from the user.

Returns:



406
407
408
409
410
411
412
413
414
415
416
417
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 406

class ApiInvocationInput < Struct.new(
  :action_group,
  :action_invocation_type,
  :agent_id,
  :api_path,
  :collaborator_name,
  :http_method,
  :parameters,
  :request_body)
  SENSITIVE = [:api_path, :collaborator_name]
  include Aws::Structure
end

#request_bodyTypes::ApiRequestBody

The request body to provide for the API request, as the agent elicited from the user.



406
407
408
409
410
411
412
413
414
415
416
417
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 406

class ApiInvocationInput < Struct.new(
  :action_group,
  :action_invocation_type,
  :agent_id,
  :api_path,
  :collaborator_name,
  :http_method,
  :parameters,
  :request_body)
  SENSITIVE = [:api_path, :collaborator_name]
  include Aws::Structure
end