Class: Aws::BedrockAgentRuntime::Types::ApiParameter

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Information about a parameter to provide to the API request.

This data type is used in the following API operations:

  • InvokeAgent response][1

^

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_InvokeAgent.html#API_agent-runtime_InvokeAgent_ResponseSyntax

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The name of the parameter.

Returns:

  • (String)


485
486
487
488
489
490
491
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 485

class ApiParameter < Struct.new(
  :name,
  :type,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The data type for the parameter.

Returns:

  • (String)


485
486
487
488
489
490
491
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 485

class ApiParameter < Struct.new(
  :name,
  :type,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

The value of the parameter.

Returns:

  • (String)


485
486
487
488
489
490
491
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 485

class ApiParameter < Struct.new(
  :name,
  :type,
  :value)
  SENSITIVE = []
  include Aws::Structure
end