Class: Aws::BedrockAgentRuntime::Types::ApiRequestBody

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

The request body to provide for the API request, as the agent elicited from the user.

This data type is used in the following API operations:

  • InvokeAgent response][1

^

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_InvokeAgent.html#API_agent-runtime_InvokeAgent_ResponseSyntax

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contentHash<String,Types::PropertyParameters>

The content of the request body. The key of the object in this field is a media type defining the format of the request body.

Returns:



513
514
515
516
517
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 513

class ApiRequestBody < Struct.new(
  :content)
  SENSITIVE = []
  include Aws::Structure
end