Class: Aws::BedrockAgentRuntime::Types::ApiResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::ApiResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains information about the API operation that was called from the action group and the response body that was returned.
This data type is used in the following API operations:
-
In the ‘returnControlInvocationResults` of the [InvokeAgent request]
^
Constant Summary collapse
- SENSITIVE =
[:api_path]
Instance Attribute Summary collapse
-
#action_group ⇒ String
The action group that the API operation belongs to.
-
#agent_id ⇒ String
The agent’s ID.
-
#api_path ⇒ String
The path to the API operation.
-
#confirmation_state ⇒ String
Controls the API operations or functions to invoke based on the user confirmation.
-
#http_method ⇒ String
The HTTP method for the API operation.
-
#http_status_code ⇒ Integer
http status code from API execution response (for example: 200, 400, 500).
-
#response_body ⇒ Hash<String,Types::ContentBody>
The response body from the API operation.
-
#response_state ⇒ String
Controls the final response state returned to end user when API/Function execution failed.
Instance Attribute Details
#action_group ⇒ String
The action group that the API operation belongs to.
1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1203 class ApiResult < Struct.new( :action_group, :agent_id, :api_path, :confirmation_state, :http_method, :http_status_code, :response_body, :response_state) SENSITIVE = [:api_path] include Aws::Structure end |
#agent_id ⇒ String
The agent’s ID.
1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1203 class ApiResult < Struct.new( :action_group, :agent_id, :api_path, :confirmation_state, :http_method, :http_status_code, :response_body, :response_state) SENSITIVE = [:api_path] include Aws::Structure end |
#api_path ⇒ String
The path to the API operation.
1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1203 class ApiResult < Struct.new( :action_group, :agent_id, :api_path, :confirmation_state, :http_method, :http_status_code, :response_body, :response_state) SENSITIVE = [:api_path] include Aws::Structure end |
#confirmation_state ⇒ String
Controls the API operations or functions to invoke based on the user confirmation.
1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1203 class ApiResult < Struct.new( :action_group, :agent_id, :api_path, :confirmation_state, :http_method, :http_status_code, :response_body, :response_state) SENSITIVE = [:api_path] include Aws::Structure end |
#http_method ⇒ String
The HTTP method for the API operation.
1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1203 class ApiResult < Struct.new( :action_group, :agent_id, :api_path, :confirmation_state, :http_method, :http_status_code, :response_body, :response_state) SENSITIVE = [:api_path] include Aws::Structure end |
#http_status_code ⇒ Integer
http status code from API execution response (for example: 200, 400, 500).
1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1203 class ApiResult < Struct.new( :action_group, :agent_id, :api_path, :confirmation_state, :http_method, :http_status_code, :response_body, :response_state) SENSITIVE = [:api_path] include Aws::Structure end |
#response_body ⇒ Hash<String,Types::ContentBody>
The response body from the API operation. The key of the object is the content type (currently, only ‘TEXT` is supported). The response may be returned directly or from the Lambda function.
1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1203 class ApiResult < Struct.new( :action_group, :agent_id, :api_path, :confirmation_state, :http_method, :http_status_code, :response_body, :response_state) SENSITIVE = [:api_path] include Aws::Structure end |
#response_state ⇒ String
Controls the final response state returned to end user when API/Function execution failed. When this state is FAILURE, the request would fail with dependency failure exception. When this state is REPROMPT, the API/function response will be sent to model for re-prompt
1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1203 class ApiResult < Struct.new( :action_group, :agent_id, :api_path, :confirmation_state, :http_method, :http_status_code, :response_body, :response_state) SENSITIVE = [:api_path] include Aws::Structure end |