Class: Aws::BedrockAgentRuntime::Types::Attribution

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains citations for a part of an agent response.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#citationsArray<Types::Citation>

A list of citations and related information for a part of an agent response.

Returns:



1225
1226
1227
1228
1229
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1225

class Attribution < Struct.new(
  :citations)
  SENSITIVE = []
  include Aws::Structure
end