Class: Aws::BedrockAgentRuntime::Types::AudioSegment

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains information about an audio segment retrieved from a knowledge base, including its location and transcription.

This data type is used in the following API operations:

  • Retrieve response][1

    – in the ‘audio` field

^

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_Retrieve.html#API_agent-runtime_Retrieve_ResponseSyntax

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#s3_uriString

The S3 URI where this specific audio segment is stored in the multimodal storage destination.

Returns:

  • (String)


627
628
629
630
631
632
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 627

class AudioSegment < Struct.new(
  :s3_uri,
  :transcription)
  SENSITIVE = []
  include Aws::Structure
end

#transcriptionString

The text transcription of the audio segment content.

Returns:

  • (String)


627
628
629
630
631
632
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 627

class AudioSegment < Struct.new(
  :s3_uri,
  :transcription)
  SENSITIVE = []
  include Aws::Structure
end