Class: Aws::BedrockAgentRuntime::Types::BedrockSessionContentBlock

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Note:

BedrockSessionContentBlock is a union - when making an API calls you must set exactly one of the members.

Note:

BedrockSessionContentBlock is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of BedrockSessionContentBlock corresponding to the set member.

A block of content that you pass to, or receive from, a Amazon Bedrock session in an invocation step. You pass the content to a session in the payLoad of the PutInvocationStep API operation. You retrieve the content with the GetInvocationStep API operation.

For more information about sessions, see Store and retrieve conversation history and context with Amazon Bedrock sessions.

Defined Under Namespace

Classes: Image, Text, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#imageTypes::ImageBlock

The image in the invocation step.

Returns:



1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1668

class BedrockSessionContentBlock < Struct.new(
  :image,
  :text,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Image < BedrockSessionContentBlock; end
  class Text < BedrockSessionContentBlock; end
  class Unknown < BedrockSessionContentBlock; end
end

#textString

The text in the invocation step.

Returns:

  • (String)


1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1668

class BedrockSessionContentBlock < Struct.new(
  :image,
  :text,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Image < BedrockSessionContentBlock; end
  class Text < BedrockSessionContentBlock; end
  class Unknown < BedrockSessionContentBlock; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



1668
1669
1670
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1668

def unknown
  @unknown
end