Class: Aws::BedrockAgentRuntime::Types::ByteContentFile

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

The property contains the file to chat with, along with its attributes.

Constant Summary collapse

SENSITIVE =
[:data]

Instance Attribute Summary collapse

Instance Attribute Details

#dataString

The raw bytes of the file to attach. The maximum size of all files that is attached is 10MB. You can attach a maximum of 5 files.

Returns:

  • (String)


676
677
678
679
680
681
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 676

class ByteContentFile < Struct.new(
  :data,
  :media_type)
  SENSITIVE = [:data]
  include Aws::Structure
end

#media_typeString

The MIME type of data contained in the file used for chat.

Returns:

  • (String)


676
677
678
679
680
681
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 676

class ByteContentFile < Struct.new(
  :data,
  :media_type)
  SENSITIVE = [:data]
  include Aws::Structure
end