Class: Aws::BedrockAgentRuntime::Types::ContentBody

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains the body of the API response.

This data type is used in the following API operations:

  • In the ‘returnControlInvocationResults` field of the [InvokeAgent request]

^

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_InvokeAgent.html#API_agent-runtime_InvokeAgent_RequestSyntax

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bodyString

The body of the API response.

Returns:

  • (String)


1137
1138
1139
1140
1141
1142
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1137

class ContentBody < Struct.new(
  :body,
  :images)
  SENSITIVE = []
  include Aws::Structure
end

#imagesArray<Types::ImageInput>

Lists details, including format and source, for the image in the response from the function call. You can specify only one image and the function in the ‘returnControlInvocationResults` must be a computer use action. For more information, see [Configure an Amazon Bedrock Agent to complete tasks with computer use tools].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/agent-computer-use.html

Returns:



1137
1138
1139
1140
1141
1142
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1137

class ContentBody < Struct.new(
  :body,
  :images)
  SENSITIVE = []
  include Aws::Structure
end