Class: Aws::BedrockAgentRuntime::Types::CreateInvocationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::CreateInvocationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description for the interactions in the invocation.
-
#invocation_id ⇒ String
A unique identifier for the invocation in UUID format.
-
#session_identifier ⇒ String
The unique identifier for the associated session for the invocation.
Instance Attribute Details
#description ⇒ String
A description for the interactions in the invocation. For example, "User asking about weather in Seattle".
2151 2152 2153 2154 2155 2156 2157 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2151 class CreateInvocationRequest < Struct.new( :description, :invocation_id, :session_identifier) SENSITIVE = [] include Aws::Structure end |
#invocation_id ⇒ String
A unique identifier for the invocation in UUID format.
2151 2152 2153 2154 2155 2156 2157 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2151 class CreateInvocationRequest < Struct.new( :description, :invocation_id, :session_identifier) SENSITIVE = [] include Aws::Structure end |
#session_identifier ⇒ String
The unique identifier for the associated session for the invocation.
You can specify either the session's sessionId or its Amazon
Resource Name (ARN).
2151 2152 2153 2154 2155 2156 2157 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2151 class CreateInvocationRequest < Struct.new( :description, :invocation_id, :session_identifier) SENSITIVE = [] include Aws::Structure end |