Class: Aws::BedrockAgentRuntime::Types::CreateSessionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#encryption_key_arnString

The Amazon Resource Name (ARN) of the KMS key to use to encrypt the session data. The user or role creating the session must have permission to use the key. For more information, see Amazon Bedrock session encryption.

Returns:

  • (String)


2206
2207
2208
2209
2210
2211
2212
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2206

class CreateSessionRequest < Struct.new(
  :encryption_key_arn,
  :session_metadata,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#session_metadataHash<String,String>

A map of key-value pairs containing attributes to be persisted across the session. For example, the user's ID, their language preference, and the type of device they are using.

Returns:

  • (Hash<String,String>)


2206
2207
2208
2209
2210
2211
2212
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2206

class CreateSessionRequest < Struct.new(
  :encryption_key_arn,
  :session_metadata,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Specify the key-value pairs for the tags that you want to attach to the session.

Returns:

  • (Hash<String,String>)


2206
2207
2208
2209
2210
2211
2212
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2206

class CreateSessionRequest < Struct.new(
  :encryption_key_arn,
  :session_metadata,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end