Class: Aws::BedrockAgentRuntime::Types::CustomOrchestration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains details of the custom orchestration configured for the agent.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#executorTypes::OrchestrationExecutor

The structure of the executor invoking the actions in custom orchestration.



1930
1931
1932
1933
1934
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1930

class CustomOrchestration < Struct.new(
  :executor)
  SENSITIVE = []
  include Aws::Structure
end