Class: Aws::BedrockAgentRuntime::Types::CustomOrchestrationTraceEvent

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

The event in the custom orchestration sequence. Events are the responses which the custom orchestration Lambda function sends as response to the agent.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#textString

The text that prompted the event at this step.

Returns:

  • (String)


1965
1966
1967
1968
1969
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1965

class CustomOrchestrationTraceEvent < Struct.new(
  :text)
  SENSITIVE = []
  include Aws::Structure
end