Class: Aws::BedrockAgentRuntime::Types::DeleteAgentMemoryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::DeleteAgentMemoryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_alias_id ⇒ String
The unique identifier of an alias of an agent.
-
#agent_id ⇒ String
The unique identifier of the agent to which the alias belongs.
-
#memory_id ⇒ String
The unique identifier of the memory.
-
#session_id ⇒ String
The unique session identifier of the memory.
Instance Attribute Details
#agent_alias_id ⇒ String
The unique identifier of an alias of an agent.
2033 2034 2035 2036 2037 2038 2039 2040 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2033 class DeleteAgentMemoryRequest < Struct.new( :agent_alias_id, :agent_id, :memory_id, :session_id) SENSITIVE = [] include Aws::Structure end |
#agent_id ⇒ String
The unique identifier of the agent to which the alias belongs.
2033 2034 2035 2036 2037 2038 2039 2040 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2033 class DeleteAgentMemoryRequest < Struct.new( :agent_alias_id, :agent_id, :memory_id, :session_id) SENSITIVE = [] include Aws::Structure end |
#memory_id ⇒ String
The unique identifier of the memory.
2033 2034 2035 2036 2037 2038 2039 2040 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2033 class DeleteAgentMemoryRequest < Struct.new( :agent_alias_id, :agent_id, :memory_id, :session_id) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
The unique session identifier of the memory.
2033 2034 2035 2036 2037 2038 2039 2040 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2033 class DeleteAgentMemoryRequest < Struct.new( :agent_alias_id, :agent_id, :memory_id, :session_id) SENSITIVE = [] include Aws::Structure end |