Class: Aws::BedrockAgentRuntime::Types::DeleteSessionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::DeleteSessionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#session_identifier ⇒ String
The unique identifier for the session to be deleted.
Instance Attribute Details
#session_identifier ⇒ String
The unique identifier for the session to be deleted. You can specify
either the session's sessionId or its Amazon Resource Name (ARN).
2053 2054 2055 2056 2057 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2053 class DeleteSessionRequest < Struct.new( :session_identifier) SENSITIVE = [] include Aws::Structure end |