Class: Aws::BedrockAgentRuntime::Types::DocumentAcl

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

The access control list for a document, containing allow and deny membership lists. Each list specifies conditions that determine which users and groups are granted or denied access.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allow_listTypes::DocumentAclMembership

The list of principals allowed access to the document.



2098
2099
2100
2101
2102
2103
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2098

class DocumentAcl < Struct.new(
  :allow_list,
  :deny_list)
  SENSITIVE = []
  include Aws::Structure
end

#deny_listTypes::DocumentAclMembership

The list of principals denied access to the document.



2098
2099
2100
2101
2102
2103
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2098

class DocumentAcl < Struct.new(
  :allow_list,
  :deny_list)
  SENSITIVE = []
  include Aws::Structure
end