Class: Aws::BedrockAgentRuntime::Types::DocumentAclCondition

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

A condition within a document access control list (ACL) membership, specifying users and groups that are evaluated together.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#condition_operatorString

The logical operator for combining users and groups within this condition. Valid values: AND – Both a user match and a group match are required. OR – Either a user match or a group match is sufficient.

Returns:

  • (String)


2125
2126
2127
2128
2129
2130
2131
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2125

class DocumentAclCondition < Struct.new(
  :condition_operator,
  :groups,
  :users)
  SENSITIVE = []
  include Aws::Structure
end

#groupsArray<Types::DocumentAclGroup>

The list of group entries in this condition.

Returns:



2125
2126
2127
2128
2129
2130
2131
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2125

class DocumentAclCondition < Struct.new(
  :condition_operator,
  :groups,
  :users)
  SENSITIVE = []
  include Aws::Structure
end

#usersArray<Types::DocumentAclUser>

The list of user entries in this condition.

Returns:



2125
2126
2127
2128
2129
2130
2131
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2125

class DocumentAclCondition < Struct.new(
  :condition_operator,
  :groups,
  :users)
  SENSITIVE = []
  include Aws::Structure
end