Class: Aws::BedrockAgentRuntime::Types::DocumentAclGroup

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

A group entry within a document access control list (ACL) condition.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idString

The identifier of the group.

Returns:

  • (String)


2145
2146
2147
2148
2149
2150
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2145

class DocumentAclGroup < Struct.new(
  :id,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The membership type indicating the scope of the group entry.

Returns:

  • (String)


2145
2146
2147
2148
2149
2150
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2145

class DocumentAclGroup < Struct.new(
  :id,
  :type)
  SENSITIVE = []
  include Aws::Structure
end