Class: Aws::BedrockAgentRuntime::Types::DocumentAclUser

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

A user entry within a document access control list (ACL) condition.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idString

The identifier of the user.

Returns:

  • (String)


2185
2186
2187
2188
2189
2190
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2185

class DocumentAclUser < Struct.new(
  :id,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The membership type indicating the scope of the user entry.

Returns:

  • (String)


2185
2186
2187
2188
2189
2190
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2185

class DocumentAclUser < Struct.new(
  :id,
  :type)
  SENSITIVE = []
  include Aws::Structure
end