Class: Aws::BedrockAgentRuntime::Types::ExternalSourcesRetrieveAndGenerateConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

The configurations of the external source wrapper object in the retrieveAndGenerate function.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#generation_configurationTypes::ExternalSourcesGenerationConfiguration

The prompt used with the external source wrapper object with the retrieveAndGenerate function.



2313
2314
2315
2316
2317
2318
2319
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2313

class ExternalSourcesRetrieveAndGenerateConfiguration < Struct.new(
  :generation_configuration,
  :model_arn,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end

#model_arnString

The model Amazon Resource Name (ARN) for the external source wrapper object in the retrieveAndGenerate function.

Returns:

  • (String)


2313
2314
2315
2316
2317
2318
2319
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2313

class ExternalSourcesRetrieveAndGenerateConfiguration < Struct.new(
  :generation_configuration,
  :model_arn,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end

#sourcesArray<Types::ExternalSource>

The document for the external source wrapper object in the retrieveAndGenerate function.

Returns:



2313
2314
2315
2316
2317
2318
2319
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2313

class ExternalSourcesRetrieveAndGenerateConfiguration < Struct.new(
  :generation_configuration,
  :model_arn,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end