Class: Aws::BedrockAgentRuntime::Types::FieldForReranking

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains information for a metadata field to include in or exclude from consideration when reranking.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#field_nameString

The name of a metadata field to include in or exclude from consideration when reranking.

Returns:

  • (String)


2208
2209
2210
2211
2212
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2208

class FieldForReranking < Struct.new(
  :field_name)
  SENSITIVE = []
  include Aws::Structure
end