Class: Aws::BedrockAgentRuntime::Types::FileSource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

The source file of the content contained in the wrapper object.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#byte_contentTypes::ByteContentFile

The data and the text of the attached files.



1124
1125
1126
1127
1128
1129
1130
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1124

class FileSource < Struct.new(
  :byte_content,
  :s3_location,
  :source_type)
  SENSITIVE = []
  include Aws::Structure
end

#s3_locationTypes::S3ObjectFile

The s3 location of the files to attach.

Returns:



1124
1125
1126
1127
1128
1129
1130
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1124

class FileSource < Struct.new(
  :byte_content,
  :s3_location,
  :source_type)
  SENSITIVE = []
  include Aws::Structure
end

#source_typeString

The source type of the files to attach.

Returns:

  • (String)


1124
1125
1126
1127
1128
1129
1130
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1124

class FileSource < Struct.new(
  :byte_content,
  :s3_location,
  :source_type)
  SENSITIVE = []
  include Aws::Structure
end