Class: Aws::BedrockAgentRuntime::Types::FlowExecutionContent

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Note:

FlowExecutionContent is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of FlowExecutionContent corresponding to the set member.

Contains the content of an flow execution input or output field.

Flow executions is in preview release for Amazon Bedrock and is subject to change.

Defined Under Namespace

Classes: Document, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#documentHash, ...

The document content of the field, which can contain text or structured data.

Returns:

  • (Hash, Array, String, Numeric, Boolean)


2764
2765
2766
2767
2768
2769
2770
2771
2772
2773
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2764

class FlowExecutionContent < Struct.new(
  :document,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Document < FlowExecutionContent; end
  class Unknown < FlowExecutionContent; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



2764
2765
2766
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2764

def unknown
  @unknown
end