Class: Aws::BedrockAgentRuntime::Types::FlowExecutionInputEvent

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains information about the inputs provided to the flow at the start of a flow execution.

Flow executions is in preview release for Amazon Bedrock and is subject to change.

Constant Summary collapse

SENSITIVE =
[:fields]

Instance Attribute Summary collapse

Instance Attribute Details

#fieldsArray<Types::FlowInputField>

A list of input fields provided to the flow.

Returns:



2639
2640
2641
2642
2643
2644
2645
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2639

class FlowExecutionInputEvent < Struct.new(
  :fields,
  :node_name,
  :timestamp)
  SENSITIVE = [:fields]
  include Aws::Structure
end

#node_nameString

The name of the node that receives the inputs.

Returns:

  • (String)


2639
2640
2641
2642
2643
2644
2645
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2639

class FlowExecutionInputEvent < Struct.new(
  :fields,
  :node_name,
  :timestamp)
  SENSITIVE = [:fields]
  include Aws::Structure
end

#timestampTime

The timestamp when the inputs are provided.

Returns:

  • (Time)


2639
2640
2641
2642
2643
2644
2645
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2639

class FlowExecutionInputEvent < Struct.new(
  :fields,
  :node_name,
  :timestamp)
  SENSITIVE = [:fields]
  include Aws::Structure
end