Class: Aws::BedrockAgentRuntime::Types::FlowInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains information about an input into the prompt flow and where to send it.

Constant Summary collapse

SENSITIVE =
[:content]

Instance Attribute Summary collapse

Instance Attribute Details

#contentTypes::FlowInputContent

Contains information about an input into the prompt flow.



2784
2785
2786
2787
2788
2789
2790
2791
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2784

class FlowInput < Struct.new(
  :content,
  :node_input_name,
  :node_name,
  :node_output_name)
  SENSITIVE = [:content]
  include Aws::Structure
end

#node_input_nameString

The name of the input from the flow input node.

Returns:

  • (String)


2784
2785
2786
2787
2788
2789
2790
2791
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2784

class FlowInput < Struct.new(
  :content,
  :node_input_name,
  :node_name,
  :node_output_name)
  SENSITIVE = [:content]
  include Aws::Structure
end

#node_nameString

The name of the flow input node that begins the prompt flow.

Returns:

  • (String)


2784
2785
2786
2787
2788
2789
2790
2791
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2784

class FlowInput < Struct.new(
  :content,
  :node_input_name,
  :node_name,
  :node_output_name)
  SENSITIVE = [:content]
  include Aws::Structure
end

#node_output_nameString

The name of the output from the flow input node that begins the prompt flow.

Returns:

  • (String)


2784
2785
2786
2787
2788
2789
2790
2791
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2784

class FlowInput < Struct.new(
  :content,
  :node_input_name,
  :node_name,
  :node_output_name)
  SENSITIVE = [:content]
  include Aws::Structure
end