Class: Aws::BedrockAgentRuntime::Types::FlowInputContent
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::FlowInputContent
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Note:
FlowInputContent is a union - when making an API calls you must set exactly one of the members.
Contains information about an input into the flow.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#document ⇒ Hash, ...
The input to send to the prompt flow input node.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#document ⇒ Hash, ...
The input to send to the prompt flow input node.
2803 2804 2805 2806 2807 2808 2809 2810 2811 2812 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2803 class FlowInputContent < Struct.new( :document, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Document < FlowInputContent; end class Unknown < FlowInputContent; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
2803 2804 2805 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2803 def unknown @unknown end |