Class: Aws::BedrockAgentRuntime::Types::FlowInputField

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Represents an input field provided to a flow during a flow execution.

<note markdown=“1”> Flow executions is in preview release for Amazon Bedrock and is subject to change.

</note>

Constant Summary collapse

SENSITIVE =
[:content]

Instance Attribute Summary collapse

Instance Attribute Details

#contentTypes::FlowExecutionContent

The content of the input field, which can contain text or structured data.



2024
2025
2026
2027
2028
2029
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2024

class FlowInputField < Struct.new(
  :content,
  :name)
  SENSITIVE = [:content]
  include Aws::Structure
end

#nameString

The name of the input field as defined in the flow’s input schema.

Returns:

  • (String)


2024
2025
2026
2027
2028
2029
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2024

class FlowInputField < Struct.new(
  :content,
  :name)
  SENSITIVE = [:content]
  include Aws::Structure
end