Class: Aws::BedrockAgentRuntime::Types::FlowMultiTurnInputContent
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::FlowMultiTurnInputContent
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Note:
FlowMultiTurnInputContent is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of FlowMultiTurnInputContent corresponding to the set member.
The content structure containing input information for multi-turn flow interactions.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#document ⇒ Hash, ...
The requested additional input to send back to the multi-turn flow node.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#document ⇒ Hash, ...
The requested additional input to send back to the multi-turn flow node.
2851 2852 2853 2854 2855 2856 2857 2858 2859 2860 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2851 class FlowMultiTurnInputContent < Struct.new( :document, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Document < FlowMultiTurnInputContent; end class Unknown < FlowMultiTurnInputContent; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
2851 2852 2853 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2851 def unknown @unknown end |