Class: Aws::BedrockAgentRuntime::Types::FlowOutputEvent
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::FlowOutputEvent
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains information about an output from prompt flow invoction.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content ⇒ Types::FlowOutputContent
The content in the output.
-
#event_type ⇒ Object
Returns the value of attribute event_type.
-
#node_name ⇒ String
The name of the flow output node that the output is from.
-
#node_type ⇒ String
The type of the node that the output is from.
Instance Attribute Details
#content ⇒ Types::FlowOutputContent
The content in the output.
3203 3204 3205 3206 3207 3208 3209 3210 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3203 class FlowOutputEvent < Struct.new( :content, :node_name, :node_type, :event_type) SENSITIVE = [] include Aws::Structure end |
#event_type ⇒ Object
Returns the value of attribute event_type
3203 3204 3205 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3203 def event_type @event_type end |
#node_name ⇒ String
The name of the flow output node that the output is from.
3203 3204 3205 3206 3207 3208 3209 3210 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3203 class FlowOutputEvent < Struct.new( :content, :node_name, :node_type, :event_type) SENSITIVE = [] include Aws::Structure end |
#node_type ⇒ String
The type of the node that the output is from.
3203 3204 3205 3206 3207 3208 3209 3210 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3203 class FlowOutputEvent < Struct.new( :content, :node_name, :node_type, :event_type) SENSITIVE = [] include Aws::Structure end |