Class: Aws::BedrockAgentRuntime::Types::FlowOutputField

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Represents an output field produced by a flow during a flow execution.

<note markdown=“1”> Flow executions is in preview release for Amazon Bedrock and is subject to change.

</note>

Constant Summary collapse

SENSITIVE =
[:content]

Instance Attribute Summary collapse

Instance Attribute Details

#contentTypes::FlowExecutionContent

The content of the output field, which can contain text or structured data.



2147
2148
2149
2150
2151
2152
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2147

class FlowOutputField < Struct.new(
  :content,
  :name)
  SENSITIVE = [:content]
  include Aws::Structure
end

#nameString

The name of the output field as defined in the flow’s output schema.

Returns:

  • (String)


2147
2148
2149
2150
2151
2152
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2147

class FlowOutputField < Struct.new(
  :content,
  :name)
  SENSITIVE = [:content]
  include Aws::Structure
end