Class: Aws::BedrockAgentRuntime::Types::FlowTraceCondition

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains information about a condition that was satisfied. For more information, see Track each step in your prompt flow by viewing its trace in Amazon Bedrock.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#condition_nameString

The name of the condition.

Returns:

  • (String)


3303
3304
3305
3306
3307
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3303

class FlowTraceCondition < Struct.new(
  :condition_name)
  SENSITIVE = []
  include Aws::Structure
end