Class: Aws::BedrockAgentRuntime::Types::FlowTraceConditionNodeResultEvent
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::FlowTraceConditionNodeResultEvent
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains information about an output from a condition node. For more information, see [Track each step in your prompt flow by viewing its trace in Amazon Bedrock][1].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/flows-trace.html
Constant Summary collapse
- SENSITIVE =
[:satisfied_conditions]
Instance Attribute Summary collapse
-
#node_name ⇒ String
The name of the condition node.
-
#satisfied_conditions ⇒ Array<Types::FlowTraceCondition>
An array of objects containing information about the conditions that were satisfied.
-
#timestamp ⇒ Time
The date and time that the trace was returned.
Instance Attribute Details
#node_name ⇒ String
The name of the condition node.
1369 1370 1371 1372 1373 1374 1375 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1369 class FlowTraceConditionNodeResultEvent < Struct.new( :node_name, :satisfied_conditions, :timestamp) SENSITIVE = [:satisfied_conditions] include Aws::Structure end |
#satisfied_conditions ⇒ Array<Types::FlowTraceCondition>
An array of objects containing information about the conditions that were satisfied.
1369 1370 1371 1372 1373 1374 1375 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1369 class FlowTraceConditionNodeResultEvent < Struct.new( :node_name, :satisfied_conditions, :timestamp) SENSITIVE = [:satisfied_conditions] include Aws::Structure end |
#timestamp ⇒ Time
The date and time that the trace was returned.
1369 1370 1371 1372 1373 1374 1375 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1369 class FlowTraceConditionNodeResultEvent < Struct.new( :node_name, :satisfied_conditions, :timestamp) SENSITIVE = [:satisfied_conditions] include Aws::Structure end |