Class: Aws::BedrockAgentRuntime::Types::FlowTraceDependencyEvent
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::FlowTraceDependencyEvent
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains information about a dependency trace event in the flow.
Constant Summary collapse
- SENSITIVE =
[:trace_elements]
Instance Attribute Summary collapse
-
#node_name ⇒ String
The name of the node that generated the dependency trace.
-
#timestamp ⇒ Time
The date and time that the dependency trace was generated.
-
#trace_elements ⇒ Types::TraceElements
The trace elements containing detailed information about the dependency.
Instance Attribute Details
#node_name ⇒ String
The name of the node that generated the dependency trace.
2929 2930 2931 2932 2933 2934 2935 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2929 class FlowTraceDependencyEvent < Struct.new( :node_name, :timestamp, :trace_elements) SENSITIVE = [:trace_elements] include Aws::Structure end |
#timestamp ⇒ Time
The date and time that the dependency trace was generated.
2929 2930 2931 2932 2933 2934 2935 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2929 class FlowTraceDependencyEvent < Struct.new( :node_name, :timestamp, :trace_elements) SENSITIVE = [:trace_elements] include Aws::Structure end |
#trace_elements ⇒ Types::TraceElements
The trace elements containing detailed information about the dependency.
2929 2930 2931 2932 2933 2934 2935 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2929 class FlowTraceDependencyEvent < Struct.new( :node_name, :timestamp, :trace_elements) SENSITIVE = [:trace_elements] include Aws::Structure end |