Class: Aws::BedrockAgentRuntime::Types::FlowTraceEvent

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains information about a trace, which tracks an input or output for a node in the flow. For more information, see [Track each step in your prompt flow by viewing its trace in Amazon Bedrock].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/flows-trace.html

Constant Summary collapse

SENSITIVE =
[:trace]

Instance Attribute Summary collapse

Instance Attribute Details

#event_typeObject

Returns the value of attribute event_type

Returns:

  • (Object)

    the current value of event_type



2296
2297
2298
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2296

def event_type
  @event_type
end

#traceTypes::FlowTrace

The trace object containing information about an input or output for a node in the flow.

Returns:



2296
2297
2298
2299
2300
2301
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2296

class FlowTraceEvent < Struct.new(
  :trace,
  :event_type)
  SENSITIVE = [:trace]
  include Aws::Structure
end