Class: Aws::BedrockAgentRuntime::Types::FlowTraceNodeInputContent

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Note:

FlowTraceNodeInputContent is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of FlowTraceNodeInputContent corresponding to the set member.

Contains the content of the node input. For more information, see Track each step in your prompt flow by viewing its trace in Amazon Bedrock.

Defined Under Namespace

Classes: Document, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#documentHash, ...

The content of the node input.

Returns:

  • (Hash, Array, String, Numeric, Boolean)


3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3450

class FlowTraceNodeInputContent < Struct.new(
  :document,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Document < FlowTraceNodeInputContent; end
  class Unknown < FlowTraceNodeInputContent; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



3450
3451
3452
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3450

def unknown
  @unknown
end