Class: Aws::BedrockAgentRuntime::Types::FlowTraceNodeInputEvent

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains information about the input into a node. For more information, see [Track each step in your prompt flow by viewing its trace in Amazon Bedrock].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/flows-trace.html

Constant Summary collapse

SENSITIVE =
[:fields]

Instance Attribute Summary collapse

Instance Attribute Details

#fieldsArray<Types::FlowTraceNodeInputField>

An array of objects containing information about each field in the input.

Returns:



1449
1450
1451
1452
1453
1454
1455
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1449

class FlowTraceNodeInputEvent < Struct.new(
  :fields,
  :node_name,
  :timestamp)
  SENSITIVE = [:fields]
  include Aws::Structure
end

#node_nameString

The name of the node that received the input.

Returns:

  • (String)


1449
1450
1451
1452
1453
1454
1455
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1449

class FlowTraceNodeInputEvent < Struct.new(
  :fields,
  :node_name,
  :timestamp)
  SENSITIVE = [:fields]
  include Aws::Structure
end

#timestampTime

The date and time that the trace was returned.

Returns:

  • (Time)


1449
1450
1451
1452
1453
1454
1455
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1449

class FlowTraceNodeInputEvent < Struct.new(
  :fields,
  :node_name,
  :timestamp)
  SENSITIVE = [:fields]
  include Aws::Structure
end