Class: Aws::BedrockAgentRuntime::Types::FlowTraceNodeInputField

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains information about a field in the input into a node. For more information, see [Track each step in your prompt flow by viewing its trace in Amazon Bedrock].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/flows-trace.html

Constant Summary collapse

SENSITIVE =
[:content]

Instance Attribute Summary collapse

Instance Attribute Details

#contentTypes::FlowTraceNodeInputContent

The content of the node input.



1475
1476
1477
1478
1479
1480
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1475

class FlowTraceNodeInputField < Struct.new(
  :content,
  :node_input_name)
  SENSITIVE = [:content]
  include Aws::Structure
end

#node_input_nameString

The name of the node input.

Returns:

  • (String)


1475
1476
1477
1478
1479
1480
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1475

class FlowTraceNodeInputField < Struct.new(
  :content,
  :node_input_name)
  SENSITIVE = [:content]
  include Aws::Structure
end