Class: Aws::BedrockAgentRuntime::Types::FlowTraceNodeOutputEvent
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::FlowTraceNodeOutputEvent
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains information about the output from a node. For more information, see Track each step in your prompt flow by viewing its trace in Amazon Bedrock.
Constant Summary collapse
- SENSITIVE =
[:fields]
Instance Attribute Summary collapse
-
#fields ⇒ Array<Types::FlowTraceNodeOutputField>
An array of objects containing information about each field in the output.
-
#node_name ⇒ String
The name of the node that yielded the output.
-
#timestamp ⇒ Time
The date and time that the trace was returned.
Instance Attribute Details
#fields ⇒ Array<Types::FlowTraceNodeOutputField>
An array of objects containing information about each field in the output.
3637 3638 3639 3640 3641 3642 3643 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3637 class FlowTraceNodeOutputEvent < Struct.new( :fields, :node_name, :timestamp) SENSITIVE = [:fields] include Aws::Structure end |
#node_name ⇒ String
The name of the node that yielded the output.
3637 3638 3639 3640 3641 3642 3643 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3637 class FlowTraceNodeOutputEvent < Struct.new( :fields, :node_name, :timestamp) SENSITIVE = [:fields] include Aws::Structure end |
#timestamp ⇒ Time
The date and time that the trace was returned.
3637 3638 3639 3640 3641 3642 3643 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3637 class FlowTraceNodeOutputEvent < Struct.new( :fields, :node_name, :timestamp) SENSITIVE = [:fields] include Aws::Structure end |