Class: Aws::BedrockAgentRuntime::Types::FlowTraceNodeOutputField

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains information about a field in the output from a node. For more information, see Track each step in your prompt flow by viewing its trace in Amazon Bedrock.

Constant Summary collapse

SENSITIVE =
[:next]

Instance Attribute Summary collapse

Instance Attribute Details

#contentTypes::FlowTraceNodeOutputContent

The content of the node output.



3395
3396
3397
3398
3399
3400
3401
3402
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3395

class FlowTraceNodeOutputField < Struct.new(
  :content,
  :next,
  :node_output_name,
  :type)
  SENSITIVE = [:next]
  include Aws::Structure
end

#nextArray<Types::FlowTraceNodeOutputNext>

The next node that receives output data from this field.

Returns:



3395
3396
3397
3398
3399
3400
3401
3402
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3395

class FlowTraceNodeOutputField < Struct.new(
  :content,
  :next,
  :node_output_name,
  :type)
  SENSITIVE = [:next]
  include Aws::Structure
end

#node_output_nameString

The name of the node output.

Returns:

  • (String)


3395
3396
3397
3398
3399
3400
3401
3402
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3395

class FlowTraceNodeOutputField < Struct.new(
  :content,
  :next,
  :node_output_name,
  :type)
  SENSITIVE = [:next]
  include Aws::Structure
end

#typeString

The data type of the output field for compatibility validation.

Returns:

  • (String)


3395
3396
3397
3398
3399
3400
3401
3402
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3395

class FlowTraceNodeOutputField < Struct.new(
  :content,
  :next,
  :node_output_name,
  :type)
  SENSITIVE = [:next]
  include Aws::Structure
end