Class: Aws::BedrockAgentRuntime::Types::FlowTraceNodeOutputNext

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Represents the next node that receives output data from a flow trace.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#input_field_nameString

The name of the input field in the next node that receives the data.

Returns:

  • (String)


3264
3265
3266
3267
3268
3269
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3264

class FlowTraceNodeOutputNext < Struct.new(
  :input_field_name,
  :node_name)
  SENSITIVE = []
  include Aws::Structure
end

#node_nameString

The name of the next node that receives the output data.

Returns:

  • (String)


3264
3265
3266
3267
3268
3269
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3264

class FlowTraceNodeOutputNext < Struct.new(
  :input_field_name,
  :node_name)
  SENSITIVE = []
  include Aws::Structure
end