Class: Aws::BedrockAgentRuntime::Types::FunctionDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::FunctionDefinition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Defines parameters that the agent needs to invoke from the user to complete the function. Corresponds to an action in an action group.
Constant Summary collapse
- SENSITIVE =
[:name]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the function and its purpose.
-
#name ⇒ String
A name for the function.
-
#parameters ⇒ Hash<String,Types::ParameterDetail>
The parameters that the agent elicits from the user to fulfill the function.
-
#require_confirmation ⇒ String
Contains information if user confirmation is required to invoke the function.
Instance Attribute Details
#description ⇒ String
A description of the function and its purpose.
1588 1589 1590 1591 1592 1593 1594 1595 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1588 class FunctionDefinition < Struct.new( :description, :name, :parameters, :require_confirmation) SENSITIVE = [:name] include Aws::Structure end |
#name ⇒ String
A name for the function.
1588 1589 1590 1591 1592 1593 1594 1595 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1588 class FunctionDefinition < Struct.new( :description, :name, :parameters, :require_confirmation) SENSITIVE = [:name] include Aws::Structure end |
#parameters ⇒ Hash<String,Types::ParameterDetail>
The parameters that the agent elicits from the user to fulfill the function.
1588 1589 1590 1591 1592 1593 1594 1595 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1588 class FunctionDefinition < Struct.new( :description, :name, :parameters, :require_confirmation) SENSITIVE = [:name] include Aws::Structure end |
#require_confirmation ⇒ String
Contains information if user confirmation is required to invoke the function.
1588 1589 1590 1591 1592 1593 1594 1595 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1588 class FunctionDefinition < Struct.new( :description, :name, :parameters, :require_confirmation) SENSITIVE = [:name] include Aws::Structure end |