Class: Aws::BedrockAgentRuntime::Types::FunctionInvocationInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains information about the function that the agent predicts should be called.

This data type is used in the following API operations:

  • In the returnControl field of the [InvokeAgent response]

^

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_InvokeAgent.html#API_agent-runtime_InvokeAgent_ResponseSyntax

Constant Summary collapse

SENSITIVE =
[:collaborator_name]

Instance Attribute Summary collapse

Instance Attribute Details

#action_groupString

The action group that the function belongs to.

Returns:

  • (String)


1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1636

class FunctionInvocationInput < Struct.new(
  :action_group,
  :action_invocation_type,
  :agent_id,
  :collaborator_name,
  :function,
  :parameters)
  SENSITIVE = [:collaborator_name]
  include Aws::Structure
end

#action_invocation_typeString

Contains information about the function to invoke,

Returns:

  • (String)


1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1636

class FunctionInvocationInput < Struct.new(
  :action_group,
  :action_invocation_type,
  :agent_id,
  :collaborator_name,
  :function,
  :parameters)
  SENSITIVE = [:collaborator_name]
  include Aws::Structure
end

#agent_idString

The agent’s ID.

Returns:

  • (String)


1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1636

class FunctionInvocationInput < Struct.new(
  :action_group,
  :action_invocation_type,
  :agent_id,
  :collaborator_name,
  :function,
  :parameters)
  SENSITIVE = [:collaborator_name]
  include Aws::Structure
end

#collaborator_nameString

The collaborator’s name.

Returns:

  • (String)


1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1636

class FunctionInvocationInput < Struct.new(
  :action_group,
  :action_invocation_type,
  :agent_id,
  :collaborator_name,
  :function,
  :parameters)
  SENSITIVE = [:collaborator_name]
  include Aws::Structure
end

#functionString

The name of the function.

Returns:

  • (String)


1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1636

class FunctionInvocationInput < Struct.new(
  :action_group,
  :action_invocation_type,
  :agent_id,
  :collaborator_name,
  :function,
  :parameters)
  SENSITIVE = [:collaborator_name]
  include Aws::Structure
end

#parametersArray<Types::FunctionParameter>

A list of parameters of the function.

Returns:



1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1636

class FunctionInvocationInput < Struct.new(
  :action_group,
  :action_invocation_type,
  :agent_id,
  :collaborator_name,
  :function,
  :parameters)
  SENSITIVE = [:collaborator_name]
  include Aws::Structure
end