Class: Aws::BedrockAgentRuntime::Types::FunctionResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains information about the function that was called from the action group and the response that was returned.

This data type is used in the following API operations:

^

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#action_groupString

The action group that the function belongs to.

Returns:

  • (String)


3614
3615
3616
3617
3618
3619
3620
3621
3622
3623
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3614

class FunctionResult < Struct.new(
  :action_group,
  :agent_id,
  :confirmation_state,
  :function,
  :response_body,
  :response_state)
  SENSITIVE = []
  include Aws::Structure
end

#agent_idString

The agent's ID.

Returns:

  • (String)


3614
3615
3616
3617
3618
3619
3620
3621
3622
3623
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3614

class FunctionResult < Struct.new(
  :action_group,
  :agent_id,
  :confirmation_state,
  :function,
  :response_body,
  :response_state)
  SENSITIVE = []
  include Aws::Structure
end

#confirmation_stateString

Contains the user confirmation information about the function that was called.

Returns:

  • (String)


3614
3615
3616
3617
3618
3619
3620
3621
3622
3623
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3614

class FunctionResult < Struct.new(
  :action_group,
  :agent_id,
  :confirmation_state,
  :function,
  :response_body,
  :response_state)
  SENSITIVE = []
  include Aws::Structure
end

#functionString

The name of the function that was called.

Returns:

  • (String)


3614
3615
3616
3617
3618
3619
3620
3621
3622
3623
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3614

class FunctionResult < Struct.new(
  :action_group,
  :agent_id,
  :confirmation_state,
  :function,
  :response_body,
  :response_state)
  SENSITIVE = []
  include Aws::Structure
end

#response_bodyHash<String,Types::ContentBody>

The response from the function call using the parameters. The response might be returned directly or from the Lambda function. Specify TEXT or IMAGES. The key of the object is the content type. You can only specify one type. If you specify IMAGES, you can specify only one image. You can specify images only when the function in the returnControlInvocationResults is a computer use action. For more information, see Configure an Amazon Bedrock Agent to complete tasks with computer use tools.

Returns:



3614
3615
3616
3617
3618
3619
3620
3621
3622
3623
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3614

class FunctionResult < Struct.new(
  :action_group,
  :agent_id,
  :confirmation_state,
  :function,
  :response_body,
  :response_state)
  SENSITIVE = []
  include Aws::Structure
end

#response_stateString

Controls the final response state returned to end user when API/Function execution failed. When this state is FAILURE, the request would fail with dependency failure exception. When this state is REPROMPT, the API/function response will be sent to model for re-prompt

Returns:

  • (String)


3614
3615
3616
3617
3618
3619
3620
3621
3622
3623
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3614

class FunctionResult < Struct.new(
  :action_group,
  :agent_id,
  :confirmation_state,
  :function,
  :response_body,
  :response_state)
  SENSITIVE = []
  include Aws::Structure
end