Class: Aws::BedrockAgentRuntime::Types::FunctionSchema

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Note:

FunctionSchema is a union - when making an API calls you must set exactly one of the members.

Contains details about the function schema for the action group or the JSON or YAML-formatted payload defining the schema.

Defined Under Namespace

Classes: Functions, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#functionsArray<Types::FunctionDefinition>

A list of functions that each define an action in the action group.

Returns:



3636
3637
3638
3639
3640
3641
3642
3643
3644
3645
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3636

class FunctionSchema < Struct.new(
  :functions,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Functions < FunctionSchema; end
  class Unknown < FunctionSchema; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



3636
3637
3638
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3636

def unknown
  @unknown
end