Class: Aws::BedrockAgentRuntime::Types::GeneratedResponsePart

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains metadata about a part of the generated response that is accompanied by a citation.

This data type is used in the following API operations:

  • InvokeAgent response][1

    – in the generatedResponsePart field

  • RetrieveAndGenerate response][2

    – in the generatedResponsePart

    field

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_InvokeAgent.html#API_agent-runtime_InvokeAgent_ResponseSyntax [2]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_RetrieveAndGenerate.html#API_agent-runtime_RetrieveAndGenerate_ResponseSyntax

Constant Summary collapse

SENSITIVE =
[:text_response_part]

Instance Attribute Summary collapse

Instance Attribute Details

#text_response_partTypes::TextResponsePart

Contains metadata about a textual part of the generated response that is accompanied by a citation.



1836
1837
1838
1839
1840
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1836

class GeneratedResponsePart < Struct.new(
  :text_response_part)
  SENSITIVE = [:text_response_part]
  include Aws::Structure
end