Class: Aws::BedrockAgentRuntime::Types::GenerationConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains configurations for response generation based on the knowledge base query results.

This data type is used in the following API operations:

  • RetrieveAndGenerate request][1

^

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_RetrieveAndGenerate.html#API_agent-runtime_RetrieveAndGenerate_RequestSyntax

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_model_request_fieldsHash<String,Hash,Array,String,Numeric,Boolean>

Additional model parameters and corresponding values not included in the textInferenceConfig structure for a knowledge base. This allows users to provide custom model parameters specific to the language model being used.

Returns:

  • (Hash<String,Hash,Array,String,Numeric,Boolean>)


1888
1889
1890
1891
1892
1893
1894
1895
1896
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1888

class GenerationConfiguration < Struct.new(
  :additional_model_request_fields,
  :guardrail_configuration,
  :inference_config,
  :performance_config,
  :prompt_template)
  SENSITIVE = []
  include Aws::Structure
end

#guardrail_configurationTypes::GuardrailConfiguration

The configuration details for the guardrail.



1888
1889
1890
1891
1892
1893
1894
1895
1896
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1888

class GenerationConfiguration < Struct.new(
  :additional_model_request_fields,
  :guardrail_configuration,
  :inference_config,
  :performance_config,
  :prompt_template)
  SENSITIVE = []
  include Aws::Structure
end

#inference_configTypes::InferenceConfig

Configuration settings for inference when using RetrieveAndGenerate to generate responses while using a knowledge base as a source.



1888
1889
1890
1891
1892
1893
1894
1895
1896
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1888

class GenerationConfiguration < Struct.new(
  :additional_model_request_fields,
  :guardrail_configuration,
  :inference_config,
  :performance_config,
  :prompt_template)
  SENSITIVE = []
  include Aws::Structure
end

#performance_configTypes::PerformanceConfiguration

The latency configuration for the model.



1888
1889
1890
1891
1892
1893
1894
1895
1896
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1888

class GenerationConfiguration < Struct.new(
  :additional_model_request_fields,
  :guardrail_configuration,
  :inference_config,
  :performance_config,
  :prompt_template)
  SENSITIVE = []
  include Aws::Structure
end

#prompt_templateTypes::PromptTemplate

Contains the template for the prompt that’s sent to the model for response generation. Generation prompts must include the ‘$search_results$` variable. For more information, see [Use placeholder variables] in the user guide.

[1]: docs.aws.amazon.com/bedrock/latest/userguide/prompt-placeholders.html



1888
1889
1890
1891
1892
1893
1894
1895
1896
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1888

class GenerationConfiguration < Struct.new(
  :additional_model_request_fields,
  :guardrail_configuration,
  :inference_config,
  :performance_config,
  :prompt_template)
  SENSITIVE = []
  include Aws::Structure
end