Class: Aws::BedrockAgentRuntime::Types::GetDocumentContentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::GetDocumentContentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:user_context]
Instance Attribute Summary collapse
-
#data_source_id ⇒ String
The unique identifier of the data source that contains the document.
-
#document_id ⇒ String
The unique identifier of the document to retrieve content for.
-
#knowledge_base_id ⇒ String
The unique identifier of the knowledge base that contains the document.
-
#output_format ⇒ String
The output format for the document content.
-
#user_context ⇒ Types::UserContext
Contains information about the user making the request.
Instance Attribute Details
#data_source_id ⇒ String
The unique identifier of the data source that contains the document.
3872 3873 3874 3875 3876 3877 3878 3879 3880 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3872 class GetDocumentContentRequest < Struct.new( :data_source_id, :document_id, :knowledge_base_id, :output_format, :user_context) SENSITIVE = [:user_context] include Aws::Structure end |
#document_id ⇒ String
The unique identifier of the document to retrieve content for.
3872 3873 3874 3875 3876 3877 3878 3879 3880 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3872 class GetDocumentContentRequest < Struct.new( :data_source_id, :document_id, :knowledge_base_id, :output_format, :user_context) SENSITIVE = [:user_context] include Aws::Structure end |
#knowledge_base_id ⇒ String
The unique identifier of the knowledge base that contains the document.
3872 3873 3874 3875 3876 3877 3878 3879 3880 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3872 class GetDocumentContentRequest < Struct.new( :data_source_id, :document_id, :knowledge_base_id, :output_format, :user_context) SENSITIVE = [:user_context] include Aws::Structure end |
#output_format ⇒ String
The output format for the document content. RAW returns the
original file. EXTRACTED returns parsed text as JSON. Defaults to
RAW.
3872 3873 3874 3875 3876 3877 3878 3879 3880 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3872 class GetDocumentContentRequest < Struct.new( :data_source_id, :document_id, :knowledge_base_id, :output_format, :user_context) SENSITIVE = [:user_context] include Aws::Structure end |
#user_context ⇒ Types::UserContext
Contains information about the user making the request. This is used for access control filtering to ensure that results only include documents the user is authorized to access.
3872 3873 3874 3875 3876 3877 3878 3879 3880 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3872 class GetDocumentContentRequest < Struct.new( :data_source_id, :document_id, :knowledge_base_id, :output_format, :user_context) SENSITIVE = [:user_context] include Aws::Structure end |