Class: Aws::BedrockAgentRuntime::Types::GetDocumentContentResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::GetDocumentContentResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:presigned_url]
Instance Attribute Summary collapse
-
#document_content_length ⇒ Integer
The size of the document content in bytes available at the pre-signed URL.
-
#mime_type ⇒ String
The MIME type of the document content.
-
#presigned_url ⇒ String
A pre-signed URL for downloading the document content.
Instance Attribute Details
#document_content_length ⇒ Integer
The size of the document content in bytes available at the pre-signed URL.
3749 3750 3751 3752 3753 3754 3755 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3749 class GetDocumentContentResponse < Struct.new( :document_content_length, :mime_type, :presigned_url) SENSITIVE = [:presigned_url] include Aws::Structure end |
#mime_type ⇒ String
The MIME type of the document content. For ‘RAW` format, this is the original file type (for example, `application/pdf`). For `EXTRACTED` format, this is always `application/json`.
3749 3750 3751 3752 3753 3754 3755 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3749 class GetDocumentContentResponse < Struct.new( :document_content_length, :mime_type, :presigned_url) SENSITIVE = [:presigned_url] include Aws::Structure end |
#presigned_url ⇒ String
A pre-signed URL for downloading the document content. The URL expires after 5 minutes.
3749 3750 3751 3752 3753 3754 3755 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3749 class GetDocumentContentResponse < Struct.new( :document_content_length, :mime_type, :presigned_url) SENSITIVE = [:presigned_url] include Aws::Structure end |