Class: Aws::BedrockAgentRuntime::Types::GetExecutionFlowSnapshotRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::GetExecutionFlowSnapshotRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#execution_identifier ⇒ String
The unique identifier of the flow execution.
-
#flow_alias_identifier ⇒ String
The unique identifier of the flow alias used for the flow execution.
-
#flow_identifier ⇒ String
The unique identifier of the flow.
Instance Attribute Details
#execution_identifier ⇒ String
The unique identifier of the flow execution.
3771 3772 3773 3774 3775 3776 3777 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3771 class GetExecutionFlowSnapshotRequest < Struct.new( :execution_identifier, :flow_alias_identifier, :flow_identifier) SENSITIVE = [] include Aws::Structure end |
#flow_alias_identifier ⇒ String
The unique identifier of the flow alias used for the flow execution.
3771 3772 3773 3774 3775 3776 3777 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3771 class GetExecutionFlowSnapshotRequest < Struct.new( :execution_identifier, :flow_alias_identifier, :flow_identifier) SENSITIVE = [] include Aws::Structure end |
#flow_identifier ⇒ String
The unique identifier of the flow.
3771 3772 3773 3774 3775 3776 3777 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3771 class GetExecutionFlowSnapshotRequest < Struct.new( :execution_identifier, :flow_alias_identifier, :flow_identifier) SENSITIVE = [] include Aws::Structure end |