Class: Aws::BedrockAgentRuntime::Types::GetFlowExecutionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#execution_identifierString

The unique identifier of the flow execution to retrieve.

Returns:

  • (String)


3841
3842
3843
3844
3845
3846
3847
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3841

class GetFlowExecutionRequest < Struct.new(
  :execution_identifier,
  :flow_alias_identifier,
  :flow_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#flow_alias_identifierString

The unique identifier of the flow alias used for the execution.

Returns:

  • (String)


3841
3842
3843
3844
3845
3846
3847
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3841

class GetFlowExecutionRequest < Struct.new(
  :execution_identifier,
  :flow_alias_identifier,
  :flow_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#flow_identifierString

The unique identifier of the flow.

Returns:

  • (String)


3841
3842
3843
3844
3845
3846
3847
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3841

class GetFlowExecutionRequest < Struct.new(
  :execution_identifier,
  :flow_alias_identifier,
  :flow_identifier)
  SENSITIVE = []
  include Aws::Structure
end