Class: Aws::BedrockAgentRuntime::Types::GetFlowExecutionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::GetFlowExecutionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ended_at ⇒ Time
The timestamp when the flow execution ended.
-
#errors ⇒ Array<Types::FlowExecutionError>
A list of errors that occurred during the flow execution.
-
#execution_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the flow execution.
-
#flow_alias_identifier ⇒ String
The unique identifier of the flow alias used for the execution.
-
#flow_identifier ⇒ String
The unique identifier of the flow.
-
#flow_version ⇒ String
The version of the flow used for the execution.
-
#started_at ⇒ Time
The timestamp when the flow execution started.
-
#status ⇒ String
The current status of the flow execution.
Instance Attribute Details
#ended_at ⇒ Time
The timestamp when the flow execution ended. This field is only populated when the execution has completed, failed, timed out, or been aborted.
4317 4318 4319 4320 4321 4322 4323 4324 4325 4326 4327 4328 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4317 class GetFlowExecutionResponse < Struct.new( :ended_at, :errors, :execution_arn, :flow_alias_identifier, :flow_identifier, :flow_version, :started_at, :status) SENSITIVE = [] include Aws::Structure end |
#errors ⇒ Array<Types::FlowExecutionError>
A list of errors that occurred during the flow execution. Each error includes an error code, message, and the node where the error occurred, if applicable.
4317 4318 4319 4320 4321 4322 4323 4324 4325 4326 4327 4328 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4317 class GetFlowExecutionResponse < Struct.new( :ended_at, :errors, :execution_arn, :flow_alias_identifier, :flow_identifier, :flow_version, :started_at, :status) SENSITIVE = [] include Aws::Structure end |
#execution_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the flow execution.
4317 4318 4319 4320 4321 4322 4323 4324 4325 4326 4327 4328 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4317 class GetFlowExecutionResponse < Struct.new( :ended_at, :errors, :execution_arn, :flow_alias_identifier, :flow_identifier, :flow_version, :started_at, :status) SENSITIVE = [] include Aws::Structure end |
#flow_alias_identifier ⇒ String
The unique identifier of the flow alias used for the execution.
4317 4318 4319 4320 4321 4322 4323 4324 4325 4326 4327 4328 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4317 class GetFlowExecutionResponse < Struct.new( :ended_at, :errors, :execution_arn, :flow_alias_identifier, :flow_identifier, :flow_version, :started_at, :status) SENSITIVE = [] include Aws::Structure end |
#flow_identifier ⇒ String
The unique identifier of the flow.
4317 4318 4319 4320 4321 4322 4323 4324 4325 4326 4327 4328 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4317 class GetFlowExecutionResponse < Struct.new( :ended_at, :errors, :execution_arn, :flow_alias_identifier, :flow_identifier, :flow_version, :started_at, :status) SENSITIVE = [] include Aws::Structure end |
#flow_version ⇒ String
The version of the flow used for the execution.
4317 4318 4319 4320 4321 4322 4323 4324 4325 4326 4327 4328 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4317 class GetFlowExecutionResponse < Struct.new( :ended_at, :errors, :execution_arn, :flow_alias_identifier, :flow_identifier, :flow_version, :started_at, :status) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The timestamp when the flow execution started.
4317 4318 4319 4320 4321 4322 4323 4324 4325 4326 4327 4328 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4317 class GetFlowExecutionResponse < Struct.new( :ended_at, :errors, :execution_arn, :flow_alias_identifier, :flow_identifier, :flow_version, :started_at, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the flow execution.
Flow executions time out after 24 hours.
4317 4318 4319 4320 4321 4322 4323 4324 4325 4326 4327 4328 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4317 class GetFlowExecutionResponse < Struct.new( :ended_at, :errors, :execution_arn, :flow_alias_identifier, :flow_identifier, :flow_version, :started_at, :status) SENSITIVE = [] include Aws::Structure end |