Class: Aws::BedrockAgentRuntime::Types::GetIngestedDocumentAclRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_source_idString

The unique identifier of the data source that contains the document.

Returns:

  • (String)


4070
4071
4072
4073
4074
4075
4076
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4070

class GetIngestedDocumentAclRequest < Struct.new(
  :data_source_id,
  :document_id,
  :knowledge_base_id)
  SENSITIVE = []
  include Aws::Structure
end

#document_idString

The unique identifier of the document to retrieve the ingested access control list (ACL) for.

Returns:

  • (String)


4070
4071
4072
4073
4074
4075
4076
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4070

class GetIngestedDocumentAclRequest < Struct.new(
  :data_source_id,
  :document_id,
  :knowledge_base_id)
  SENSITIVE = []
  include Aws::Structure
end

#knowledge_base_idString

The unique identifier of the knowledge base that contains the document.

Returns:

  • (String)


4070
4071
4072
4073
4074
4075
4076
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4070

class GetIngestedDocumentAclRequest < Struct.new(
  :data_source_id,
  :document_id,
  :knowledge_base_id)
  SENSITIVE = []
  include Aws::Structure
end