Class: Aws::BedrockAgentRuntime::Types::GetSessionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::GetSessionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp for when the session was created.
-
#encryption_key_arn ⇒ String
The Amazon Resource Name (ARN) of the Key Management Service key used to encrypt the session data.
-
#last_updated_at ⇒ Time
The timestamp for when the session was last modified.
-
#session_arn ⇒ String
The Amazon Resource Name (ARN) of the session.
-
#session_id ⇒ String
The unique identifier for the session in UUID format.
-
#session_metadata ⇒ Hash<String,String>
A map of key-value pairs containing attributes persisted across the session.
-
#session_status ⇒ String
The current status of the session.
Instance Attribute Details
#created_at ⇒ Time
The timestamp for when the session was created.
4178 4179 4180 4181 4182 4183 4184 4185 4186 4187 4188 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4178 class GetSessionResponse < Struct.new( :created_at, :encryption_key_arn, :last_updated_at, :session_arn, :session_id, :session_metadata, :session_status) SENSITIVE = [] include Aws::Structure end |
#encryption_key_arn ⇒ String
The Amazon Resource Name (ARN) of the Key Management Service key used to encrypt the session data. For more information, see Amazon Bedrock session encryption.
4178 4179 4180 4181 4182 4183 4184 4185 4186 4187 4188 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4178 class GetSessionResponse < Struct.new( :created_at, :encryption_key_arn, :last_updated_at, :session_arn, :session_id, :session_metadata, :session_status) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp for when the session was last modified.
4178 4179 4180 4181 4182 4183 4184 4185 4186 4187 4188 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4178 class GetSessionResponse < Struct.new( :created_at, :encryption_key_arn, :last_updated_at, :session_arn, :session_id, :session_metadata, :session_status) SENSITIVE = [] include Aws::Structure end |
#session_arn ⇒ String
The Amazon Resource Name (ARN) of the session.
4178 4179 4180 4181 4182 4183 4184 4185 4186 4187 4188 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4178 class GetSessionResponse < Struct.new( :created_at, :encryption_key_arn, :last_updated_at, :session_arn, :session_id, :session_metadata, :session_status) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
The unique identifier for the session in UUID format.
4178 4179 4180 4181 4182 4183 4184 4185 4186 4187 4188 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4178 class GetSessionResponse < Struct.new( :created_at, :encryption_key_arn, :last_updated_at, :session_arn, :session_id, :session_metadata, :session_status) SENSITIVE = [] include Aws::Structure end |
#session_metadata ⇒ Hash<String,String>
A map of key-value pairs containing attributes persisted across the session.
4178 4179 4180 4181 4182 4183 4184 4185 4186 4187 4188 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4178 class GetSessionResponse < Struct.new( :created_at, :encryption_key_arn, :last_updated_at, :session_arn, :session_id, :session_metadata, :session_status) SENSITIVE = [] include Aws::Structure end |
#session_status ⇒ String
The current status of the session.
4178 4179 4180 4181 4182 4183 4184 4185 4186 4187 4188 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4178 class GetSessionResponse < Struct.new( :created_at, :encryption_key_arn, :last_updated_at, :session_arn, :session_id, :session_metadata, :session_status) SENSITIVE = [] include Aws::Structure end |