Class: Aws::BedrockAgentRuntime::Types::GuardrailManagedWord
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::GuardrailManagedWord
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
The managed word details for the filter in the Guardrail.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The action details for the managed word filter in the Guardrail.
-
#match ⇒ String
The match details for the managed word filter in the Guardrail.
-
#type ⇒ String
The type details for the managed word filter in the Guardrail.
Instance Attribute Details
#action ⇒ String
The action details for the managed word filter in the Guardrail.
4159 4160 4161 4162 4163 4164 4165 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4159 class GuardrailManagedWord < Struct.new( :action, :match, :type) SENSITIVE = [] include Aws::Structure end |
#match ⇒ String
The match details for the managed word filter in the Guardrail.
4159 4160 4161 4162 4163 4164 4165 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4159 class GuardrailManagedWord < Struct.new( :action, :match, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type details for the managed word filter in the Guardrail.
4159 4160 4161 4162 4163 4164 4165 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4159 class GuardrailManagedWord < Struct.new( :action, :match, :type) SENSITIVE = [] include Aws::Structure end |