Class: Aws::BedrockAgentRuntime::Types::GuardrailSensitiveInformationPolicyAssessment

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

The details of the sensitive policy assessment used in the Guardrail.

Constant Summary collapse

SENSITIVE =
[:pii_entities, :regexes]

Instance Attribute Summary collapse

Instance Attribute Details

#pii_entitiesArray<Types::GuardrailPiiEntityFilter>

The details of the PII entities used in the sensitive policy assessment for the Guardrail.



4424
4425
4426
4427
4428
4429
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4424

class GuardrailSensitiveInformationPolicyAssessment < Struct.new(
  :pii_entities,
  :regexes)
  SENSITIVE = [:pii_entities, :regexes]
  include Aws::Structure
end

#regexesArray<Types::GuardrailRegexFilter>

The details of the regexes used in the sensitive policy assessment for the Guardrail.

Returns:



4424
4425
4426
4427
4428
4429
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4424

class GuardrailSensitiveInformationPolicyAssessment < Struct.new(
  :pii_entities,
  :regexes)
  SENSITIVE = [:pii_entities, :regexes]
  include Aws::Structure
end