Class: Aws::BedrockAgentRuntime::Types::GuardrailTopic

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

The details for a specific topic defined in the Guardrail.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionString

The action details on a specific topic in the Guardrail.

Returns:

  • (String)


4259
4260
4261
4262
4263
4264
4265
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4259

class GuardrailTopic < Struct.new(
  :action,
  :name,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name details on a specific topic in the Guardrail.

Returns:

  • (String)


4259
4260
4261
4262
4263
4264
4265
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4259

class GuardrailTopic < Struct.new(
  :action,
  :name,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type details on a specific topic in the Guardrail.

Returns:

  • (String)


4259
4260
4261
4262
4263
4264
4265
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4259

class GuardrailTopic < Struct.new(
  :action,
  :name,
  :type)
  SENSITIVE = []
  include Aws::Structure
end