Class: Aws::BedrockAgentRuntime::Types::GuardrailTopicPolicyAssessment

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

The details of the policy assessment used in the Guardrail.

Constant Summary collapse

SENSITIVE =
[:topics]

Instance Attribute Summary collapse

Instance Attribute Details

#topicsArray<Types::GuardrailTopic>

The topic details of the policy assessment used in the Guardrail.

Returns:



4275
4276
4277
4278
4279
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4275

class GuardrailTopicPolicyAssessment < Struct.new(
  :topics)
  SENSITIVE = [:topics]
  include Aws::Structure
end