Class: Aws::BedrockAgentRuntime::Types::GuardrailWordPolicyAssessment

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

The assessment details for words defined in the Guardrail filter.

Constant Summary collapse

SENSITIVE =
[:custom_words, :managed_word_lists]

Instance Attribute Summary collapse

Instance Attribute Details

#custom_wordsArray<Types::GuardrailCustomWord>

The custom word details for words defined in the Guardrail filter.

Returns:



4327
4328
4329
4330
4331
4332
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4327

class GuardrailWordPolicyAssessment < Struct.new(
  :custom_words,
  :managed_word_lists)
  SENSITIVE = [:custom_words, :managed_word_lists]
  include Aws::Structure
end

#managed_word_listsArray<Types::GuardrailManagedWord>

The managed word lists for words defined in the Guardrail filter.

Returns:



4327
4328
4329
4330
4331
4332
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4327

class GuardrailWordPolicyAssessment < Struct.new(
  :custom_words,
  :managed_word_lists)
  SENSITIVE = [:custom_words, :managed_word_lists]
  include Aws::Structure
end