Class: Aws::BedrockAgentRuntime::Types::ImageInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Details about an image in the result from a function in the action group invocation. You can specify images only when the function is a computer use action. For more information, see [Configure an Amazon Bedrock Agent to complete tasks with computer use tools].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/agent-computer-use.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#formatString

The type of image in the result.

Returns:

  • (String)


3633
3634
3635
3636
3637
3638
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3633

class ImageInput < Struct.new(
  :format,
  :source)
  SENSITIVE = []
  include Aws::Structure
end

#sourceTypes::ImageInputSource

The source of the image in the result.



3633
3634
3635
3636
3637
3638
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3633

class ImageInput < Struct.new(
  :format,
  :source)
  SENSITIVE = []
  include Aws::Structure
end