Class: Aws::BedrockAgentRuntime::Types::ImageInputSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::ImageInputSource
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Note:
ImageInputSource is a union - when making an API calls you must set exactly one of the members.
Note:
ImageInputSource is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ImageInputSource corresponding to the set member.
Details about the source of an input image in the result from a function in the action group invocation.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bytes ⇒ String
The raw image bytes for the image.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#bytes ⇒ String
The raw image bytes for the image. If you use an Amazon Web Services SDK, you don't need to encode the image bytes in base64.
4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4857 class ImageInputSource < Struct.new( :bytes, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Bytes < ImageInputSource; end class Unknown < ImageInputSource; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
4857 4858 4859 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4857 def unknown @unknown end |