Class: Aws::BedrockAgentRuntime::Types::InferenceConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::InferenceConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Specifications about the inference parameters that were provided alongside the prompt. These are specified in the
- PromptOverrideConfiguration][1
-
object that was set when the agent
was created or updated. For more information, see [Inference parameters for foundation models].
[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent_PromptOverrideConfiguration.html [2]: docs.aws.amazon.com/bedrock/latest/userguide/model-parameters.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#maximum_length ⇒ Integer
The maximum number of tokens allowed in the generated response.
-
#stop_sequences ⇒ Array<String>
A list of stop sequences.
-
#temperature ⇒ Float
The likelihood of the model selecting higher-probability options while generating a response.
-
#top_k ⇒ Integer
While generating a response, the model determines the probability of the following token at each point of generation.
-
#top_p ⇒ Float
While generating a response, the model determines the probability of the following token at each point of generation.
Instance Attribute Details
#maximum_length ⇒ Integer
The maximum number of tokens allowed in the generated response.
2370 2371 2372 2373 2374 2375 2376 2377 2378 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2370 class InferenceConfiguration < Struct.new( :maximum_length, :stop_sequences, :temperature, :top_k, :top_p) SENSITIVE = [] include Aws::Structure end |
#stop_sequences ⇒ Array<String>
A list of stop sequences. A stop sequence is a sequence of characters that causes the model to stop generating the response.
2370 2371 2372 2373 2374 2375 2376 2377 2378 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2370 class InferenceConfiguration < Struct.new( :maximum_length, :stop_sequences, :temperature, :top_k, :top_p) SENSITIVE = [] include Aws::Structure end |
#temperature ⇒ Float
The likelihood of the model selecting higher-probability options while generating a response. A lower value makes the model more likely to choose higher-probability options, while a higher value makes the model more likely to choose lower-probability options.
2370 2371 2372 2373 2374 2375 2376 2377 2378 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2370 class InferenceConfiguration < Struct.new( :maximum_length, :stop_sequences, :temperature, :top_k, :top_p) SENSITIVE = [] include Aws::Structure end |
#top_k ⇒ Integer
While generating a response, the model determines the probability of the following token at each point of generation. The value that you set for topK is the number of most-likely candidates from which the model chooses the next token in the sequence. For example, if you set topK to 50, the model selects the next token from among the top 50 most likely choices.
2370 2371 2372 2373 2374 2375 2376 2377 2378 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2370 class InferenceConfiguration < Struct.new( :maximum_length, :stop_sequences, :temperature, :top_k, :top_p) SENSITIVE = [] include Aws::Structure end |
#top_p ⇒ Float
While generating a response, the model determines the probability of the following token at each point of generation. The value that you set for ‘Top P` determines the number of most-likely candidates from which the model chooses the next token in the sequence. For example, if you set topP to 0.8, the model only selects the next token from the top 80% of the probability distribution of next tokens.
2370 2371 2372 2373 2374 2375 2376 2377 2378 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2370 class InferenceConfiguration < Struct.new( :maximum_length, :stop_sequences, :temperature, :top_k, :top_p) SENSITIVE = [] include Aws::Structure end |