Class: Aws::BedrockAgentRuntime::Types::InlineAgentPayloadPart

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains a part of an agent response and citations for it.

Constant Summary collapse

SENSITIVE =
[:bytes]

Instance Attribute Summary collapse

Instance Attribute Details

#attributionTypes::Attribution

Contains citations for a part of an agent response.

Returns:



4555
4556
4557
4558
4559
4560
4561
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4555

class InlineAgentPayloadPart < Struct.new(
  :attribution,
  :bytes,
  :event_type)
  SENSITIVE = [:bytes]
  include Aws::Structure
end

#bytesString

A part of the agent response in bytes.

Returns:

  • (String)


4555
4556
4557
4558
4559
4560
4561
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4555

class InlineAgentPayloadPart < Struct.new(
  :attribution,
  :bytes,
  :event_type)
  SENSITIVE = [:bytes]
  include Aws::Structure
end

#event_typeObject

Returns the value of attribute event_type

Returns:

  • (Object)

    the current value of event_type



4555
4556
4557
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4555

def event_type
  @event_type
end