Class: Aws::BedrockAgentRuntime::Types::InlineAgentResponseStream

Inherits:
Enumerator
  • Object
show all
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

The response from invoking the agent and associated citations and trace information.

EventStream is an Enumerator of Events.

#event_types #=> Array, returns all modeled event types in the stream

Instance Method Summary collapse

Instance Method Details

#event_typesObject



10267
10268
10269
10270
10271
10272
10273
10274
10275
10276
10277
10278
10279
10280
10281
10282
10283
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10267

def event_types
  [
    :access_denied_exception,
    :bad_gateway_exception,
    :chunk,
    :conflict_exception,
    :dependency_failed_exception,
    :files,
    :internal_server_exception,
    :resource_not_found_exception,
    :return_control,
    :service_quota_exceeded_exception,
    :throttling_exception,
    :trace,
    :validation_exception
  ]
end