Class: Aws::BedrockAgentRuntime::Types::InlineAgentTracePart

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains information about the agent and session, alongside the agent's reasoning process and results from calling API actions and querying knowledge bases and metadata about the trace. You can use the trace to understand how the agent arrived at the response it provided the customer. For more information, see Trace enablement.

Constant Summary collapse

SENSITIVE =
[:collaborator_name, :trace]

Instance Attribute Summary collapse

Instance Attribute Details

#caller_chainArray<Types::Caller>

The caller chain for the trace part.

Returns:



5096
5097
5098
5099
5100
5101
5102
5103
5104
5105
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5096

class InlineAgentTracePart < Struct.new(
  :caller_chain,
  :collaborator_name,
  :event_time,
  :session_id,
  :trace,
  :event_type)
  SENSITIVE = [:collaborator_name, :trace]
  include Aws::Structure
end

#collaborator_nameString

The collaborator name for the trace part.

Returns:

  • (String)


5096
5097
5098
5099
5100
5101
5102
5103
5104
5105
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5096

class InlineAgentTracePart < Struct.new(
  :caller_chain,
  :collaborator_name,
  :event_time,
  :session_id,
  :trace,
  :event_type)
  SENSITIVE = [:collaborator_name, :trace]
  include Aws::Structure
end

#event_timeTime

The time that trace occurred.

Returns:

  • (Time)


5096
5097
5098
5099
5100
5101
5102
5103
5104
5105
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5096

class InlineAgentTracePart < Struct.new(
  :caller_chain,
  :collaborator_name,
  :event_time,
  :session_id,
  :trace,
  :event_type)
  SENSITIVE = [:collaborator_name, :trace]
  include Aws::Structure
end

#event_typeObject

Returns the value of attribute event_type

Returns:

  • (Object)

    the current value of event_type



5096
5097
5098
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5096

def event_type
  @event_type
end

#session_idString

The unique identifier of the session with the agent.

Returns:

  • (String)


5096
5097
5098
5099
5100
5101
5102
5103
5104
5105
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5096

class InlineAgentTracePart < Struct.new(
  :caller_chain,
  :collaborator_name,
  :event_time,
  :session_id,
  :trace,
  :event_type)
  SENSITIVE = [:collaborator_name, :trace]
  include Aws::Structure
end

#traceTypes::Trace

Contains one part of the agent's reasoning process and results from calling API actions and querying knowledge bases. You can use the trace to understand how the agent arrived at the response it provided the customer. For more information, see Trace enablement.

Returns:



5096
5097
5098
5099
5100
5101
5102
5103
5104
5105
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5096

class InlineAgentTracePart < Struct.new(
  :caller_chain,
  :collaborator_name,
  :event_time,
  :session_id,
  :trace,
  :event_type)
  SENSITIVE = [:collaborator_name, :trace]
  include Aws::Structure
end