Class: Aws::BedrockAgentRuntime::Types::InlineSessionState

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains parameters that specify various attributes that persist across a session or prompt. You can define session state attributes as key-value pairs when writing a Lambda function for an action group or pass them when making an InvokeInlineAgent request. Use session state attributes to control and provide conversational context for your inline agent and to help customize your agent's behavior. For more information, see Control session context

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#conversation_historyTypes::ConversationHistory

Contains the conversation history that persist across sessions.



4905
4906
4907
4908
4909
4910
4911
4912
4913
4914
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4905

class InlineSessionState < Struct.new(
  :conversation_history,
  :files,
  :invocation_id,
  :prompt_session_attributes,
  :return_control_invocation_results,
  :session_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#filesArray<Types::InputFile>

Contains information about the files used by code interpreter.

Returns:



4905
4906
4907
4908
4909
4910
4911
4912
4913
4914
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4905

class InlineSessionState < Struct.new(
  :conversation_history,
  :files,
  :invocation_id,
  :prompt_session_attributes,
  :return_control_invocation_results,
  :session_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#invocation_idString

The identifier of the invocation of an action. This value must match the invocationId returned in the InvokeInlineAgent response for the action whose results are provided in the returnControlInvocationResults field. For more information, see Return control to the agent developer.

Returns:

  • (String)


4905
4906
4907
4908
4909
4910
4911
4912
4913
4914
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4905

class InlineSessionState < Struct.new(
  :conversation_history,
  :files,
  :invocation_id,
  :prompt_session_attributes,
  :return_control_invocation_results,
  :session_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#prompt_session_attributesHash<String,String>

Contains attributes that persist across a session and the values of those attributes.

Returns:

  • (Hash<String,String>)


4905
4906
4907
4908
4909
4910
4911
4912
4913
4914
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4905

class InlineSessionState < Struct.new(
  :conversation_history,
  :files,
  :invocation_id,
  :prompt_session_attributes,
  :return_control_invocation_results,
  :session_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#return_control_invocation_resultsArray<Types::InvocationResultMember>

Contains information about the results from the action group invocation. For more information, see Return control to the agent developer.

If you include this field in the sessionState field, the inputText field will be ignored.

Returns:



4905
4906
4907
4908
4909
4910
4911
4912
4913
4914
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4905

class InlineSessionState < Struct.new(
  :conversation_history,
  :files,
  :invocation_id,
  :prompt_session_attributes,
  :return_control_invocation_results,
  :session_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#session_attributesHash<String,String>

Contains attributes that persist across a session and the values of those attributes.

Returns:

  • (Hash<String,String>)


4905
4906
4907
4908
4909
4910
4911
4912
4913
4914
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4905

class InlineSessionState < Struct.new(
  :conversation_history,
  :files,
  :invocation_id,
  :prompt_session_attributes,
  :return_control_invocation_results,
  :session_attributes)
  SENSITIVE = []
  include Aws::Structure
end