Class: Aws::BedrockAgentRuntime::Types::InputFile
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::InputFile
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains details of the source files.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the source file.
-
#source ⇒ Types::FileSource
Specifies where the files are located.
-
#use_case ⇒ String
Specifies how the source files will be used by the code interpreter.
Instance Attribute Details
#name ⇒ String
The name of the source file.
2577 2578 2579 2580 2581 2582 2583 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2577 class InputFile < Struct.new( :name, :source, :use_case) SENSITIVE = [] include Aws::Structure end |
#source ⇒ Types::FileSource
Specifies where the files are located.
2577 2578 2579 2580 2581 2582 2583 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2577 class InputFile < Struct.new( :name, :source, :use_case) SENSITIVE = [] include Aws::Structure end |
#use_case ⇒ String
Specifies how the source files will be used by the code interpreter.
2577 2578 2579 2580 2581 2582 2583 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2577 class InputFile < Struct.new( :name, :source, :use_case) SENSITIVE = [] include Aws::Structure end |