Class: Aws::BedrockAgentRuntime::Types::InputImage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains the image data for multimodal knowledge base queries, including format and content.

This data type is used in the following API operations:

^

Constant Summary collapse

SENSITIVE =
[:inline_content]

Instance Attribute Summary collapse

Instance Attribute Details

#formatString

The format of the input image. Supported formats include png, gif, jpeg, and webp.

Returns:

  • (String)


4777
4778
4779
4780
4781
4782
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4777

class InputImage < Struct.new(
  :format,
  :inline_content)
  SENSITIVE = [:inline_content]
  include Aws::Structure
end

#inline_contentString

The base64-encoded image data for inline image content. Maximum size is 5MB.

Returns:

  • (String)


4777
4778
4779
4780
4781
4782
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4777

class InputImage < Struct.new(
  :format,
  :inline_content)
  SENSITIVE = [:inline_content]
  include Aws::Structure
end