Class: Aws::BedrockAgentRuntime::Types::InvocationInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::InvocationInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains information pertaining to the action group or knowledge base that is being invoked.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_group_invocation_input ⇒ Types::ActionGroupInvocationInput
Contains information about the action group to be invoked.
-
#agent_collaborator_invocation_input ⇒ Types::AgentCollaboratorInvocationInput
The collaborator’s invocation input.
-
#code_interpreter_invocation_input ⇒ Types::CodeInterpreterInvocationInput
Contains information about the code interpreter to be invoked.
-
#invocation_type ⇒ String
Specifies whether the agent is invoking an action group or a knowledge base.
-
#knowledge_base_lookup_input ⇒ Types::KnowledgeBaseLookupInput
Contains details about the knowledge base to look up and the query to be made.
-
#trace_id ⇒ String
The unique identifier of the trace.
Instance Attribute Details
#action_group_invocation_input ⇒ Types::ActionGroupInvocationInput
Contains information about the action group to be invoked.
2651 2652 2653 2654 2655 2656 2657 2658 2659 2660 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2651 class InvocationInput < Struct.new( :action_group_invocation_input, :agent_collaborator_invocation_input, :code_interpreter_invocation_input, :invocation_type, :knowledge_base_lookup_input, :trace_id) SENSITIVE = [] include Aws::Structure end |
#agent_collaborator_invocation_input ⇒ Types::AgentCollaboratorInvocationInput
The collaborator’s invocation input.
2651 2652 2653 2654 2655 2656 2657 2658 2659 2660 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2651 class InvocationInput < Struct.new( :action_group_invocation_input, :agent_collaborator_invocation_input, :code_interpreter_invocation_input, :invocation_type, :knowledge_base_lookup_input, :trace_id) SENSITIVE = [] include Aws::Structure end |
#code_interpreter_invocation_input ⇒ Types::CodeInterpreterInvocationInput
Contains information about the code interpreter to be invoked.
2651 2652 2653 2654 2655 2656 2657 2658 2659 2660 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2651 class InvocationInput < Struct.new( :action_group_invocation_input, :agent_collaborator_invocation_input, :code_interpreter_invocation_input, :invocation_type, :knowledge_base_lookup_input, :trace_id) SENSITIVE = [] include Aws::Structure end |
#invocation_type ⇒ String
Specifies whether the agent is invoking an action group or a knowledge base.
2651 2652 2653 2654 2655 2656 2657 2658 2659 2660 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2651 class InvocationInput < Struct.new( :action_group_invocation_input, :agent_collaborator_invocation_input, :code_interpreter_invocation_input, :invocation_type, :knowledge_base_lookup_input, :trace_id) SENSITIVE = [] include Aws::Structure end |
#knowledge_base_lookup_input ⇒ Types::KnowledgeBaseLookupInput
Contains details about the knowledge base to look up and the query to be made.
2651 2652 2653 2654 2655 2656 2657 2658 2659 2660 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2651 class InvocationInput < Struct.new( :action_group_invocation_input, :agent_collaborator_invocation_input, :code_interpreter_invocation_input, :invocation_type, :knowledge_base_lookup_input, :trace_id) SENSITIVE = [] include Aws::Structure end |
#trace_id ⇒ String
The unique identifier of the trace.
2651 2652 2653 2654 2655 2656 2657 2658 2659 2660 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2651 class InvocationInput < Struct.new( :action_group_invocation_input, :agent_collaborator_invocation_input, :code_interpreter_invocation_input, :invocation_type, :knowledge_base_lookup_input, :trace_id) SENSITIVE = [] include Aws::Structure end |