Class: Aws::BedrockAgentRuntime::Types::InvocationInputMember

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Note:

InvocationInputMember is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of InvocationInputMember corresponding to the set member.

Contains details about the API operation or function that the agent predicts should be called.

This data type is used in the following API operations:

^

Defined Under Namespace

Classes: ApiInvocationInput, FunctionInvocationInput, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#api_invocation_inputTypes::ApiInvocationInput

Contains information about the API operation that the agent predicts should be called.



5359
5360
5361
5362
5363
5364
5365
5366
5367
5368
5369
5370
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5359

class InvocationInputMember < Struct.new(
  :api_invocation_input,
  :function_invocation_input,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ApiInvocationInput < InvocationInputMember; end
  class FunctionInvocationInput < InvocationInputMember; end
  class Unknown < InvocationInputMember; end
end

#function_invocation_inputTypes::FunctionInvocationInput

Contains information about the function that the agent predicts should be called.



5359
5360
5361
5362
5363
5364
5365
5366
5367
5368
5369
5370
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5359

class InvocationInputMember < Struct.new(
  :api_invocation_input,
  :function_invocation_input,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ApiInvocationInput < InvocationInputMember; end
  class FunctionInvocationInput < InvocationInputMember; end
  class Unknown < InvocationInputMember; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



5359
5360
5361
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5359

def unknown
  @unknown
end