Class: Aws::BedrockAgentRuntime::Types::InvocationResultMember
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::InvocationResultMember
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
InvocationResultMember is a union - when making an API calls you must set exactly one of the members.
InvocationResultMember is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of InvocationResultMember corresponding to the set member.
A result from the invocation of an action. For more information, see Return control to the agent developer and Control session context.
This data type is used in the following API operations:
^
Defined Under Namespace
Classes: ApiResult, FunctionResult, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#api_result ⇒ Types::ApiResult
The result from the API response from the action group invocation.
-
#function_result ⇒ Types::FunctionResult
The result from the function from the action group invocation.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#api_result ⇒ Types::ApiResult
The result from the API response from the action group invocation.
5402 5403 5404 5405 5406 5407 5408 5409 5410 5411 5412 5413 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5402 class InvocationResultMember < Struct.new( :api_result, :function_result, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ApiResult < InvocationResultMember; end class FunctionResult < InvocationResultMember; end class Unknown < InvocationResultMember; end end |
#function_result ⇒ Types::FunctionResult
The result from the function from the action group invocation.
5402 5403 5404 5405 5406 5407 5408 5409 5410 5411 5412 5413 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5402 class InvocationResultMember < Struct.new( :api_result, :function_result, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ApiResult < InvocationResultMember; end class FunctionResult < InvocationResultMember; end class Unknown < InvocationResultMember; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
5402 5403 5404 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5402 def unknown @unknown end |