Class: Aws::BedrockAgentRuntime::Types::InvocationStep
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::InvocationStep
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Stores fine-grained state checkpoints, including text and images, for each interaction in an invocation in a session. For more information about sessions, see [Store and retrieve conversation history and context with Amazon Bedrock sessions].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/sessions.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#invocation_id ⇒ String
The unique identifier (in UUID format) for the invocation that includes the invocation step.
-
#invocation_step_id ⇒ String
The unique identifier (in UUID format) for the invocation step.
-
#invocation_step_time ⇒ Time
The timestamp for when the invocation step was created.
-
#payload ⇒ Types::InvocationStepPayload
Payload content, such as text and images, for the invocation step.
-
#session_id ⇒ String
The unique identifier of the session containing the invocation step.
Instance Attribute Details
#invocation_id ⇒ String
The unique identifier (in UUID format) for the invocation that includes the invocation step.
4244 4245 4246 4247 4248 4249 4250 4251 4252 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4244 class InvocationStep < Struct.new( :invocation_id, :invocation_step_id, :invocation_step_time, :payload, :session_id) SENSITIVE = [] include Aws::Structure end |
#invocation_step_id ⇒ String
The unique identifier (in UUID format) for the invocation step.
4244 4245 4246 4247 4248 4249 4250 4251 4252 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4244 class InvocationStep < Struct.new( :invocation_id, :invocation_step_id, :invocation_step_time, :payload, :session_id) SENSITIVE = [] include Aws::Structure end |
#invocation_step_time ⇒ Time
The timestamp for when the invocation step was created.
4244 4245 4246 4247 4248 4249 4250 4251 4252 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4244 class InvocationStep < Struct.new( :invocation_id, :invocation_step_id, :invocation_step_time, :payload, :session_id) SENSITIVE = [] include Aws::Structure end |
#payload ⇒ Types::InvocationStepPayload
Payload content, such as text and images, for the invocation step.
4244 4245 4246 4247 4248 4249 4250 4251 4252 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4244 class InvocationStep < Struct.new( :invocation_id, :invocation_step_id, :invocation_step_time, :payload, :session_id) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
The unique identifier of the session containing the invocation step.
4244 4245 4246 4247 4248 4249 4250 4251 4252 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4244 class InvocationStep < Struct.new( :invocation_id, :invocation_step_id, :invocation_step_time, :payload, :session_id) SENSITIVE = [] include Aws::Structure end |