Class: Aws::BedrockAgentRuntime::Types::InvocationStepSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains details about an invocation step within an invocation in a session. For more information about sessions, see [Store and retrieve conversation history and context with Amazon Bedrock sessions].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/sessions.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#invocation_idString

A unique identifier for the invocation in UUID format.

Returns:

  • (String)


4304
4305
4306
4307
4308
4309
4310
4311
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4304

class InvocationStepSummary < Struct.new(
  :invocation_id,
  :invocation_step_id,
  :invocation_step_time,
  :session_id)
  SENSITIVE = []
  include Aws::Structure
end

#invocation_step_idString

The unique identifier (in UUID format) for the invocation step.

Returns:

  • (String)


4304
4305
4306
4307
4308
4309
4310
4311
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4304

class InvocationStepSummary < Struct.new(
  :invocation_id,
  :invocation_step_id,
  :invocation_step_time,
  :session_id)
  SENSITIVE = []
  include Aws::Structure
end

#invocation_step_timeTime

The timestamp for when the invocation step was created.

Returns:

  • (Time)


4304
4305
4306
4307
4308
4309
4310
4311
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4304

class InvocationStepSummary < Struct.new(
  :invocation_id,
  :invocation_step_id,
  :invocation_step_time,
  :session_id)
  SENSITIVE = []
  include Aws::Structure
end

#session_idString

The unique identifier for the session associated with the invocation step.

Returns:

  • (String)


4304
4305
4306
4307
4308
4309
4310
4311
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4304

class InvocationStepSummary < Struct.new(
  :invocation_id,
  :invocation_step_id,
  :invocation_step_time,
  :session_id)
  SENSITIVE = []
  include Aws::Structure
end