Class: Aws::BedrockAgentRuntime::Types::InvocationSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains details about an invocation in a session. For more information about sessions, see [Store and retrieve conversation history and context with Amazon Bedrock sessions].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/sessions.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp for when the invocation was created.

Returns:

  • (Time)


4336
4337
4338
4339
4340
4341
4342
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4336

class InvocationSummary < Struct.new(
  :created_at,
  :invocation_id,
  :session_id)
  SENSITIVE = []
  include Aws::Structure
end

#invocation_idString

A unique identifier for the invocation in UUID format.

Returns:

  • (String)


4336
4337
4338
4339
4340
4341
4342
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4336

class InvocationSummary < Struct.new(
  :created_at,
  :invocation_id,
  :session_id)
  SENSITIVE = []
  include Aws::Structure
end

#session_idString

The unique identifier for the session associated with the invocation.

Returns:

  • (String)


4336
4337
4338
4339
4340
4341
4342
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4336

class InvocationSummary < Struct.new(
  :created_at,
  :invocation_id,
  :session_id)
  SENSITIVE = []
  include Aws::Structure
end