Class: Aws::BedrockAgentRuntime::Types::InvokeAgentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::InvokeAgentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:input_text]
Instance Attribute Summary collapse
-
#agent_alias_id ⇒ String
The alias of the agent to use.
-
#agent_id ⇒ String
The unique identifier of the agent to use.
-
#bedrock_model_configurations ⇒ Types::BedrockModelConfigurations
Model performance settings for the request.
-
#enable_trace ⇒ Boolean
Specifies whether to turn on the trace or not to track the agent's reasoning process.
-
#end_session ⇒ Boolean
Specifies whether to end the session with the agent or not.
-
#input_text ⇒ String
The prompt text to send the agent.
-
#memory_id ⇒ String
The unique identifier of the agent memory.
-
#prompt_creation_configurations ⇒ Types::PromptCreationConfigurations
Specifies parameters that control how the service populates the agent prompt for an
InvokeAgentrequest. -
#session_id ⇒ String
The unique identifier of the session.
-
#session_state ⇒ Types::SessionState
Contains parameters that specify various attributes of the session.
-
#source_arn ⇒ String
The ARN of the resource making the request.
-
#streaming_configurations ⇒ Types::StreamingConfigurations
Specifies the configurations for streaming.
Instance Attribute Details
#agent_alias_id ⇒ String
The alias of the agent to use.
5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 5642 5643 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5628 class InvokeAgentRequest < Struct.new( :agent_alias_id, :agent_id, :bedrock_model_configurations, :enable_trace, :end_session, :input_text, :memory_id, :prompt_creation_configurations, :session_id, :session_state, :source_arn, :streaming_configurations) SENSITIVE = [:input_text] include Aws::Structure end |
#agent_id ⇒ String
The unique identifier of the agent to use.
5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 5642 5643 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5628 class InvokeAgentRequest < Struct.new( :agent_alias_id, :agent_id, :bedrock_model_configurations, :enable_trace, :end_session, :input_text, :memory_id, :prompt_creation_configurations, :session_id, :session_state, :source_arn, :streaming_configurations) SENSITIVE = [:input_text] include Aws::Structure end |
#bedrock_model_configurations ⇒ Types::BedrockModelConfigurations
Model performance settings for the request.
5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 5642 5643 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5628 class InvokeAgentRequest < Struct.new( :agent_alias_id, :agent_id, :bedrock_model_configurations, :enable_trace, :end_session, :input_text, :memory_id, :prompt_creation_configurations, :session_id, :session_state, :source_arn, :streaming_configurations) SENSITIVE = [:input_text] include Aws::Structure end |
#enable_trace ⇒ Boolean
Specifies whether to turn on the trace or not to track the agent's reasoning process. For more information, see Trace enablement.
5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 5642 5643 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5628 class InvokeAgentRequest < Struct.new( :agent_alias_id, :agent_id, :bedrock_model_configurations, :enable_trace, :end_session, :input_text, :memory_id, :prompt_creation_configurations, :session_id, :session_state, :source_arn, :streaming_configurations) SENSITIVE = [:input_text] include Aws::Structure end |
#end_session ⇒ Boolean
Specifies whether to end the session with the agent or not.
5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 5642 5643 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5628 class InvokeAgentRequest < Struct.new( :agent_alias_id, :agent_id, :bedrock_model_configurations, :enable_trace, :end_session, :input_text, :memory_id, :prompt_creation_configurations, :session_id, :session_state, :source_arn, :streaming_configurations) SENSITIVE = [:input_text] include Aws::Structure end |
#input_text ⇒ String
The prompt text to send the agent.
returnControlInvocationResults in the
sessionState field, the inputText field will be ignored.
5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 5642 5643 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5628 class InvokeAgentRequest < Struct.new( :agent_alias_id, :agent_id, :bedrock_model_configurations, :enable_trace, :end_session, :input_text, :memory_id, :prompt_creation_configurations, :session_id, :session_state, :source_arn, :streaming_configurations) SENSITIVE = [:input_text] include Aws::Structure end |
#memory_id ⇒ String
The unique identifier of the agent memory.
5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 5642 5643 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5628 class InvokeAgentRequest < Struct.new( :agent_alias_id, :agent_id, :bedrock_model_configurations, :enable_trace, :end_session, :input_text, :memory_id, :prompt_creation_configurations, :session_id, :session_state, :source_arn, :streaming_configurations) SENSITIVE = [:input_text] include Aws::Structure end |
#prompt_creation_configurations ⇒ Types::PromptCreationConfigurations
Specifies parameters that control how the service populates the
agent prompt for an InvokeAgent request. You can control which
aspects of previous invocations in the same agent session the
service uses to populate the agent prompt. This gives you more
granular control over the contextual history that is used to process
the current request.
5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 5642 5643 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5628 class InvokeAgentRequest < Struct.new( :agent_alias_id, :agent_id, :bedrock_model_configurations, :enable_trace, :end_session, :input_text, :memory_id, :prompt_creation_configurations, :session_id, :session_state, :source_arn, :streaming_configurations) SENSITIVE = [:input_text] include Aws::Structure end |
#session_id ⇒ String
The unique identifier of the session. Use the same value across requests to continue the same conversation.
5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 5642 5643 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5628 class InvokeAgentRequest < Struct.new( :agent_alias_id, :agent_id, :bedrock_model_configurations, :enable_trace, :end_session, :input_text, :memory_id, :prompt_creation_configurations, :session_id, :session_state, :source_arn, :streaming_configurations) SENSITIVE = [:input_text] include Aws::Structure end |
#session_state ⇒ Types::SessionState
Contains parameters that specify various attributes of the session. For more information, see Control session context.
returnControlInvocationResults in the
sessionState field, the inputText field will be ignored.
5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 5642 5643 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5628 class InvokeAgentRequest < Struct.new( :agent_alias_id, :agent_id, :bedrock_model_configurations, :enable_trace, :end_session, :input_text, :memory_id, :prompt_creation_configurations, :session_id, :session_state, :source_arn, :streaming_configurations) SENSITIVE = [:input_text] include Aws::Structure end |
#source_arn ⇒ String
The ARN of the resource making the request.
5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 5642 5643 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5628 class InvokeAgentRequest < Struct.new( :agent_alias_id, :agent_id, :bedrock_model_configurations, :enable_trace, :end_session, :input_text, :memory_id, :prompt_creation_configurations, :session_id, :session_state, :source_arn, :streaming_configurations) SENSITIVE = [:input_text] include Aws::Structure end |
#streaming_configurations ⇒ Types::StreamingConfigurations
Specifies the configurations for streaming.
bedrock:InvokeModelWithResponseStream action.
5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 5642 5643 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5628 class InvokeAgentRequest < Struct.new( :agent_alias_id, :agent_id, :bedrock_model_configurations, :enable_trace, :end_session, :input_text, :memory_id, :prompt_creation_configurations, :session_id, :session_state, :source_arn, :streaming_configurations) SENSITIVE = [:input_text] include Aws::Structure end |