Class: Aws::BedrockAgentRuntime::Types::InvokeAgentResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#completionTypes::ResponseStream

The agent’s response to the user prompt.



5200
5201
5202
5203
5204
5205
5206
5207
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5200

class InvokeAgentResponse < Struct.new(
  :completion,
  :content_type,
  :memory_id,
  :session_id)
  SENSITIVE = []
  include Aws::Structure
end

#content_typeString

The MIME type of the input data in the request. The default value is ‘application/json`.

Returns:

  • (String)


5200
5201
5202
5203
5204
5205
5206
5207
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5200

class InvokeAgentResponse < Struct.new(
  :completion,
  :content_type,
  :memory_id,
  :session_id)
  SENSITIVE = []
  include Aws::Structure
end

#memory_idString

The unique identifier of the agent memory.

Returns:

  • (String)


5200
5201
5202
5203
5204
5205
5206
5207
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5200

class InvokeAgentResponse < Struct.new(
  :completion,
  :content_type,
  :memory_id,
  :session_id)
  SENSITIVE = []
  include Aws::Structure
end

#session_idString

The unique identifier of the session with the agent.

Returns:

  • (String)


5200
5201
5202
5203
5204
5205
5206
5207
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5200

class InvokeAgentResponse < Struct.new(
  :completion,
  :content_type,
  :memory_id,
  :session_id)
  SENSITIVE = []
  include Aws::Structure
end