Class: Aws::BedrockAgentRuntime::Types::InvokeFlowResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::InvokeFlowResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#execution_id ⇒ String
The unique identifier for the current flow execution.
-
#response_stream ⇒ Types::FlowResponseStream
The output of the flow, returned as a stream.
Instance Attribute Details
#execution_id ⇒ String
The unique identifier for the current flow execution.
5266 5267 5268 5269 5270 5271 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5266 class InvokeFlowResponse < Struct.new( :execution_id, :response_stream) SENSITIVE = [] include Aws::Structure end |
#response_stream ⇒ Types::FlowResponseStream
The output of the flow, returned as a stream. If there’s an error, the error is returned.
5266 5267 5268 5269 5270 5271 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5266 class InvokeFlowResponse < Struct.new( :execution_id, :response_stream) SENSITIVE = [] include Aws::Structure end |