Class: Aws::BedrockAgentRuntime::Types::InvokeInlineAgentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::InvokeInlineAgentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:agent_name, :input_text, :instruction, :prompt_override_configuration]
Instance Attribute Summary collapse
-
#action_groups ⇒ Array<Types::AgentActionGroup>
A list of action groups with each action group defining the action the inline agent needs to carry out.
-
#agent_collaboration ⇒ String
Defines how the inline collaborator agent handles information across multiple collaborator agents to coordinate a final response.
-
#agent_name ⇒ String
The name for the agent.
-
#bedrock_model_configurations ⇒ Types::InlineBedrockModelConfigurations
Model settings for the request.
-
#collaborator_configurations ⇒ Array<Types::CollaboratorConfiguration>
Settings for an inline agent collaborator called with [InvokeInlineAgent].
-
#collaborators ⇒ Array<Types::Collaborator>
List of collaborator inline agents.
-
#custom_orchestration ⇒ Types::CustomOrchestration
Contains details of the custom orchestration configured for the agent.
-
#customer_encryption_key_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services KMS key to use to encrypt your inline agent.
-
#enable_trace ⇒ Boolean
Specifies whether to turn on the trace or not to track the agent’s reasoning process.
-
#end_session ⇒ Boolean
Specifies whether to end the session with the inline agent or not.
-
#foundation_model ⇒ String
The [model identifier (ID)] of the model to use for orchestration by the inline agent.
-
#guardrail_configuration ⇒ Types::GuardrailConfigurationWithArn
The [guardrails] to assign to the inline agent.
-
#idle_session_ttl_in_seconds ⇒ Integer
The number of seconds for which the inline agent should maintain session information.
-
#inline_session_state ⇒ Types::InlineSessionState
Parameters that specify the various attributes of a sessions.
-
#input_text ⇒ String
The prompt text to send to the agent.
-
#instruction ⇒ String
The instructions that tell the inline agent what it should do and how it should interact with users.
-
#knowledge_bases ⇒ Array<Types::KnowledgeBase>
Contains information of the knowledge bases to associate with.
-
#orchestration_type ⇒ String
Specifies the type of orchestration strategy for the agent.
-
#prompt_creation_configurations ⇒ Types::PromptCreationConfigurations
Specifies parameters that control how the service populates the agent prompt for an ‘InvokeInlineAgent` request.
-
#prompt_override_configuration ⇒ Types::PromptOverrideConfiguration
Configurations for advanced prompts used to override the default prompts to enhance the accuracy of the inline agent.
-
#session_id ⇒ String
The unique identifier of the session.
-
#streaming_configurations ⇒ Types::StreamingConfigurations
Specifies the configurations for streaming.
Instance Attribute Details
#action_groups ⇒ Array<Types::AgentActionGroup>
A list of action groups with each action group defining the action the inline agent needs to carry out.
5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 5441 5442 5443 5444 5445 5446 5447 5448 5449 5450 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5425 class InvokeInlineAgentRequest < Struct.new( :action_groups, :agent_collaboration, :agent_name, :bedrock_model_configurations, :collaborator_configurations, :collaborators, :custom_orchestration, :customer_encryption_key_arn, :enable_trace, :end_session, :foundation_model, :guardrail_configuration, :idle_session_ttl_in_seconds, :inline_session_state, :input_text, :instruction, :knowledge_bases, :orchestration_type, :prompt_creation_configurations, :prompt_override_configuration, :session_id, :streaming_configurations) SENSITIVE = [:agent_name, :input_text, :instruction, :prompt_override_configuration] include Aws::Structure end |
#agent_collaboration ⇒ String
Defines how the inline collaborator agent handles information across multiple collaborator agents to coordinate a final response. The inline collaborator agent can also be the supervisor.
5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 5441 5442 5443 5444 5445 5446 5447 5448 5449 5450 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5425 class InvokeInlineAgentRequest < Struct.new( :action_groups, :agent_collaboration, :agent_name, :bedrock_model_configurations, :collaborator_configurations, :collaborators, :custom_orchestration, :customer_encryption_key_arn, :enable_trace, :end_session, :foundation_model, :guardrail_configuration, :idle_session_ttl_in_seconds, :inline_session_state, :input_text, :instruction, :knowledge_bases, :orchestration_type, :prompt_creation_configurations, :prompt_override_configuration, :session_id, :streaming_configurations) SENSITIVE = [:agent_name, :input_text, :instruction, :prompt_override_configuration] include Aws::Structure end |
#agent_name ⇒ String
The name for the agent.
5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 5441 5442 5443 5444 5445 5446 5447 5448 5449 5450 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5425 class InvokeInlineAgentRequest < Struct.new( :action_groups, :agent_collaboration, :agent_name, :bedrock_model_configurations, :collaborator_configurations, :collaborators, :custom_orchestration, :customer_encryption_key_arn, :enable_trace, :end_session, :foundation_model, :guardrail_configuration, :idle_session_ttl_in_seconds, :inline_session_state, :input_text, :instruction, :knowledge_bases, :orchestration_type, :prompt_creation_configurations, :prompt_override_configuration, :session_id, :streaming_configurations) SENSITIVE = [:agent_name, :input_text, :instruction, :prompt_override_configuration] include Aws::Structure end |
#bedrock_model_configurations ⇒ Types::InlineBedrockModelConfigurations
Model settings for the request.
5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 5441 5442 5443 5444 5445 5446 5447 5448 5449 5450 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5425 class InvokeInlineAgentRequest < Struct.new( :action_groups, :agent_collaboration, :agent_name, :bedrock_model_configurations, :collaborator_configurations, :collaborators, :custom_orchestration, :customer_encryption_key_arn, :enable_trace, :end_session, :foundation_model, :guardrail_configuration, :idle_session_ttl_in_seconds, :inline_session_state, :input_text, :instruction, :knowledge_bases, :orchestration_type, :prompt_creation_configurations, :prompt_override_configuration, :session_id, :streaming_configurations) SENSITIVE = [:agent_name, :input_text, :instruction, :prompt_override_configuration] include Aws::Structure end |
#collaborator_configurations ⇒ Array<Types::CollaboratorConfiguration>
Settings for an inline agent collaborator called with [InvokeInlineAgent].
[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_InvokeInlineAgent.html
5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 5441 5442 5443 5444 5445 5446 5447 5448 5449 5450 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5425 class InvokeInlineAgentRequest < Struct.new( :action_groups, :agent_collaboration, :agent_name, :bedrock_model_configurations, :collaborator_configurations, :collaborators, :custom_orchestration, :customer_encryption_key_arn, :enable_trace, :end_session, :foundation_model, :guardrail_configuration, :idle_session_ttl_in_seconds, :inline_session_state, :input_text, :instruction, :knowledge_bases, :orchestration_type, :prompt_creation_configurations, :prompt_override_configuration, :session_id, :streaming_configurations) SENSITIVE = [:agent_name, :input_text, :instruction, :prompt_override_configuration] include Aws::Structure end |
#collaborators ⇒ Array<Types::Collaborator>
List of collaborator inline agents.
5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 5441 5442 5443 5444 5445 5446 5447 5448 5449 5450 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5425 class InvokeInlineAgentRequest < Struct.new( :action_groups, :agent_collaboration, :agent_name, :bedrock_model_configurations, :collaborator_configurations, :collaborators, :custom_orchestration, :customer_encryption_key_arn, :enable_trace, :end_session, :foundation_model, :guardrail_configuration, :idle_session_ttl_in_seconds, :inline_session_state, :input_text, :instruction, :knowledge_bases, :orchestration_type, :prompt_creation_configurations, :prompt_override_configuration, :session_id, :streaming_configurations) SENSITIVE = [:agent_name, :input_text, :instruction, :prompt_override_configuration] include Aws::Structure end |
#custom_orchestration ⇒ Types::CustomOrchestration
Contains details of the custom orchestration configured for the agent.
5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 5441 5442 5443 5444 5445 5446 5447 5448 5449 5450 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5425 class InvokeInlineAgentRequest < Struct.new( :action_groups, :agent_collaboration, :agent_name, :bedrock_model_configurations, :collaborator_configurations, :collaborators, :custom_orchestration, :customer_encryption_key_arn, :enable_trace, :end_session, :foundation_model, :guardrail_configuration, :idle_session_ttl_in_seconds, :inline_session_state, :input_text, :instruction, :knowledge_bases, :orchestration_type, :prompt_creation_configurations, :prompt_override_configuration, :session_id, :streaming_configurations) SENSITIVE = [:agent_name, :input_text, :instruction, :prompt_override_configuration] include Aws::Structure end |
#customer_encryption_key_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services KMS key to use to encrypt your inline agent.
5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 5441 5442 5443 5444 5445 5446 5447 5448 5449 5450 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5425 class InvokeInlineAgentRequest < Struct.new( :action_groups, :agent_collaboration, :agent_name, :bedrock_model_configurations, :collaborator_configurations, :collaborators, :custom_orchestration, :customer_encryption_key_arn, :enable_trace, :end_session, :foundation_model, :guardrail_configuration, :idle_session_ttl_in_seconds, :inline_session_state, :input_text, :instruction, :knowledge_bases, :orchestration_type, :prompt_creation_configurations, :prompt_override_configuration, :session_id, :streaming_configurations) SENSITIVE = [:agent_name, :input_text, :instruction, :prompt_override_configuration] include Aws::Structure end |
#enable_trace ⇒ Boolean
Specifies whether to turn on the trace or not to track the agent’s reasoning process. For more information, see [Using trace].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/trace-events.html
5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 5441 5442 5443 5444 5445 5446 5447 5448 5449 5450 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5425 class InvokeInlineAgentRequest < Struct.new( :action_groups, :agent_collaboration, :agent_name, :bedrock_model_configurations, :collaborator_configurations, :collaborators, :custom_orchestration, :customer_encryption_key_arn, :enable_trace, :end_session, :foundation_model, :guardrail_configuration, :idle_session_ttl_in_seconds, :inline_session_state, :input_text, :instruction, :knowledge_bases, :orchestration_type, :prompt_creation_configurations, :prompt_override_configuration, :session_id, :streaming_configurations) SENSITIVE = [:agent_name, :input_text, :instruction, :prompt_override_configuration] include Aws::Structure end |
#end_session ⇒ Boolean
Specifies whether to end the session with the inline agent or not.
5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 5441 5442 5443 5444 5445 5446 5447 5448 5449 5450 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5425 class InvokeInlineAgentRequest < Struct.new( :action_groups, :agent_collaboration, :agent_name, :bedrock_model_configurations, :collaborator_configurations, :collaborators, :custom_orchestration, :customer_encryption_key_arn, :enable_trace, :end_session, :foundation_model, :guardrail_configuration, :idle_session_ttl_in_seconds, :inline_session_state, :input_text, :instruction, :knowledge_bases, :orchestration_type, :prompt_creation_configurations, :prompt_override_configuration, :session_id, :streaming_configurations) SENSITIVE = [:agent_name, :input_text, :instruction, :prompt_override_configuration] include Aws::Structure end |
#foundation_model ⇒ String
The [model identifier (ID)] of the model to use for orchestration by the inline agent. For example, ‘meta.llama3-1-70b-instruct-v1:0`.
[1]: docs.aws.amazon.com/bedrock/latest/userguide/model-ids.html#model-ids-arns
5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 5441 5442 5443 5444 5445 5446 5447 5448 5449 5450 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5425 class InvokeInlineAgentRequest < Struct.new( :action_groups, :agent_collaboration, :agent_name, :bedrock_model_configurations, :collaborator_configurations, :collaborators, :custom_orchestration, :customer_encryption_key_arn, :enable_trace, :end_session, :foundation_model, :guardrail_configuration, :idle_session_ttl_in_seconds, :inline_session_state, :input_text, :instruction, :knowledge_bases, :orchestration_type, :prompt_creation_configurations, :prompt_override_configuration, :session_id, :streaming_configurations) SENSITIVE = [:agent_name, :input_text, :instruction, :prompt_override_configuration] include Aws::Structure end |
#guardrail_configuration ⇒ Types::GuardrailConfigurationWithArn
The [guardrails] to assign to the inline agent.
[1]: docs.aws.amazon.com/bedrock/latest/userguide/guardrails.html
5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 5441 5442 5443 5444 5445 5446 5447 5448 5449 5450 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5425 class InvokeInlineAgentRequest < Struct.new( :action_groups, :agent_collaboration, :agent_name, :bedrock_model_configurations, :collaborator_configurations, :collaborators, :custom_orchestration, :customer_encryption_key_arn, :enable_trace, :end_session, :foundation_model, :guardrail_configuration, :idle_session_ttl_in_seconds, :inline_session_state, :input_text, :instruction, :knowledge_bases, :orchestration_type, :prompt_creation_configurations, :prompt_override_configuration, :session_id, :streaming_configurations) SENSITIVE = [:agent_name, :input_text, :instruction, :prompt_override_configuration] include Aws::Structure end |
#idle_session_ttl_in_seconds ⇒ Integer
The number of seconds for which the inline agent should maintain session information. After this time expires, the subsequent ‘InvokeInlineAgent` request begins a new session.
A user interaction remains active for the amount of time specified. If no conversation occurs during this time, the session expires and the data provided before the timeout is deleted.
5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 5441 5442 5443 5444 5445 5446 5447 5448 5449 5450 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5425 class InvokeInlineAgentRequest < Struct.new( :action_groups, :agent_collaboration, :agent_name, :bedrock_model_configurations, :collaborator_configurations, :collaborators, :custom_orchestration, :customer_encryption_key_arn, :enable_trace, :end_session, :foundation_model, :guardrail_configuration, :idle_session_ttl_in_seconds, :inline_session_state, :input_text, :instruction, :knowledge_bases, :orchestration_type, :prompt_creation_configurations, :prompt_override_configuration, :session_id, :streaming_configurations) SENSITIVE = [:agent_name, :input_text, :instruction, :prompt_override_configuration] include Aws::Structure end |
#inline_session_state ⇒ Types::InlineSessionState
Parameters that specify the various attributes of a sessions. You can include attributes for the session or prompt or, if you configured an action group to return control, results from invocation of the action group. For more information, see [Control session context].
<note markdown=“1”> If you include ‘returnControlInvocationResults` in the `sessionState` field, the `inputText` field will be ignored.
</note>
[1]: docs.aws.amazon.com/bedrock/latest/userguide/agents-session-state.html
5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 5441 5442 5443 5444 5445 5446 5447 5448 5449 5450 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5425 class InvokeInlineAgentRequest < Struct.new( :action_groups, :agent_collaboration, :agent_name, :bedrock_model_configurations, :collaborator_configurations, :collaborators, :custom_orchestration, :customer_encryption_key_arn, :enable_trace, :end_session, :foundation_model, :guardrail_configuration, :idle_session_ttl_in_seconds, :inline_session_state, :input_text, :instruction, :knowledge_bases, :orchestration_type, :prompt_creation_configurations, :prompt_override_configuration, :session_id, :streaming_configurations) SENSITIVE = [:agent_name, :input_text, :instruction, :prompt_override_configuration] include Aws::Structure end |
#input_text ⇒ String
The prompt text to send to the agent.
<note markdown=“1”> If you include ‘returnControlInvocationResults` in the `sessionState` field, the `inputText` field will be ignored.
</note>
5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 5441 5442 5443 5444 5445 5446 5447 5448 5449 5450 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5425 class InvokeInlineAgentRequest < Struct.new( :action_groups, :agent_collaboration, :agent_name, :bedrock_model_configurations, :collaborator_configurations, :collaborators, :custom_orchestration, :customer_encryption_key_arn, :enable_trace, :end_session, :foundation_model, :guardrail_configuration, :idle_session_ttl_in_seconds, :inline_session_state, :input_text, :instruction, :knowledge_bases, :orchestration_type, :prompt_creation_configurations, :prompt_override_configuration, :session_id, :streaming_configurations) SENSITIVE = [:agent_name, :input_text, :instruction, :prompt_override_configuration] include Aws::Structure end |
#instruction ⇒ String
The instructions that tell the inline agent what it should do and how it should interact with users.
5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 5441 5442 5443 5444 5445 5446 5447 5448 5449 5450 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5425 class InvokeInlineAgentRequest < Struct.new( :action_groups, :agent_collaboration, :agent_name, :bedrock_model_configurations, :collaborator_configurations, :collaborators, :custom_orchestration, :customer_encryption_key_arn, :enable_trace, :end_session, :foundation_model, :guardrail_configuration, :idle_session_ttl_in_seconds, :inline_session_state, :input_text, :instruction, :knowledge_bases, :orchestration_type, :prompt_creation_configurations, :prompt_override_configuration, :session_id, :streaming_configurations) SENSITIVE = [:agent_name, :input_text, :instruction, :prompt_override_configuration] include Aws::Structure end |
#knowledge_bases ⇒ Array<Types::KnowledgeBase>
Contains information of the knowledge bases to associate with.
5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 5441 5442 5443 5444 5445 5446 5447 5448 5449 5450 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5425 class InvokeInlineAgentRequest < Struct.new( :action_groups, :agent_collaboration, :agent_name, :bedrock_model_configurations, :collaborator_configurations, :collaborators, :custom_orchestration, :customer_encryption_key_arn, :enable_trace, :end_session, :foundation_model, :guardrail_configuration, :idle_session_ttl_in_seconds, :inline_session_state, :input_text, :instruction, :knowledge_bases, :orchestration_type, :prompt_creation_configurations, :prompt_override_configuration, :session_id, :streaming_configurations) SENSITIVE = [:agent_name, :input_text, :instruction, :prompt_override_configuration] include Aws::Structure end |
#orchestration_type ⇒ String
Specifies the type of orchestration strategy for the agent. This is set to DEFAULT orchestration type, by default.
5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 5441 5442 5443 5444 5445 5446 5447 5448 5449 5450 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5425 class InvokeInlineAgentRequest < Struct.new( :action_groups, :agent_collaboration, :agent_name, :bedrock_model_configurations, :collaborator_configurations, :collaborators, :custom_orchestration, :customer_encryption_key_arn, :enable_trace, :end_session, :foundation_model, :guardrail_configuration, :idle_session_ttl_in_seconds, :inline_session_state, :input_text, :instruction, :knowledge_bases, :orchestration_type, :prompt_creation_configurations, :prompt_override_configuration, :session_id, :streaming_configurations) SENSITIVE = [:agent_name, :input_text, :instruction, :prompt_override_configuration] include Aws::Structure end |
#prompt_creation_configurations ⇒ Types::PromptCreationConfigurations
Specifies parameters that control how the service populates the agent prompt for an ‘InvokeInlineAgent` request. You can control which aspects of previous invocations in the same agent session the service uses to populate the agent prompt. This gives you more granular control over the contextual history that is used to process the current request.
5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 5441 5442 5443 5444 5445 5446 5447 5448 5449 5450 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5425 class InvokeInlineAgentRequest < Struct.new( :action_groups, :agent_collaboration, :agent_name, :bedrock_model_configurations, :collaborator_configurations, :collaborators, :custom_orchestration, :customer_encryption_key_arn, :enable_trace, :end_session, :foundation_model, :guardrail_configuration, :idle_session_ttl_in_seconds, :inline_session_state, :input_text, :instruction, :knowledge_bases, :orchestration_type, :prompt_creation_configurations, :prompt_override_configuration, :session_id, :streaming_configurations) SENSITIVE = [:agent_name, :input_text, :instruction, :prompt_override_configuration] include Aws::Structure end |
#prompt_override_configuration ⇒ Types::PromptOverrideConfiguration
Configurations for advanced prompts used to override the default prompts to enhance the accuracy of the inline agent.
5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 5441 5442 5443 5444 5445 5446 5447 5448 5449 5450 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5425 class InvokeInlineAgentRequest < Struct.new( :action_groups, :agent_collaboration, :agent_name, :bedrock_model_configurations, :collaborator_configurations, :collaborators, :custom_orchestration, :customer_encryption_key_arn, :enable_trace, :end_session, :foundation_model, :guardrail_configuration, :idle_session_ttl_in_seconds, :inline_session_state, :input_text, :instruction, :knowledge_bases, :orchestration_type, :prompt_creation_configurations, :prompt_override_configuration, :session_id, :streaming_configurations) SENSITIVE = [:agent_name, :input_text, :instruction, :prompt_override_configuration] include Aws::Structure end |
#session_id ⇒ String
The unique identifier of the session. Use the same value across requests to continue the same conversation.
5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 5441 5442 5443 5444 5445 5446 5447 5448 5449 5450 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5425 class InvokeInlineAgentRequest < Struct.new( :action_groups, :agent_collaboration, :agent_name, :bedrock_model_configurations, :collaborator_configurations, :collaborators, :custom_orchestration, :customer_encryption_key_arn, :enable_trace, :end_session, :foundation_model, :guardrail_configuration, :idle_session_ttl_in_seconds, :inline_session_state, :input_text, :instruction, :knowledge_bases, :orchestration_type, :prompt_creation_configurations, :prompt_override_configuration, :session_id, :streaming_configurations) SENSITIVE = [:agent_name, :input_text, :instruction, :prompt_override_configuration] include Aws::Structure end |
#streaming_configurations ⇒ Types::StreamingConfigurations
Specifies the configurations for streaming.
<note markdown=“1”> To use agent streaming, you need permissions to perform the ‘bedrock:InvokeModelWithResponseStream` action.
</note>
5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 5441 5442 5443 5444 5445 5446 5447 5448 5449 5450 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5425 class InvokeInlineAgentRequest < Struct.new( :action_groups, :agent_collaboration, :agent_name, :bedrock_model_configurations, :collaborator_configurations, :collaborators, :custom_orchestration, :customer_encryption_key_arn, :enable_trace, :end_session, :foundation_model, :guardrail_configuration, :idle_session_ttl_in_seconds, :inline_session_state, :input_text, :instruction, :knowledge_bases, :orchestration_type, :prompt_creation_configurations, :prompt_override_configuration, :session_id, :streaming_configurations) SENSITIVE = [:agent_name, :input_text, :instruction, :prompt_override_configuration] include Aws::Structure end |