Class: Aws::BedrockAgentRuntime::Types::KnowledgeBase

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Details of the knowledge base associated withe inline agent.

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the knowledge base associated with the inline agent.

Returns:

  • (String)


5498
5499
5500
5501
5502
5503
5504
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5498

class KnowledgeBase < Struct.new(
  :description,
  :knowledge_base_id,
  :retrieval_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#knowledge_base_idString

The unique identifier for a knowledge base associated with the inline agent.

Returns:

  • (String)


5498
5499
5500
5501
5502
5503
5504
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5498

class KnowledgeBase < Struct.new(
  :description,
  :knowledge_base_id,
  :retrieval_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#retrieval_configurationTypes::KnowledgeBaseRetrievalConfiguration

The configurations to apply to the knowledge base during query. For more information, see [Query configurations].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/kb-test-config.html



5498
5499
5500
5501
5502
5503
5504
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5498

class KnowledgeBase < Struct.new(
  :description,
  :knowledge_base_id,
  :retrieval_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end