Class: Aws::BedrockAgentRuntime::Types::KnowledgeBaseConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Configurations to apply to a knowledge base attached to the agent during query. For more information, see Knowledge base retrieval configurations.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#knowledge_base_idString

The unique identifier for a knowledge base attached to the agent.

Returns:

  • (String)


5993
5994
5995
5996
5997
5998
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5993

class KnowledgeBaseConfiguration < Struct.new(
  :knowledge_base_id,
  :retrieval_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#retrieval_configurationTypes::KnowledgeBaseRetrievalConfiguration

The configurations to apply to the knowledge base during query. For more information, see Query configurations.



5993
5994
5995
5996
5997
5998
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5993

class KnowledgeBaseConfiguration < Struct.new(
  :knowledge_base_id,
  :retrieval_configuration)
  SENSITIVE = []
  include Aws::Structure
end