Class: Aws::BedrockAgentRuntime::Types::KnowledgeBaseQuery

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains the query made to the knowledge base.

This data type is used in the following API operations:

  • Retrieve request][1

    – in the retrievalQuery field

^

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_Retrieve.html#API_agent-runtime_Retrieve_RequestSyntax

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#textString

The text of the query made to the knowledge base.

Returns:

  • (String)


3172
3173
3174
3175
3176
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3172

class KnowledgeBaseQuery < Struct.new(
  :text)
  SENSITIVE = []
  include Aws::Structure
end