Class: Aws::BedrockAgentRuntime::Types::KnowledgeBaseRetrievalConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains configurations for knowledge base query. For more information, see [Query configurations].

This data type is used in the following API operations:

  • Retrieve request][2

    – in the retrievalConfiguration field

  • RetrieveAndGenerate request][3

    – in the retrievalConfiguration

    field

[1]: docs.aws.amazon.com/bedrock/latest/userguide/kb-test-config.html [2]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_Retrieve.html#API_agent-runtime_Retrieve_RequestSyntax [3]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_RetrieveAndGenerate.html#API_agent-runtime_RetrieveAndGenerate_RequestSyntax

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#vector_search_configurationTypes::KnowledgeBaseVectorSearchConfiguration

Contains details about how the results from the vector search should be returned. For more information, see [Query configurations].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/kb-test-config.html



3205
3206
3207
3208
3209
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3205

class KnowledgeBaseRetrievalConfiguration < Struct.new(
  :vector_search_configuration)
  SENSITIVE = []
  include Aws::Structure
end