Class: Aws::BedrockAgentRuntime::Types::KnowledgeBaseRetrievalResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Details about a result from querying the knowledge base.

This data type is used in the following API operations:

  • Retrieve response][1

    – in the ‘retrievalResults` field

^

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_Retrieve.html#API_agent-runtime_Retrieve_ResponseSyntax

Constant Summary collapse

SENSITIVE =
[:content, :location, :metadata]

Instance Attribute Summary collapse

Instance Attribute Details

#contentTypes::RetrievalResultContent

Contains information about the content of the chunk.



5694
5695
5696
5697
5698
5699
5700
5701
5702
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5694

class KnowledgeBaseRetrievalResult < Struct.new(
  :content,
  :document_id,
  :location,
  :metadata,
  :score)
  SENSITIVE = [:content, :location, :metadata]
  include Aws::Structure
end

#document_idString

The unique identifier of the document. Use with ‘GetDocumentContent` to retrieve the full document.

Returns:

  • (String)


5694
5695
5696
5697
5698
5699
5700
5701
5702
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5694

class KnowledgeBaseRetrievalResult < Struct.new(
  :content,
  :document_id,
  :location,
  :metadata,
  :score)
  SENSITIVE = [:content, :location, :metadata]
  include Aws::Structure
end

#locationTypes::RetrievalResultLocation

Contains information about the location of the data source.



5694
5695
5696
5697
5698
5699
5700
5701
5702
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5694

class KnowledgeBaseRetrievalResult < Struct.new(
  :content,
  :document_id,
  :location,
  :metadata,
  :score)
  SENSITIVE = [:content, :location, :metadata]
  include Aws::Structure
end

#metadataHash<String,Hash,Array,String,Numeric,Boolean>

Contains metadata attributes and their values for the file in the data source. For more information, see [Metadata and filtering].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/knowledge-base-ds.html#kb-ds-metadata

Returns:

  • (Hash<String,Hash,Array,String,Numeric,Boolean>)


5694
5695
5696
5697
5698
5699
5700
5701
5702
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5694

class KnowledgeBaseRetrievalResult < Struct.new(
  :content,
  :document_id,
  :location,
  :metadata,
  :score)
  SENSITIVE = [:content, :location, :metadata]
  include Aws::Structure
end

#scoreFloat

The level of relevance of the result to the query.

Returns:

  • (Float)


5694
5695
5696
5697
5698
5699
5700
5701
5702
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5694

class KnowledgeBaseRetrievalResult < Struct.new(
  :content,
  :document_id,
  :location,
  :metadata,
  :score)
  SENSITIVE = [:content, :location, :metadata]
  include Aws::Structure
end