Class: Aws::BedrockAgentRuntime::Types::ListFlowExecutionEventsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#flow_execution_eventsArray<Types::FlowExecutionEvent>

A list of events that occurred during the flow execution. Events can include node inputs and outputs, flow inputs and outputs, condition results, and failure events.

Returns:



6367
6368
6369
6370
6371
6372
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6367

class ListFlowExecutionEventsResponse < Struct.new(
  :flow_execution_events,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token to retrieve the next set of results. This value is returned if more results are available.

Returns:



6367
6368
6369
6370
6371
6372
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6367

class ListFlowExecutionEventsResponse < Struct.new(
  :flow_execution_events,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end