Class: Aws::BedrockAgentRuntime::Types::ListInvocationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of results to return in the response. If the total number of results is greater than this value, use the token returned in the response in the nextToken field when making another request to return the next batch of results.

Returns:

  • (Integer)


6504
6505
6506
6507
6508
6509
6510
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6504

class ListInvocationsRequest < Struct.new(
  :max_results,
  :next_token,
  :session_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the total number of results is greater than the maxResults value provided in the request, enter the token returned in the nextToken field in the response in this field to return the next batch of results.

Returns:

  • (String)


6504
6505
6506
6507
6508
6509
6510
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6504

class ListInvocationsRequest < Struct.new(
  :max_results,
  :next_token,
  :session_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#session_identifierString

The unique identifier for the session to list invocations for. You can specify either the session's sessionId or its Amazon Resource Name (ARN).

Returns:

  • (String)


6504
6505
6506
6507
6508
6509
6510
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6504

class ListInvocationsRequest < Struct.new(
  :max_results,
  :next_token,
  :session_identifier)
  SENSITIVE = []
  include Aws::Structure
end