Class: Aws::BedrockAgentRuntime::Types::ListSessionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::ListSessionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return in the response.
-
#next_token ⇒ String
If the total number of results is greater than the
maxResultsvalue provided in the request, enter the token returned in thenextTokenfield in the response in this field to return the next batch of results.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return in the response. If the
total number of results is greater than this value, use the token
returned in the response in the nextToken field when making
another request to return the next batch of results.
6548 6549 6550 6551 6552 6553 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6548 class ListSessionsRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the total number of results is greater than the maxResults
value provided in the request, enter the token returned in the
nextToken field in the response in this field to return the next
batch of results.
6548 6549 6550 6551 6552 6553 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6548 class ListSessionsRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |