Class: Aws::BedrockAgentRuntime::Types::ListSessionsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

If the total number of results is greater than the maxResults value provided in the request, use this token when making another request in the nextToken field to return the next batch of results.

Returns:

  • (String)


6569
6570
6571
6572
6573
6574
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6569

class ListSessionsResponse < Struct.new(
  :next_token,
  :session_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#session_summariesArray<Types::SessionSummary>

A list of summaries for each session in your Amazon Web Services account.

Returns:



6569
6570
6571
6572
6573
6574
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6569

class ListSessionsResponse < Struct.new(
  :next_token,
  :session_summaries)
  SENSITIVE = []
  include Aws::Structure
end