Class: Aws::BedrockAgentRuntime::Types::Memory
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::Memory
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Note:
Memory is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of Memory corresponding to the set member.
Contains sessions summaries.
Direct Known Subclasses
Defined Under Namespace
Classes: SessionSummary, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#session_summary ⇒ Types::MemorySessionSummary
Contains summary of a session.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#session_summary ⇒ Types::MemorySessionSummary
Contains summary of a session.
6259 6260 6261 6262 6263 6264 6265 6266 6267 6268 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6259 class Memory < Struct.new( :session_summary, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class SessionSummary < Memory; end class Unknown < Memory; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
6259 6260 6261 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6259 def unknown @unknown end |