Class: Aws::BedrockAgentRuntime::Types::MemorySessionSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::MemorySessionSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains details of a session summary.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#memory_id ⇒ String
The unique identifier of the memory where the session summary is stored.
-
#session_expiry_time ⇒ Time
The time when the memory duration for the session is set to end.
-
#session_id ⇒ String
The identifier for this session.
-
#session_start_time ⇒ Time
The start time for this session.
-
#summary_text ⇒ String
The summarized text for this session.
Instance Attribute Details
#memory_id ⇒ String
The unique identifier of the memory where the session summary is stored.
6295 6296 6297 6298 6299 6300 6301 6302 6303 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6295 class MemorySessionSummary < Struct.new( :memory_id, :session_expiry_time, :session_id, :session_start_time, :summary_text) SENSITIVE = [] include Aws::Structure end |
#session_expiry_time ⇒ Time
The time when the memory duration for the session is set to end.
6295 6296 6297 6298 6299 6300 6301 6302 6303 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6295 class MemorySessionSummary < Struct.new( :memory_id, :session_expiry_time, :session_id, :session_start_time, :summary_text) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
The identifier for this session.
6295 6296 6297 6298 6299 6300 6301 6302 6303 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6295 class MemorySessionSummary < Struct.new( :memory_id, :session_expiry_time, :session_id, :session_start_time, :summary_text) SENSITIVE = [] include Aws::Structure end |
#session_start_time ⇒ Time
The start time for this session.
6295 6296 6297 6298 6299 6300 6301 6302 6303 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6295 class MemorySessionSummary < Struct.new( :memory_id, :session_expiry_time, :session_id, :session_start_time, :summary_text) SENSITIVE = [] include Aws::Structure end |
#summary_text ⇒ String
The summarized text for this session.
6295 6296 6297 6298 6299 6300 6301 6302 6303 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6295 class MemorySessionSummary < Struct.new( :memory_id, :session_expiry_time, :session_id, :session_start_time, :summary_text) SENSITIVE = [] include Aws::Structure end |