Class: Aws::BedrockAgentRuntime::Types::Metadata

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Provides information about the execution process for different types of invocations, such as model invocation, knowledge base invocation, agent collaborator invocation, guardrail invocation, and code interpreter Invocation.

Constant Summary collapse

SENSITIVE =
[:usage]

Instance Attribute Summary collapse

Instance Attribute Details

#client_request_idString

A unique identifier associated with the downstream invocation. This ID can be used for tracing, debugging, and identifying specific invocations in customer logs or systems.

Returns:

  • (String)


6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6813

class Metadata < Struct.new(
  :client_request_id,
  :end_time,
  :operation_total_time_ms,
  :start_time,
  :total_time_ms,
  :usage)
  SENSITIVE = [:usage]
  include Aws::Structure
end

#end_timeTime

In the final response, endTime is the end time of the agent invocation operation.

Returns:

  • (Time)


6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6813

class Metadata < Struct.new(
  :client_request_id,
  :end_time,
  :operation_total_time_ms,
  :start_time,
  :total_time_ms,
  :usage)
  SENSITIVE = [:usage]
  include Aws::Structure
end

#operation_total_time_msInteger

The total time it took for the agent to complete execution. This field is only set for the final response.

Returns:

  • (Integer)


6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6813

class Metadata < Struct.new(
  :client_request_id,
  :end_time,
  :operation_total_time_ms,
  :start_time,
  :total_time_ms,
  :usage)
  SENSITIVE = [:usage]
  include Aws::Structure
end

#start_timeTime

In the final response, startTime is the start time of the agent invocation operation.

Returns:

  • (Time)


6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6813

class Metadata < Struct.new(
  :client_request_id,
  :end_time,
  :operation_total_time_ms,
  :start_time,
  :total_time_ms,
  :usage)
  SENSITIVE = [:usage]
  include Aws::Structure
end

#total_time_msInteger

The total execution time for the specific invocation being processed (model, knowledge base, guardrail, agent collaborator, or code interpreter). It represents how long the individual invocation took.

Returns:

  • (Integer)


6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6813

class Metadata < Struct.new(
  :client_request_id,
  :end_time,
  :operation_total_time_ms,
  :start_time,
  :total_time_ms,
  :usage)
  SENSITIVE = [:usage]
  include Aws::Structure
end

#usageTypes::Usage

Specific to model invocation and contains details about the usage of a foundation model.

Returns:



6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6813

class Metadata < Struct.new(
  :client_request_id,
  :end_time,
  :operation_total_time_ms,
  :start_time,
  :total_time_ms,
  :usage)
  SENSITIVE = [:usage]
  include Aws::Structure
end