Class: Aws::BedrockAgentRuntime::Types::ModelInvocationInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

The input for the pre-processing step.

  • The type matches the agent step.

  • The text contains the prompt.

  • The inferenceConfiguration, parserMode, and overrideLambda values are set in the PromptOverrideConfiguration object that was set when the agent was created or updated.

Constant Summary collapse

SENSITIVE =
[:text]

Instance Attribute Summary collapse

Instance Attribute Details

#foundation_modelString

The identifier of a foundation model.

Returns:

  • (String)


6661
6662
6663
6664
6665
6666
6667
6668
6669
6670
6671
6672
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6661

class ModelInvocationInput < Struct.new(
  :foundation_model,
  :inference_configuration,
  :override_lambda,
  :parser_mode,
  :prompt_creation_mode,
  :text,
  :trace_id,
  :type)
  SENSITIVE = [:text]
  include Aws::Structure
end

#inference_configurationTypes::InferenceConfiguration

Specifications about the inference parameters that were provided alongside the prompt. These are specified in the PromptOverrideConfiguration object that was set when the agent was created or updated. For more information, see Inference parameters for foundation models.



6661
6662
6663
6664
6665
6666
6667
6668
6669
6670
6671
6672
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6661

class ModelInvocationInput < Struct.new(
  :foundation_model,
  :inference_configuration,
  :override_lambda,
  :parser_mode,
  :prompt_creation_mode,
  :text,
  :trace_id,
  :type)
  SENSITIVE = [:text]
  include Aws::Structure
end

#override_lambdaString

The ARN of the Lambda function to use when parsing the raw foundation model output in parts of the agent sequence.

Returns:

  • (String)


6661
6662
6663
6664
6665
6666
6667
6668
6669
6670
6671
6672
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6661

class ModelInvocationInput < Struct.new(
  :foundation_model,
  :inference_configuration,
  :override_lambda,
  :parser_mode,
  :prompt_creation_mode,
  :text,
  :trace_id,
  :type)
  SENSITIVE = [:text]
  include Aws::Structure
end

#parser_modeString

Specifies whether to override the default parser Lambda function when parsing the raw foundation model output in the part of the agent sequence defined by the promptType.

Returns:

  • (String)


6661
6662
6663
6664
6665
6666
6667
6668
6669
6670
6671
6672
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6661

class ModelInvocationInput < Struct.new(
  :foundation_model,
  :inference_configuration,
  :override_lambda,
  :parser_mode,
  :prompt_creation_mode,
  :text,
  :trace_id,
  :type)
  SENSITIVE = [:text]
  include Aws::Structure
end

#prompt_creation_modeString

Specifies whether the default prompt template was OVERRIDDEN. If it was, the basePromptTemplate that was set in the PromptOverrideConfiguration object when the agent was created or updated is used instead.

Returns:

  • (String)


6661
6662
6663
6664
6665
6666
6667
6668
6669
6670
6671
6672
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6661

class ModelInvocationInput < Struct.new(
  :foundation_model,
  :inference_configuration,
  :override_lambda,
  :parser_mode,
  :prompt_creation_mode,
  :text,
  :trace_id,
  :type)
  SENSITIVE = [:text]
  include Aws::Structure
end

#textString

The text that prompted the agent at this step.

Returns:

  • (String)


6661
6662
6663
6664
6665
6666
6667
6668
6669
6670
6671
6672
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6661

class ModelInvocationInput < Struct.new(
  :foundation_model,
  :inference_configuration,
  :override_lambda,
  :parser_mode,
  :prompt_creation_mode,
  :text,
  :trace_id,
  :type)
  SENSITIVE = [:text]
  include Aws::Structure
end

#trace_idString

The unique identifier of the trace.

Returns:

  • (String)


6661
6662
6663
6664
6665
6666
6667
6668
6669
6670
6671
6672
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6661

class ModelInvocationInput < Struct.new(
  :foundation_model,
  :inference_configuration,
  :override_lambda,
  :parser_mode,
  :prompt_creation_mode,
  :text,
  :trace_id,
  :type)
  SENSITIVE = [:text]
  include Aws::Structure
end

#typeString

The step in the agent sequence.

Returns:

  • (String)


6661
6662
6663
6664
6665
6666
6667
6668
6669
6670
6671
6672
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6661

class ModelInvocationInput < Struct.new(
  :foundation_model,
  :inference_configuration,
  :override_lambda,
  :parser_mode,
  :prompt_creation_mode,
  :text,
  :trace_id,
  :type)
  SENSITIVE = [:text]
  include Aws::Structure
end