Class: Aws::BedrockAgentRuntime::Types::ModelNotReadyException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

The model specified in the request is not ready to serve inference requests. The AWS SDK will automatically retry the operation up to 5 times. For information about configuring automatic retries, see Retry behavior in the AWS SDKs and Tools reference guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#event_typeObject

Returns the value of attribute event_type

Returns:

  • (Object)

    the current value of event_type



6688
6689
6690
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6688

def event_type
  @event_type
end

#messageString

Returns:

  • (String)


6688
6689
6690
6691
6692
6693
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6688

class ModelNotReadyException < Struct.new(
  :message,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end