Class: Aws::BedrockAgentRuntime::Types::NodeActionEvent

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains information about an action (operation) called by a node during execution.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#node_nameString

The name of the node that called the operation.

Returns:

  • (String)


6568
6569
6570
6571
6572
6573
6574
6575
6576
6577
6578
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6568

class NodeActionEvent < Struct.new(
  :node_name,
  :operation_name,
  :operation_request,
  :operation_response,
  :request_id,
  :service_name,
  :timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#operation_nameString

The name of the operation that the node called.

Returns:

  • (String)


6568
6569
6570
6571
6572
6573
6574
6575
6576
6577
6578
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6568

class NodeActionEvent < Struct.new(
  :node_name,
  :operation_name,
  :operation_request,
  :operation_response,
  :request_id,
  :service_name,
  :timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#operation_requestHash, ...

The request payload sent to the downstream service.

Returns:

  • (Hash, Array, String, Numeric, Boolean)


6568
6569
6570
6571
6572
6573
6574
6575
6576
6577
6578
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6568

class NodeActionEvent < Struct.new(
  :node_name,
  :operation_name,
  :operation_request,
  :operation_response,
  :request_id,
  :service_name,
  :timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#operation_responseHash, ...

The response payload received from the downstream service.

Returns:

  • (Hash, Array, String, Numeric, Boolean)


6568
6569
6570
6571
6572
6573
6574
6575
6576
6577
6578
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6568

class NodeActionEvent < Struct.new(
  :node_name,
  :operation_name,
  :operation_request,
  :operation_response,
  :request_id,
  :service_name,
  :timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#request_idString

The ID of the request that the node made to the operation.

Returns:

  • (String)


6568
6569
6570
6571
6572
6573
6574
6575
6576
6577
6578
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6568

class NodeActionEvent < Struct.new(
  :node_name,
  :operation_name,
  :operation_request,
  :operation_response,
  :request_id,
  :service_name,
  :timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#service_nameString

The name of the service that the node called.

Returns:

  • (String)


6568
6569
6570
6571
6572
6573
6574
6575
6576
6577
6578
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6568

class NodeActionEvent < Struct.new(
  :node_name,
  :operation_name,
  :operation_request,
  :operation_response,
  :request_id,
  :service_name,
  :timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#timestampTime

The date and time that the operation was called.

Returns:

  • (Time)


6568
6569
6570
6571
6572
6573
6574
6575
6576
6577
6578
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6568

class NodeActionEvent < Struct.new(
  :node_name,
  :operation_name,
  :operation_request,
  :operation_response,
  :request_id,
  :service_name,
  :timestamp)
  SENSITIVE = []
  include Aws::Structure
end