Class: Aws::BedrockAgentRuntime::Types::NodeExecutionContent
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::NodeExecutionContent
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Note:
NodeExecutionContent is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of NodeExecutionContent corresponding to the set member.
Contains the content of a flow node’s input or output field for a flow execution.
<note markdown=“1”> Flow executions is in preview release for Amazon Bedrock and is subject to change.
</note>
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#document ⇒ Hash, ...
The document content of the field, which can contain text or structured data.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#document ⇒ Hash, ...
The document content of the field, which can contain text or structured data.
6623 6624 6625 6626 6627 6628 6629 6630 6631 6632 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6623 class NodeExecutionContent < Struct.new( :document, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Document < NodeExecutionContent; end class Unknown < NodeExecutionContent; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
6623 6624 6625 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6623 def unknown @unknown end |