Class: Aws::BedrockAgentRuntime::Types::NodeInputEvent
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::NodeInputEvent
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains information about the inputs provided to a specific node during a flow execution.
Constant Summary collapse
- SENSITIVE =
[:fields]
Instance Attribute Summary collapse
-
#fields ⇒ Array<Types::NodeInputField>
A list of input fields provided to the node.
-
#node_name ⇒ String
The name of the node that received the inputs.
-
#timestamp ⇒ Time
The timestamp when the inputs were provided to the node.
Instance Attribute Details
#fields ⇒ Array<Types::NodeInputField>
A list of input fields provided to the node.
7142 7143 7144 7145 7146 7147 7148 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7142 class NodeInputEvent < Struct.new( :fields, :node_name, :timestamp) SENSITIVE = [:fields] include Aws::Structure end |
#node_name ⇒ String
The name of the node that received the inputs.
7142 7143 7144 7145 7146 7147 7148 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7142 class NodeInputEvent < Struct.new( :fields, :node_name, :timestamp) SENSITIVE = [:fields] include Aws::Structure end |
#timestamp ⇒ Time
The timestamp when the inputs were provided to the node.
7142 7143 7144 7145 7146 7147 7148 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7142 class NodeInputEvent < Struct.new( :fields, :node_name, :timestamp) SENSITIVE = [:fields] include Aws::Structure end |