Class: Aws::BedrockAgentRuntime::Types::NodeInputField

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Represents an input field provided to a node during a flow execution.

Constant Summary collapse

SENSITIVE =
[:content]

Instance Attribute Summary collapse

Instance Attribute Details

#categoryString

The category of the input field.

Returns:

  • (String)


6754
6755
6756
6757
6758
6759
6760
6761
6762
6763
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6754

class NodeInputField < Struct.new(
  :category,
  :content,
  :execution_chain,
  :name,
  :source,
  :type)
  SENSITIVE = [:content]
  include Aws::Structure
end

#contentTypes::NodeExecutionContent

The content of the input field, which can contain text or structured data.



6754
6755
6756
6757
6758
6759
6760
6761
6762
6763
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6754

class NodeInputField < Struct.new(
  :category,
  :content,
  :execution_chain,
  :name,
  :source,
  :type)
  SENSITIVE = [:content]
  include Aws::Structure
end

#execution_chainArray<Types::NodeInputExecutionChainItem>

The execution path through nested nodes like iterators and loops.



6754
6755
6756
6757
6758
6759
6760
6761
6762
6763
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6754

class NodeInputField < Struct.new(
  :category,
  :content,
  :execution_chain,
  :name,
  :source,
  :type)
  SENSITIVE = [:content]
  include Aws::Structure
end

#nameString

The name of the input field as defined in the node’s input schema.

Returns:

  • (String)


6754
6755
6756
6757
6758
6759
6760
6761
6762
6763
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6754

class NodeInputField < Struct.new(
  :category,
  :content,
  :execution_chain,
  :name,
  :source,
  :type)
  SENSITIVE = [:content]
  include Aws::Structure
end

#sourceTypes::NodeInputSource

The source node that provides input data to this field.



6754
6755
6756
6757
6758
6759
6760
6761
6762
6763
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6754

class NodeInputField < Struct.new(
  :category,
  :content,
  :execution_chain,
  :name,
  :source,
  :type)
  SENSITIVE = [:content]
  include Aws::Structure
end

#typeString

The data type of the input field for compatibility validation.

Returns:

  • (String)


6754
6755
6756
6757
6758
6759
6760
6761
6762
6763
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6754

class NodeInputField < Struct.new(
  :category,
  :content,
  :execution_chain,
  :name,
  :source,
  :type)
  SENSITIVE = [:content]
  include Aws::Structure
end