Class: Aws::BedrockAgentRuntime::Types::NodeOutputEvent
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::NodeOutputEvent
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains information about the outputs produced by a specific node during a flow execution.
<note markdown=“1”> Flow executions is in preview release for Amazon Bedrock and is subject to change.
</note>
Constant Summary collapse
- SENSITIVE =
[:fields]
Instance Attribute Summary collapse
-
#fields ⇒ Array<Types::NodeOutputField>
A list of output fields produced by the node.
-
#node_name ⇒ String
The name of the node that produced the outputs.
-
#timestamp ⇒ Time
The timestamp when the outputs were produced by the node.
Instance Attribute Details
#fields ⇒ Array<Types::NodeOutputField>
A list of output fields produced by the node.
6811 6812 6813 6814 6815 6816 6817 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6811 class NodeOutputEvent < Struct.new( :fields, :node_name, :timestamp) SENSITIVE = [:fields] include Aws::Structure end |
#node_name ⇒ String
The name of the node that produced the outputs.
6811 6812 6813 6814 6815 6816 6817 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6811 class NodeOutputEvent < Struct.new( :fields, :node_name, :timestamp) SENSITIVE = [:fields] include Aws::Structure end |
#timestamp ⇒ Time
The timestamp when the outputs were produced by the node.
6811 6812 6813 6814 6815 6816 6817 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6811 class NodeOutputEvent < Struct.new( :fields, :node_name, :timestamp) SENSITIVE = [:fields] include Aws::Structure end |