Class: Aws::BedrockAgentRuntime::Types::NodeOutputField
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::NodeOutputField
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Represents an output field produced by a node during a flow execution.
Constant Summary collapse
- SENSITIVE =
[:content, :next]
Instance Attribute Summary collapse
-
#content ⇒ Types::NodeExecutionContent
The content of the output field, which can contain text or structured data.
-
#name ⇒ String
The name of the output field as defined in the node's output schema.
-
#next ⇒ Array<Types::NodeOutputNext>
The next node that receives output data from this field.
-
#type ⇒ String
The data type of the output field for compatibility validation.
Instance Attribute Details
#content ⇒ Types::NodeExecutionContent
The content of the output field, which can contain text or structured data.
7020 7021 7022 7023 7024 7025 7026 7027 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7020 class NodeOutputField < Struct.new( :content, :name, :next, :type) SENSITIVE = [:content, :next] include Aws::Structure end |
#name ⇒ String
The name of the output field as defined in the node's output schema.
7020 7021 7022 7023 7024 7025 7026 7027 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7020 class NodeOutputField < Struct.new( :content, :name, :next, :type) SENSITIVE = [:content, :next] include Aws::Structure end |
#next ⇒ Array<Types::NodeOutputNext>
The next node that receives output data from this field.
7020 7021 7022 7023 7024 7025 7026 7027 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7020 class NodeOutputField < Struct.new( :content, :name, :next, :type) SENSITIVE = [:content, :next] include Aws::Structure end |
#type ⇒ String
The data type of the output field for compatibility validation.
7020 7021 7022 7023 7024 7025 7026 7027 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7020 class NodeOutputField < Struct.new( :content, :name, :next, :type) SENSITIVE = [:content, :next] include Aws::Structure end |