Class: Aws::BedrockAgentRuntime::Types::NodeOutputNext
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::NodeOutputNext
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Represents the next node that receives output data.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#input_field_name ⇒ String
The name of the input field in the next node that receives the data.
-
#node_name ⇒ String
The name of the next node that receives the output data.
Instance Attribute Details
#input_field_name ⇒ String
The name of the input field in the next node that receives the data.
7041 7042 7043 7044 7045 7046 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7041 class NodeOutputNext < Struct.new( :input_field_name, :node_name) SENSITIVE = [] include Aws::Structure end |
#node_name ⇒ String
The name of the next node that receives the output data.
7041 7042 7043 7044 7045 7046 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7041 class NodeOutputNext < Struct.new( :input_field_name, :node_name) SENSITIVE = [] include Aws::Structure end |