Class: Aws::BedrockAgentRuntime::Types::NodeTraceElements
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::NodeTraceElements
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Note:
NodeTraceElements is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of NodeTraceElements corresponding to the set member.
Contains trace elements for node execution tracking.
Defined Under Namespace
Classes: AgentTraces, Unknown
Constant Summary collapse
- SENSITIVE =
[:agent_traces]
Instance Attribute Summary collapse
-
#agent_traces ⇒ Array<Types::TracePart>
Agent trace information for the node execution.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#agent_traces ⇒ Array<Types::TracePart>
Agent trace information for the node execution.
7058 7059 7060 7061 7062 7063 7064 7065 7066 7067 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7058 class NodeTraceElements < Struct.new( :agent_traces, :unknown) SENSITIVE = [:agent_traces] include Aws::Structure include Aws::Structure::Union class AgentTraces < NodeTraceElements; end class Unknown < NodeTraceElements; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
7058 7059 7060 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7058 def unknown @unknown end |