Class: Aws::BedrockAgentRuntime::Types::Observation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains the result or output of an action group or knowledge base, or the response to the user.

Constant Summary collapse

SENSITIVE =
[:reprompt_response]

Instance Attribute Summary collapse

Instance Attribute Details

#action_group_invocation_outputTypes::ActionGroupInvocationOutput

Contains the JSON-formatted string returned by the API invoked by the action group.



6063
6064
6065
6066
6067
6068
6069
6070
6071
6072
6073
6074
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6063

class Observation < Struct.new(
  :action_group_invocation_output,
  :agent_collaborator_invocation_output,
  :code_interpreter_invocation_output,
  :final_response,
  :knowledge_base_lookup_output,
  :reprompt_response,
  :trace_id,
  :type)
  SENSITIVE = [:reprompt_response]
  include Aws::Structure
end

#agent_collaborator_invocation_outputTypes::AgentCollaboratorInvocationOutput

A collaborator’s invocation output.



6063
6064
6065
6066
6067
6068
6069
6070
6071
6072
6073
6074
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6063

class Observation < Struct.new(
  :action_group_invocation_output,
  :agent_collaborator_invocation_output,
  :code_interpreter_invocation_output,
  :final_response,
  :knowledge_base_lookup_output,
  :reprompt_response,
  :trace_id,
  :type)
  SENSITIVE = [:reprompt_response]
  include Aws::Structure
end

#code_interpreter_invocation_outputTypes::CodeInterpreterInvocationOutput

Contains the JSON-formatted string returned by the API invoked by the code interpreter.



6063
6064
6065
6066
6067
6068
6069
6070
6071
6072
6073
6074
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6063

class Observation < Struct.new(
  :action_group_invocation_output,
  :agent_collaborator_invocation_output,
  :code_interpreter_invocation_output,
  :final_response,
  :knowledge_base_lookup_output,
  :reprompt_response,
  :trace_id,
  :type)
  SENSITIVE = [:reprompt_response]
  include Aws::Structure
end

#final_responseTypes::FinalResponse

Contains details about the response to the user.



6063
6064
6065
6066
6067
6068
6069
6070
6071
6072
6073
6074
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6063

class Observation < Struct.new(
  :action_group_invocation_output,
  :agent_collaborator_invocation_output,
  :code_interpreter_invocation_output,
  :final_response,
  :knowledge_base_lookup_output,
  :reprompt_response,
  :trace_id,
  :type)
  SENSITIVE = [:reprompt_response]
  include Aws::Structure
end

#knowledge_base_lookup_outputTypes::KnowledgeBaseLookupOutput

Contains details about the results from looking up the knowledge base.



6063
6064
6065
6066
6067
6068
6069
6070
6071
6072
6073
6074
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6063

class Observation < Struct.new(
  :action_group_invocation_output,
  :agent_collaborator_invocation_output,
  :code_interpreter_invocation_output,
  :final_response,
  :knowledge_base_lookup_output,
  :reprompt_response,
  :trace_id,
  :type)
  SENSITIVE = [:reprompt_response]
  include Aws::Structure
end

#reprompt_responseTypes::RepromptResponse

Contains details about the response to reprompt the input.



6063
6064
6065
6066
6067
6068
6069
6070
6071
6072
6073
6074
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6063

class Observation < Struct.new(
  :action_group_invocation_output,
  :agent_collaborator_invocation_output,
  :code_interpreter_invocation_output,
  :final_response,
  :knowledge_base_lookup_output,
  :reprompt_response,
  :trace_id,
  :type)
  SENSITIVE = [:reprompt_response]
  include Aws::Structure
end

#trace_idString

The unique identifier of the trace.

Returns:

  • (String)


6063
6064
6065
6066
6067
6068
6069
6070
6071
6072
6073
6074
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6063

class Observation < Struct.new(
  :action_group_invocation_output,
  :agent_collaborator_invocation_output,
  :code_interpreter_invocation_output,
  :final_response,
  :knowledge_base_lookup_output,
  :reprompt_response,
  :trace_id,
  :type)
  SENSITIVE = [:reprompt_response]
  include Aws::Structure
end

#typeString

Specifies what kind of information the agent returns in the observation. The following values are possible.

  • ‘ACTION_GROUP` – The agent returns the result of an action group.

  • ‘KNOWLEDGE_BASE` – The agent returns information from a knowledge base.

  • ‘FINISH` – The agent returns a final response to the user with no follow-up.

  • ‘ASK_USER` – The agent asks the user a question.

  • ‘REPROMPT` – The agent prompts the user again for the same information.

Returns:

  • (String)


6063
6064
6065
6066
6067
6068
6069
6070
6071
6072
6073
6074
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6063

class Observation < Struct.new(
  :action_group_invocation_output,
  :agent_collaborator_invocation_output,
  :code_interpreter_invocation_output,
  :final_response,
  :knowledge_base_lookup_output,
  :reprompt_response,
  :trace_id,
  :type)
  SENSITIVE = [:reprompt_response]
  include Aws::Structure
end