Class: Aws::BedrockAgentRuntime::Types::OptimizePromptRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::OptimizePromptRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#input ⇒ Types::InputPrompt
Contains the prompt to optimize.
-
#target_model_id ⇒ String
The unique identifier of the model that you want to optimize the prompt for.
Instance Attribute Details
#input ⇒ Types::InputPrompt
Contains the prompt to optimize.
3708 3709 3710 3711 3712 3713 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3708 class OptimizePromptRequest < Struct.new( :input, :target_model_id) SENSITIVE = [] include Aws::Structure end |
#target_model_id ⇒ String
The unique identifier of the model that you want to optimize the prompt for.
3708 3709 3710 3711 3712 3713 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3708 class OptimizePromptRequest < Struct.new( :input, :target_model_id) SENSITIVE = [] include Aws::Structure end |