Class: Aws::BedrockAgentRuntime::Types::OptimizedPromptStream

Inherits:
Enumerator
  • Object
show all
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

The stream containing events in the prompt optimization process.

EventStream is an Enumerator of Events. #event_types #=> Array, returns all modeled event types in the stream

Instance Method Summary collapse

Instance Method Details

#event_typesObject



10743
10744
10745
10746
10747
10748
10749
10750
10751
10752
10753
10754
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10743

def event_types
  [
    :access_denied_exception,
    :analyze_prompt_event,
    :bad_gateway_exception,
    :dependency_failed_exception,
    :internal_server_exception,
    :optimized_prompt_event,
    :throttling_exception,
    :validation_exception
  ]
end