Class: Aws::BedrockAgentRuntime::Types::OrchestrationConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::OrchestrationConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Settings for how the model processes the prompt prior to retrieval and generation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_model_request_fields ⇒ Hash<String,Hash,Array,String,Numeric,Boolean>
Additional model parameters and corresponding values not included in the textInferenceConfig structure for a knowledge base.
-
#inference_config ⇒ Types::InferenceConfig
Configuration settings for inference when using RetrieveAndGenerate to generate responses while using a knowledge base as a source.
-
#performance_config ⇒ Types::PerformanceConfiguration
The latency configuration for the model.
-
#prompt_template ⇒ Types::PromptTemplate
Contains the template for the prompt that’s sent to the model.
-
#query_transformation_configuration ⇒ Types::QueryTransformationConfiguration
To split up the prompt and retrieve multiple sources, set the transformation type to ‘QUERY_DECOMPOSITION`.
Instance Attribute Details
#additional_model_request_fields ⇒ Hash<String,Hash,Array,String,Numeric,Boolean>
Additional model parameters and corresponding values not included in the textInferenceConfig structure for a knowledge base. This allows users to provide custom model parameters specific to the language model being used.
6180 6181 6182 6183 6184 6185 6186 6187 6188 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6180 class OrchestrationConfiguration < Struct.new( :additional_model_request_fields, :inference_config, :performance_config, :prompt_template, :query_transformation_configuration) SENSITIVE = [] include Aws::Structure end |
#inference_config ⇒ Types::InferenceConfig
Configuration settings for inference when using RetrieveAndGenerate to generate responses while using a knowledge base as a source.
6180 6181 6182 6183 6184 6185 6186 6187 6188 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6180 class OrchestrationConfiguration < Struct.new( :additional_model_request_fields, :inference_config, :performance_config, :prompt_template, :query_transformation_configuration) SENSITIVE = [] include Aws::Structure end |
#performance_config ⇒ Types::PerformanceConfiguration
The latency configuration for the model.
6180 6181 6182 6183 6184 6185 6186 6187 6188 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6180 class OrchestrationConfiguration < Struct.new( :additional_model_request_fields, :inference_config, :performance_config, :prompt_template, :query_transformation_configuration) SENSITIVE = [] include Aws::Structure end |
#prompt_template ⇒ Types::PromptTemplate
Contains the template for the prompt that’s sent to the model. Orchestration prompts must include the ‘$conversation_history$` and `$output_format_instructions$` variables. For more information, see
- Use placeholder variables][1
-
in the user guide.
[1]: docs.aws.amazon.com/bedrock/latest/userguide/prompt-placeholders.html
6180 6181 6182 6183 6184 6185 6186 6187 6188 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6180 class OrchestrationConfiguration < Struct.new( :additional_model_request_fields, :inference_config, :performance_config, :prompt_template, :query_transformation_configuration) SENSITIVE = [] include Aws::Structure end |
#query_transformation_configuration ⇒ Types::QueryTransformationConfiguration
To split up the prompt and retrieve multiple sources, set the transformation type to ‘QUERY_DECOMPOSITION`.
6180 6181 6182 6183 6184 6185 6186 6187 6188 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6180 class OrchestrationConfiguration < Struct.new( :additional_model_request_fields, :inference_config, :performance_config, :prompt_template, :query_transformation_configuration) SENSITIVE = [] include Aws::Structure end |