Class: Aws::BedrockAgentRuntime::Types::OrchestrationModelInvocationOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

The foundation model output from the orchestration step.

Constant Summary collapse

SENSITIVE =
[:metadata, :raw_response]

Instance Attribute Summary collapse

Instance Attribute Details

#metadataTypes::Metadata

Contains information about the foundation model output from the orchestration step.

Returns:



3829
3830
3831
3832
3833
3834
3835
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3829

class OrchestrationModelInvocationOutput < Struct.new(
  :metadata,
  :raw_response,
  :trace_id)
  SENSITIVE = [:metadata, :raw_response]
  include Aws::Structure
end

#raw_responseTypes::RawResponse

Contains details of the raw response from the foundation model output.

Returns:



3829
3830
3831
3832
3833
3834
3835
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3829

class OrchestrationModelInvocationOutput < Struct.new(
  :metadata,
  :raw_response,
  :trace_id)
  SENSITIVE = [:metadata, :raw_response]
  include Aws::Structure
end

#trace_idString

The unique identifier of the trace.

Returns:

  • (String)


3829
3830
3831
3832
3833
3834
3835
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3829

class OrchestrationModelInvocationOutput < Struct.new(
  :metadata,
  :raw_response,
  :trace_id)
  SENSITIVE = [:metadata, :raw_response]
  include Aws::Structure
end