Class: Aws::BedrockAgentRuntime::Types::PreProcessingModelInvocationOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::PreProcessingModelInvocationOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
The foundation model output from the pre-processing step.
Constant Summary collapse
- SENSITIVE =
[:metadata, :parsed_response, :raw_response, :reasoning_content]
Instance Attribute Summary collapse
-
#metadata ⇒ Types::Metadata
Contains information about the foundation model output from the pre-processing step.
-
#parsed_response ⇒ Types::PreProcessingParsedResponse
Details about the response from the Lambda parsing of the output of the pre-processing step.
-
#raw_response ⇒ Types::RawResponse
Details of the raw response from the foundation model output.
-
#reasoning_content ⇒ Types::ReasoningContentBlock
Contains content about the reasoning that the model made during the pre-processing step.
-
#trace_id ⇒ String
The unique identifier of the trace.
Instance Attribute Details
#metadata ⇒ Types::Metadata
Contains information about the foundation model output from the pre-processing step.
7423 7424 7425 7426 7427 7428 7429 7430 7431 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7423 class PreProcessingModelInvocationOutput < Struct.new( :metadata, :parsed_response, :raw_response, :reasoning_content, :trace_id) SENSITIVE = [:metadata, :parsed_response, :raw_response, :reasoning_content] include Aws::Structure end |
#parsed_response ⇒ Types::PreProcessingParsedResponse
Details about the response from the Lambda parsing of the output of the pre-processing step.
7423 7424 7425 7426 7427 7428 7429 7430 7431 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7423 class PreProcessingModelInvocationOutput < Struct.new( :metadata, :parsed_response, :raw_response, :reasoning_content, :trace_id) SENSITIVE = [:metadata, :parsed_response, :raw_response, :reasoning_content] include Aws::Structure end |
#raw_response ⇒ Types::RawResponse
Details of the raw response from the foundation model output.
7423 7424 7425 7426 7427 7428 7429 7430 7431 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7423 class PreProcessingModelInvocationOutput < Struct.new( :metadata, :parsed_response, :raw_response, :reasoning_content, :trace_id) SENSITIVE = [:metadata, :parsed_response, :raw_response, :reasoning_content] include Aws::Structure end |
#reasoning_content ⇒ Types::ReasoningContentBlock
Contains content about the reasoning that the model made during the pre-processing step.
7423 7424 7425 7426 7427 7428 7429 7430 7431 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7423 class PreProcessingModelInvocationOutput < Struct.new( :metadata, :parsed_response, :raw_response, :reasoning_content, :trace_id) SENSITIVE = [:metadata, :parsed_response, :raw_response, :reasoning_content] include Aws::Structure end |
#trace_id ⇒ String
The unique identifier of the trace.
7423 7424 7425 7426 7427 7428 7429 7430 7431 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7423 class PreProcessingModelInvocationOutput < Struct.new( :metadata, :parsed_response, :raw_response, :reasoning_content, :trace_id) SENSITIVE = [:metadata, :parsed_response, :raw_response, :reasoning_content] include Aws::Structure end |