Class: Aws::BedrockAgentRuntime::Types::PreProcessingParsedResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Details about the response from the Lambda parsing of the output from the pre-processing step.

Constant Summary collapse

SENSITIVE =
[:rationale]

Instance Attribute Summary collapse

Instance Attribute Details

#is_validBoolean

Whether the user input is valid or not. If false, the agent doesn’t proceed to orchestration.

Returns:

  • (Boolean)


4143
4144
4145
4146
4147
4148
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4143

class PreProcessingParsedResponse < Struct.new(
  :is_valid,
  :rationale)
  SENSITIVE = [:rationale]
  include Aws::Structure
end

#rationaleString

The text returned by the parsing of the pre-processing step, explaining the steps that the agent plans to take in orchestration, if the user input is valid.

Returns:

  • (String)


4143
4144
4145
4146
4147
4148
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4143

class PreProcessingParsedResponse < Struct.new(
  :is_valid,
  :rationale)
  SENSITIVE = [:rationale]
  include Aws::Structure
end