Class: Aws::BedrockAgentRuntime::Types::PromptConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains configurations to override a prompt template in one part of an agent sequence. For more information, see [Advanced prompts].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/advanced-prompts.html

Constant Summary collapse

SENSITIVE =
[:base_prompt_template]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_model_request_fieldsHash, ...

If the Converse or ConverseStream operations support the model, ‘additionalModelRequestFields` contains additional inference parameters, beyond the base set of inference parameters in the `inferenceConfiguration` field.

For more information, see *Inference request parameters and response fields for foundation models* in the Amazon Bedrock user guide.

Returns:

  • (Hash, Array, String, Numeric, Boolean)


7583
7584
7585
7586
7587
7588
7589
7590
7591
7592
7593
7594
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7583

class PromptConfiguration < Struct.new(
  :additional_model_request_fields,
  :base_prompt_template,
  :foundation_model,
  :inference_configuration,
  :parser_mode,
  :prompt_creation_mode,
  :prompt_state,
  :prompt_type)
  SENSITIVE = [:base_prompt_template]
  include Aws::Structure
end

#base_prompt_templateString

Defines the prompt template with which to replace the default prompt template. You can use placeholder variables in the base prompt template to customize the prompt. For more information, see [Prompt template placeholder variables]. For more information, see [Configure the prompt templates].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/prompt-placeholders.html [2]: docs.aws.amazon.com/bedrock/latest/userguide/advanced-prompts-configure.html

Returns:

  • (String)


7583
7584
7585
7586
7587
7588
7589
7590
7591
7592
7593
7594
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7583

class PromptConfiguration < Struct.new(
  :additional_model_request_fields,
  :base_prompt_template,
  :foundation_model,
  :inference_configuration,
  :parser_mode,
  :prompt_creation_mode,
  :prompt_state,
  :prompt_type)
  SENSITIVE = [:base_prompt_template]
  include Aws::Structure
end

#foundation_modelString

The foundation model to use.

Returns:

  • (String)


7583
7584
7585
7586
7587
7588
7589
7590
7591
7592
7593
7594
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7583

class PromptConfiguration < Struct.new(
  :additional_model_request_fields,
  :base_prompt_template,
  :foundation_model,
  :inference_configuration,
  :parser_mode,
  :prompt_creation_mode,
  :prompt_state,
  :prompt_type)
  SENSITIVE = [:base_prompt_template]
  include Aws::Structure
end

#inference_configurationTypes::InferenceConfiguration

Contains inference parameters to use when the agent invokes a foundation model in the part of the agent sequence defined by the ‘promptType`. For more information, see [Inference parameters for foundation models].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/model-parameters.html



7583
7584
7585
7586
7587
7588
7589
7590
7591
7592
7593
7594
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7583

class PromptConfiguration < Struct.new(
  :additional_model_request_fields,
  :base_prompt_template,
  :foundation_model,
  :inference_configuration,
  :parser_mode,
  :prompt_creation_mode,
  :prompt_state,
  :prompt_type)
  SENSITIVE = [:base_prompt_template]
  include Aws::Structure
end

#parser_modeString

Specifies whether to override the default parser Lambda function when parsing the raw foundation model output in the part of the agent sequence defined by the ‘promptType`. If you set the field as `OVERRIDDEN`, the `overrideLambda` field in the

PromptOverrideConfiguration][1

must be specified with the ARN of a

Lambda function.

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent_PromptOverrideConfiguration.html

Returns:

  • (String)


7583
7584
7585
7586
7587
7588
7589
7590
7591
7592
7593
7594
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7583

class PromptConfiguration < Struct.new(
  :additional_model_request_fields,
  :base_prompt_template,
  :foundation_model,
  :inference_configuration,
  :parser_mode,
  :prompt_creation_mode,
  :prompt_state,
  :prompt_type)
  SENSITIVE = [:base_prompt_template]
  include Aws::Structure
end

#prompt_creation_modeString

Specifies whether to override the default prompt template for this ‘promptType`. Set this value to `OVERRIDDEN` to use the prompt that you provide in the `basePromptTemplate`. If you leave it as `DEFAULT`, the agent uses a default prompt template.

Returns:

  • (String)


7583
7584
7585
7586
7587
7588
7589
7590
7591
7592
7593
7594
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7583

class PromptConfiguration < Struct.new(
  :additional_model_request_fields,
  :base_prompt_template,
  :foundation_model,
  :inference_configuration,
  :parser_mode,
  :prompt_creation_mode,
  :prompt_state,
  :prompt_type)
  SENSITIVE = [:base_prompt_template]
  include Aws::Structure
end

#prompt_stateString

Specifies whether to allow the inline agent to carry out the step specified in the ‘promptType`. If you set this value to `DISABLED`, the agent skips that step. The default state for each `promptType` is as follows.

  • ‘PRE_PROCESSING` – `ENABLED`

  • ‘ORCHESTRATION` – `ENABLED`

  • ‘KNOWLEDGE_BASE_RESPONSE_GENERATION` – `ENABLED`

  • ‘POST_PROCESSING` – `DISABLED`

Returns:

  • (String)


7583
7584
7585
7586
7587
7588
7589
7590
7591
7592
7593
7594
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7583

class PromptConfiguration < Struct.new(
  :additional_model_request_fields,
  :base_prompt_template,
  :foundation_model,
  :inference_configuration,
  :parser_mode,
  :prompt_creation_mode,
  :prompt_state,
  :prompt_type)
  SENSITIVE = [:base_prompt_template]
  include Aws::Structure
end

#prompt_typeString

The step in the agent sequence that this prompt configuration applies to.

Returns:

  • (String)


7583
7584
7585
7586
7587
7588
7589
7590
7591
7592
7593
7594
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7583

class PromptConfiguration < Struct.new(
  :additional_model_request_fields,
  :base_prompt_template,
  :foundation_model,
  :inference_configuration,
  :parser_mode,
  :prompt_creation_mode,
  :prompt_state,
  :prompt_type)
  SENSITIVE = [:base_prompt_template]
  include Aws::Structure
end