Class: Aws::BedrockAgentRuntime::Types::PromptTemplate
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::PromptTemplate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains the template for the prompt that's sent to the model for response generation. For more information, see Knowledge base prompt templates.
This data type is used in the following API operations:
- RetrieveAndGenerate request – in the
filterfield
^
Constant Summary collapse
- SENSITIVE =
[:text_prompt_template]
Instance Attribute Summary collapse
-
#text_prompt_template ⇒ String
The template for the prompt that's sent to the model for response generation.
Instance Attribute Details
#text_prompt_template ⇒ String
The template for the prompt that's sent to the model for response generation. You can include prompt placeholders, which become replaced before the prompt is sent to the model to provide instructions and context to the model. In addition, you can include XML tags to delineate meaningful sections of the prompt template.
For more information, see the following resources:
8154 8155 8156 8157 8158 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8154 class PromptTemplate < Struct.new( :text_prompt_template) SENSITIVE = [:text_prompt_template] include Aws::Structure end |