Class: Aws::BedrockAgentRuntime::Types::PutInvocationStepRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::PutInvocationStepRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#invocation_identifier ⇒ String
The unique identifier (in UUID format) of the invocation to add the invocation step to.
-
#invocation_step_id ⇒ String
The unique identifier of the invocation step in UUID format.
-
#invocation_step_time ⇒ Time
The timestamp for when the invocation step occurred.
-
#payload ⇒ Types::InvocationStepPayload
The payload for the invocation step, including text and images for the interaction.
-
#session_identifier ⇒ String
The unique identifier for the session to add the invocation step to.
Instance Attribute Details
#invocation_identifier ⇒ String
The unique identifier (in UUID format) of the invocation to add the invocation step to.
8200 8201 8202 8203 8204 8205 8206 8207 8208 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8200 class PutInvocationStepRequest < Struct.new( :invocation_identifier, :invocation_step_id, :invocation_step_time, :payload, :session_identifier) SENSITIVE = [] include Aws::Structure end |
#invocation_step_id ⇒ String
The unique identifier of the invocation step in UUID format.
8200 8201 8202 8203 8204 8205 8206 8207 8208 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8200 class PutInvocationStepRequest < Struct.new( :invocation_identifier, :invocation_step_id, :invocation_step_time, :payload, :session_identifier) SENSITIVE = [] include Aws::Structure end |
#invocation_step_time ⇒ Time
The timestamp for when the invocation step occurred.
8200 8201 8202 8203 8204 8205 8206 8207 8208 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8200 class PutInvocationStepRequest < Struct.new( :invocation_identifier, :invocation_step_id, :invocation_step_time, :payload, :session_identifier) SENSITIVE = [] include Aws::Structure end |
#payload ⇒ Types::InvocationStepPayload
The payload for the invocation step, including text and images for the interaction.
8200 8201 8202 8203 8204 8205 8206 8207 8208 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8200 class PutInvocationStepRequest < Struct.new( :invocation_identifier, :invocation_step_id, :invocation_step_time, :payload, :session_identifier) SENSITIVE = [] include Aws::Structure end |
#session_identifier ⇒ String
The unique identifier for the session to add the invocation step to.
You can specify either the session's sessionId or its Amazon
Resource Name (ARN).
8200 8201 8202 8203 8204 8205 8206 8207 8208 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8200 class PutInvocationStepRequest < Struct.new( :invocation_identifier, :invocation_step_id, :invocation_step_time, :payload, :session_identifier) SENSITIVE = [] include Aws::Structure end |