Class: Aws::BedrockAgentRuntime::Types::QueryTransformationConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

To split up the prompt and retrieve multiple sources, set the transformation type to ‘QUERY_DECOMPOSITION`.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#typeString

The type of transformation to apply to the prompt.

Returns:

  • (String)


6915
6916
6917
6918
6919
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6915

class QueryTransformationConfiguration < Struct.new(
  :type)
  SENSITIVE = []
  include Aws::Structure
end