Class: Aws::BedrockAgentRuntime::Types::Rationale
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::Rationale
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains the reasoning, based on the input, that the agent uses to justify carrying out an action group or getting information from a knowledge base.
Constant Summary collapse
- SENSITIVE =
[:text]
Instance Attribute Summary collapse
-
#text ⇒ String
The reasoning or thought process of the agent, based on the input.
-
#trace_id ⇒ String
The unique identifier of the trace step.