Class: Aws::BedrockAgentRuntime::Types::ReasoningTextBlock

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains information about the reasoning that the model used to return the content in the content block.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#signatureString

A hash of all the messages in the conversation to ensure that the content in the reasoning text block isn’t tampered with. You must submit the signature in subsequent ‘Converse` requests, in addition to the previous messages. If the previous messages are tampered with, the response throws an error.

Returns:

  • (String)


7006
7007
7008
7009
7010
7011
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7006

class ReasoningTextBlock < Struct.new(
  :signature,
  :text)
  SENSITIVE = []
  include Aws::Structure
end

#textString

Text describing the reasoning that the model used to return the content in the content block.

Returns:

  • (String)


7006
7007
7008
7009
7010
7011
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7006

class ReasoningTextBlock < Struct.new(
  :signature,
  :text)
  SENSITIVE = []
  include Aws::Structure
end