Class: Aws::BedrockAgentRuntime::Types::RerankRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:queries, :sources]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

If the total number of results was greater than could fit in a response, a token is returned in the nextToken field. You can enter that token in this field to return the next batch of results.

Returns:

  • (String)


8172
8173
8174
8175
8176
8177
8178
8179
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8172

class RerankRequest < Struct.new(
  :next_token,
  :queries,
  :reranking_configuration,
  :sources)
  SENSITIVE = [:queries, :sources]
  include Aws::Structure
end

#queriesArray<Types::RerankQuery>

An array of objects, each of which contains information about a query to submit to the reranker model.

Returns:



8172
8173
8174
8175
8176
8177
8178
8179
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8172

class RerankRequest < Struct.new(
  :next_token,
  :queries,
  :reranking_configuration,
  :sources)
  SENSITIVE = [:queries, :sources]
  include Aws::Structure
end

#reranking_configurationTypes::RerankingConfiguration

Contains configurations for reranking.



8172
8173
8174
8175
8176
8177
8178
8179
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8172

class RerankRequest < Struct.new(
  :next_token,
  :queries,
  :reranking_configuration,
  :sources)
  SENSITIVE = [:queries, :sources]
  include Aws::Structure
end

#sourcesArray<Types::RerankSource>

An array of objects, each of which contains information about the sources to rerank.

Returns:



8172
8173
8174
8175
8176
8177
8178
8179
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8172

class RerankRequest < Struct.new(
  :next_token,
  :queries,
  :reranking_configuration,
  :sources)
  SENSITIVE = [:queries, :sources]
  include Aws::Structure
end