Class: Aws::BedrockAgentRuntime::Types::RerankResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

If the total number of results is greater than can fit in the response, use this token in the nextToken field when making another request to return the next batch of results.

Returns:

  • (String)


8470
8471
8472
8473
8474
8475
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8470

class RerankResponse < Struct.new(
  :next_token,
  :results)
  SENSITIVE = []
  include Aws::Structure
end

#resultsArray<Types::RerankResult>

An array of objects, each of which contains information about the results of reranking.

Returns:



8470
8471
8472
8473
8474
8475
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8470

class RerankResponse < Struct.new(
  :next_token,
  :results)
  SENSITIVE = []
  include Aws::Structure
end