Class: Aws::BedrockAgentRuntime::Types::RerankingMetadataSelectiveModeConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::RerankingMetadataSelectiveModeConfiguration
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
RerankingMetadataSelectiveModeConfiguration is a union - when making an API calls you must set exactly one of the members.
Contains configurations for the metadata fields to include or exclude
when considering reranking. If you include the fieldsToExclude
field, the reranker ignores all the metadata fields that you specify.
If you include the fieldsToInclude field, the reranker uses only the
metadata fields that you specify and ignores all others. You can
include only one of these fields.
Defined Under Namespace
Classes: FieldsToExclude, FieldsToInclude, Unknown
Constant Summary collapse
- SENSITIVE =
[:fields_to_exclude, :fields_to_include]
Instance Attribute Summary collapse
-
#fields_to_exclude ⇒ Array<Types::FieldForReranking>
An array of objects, each of which specifies a metadata field to exclude from consideration when reranking.
-
#fields_to_include ⇒ Array<Types::FieldForReranking>
An array of objects, each of which specifies a metadata field to include in consideration when reranking.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#fields_to_exclude ⇒ Array<Types::FieldForReranking>
An array of objects, each of which specifies a metadata field to exclude from consideration when reranking.
8575 8576 8577 8578 8579 8580 8581 8582 8583 8584 8585 8586 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8575 class RerankingMetadataSelectiveModeConfiguration < Struct.new( :fields_to_exclude, :fields_to_include, :unknown) SENSITIVE = [:fields_to_exclude, :fields_to_include] include Aws::Structure include Aws::Structure::Union class FieldsToExclude < RerankingMetadataSelectiveModeConfiguration; end class FieldsToInclude < RerankingMetadataSelectiveModeConfiguration; end class Unknown < RerankingMetadataSelectiveModeConfiguration; end end |
#fields_to_include ⇒ Array<Types::FieldForReranking>
An array of objects, each of which specifies a metadata field to include in consideration when reranking. The remaining metadata fields are ignored.
8575 8576 8577 8578 8579 8580 8581 8582 8583 8584 8585 8586 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8575 class RerankingMetadataSelectiveModeConfiguration < Struct.new( :fields_to_exclude, :fields_to_include, :unknown) SENSITIVE = [:fields_to_exclude, :fields_to_include] include Aws::Structure include Aws::Structure::Union class FieldsToExclude < RerankingMetadataSelectiveModeConfiguration; end class FieldsToInclude < RerankingMetadataSelectiveModeConfiguration; end class Unknown < RerankingMetadataSelectiveModeConfiguration; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
8575 8576 8577 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8575 def unknown @unknown end |