Class: Aws::BedrockAgentRuntime::Types::ResponseStream

Inherits:
Enumerator
  • Object
show all
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

The response from invoking the agent and associated citations and trace information.

EventStream is an Enumerator of Events. #event_types #=> Array, returns all modeled event types in the stream

Instance Method Summary collapse

Instance Method Details

#event_typesObject



10768
10769
10770
10771
10772
10773
10774
10775
10776
10777
10778
10779
10780
10781
10782
10783
10784
10785
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10768

def event_types
  [
    :access_denied_exception,
    :bad_gateway_exception,
    :chunk,
    :conflict_exception,
    :dependency_failed_exception,
    :files,
    :internal_server_exception,
    :model_not_ready_exception,
    :resource_not_found_exception,
    :return_control,
    :service_quota_exceeded_exception,
    :throttling_exception,
    :trace,
    :validation_exception
  ]
end