Class: Aws::BedrockAgentRuntime::Types::RetrievalResultContent
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::RetrievalResultContent
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains information about a chunk of text from a data source in the knowledge base. If the result is from a structured data source, the cell in the database and the type of the value is also identified.
This data type is used in the following API operations:
-
Retrieve response – in the
contentfield -
RetrieveAndGenerate response – in the
contentfield -
InvokeAgent response – in the
contentfield
Constant Summary collapse
- SENSITIVE =
[:row]
Instance Attribute Summary collapse
-
#audio ⇒ Types::AudioSegment
Audio segment information when the retrieval result contains audio content.
-
#byte_content ⇒ String
A data URI with base64-encoded content from the data source.
-
#row ⇒ Array<Types::RetrievalResultContentColumn>
Specifies information about the rows with the cells to return in retrieval.
-
#text ⇒ String
The cited text from the data source.
-
#type ⇒ String
The type of content in the retrieval result.
-
#video ⇒ Types::VideoSegment
Video segment information when the retrieval result contains video content.
Instance Attribute Details
#audio ⇒ Types::AudioSegment
Audio segment information when the retrieval result contains audio content.
8460 8461 8462 8463 8464 8465 8466 8467 8468 8469 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8460 class RetrievalResultContent < Struct.new( :audio, :byte_content, :row, :text, :type, :video) SENSITIVE = [:row] include Aws::Structure end |
#byte_content ⇒ String
A data URI with base64-encoded content from the data source. The URI
is in the following format: returned in the following format:
data:image/jpeg;base64,${base64-encoded string}.
8460 8461 8462 8463 8464 8465 8466 8467 8468 8469 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8460 class RetrievalResultContent < Struct.new( :audio, :byte_content, :row, :text, :type, :video) SENSITIVE = [:row] include Aws::Structure end |
#row ⇒ Array<Types::RetrievalResultContentColumn>
Specifies information about the rows with the cells to return in retrieval.
8460 8461 8462 8463 8464 8465 8466 8467 8468 8469 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8460 class RetrievalResultContent < Struct.new( :audio, :byte_content, :row, :text, :type, :video) SENSITIVE = [:row] include Aws::Structure end |
#text ⇒ String
The cited text from the data source.
8460 8461 8462 8463 8464 8465 8466 8467 8468 8469 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8460 class RetrievalResultContent < Struct.new( :audio, :byte_content, :row, :text, :type, :video) SENSITIVE = [:row] include Aws::Structure end |
#type ⇒ String
The type of content in the retrieval result.
8460 8461 8462 8463 8464 8465 8466 8467 8468 8469 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8460 class RetrievalResultContent < Struct.new( :audio, :byte_content, :row, :text, :type, :video) SENSITIVE = [:row] include Aws::Structure end |
#video ⇒ Types::VideoSegment
Video segment information when the retrieval result contains video content.
8460 8461 8462 8463 8464 8465 8466 8467 8468 8469 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8460 class RetrievalResultContent < Struct.new( :audio, :byte_content, :row, :text, :type, :video) SENSITIVE = [:row] include Aws::Structure end |