Class: Aws::BedrockAgentRuntime::Types::RetrievalResultLocation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains information about the data source location.

This data type is used in the following API operations:

  • Retrieve response][1

    – in the ‘location` field

  • RetrieveAndGenerate response][2

    – in the ‘location` field

  • InvokeAgent response][3

    – in the ‘location` field

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_Retrieve.html#API_agent-runtime_Retrieve_ResponseSyntax [2]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_RetrieveAndGenerate.html#API_agent-runtime_RetrieveAndGenerate_ResponseSyntax [3]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_InvokeAgent.html#API_agent-runtime_InvokeAgent_ResponseSyntax

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#confluence_locationTypes::RetrievalResultConfluenceLocation

The Confluence data source location.



7651
7652
7653
7654
7655
7656
7657
7658
7659
7660
7661
7662
7663
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7651

class RetrievalResultLocation < Struct.new(
  :confluence_location,
  :custom_document_location,
  :kendra_document_location,
  :s3_location,
  :salesforce_location,
  :share_point_location,
  :sql_location,
  :type,
  :web_location)
  SENSITIVE = []
  include Aws::Structure
end

#custom_document_locationTypes::RetrievalResultCustomDocumentLocation

Specifies the location of a document in a custom data source.



7651
7652
7653
7654
7655
7656
7657
7658
7659
7660
7661
7662
7663
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7651

class RetrievalResultLocation < Struct.new(
  :confluence_location,
  :custom_document_location,
  :kendra_document_location,
  :s3_location,
  :salesforce_location,
  :share_point_location,
  :sql_location,
  :type,
  :web_location)
  SENSITIVE = []
  include Aws::Structure
end

#kendra_document_locationTypes::RetrievalResultKendraDocumentLocation

The location of a document in Amazon Kendra.



7651
7652
7653
7654
7655
7656
7657
7658
7659
7660
7661
7662
7663
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7651

class RetrievalResultLocation < Struct.new(
  :confluence_location,
  :custom_document_location,
  :kendra_document_location,
  :s3_location,
  :salesforce_location,
  :share_point_location,
  :sql_location,
  :type,
  :web_location)
  SENSITIVE = []
  include Aws::Structure
end

#s3_locationTypes::RetrievalResultS3Location

The S3 data source location.



7651
7652
7653
7654
7655
7656
7657
7658
7659
7660
7661
7662
7663
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7651

class RetrievalResultLocation < Struct.new(
  :confluence_location,
  :custom_document_location,
  :kendra_document_location,
  :s3_location,
  :salesforce_location,
  :share_point_location,
  :sql_location,
  :type,
  :web_location)
  SENSITIVE = []
  include Aws::Structure
end

#salesforce_locationTypes::RetrievalResultSalesforceLocation

The Salesforce data source location.



7651
7652
7653
7654
7655
7656
7657
7658
7659
7660
7661
7662
7663
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7651

class RetrievalResultLocation < Struct.new(
  :confluence_location,
  :custom_document_location,
  :kendra_document_location,
  :s3_location,
  :salesforce_location,
  :share_point_location,
  :sql_location,
  :type,
  :web_location)
  SENSITIVE = []
  include Aws::Structure
end

#share_point_locationTypes::RetrievalResultSharePointLocation

The SharePoint data source location.



7651
7652
7653
7654
7655
7656
7657
7658
7659
7660
7661
7662
7663
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7651

class RetrievalResultLocation < Struct.new(
  :confluence_location,
  :custom_document_location,
  :kendra_document_location,
  :s3_location,
  :salesforce_location,
  :share_point_location,
  :sql_location,
  :type,
  :web_location)
  SENSITIVE = []
  include Aws::Structure
end

#sql_locationTypes::RetrievalResultSqlLocation

Specifies information about the SQL query used to retrieve the result.



7651
7652
7653
7654
7655
7656
7657
7658
7659
7660
7661
7662
7663
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7651

class RetrievalResultLocation < Struct.new(
  :confluence_location,
  :custom_document_location,
  :kendra_document_location,
  :s3_location,
  :salesforce_location,
  :share_point_location,
  :sql_location,
  :type,
  :web_location)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of data source location.

Returns:

  • (String)


7651
7652
7653
7654
7655
7656
7657
7658
7659
7660
7661
7662
7663
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7651

class RetrievalResultLocation < Struct.new(
  :confluence_location,
  :custom_document_location,
  :kendra_document_location,
  :s3_location,
  :salesforce_location,
  :share_point_location,
  :sql_location,
  :type,
  :web_location)
  SENSITIVE = []
  include Aws::Structure
end

#web_locationTypes::RetrievalResultWebLocation

The web URL/URLs data source location.



7651
7652
7653
7654
7655
7656
7657
7658
7659
7660
7661
7662
7663
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7651

class RetrievalResultLocation < Struct.new(
  :confluence_location,
  :custom_document_location,
  :kendra_document_location,
  :s3_location,
  :salesforce_location,
  :share_point_location,
  :sql_location,
  :type,
  :web_location)
  SENSITIVE = []
  include Aws::Structure
end