Class: Aws::BedrockAgentRuntime::Types::RetrieveAndGenerateConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains details about the resource being queried.

This data type is used in the following API operations:

^

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#external_sources_configurationTypes::ExternalSourcesRetrieveAndGenerateConfiguration

The configuration for the external source wrapper object in the retrieveAndGenerate function.



8925
8926
8927
8928
8929
8930
8931
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8925

class RetrieveAndGenerateConfiguration < Struct.new(
  :external_sources_configuration,
  :knowledge_base_configuration,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#knowledge_base_configurationTypes::KnowledgeBaseRetrieveAndGenerateConfiguration

Contains details about the knowledge base for retrieving information and generating responses.



8925
8926
8927
8928
8929
8930
8931
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8925

class RetrieveAndGenerateConfiguration < Struct.new(
  :external_sources_configuration,
  :knowledge_base_configuration,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of resource that contains your data for retrieving information and generating responses.

If you choose to use EXTERNAL_SOURCES, then currently only Anthropic Claude 3 Sonnet models for knowledge bases are supported.

Returns:

  • (String)


8925
8926
8927
8928
8929
8930
8931
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8925

class RetrieveAndGenerateConfiguration < Struct.new(
  :external_sources_configuration,
  :knowledge_base_configuration,
  :type)
  SENSITIVE = []
  include Aws::Structure
end