Class: Aws::BedrockAgentRuntime::Types::RetrieveAndGenerateInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::RetrieveAndGenerateInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains the query made to the knowledge base.
This data type is used in the following API operations:
- RetrieveAndGenerate request][1
-
– in the ‘input` field
^
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#text ⇒ String
The query made to the knowledge base, in characters.
Instance Attribute Details
#text ⇒ String
The query made to the knowledge base, in characters.
7810 7811 7812 7813 7814 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7810 class RetrieveAndGenerateInput < Struct.new( :text) SENSITIVE = [] include Aws::Structure end |