Class: Aws::BedrockAgentRuntime::Types::RetrieveAndGenerateOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains the response generated from querying the knowledge base.

This data type is used in the following API operations:

^

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#textString

The response generated from querying the knowledge base.

Returns:

  • (String)


8975
8976
8977
8978
8979
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8975

class RetrieveAndGenerateOutput < Struct.new(
  :text)
  SENSITIVE = []
  include Aws::Structure
end