Class: Aws::BedrockAgentRuntime::Types::RetrieveAndGenerateSessionConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains configuration about the session with the knowledge base.

This data type is used in the following API operations:

^

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#kms_key_arnString

The ARN of the KMS key encrypting the session.

Returns:

  • (String)


9093
9094
9095
9096
9097
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9093

class RetrieveAndGenerateSessionConfiguration < Struct.new(
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end