Class: Aws::BedrockAgentRuntime::Types::RetrieveResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::RetrieveResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:retrieval_results]
Instance Attribute Summary collapse
-
#guardrail_action ⇒ String
Specifies if there is a guardrail intervention in the response.
-
#next_token ⇒ String
If there are more results than can fit in the response, the response returns a ‘nextToken`.
-
#retrieval_results ⇒ Array<Types::KnowledgeBaseRetrievalResult>
A list of results from querying the knowledge base.
Instance Attribute Details
#guardrail_action ⇒ String
Specifies if there is a guardrail intervention in the response.
9051 9052 9053 9054 9055 9056 9057 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9051 class RetrieveResponse < Struct.new( :guardrail_action, :next_token, :retrieval_results) SENSITIVE = [:retrieval_results] include Aws::Structure end |
#next_token ⇒ String
If there are more results than can fit in the response, the response returns a ‘nextToken`. Use this token in the `nextToken` field of another request to retrieve the next batch of results.
9051 9052 9053 9054 9055 9056 9057 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9051 class RetrieveResponse < Struct.new( :guardrail_action, :next_token, :retrieval_results) SENSITIVE = [:retrieval_results] include Aws::Structure end |
#retrieval_results ⇒ Array<Types::KnowledgeBaseRetrievalResult>
A list of results from querying the knowledge base.
9051 9052 9053 9054 9055 9056 9057 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9051 class RetrieveResponse < Struct.new( :guardrail_action, :next_token, :retrieval_results) SENSITIVE = [:retrieval_results] include Aws::Structure end |