Class: Aws::BedrockAgentRuntime::Types::RetrievedReference

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains metadata about a source cited for the generated response.

This data type is used in the following API operations:

Constant Summary collapse

SENSITIVE =
[:content, :location, :metadata]

Instance Attribute Summary collapse

Instance Attribute Details

#contentTypes::RetrievalResultContent

Contains the cited text from the data source.



9263
9264
9265
9266
9267
9268
9269
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9263

class RetrievedReference < Struct.new(
  :content,
  :location,
  :metadata)
  SENSITIVE = [:content, :location, :metadata]
  include Aws::Structure
end

#locationTypes::RetrievalResultLocation

Contains information about the location of the data source.



9263
9264
9265
9266
9267
9268
9269
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9263

class RetrievedReference < Struct.new(
  :content,
  :location,
  :metadata)
  SENSITIVE = [:content, :location, :metadata]
  include Aws::Structure
end

#metadataHash<String,Hash,Array,String,Numeric,Boolean>

Contains metadata attributes and their values for the file in the data source. For more information, see Metadata and filtering.

Returns:

  • (Hash<String,Hash,Array,String,Numeric,Boolean>)


9263
9264
9265
9266
9267
9268
9269
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9263

class RetrievedReference < Struct.new(
  :content,
  :location,
  :metadata)
  SENSITIVE = [:content, :location, :metadata]
  include Aws::Structure
end