Class: Aws::BedrockAgentRuntime::Types::RetrieverConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Note:

RetrieverConfiguration is a union - when making an API calls you must set exactly one of the members.

Configuration for a retriever, specified as a union of retriever types.

Defined Under Namespace

Classes: KnowledgeBase, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#knowledge_baseTypes::KnowledgeBaseRetrieverConfiguration

Configuration for a knowledge base retriever.



9558
9559
9560
9561
9562
9563
9564
9565
9566
9567
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9558

class RetrieverConfiguration < Struct.new(
  :knowledge_base,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class KnowledgeBase < RetrieverConfiguration; end
  class Unknown < RetrieverConfiguration; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



9558
9559
9560
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9558

def unknown
  @unknown
end