Class: Aws::BedrockAgentRuntime::Types::SessionSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains details about a session. For more information about sessions, see Store and retrieve conversation history and context with Amazon Bedrock sessions.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp for when the session was created.

Returns:

  • (Time)


9633
9634
9635
9636
9637
9638
9639
9640
9641
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9633

class SessionSummary < Struct.new(
  :created_at,
  :last_updated_at,
  :session_arn,
  :session_id,
  :session_status)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_atTime

The timestamp for when the session was last modified.

Returns:

  • (Time)


9633
9634
9635
9636
9637
9638
9639
9640
9641
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9633

class SessionSummary < Struct.new(
  :created_at,
  :last_updated_at,
  :session_arn,
  :session_id,
  :session_status)
  SENSITIVE = []
  include Aws::Structure
end

#session_arnString

The Amazon Resource Name (ARN) of the session.

Returns:

  • (String)


9633
9634
9635
9636
9637
9638
9639
9640
9641
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9633

class SessionSummary < Struct.new(
  :created_at,
  :last_updated_at,
  :session_arn,
  :session_id,
  :session_status)
  SENSITIVE = []
  include Aws::Structure
end

#session_idString

The unique identifier for the session.

Returns:

  • (String)


9633
9634
9635
9636
9637
9638
9639
9640
9641
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9633

class SessionSummary < Struct.new(
  :created_at,
  :last_updated_at,
  :session_arn,
  :session_id,
  :session_status)
  SENSITIVE = []
  include Aws::Structure
end

#session_statusString

The current status of the session.

Returns:

  • (String)


9633
9634
9635
9636
9637
9638
9639
9640
9641
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9633

class SessionSummary < Struct.new(
  :created_at,
  :last_updated_at,
  :session_arn,
  :session_id,
  :session_status)
  SENSITIVE = []
  include Aws::Structure
end