Class: Aws::BedrockAgentRuntime::Types::StartFlowExecutionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#flow_alias_identifierString

The unique identifier of the flow alias to use for the flow execution.

Returns:

  • (String)


9529
9530
9531
9532
9533
9534
9535
9536
9537
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9529

class StartFlowExecutionRequest < Struct.new(
  :flow_alias_identifier,
  :flow_execution_name,
  :flow_identifier,
  :inputs,
  :model_performance_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#flow_execution_nameString

The unique name for the flow execution. If you don’t provide one, a system-generated name is used.

Returns:

  • (String)


9529
9530
9531
9532
9533
9534
9535
9536
9537
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9529

class StartFlowExecutionRequest < Struct.new(
  :flow_alias_identifier,
  :flow_execution_name,
  :flow_identifier,
  :inputs,
  :model_performance_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#flow_identifierString

The unique identifier of the flow to execute.

Returns:

  • (String)


9529
9530
9531
9532
9533
9534
9535
9536
9537
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9529

class StartFlowExecutionRequest < Struct.new(
  :flow_alias_identifier,
  :flow_execution_name,
  :flow_identifier,
  :inputs,
  :model_performance_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#inputsArray<Types::FlowInput>

The input data required for the flow execution. This must match the input schema defined in the flow.

Returns:



9529
9530
9531
9532
9533
9534
9535
9536
9537
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9529

class StartFlowExecutionRequest < Struct.new(
  :flow_alias_identifier,
  :flow_execution_name,
  :flow_identifier,
  :inputs,
  :model_performance_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#model_performance_configurationTypes::ModelPerformanceConfiguration

The performance settings for the foundation model used in the flow execution.



9529
9530
9531
9532
9533
9534
9535
9536
9537
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9529

class StartFlowExecutionRequest < Struct.new(
  :flow_alias_identifier,
  :flow_execution_name,
  :flow_identifier,
  :inputs,
  :model_performance_configuration)
  SENSITIVE = []
  include Aws::Structure
end