Class: Aws::BedrockAgentRuntime::Types::StopFlowExecutionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#execution_identifierString

The unique identifier of the flow execution to stop.

Returns:

  • (String)


10013
10014
10015
10016
10017
10018
10019
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10013

class StopFlowExecutionRequest < Struct.new(
  :execution_identifier,
  :flow_alias_identifier,
  :flow_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#flow_alias_identifierString

The unique identifier of the flow alias used for the execution.

Returns:

  • (String)


10013
10014
10015
10016
10017
10018
10019
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10013

class StopFlowExecutionRequest < Struct.new(
  :execution_identifier,
  :flow_alias_identifier,
  :flow_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#flow_identifierString

The unique identifier of the flow.

Returns:

  • (String)


10013
10014
10015
10016
10017
10018
10019
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10013

class StopFlowExecutionRequest < Struct.new(
  :execution_identifier,
  :flow_alias_identifier,
  :flow_identifier)
  SENSITIVE = []
  include Aws::Structure
end