Class: Aws::BedrockAgentRuntime::Types::StopFlowExecutionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#execution_arnString

The Amazon Resource Name (ARN) that uniquely identifies the flow execution that was stopped.

Returns:

  • (String)


9758
9759
9760
9761
9762
9763
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9758

class StopFlowExecutionResponse < Struct.new(
  :execution_arn,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The updated status of the flow execution after the stop request. This will typically be ABORTED if the execution was successfully stopped.

Returns:

  • (String)


9758
9759
9760
9761
9762
9763
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9758

class StopFlowExecutionResponse < Struct.new(
  :execution_arn,
  :status)
  SENSITIVE = []
  include Aws::Structure
end