Class: Aws::BedrockAgentRuntime::Types::StreamingConfigurations
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::StreamingConfigurations
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Configurations for streaming.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#apply_guardrail_interval ⇒ Integer
The guardrail interval to apply as response is generated.
-
#stream_final_response ⇒ Boolean
Specifies whether to enable streaming for the final response.
Instance Attribute Details
#apply_guardrail_interval ⇒ Integer
The guardrail interval to apply as response is generated. By default, the guardrail interval is set to 50 characters. If a larger interval is specified, the response will be generated in larger chunks with fewer ‘ApplyGuardrail` calls. The following examples show the response generated for *Hello, I am an agent* input string.
**Example response in chunks: Interval set to 3 characters**
‘’Hel’, ‘lo, ’,‘I am’, ‘ an’, ‘ Age’, ‘nt’‘
Each chunk has at least 3 characters except for the last chunk
**Example response in chunks: Interval set to 20 or more characters**
‘Hello, I am an Agent`
8609 8610 8611 8612 8613 8614 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8609 class StreamingConfigurations < Struct.new( :apply_guardrail_interval, :stream_final_response) SENSITIVE = [] include Aws::Structure end |
#stream_final_response ⇒ Boolean
Specifies whether to enable streaming for the final response. This is set to ‘false` by default.
8609 8610 8611 8612 8613 8614 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8609 class StreamingConfigurations < Struct.new( :apply_guardrail_interval, :stream_final_response) SENSITIVE = [] include Aws::Structure end |