Class: Aws::BedrockAgentRuntime::Types::TextResponsePart
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::TextResponsePart
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains the part of the generated text that contains a citation, alongside where it begins and ends.
This data type is used in the following API operations:
- RetrieveAndGenerate response][1
-
– in the ‘textResponsePart` field
- InvokeAgent response][2
-
– in the ‘textResponsePart` field
[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_RetrieveAndGenerate.html#API_agent-runtime_RetrieveAndGenerate_ResponseSyntax [2]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_InvokeAgent.html#API_agent-runtime_InvokeAgent_ResponseSyntax
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#span ⇒ Types::Span
Contains information about where the text with a citation begins and ends in the generated output.
-
#text ⇒ String
The part of the generated text that contains a citation.
Instance Attribute Details
#span ⇒ Types::Span
Contains information about where the text with a citation begins and ends in the generated output.
8733 8734 8735 8736 8737 8738 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8733 class TextResponsePart < Struct.new( :span, :text) SENSITIVE = [] include Aws::Structure end |
#text ⇒ String
The part of the generated text that contains a citation.
8733 8734 8735 8736 8737 8738 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8733 class TextResponsePart < Struct.new( :span, :text) SENSITIVE = [] include Aws::Structure end |