Class: Aws::BedrockAgentRuntime::Types::TextToSqlConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::TextToSqlConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains configurations for transforming text to SQL.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#knowledge_base_configuration ⇒ Types::TextToSqlKnowledgeBaseConfiguration
Specifies configurations for a knowledge base to use in transformation.
-
#type ⇒ String
The type of resource to use in transformation.
Instance Attribute Details
#knowledge_base_configuration ⇒ Types::TextToSqlKnowledgeBaseConfiguration
Specifies configurations for a knowledge base to use in transformation.
5948 5949 5950 5951 5952 5953 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5948 class TextToSqlConfiguration < Struct.new( :knowledge_base_configuration, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of resource to use in transformation.
5948 5949 5950 5951 5952 5953 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5948 class TextToSqlConfiguration < Struct.new( :knowledge_base_configuration, :type) SENSITIVE = [] include Aws::Structure end |