Class: Aws::BedrockAgentRuntime::Types::TraceElements
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::TraceElements
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Note:
TraceElements is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of TraceElements corresponding to the set member.
Contains trace elements for flow execution tracking.
Defined Under Namespace
Classes: AgentTraces, Unknown
Constant Summary collapse
- SENSITIVE =
[:agent_traces]
Instance Attribute Summary collapse
-
#agent_traces ⇒ Array<Types::TracePart>
Agent trace information for the flow execution.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#agent_traces ⇒ Array<Types::TracePart>
Agent trace information for the flow execution.
10327 10328 10329 10330 10331 10332 10333 10334 10335 10336 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10327 class TraceElements < Struct.new( :agent_traces, :unknown) SENSITIVE = [:agent_traces] include Aws::Structure include Aws::Structure::Union class AgentTraces < TraceElements; end class Unknown < TraceElements; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
10327 10328 10329 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10327 def unknown @unknown end |