Class: Aws::BedrockAgentRuntime::Types::Usage
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::Usage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains information of the usage of the foundation model.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#input_tokens ⇒ Integer
Contains information about the input tokens from the foundation model usage.
-
#output_tokens ⇒ Integer
Contains information about the output tokens from the foundation model usage.