Class: Aws::BedrockAgentRuntime::Types::VectorSearchBedrockRerankingConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains configurations for reranking with an Amazon Bedrock reranker model.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#metadata_configurationTypes::MetadataConfigurationForReranking

Contains configurations for the metadata to use in reranking.



10568
10569
10570
10571
10572
10573
10574
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10568

class VectorSearchBedrockRerankingConfiguration < Struct.new(
  :metadata_configuration,
  :model_configuration,
  :number_of_reranked_results)
  SENSITIVE = []
  include Aws::Structure
end

#model_configurationTypes::VectorSearchBedrockRerankingModelConfiguration

Contains configurations for the reranker model.



10568
10569
10570
10571
10572
10573
10574
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10568

class VectorSearchBedrockRerankingConfiguration < Struct.new(
  :metadata_configuration,
  :model_configuration,
  :number_of_reranked_results)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_reranked_resultsInteger

The number of results to return after reranking.

Returns:

  • (Integer)


10568
10569
10570
10571
10572
10573
10574
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10568

class VectorSearchBedrockRerankingConfiguration < Struct.new(
  :metadata_configuration,
  :model_configuration,
  :number_of_reranked_results)
  SENSITIVE = []
  include Aws::Structure
end