Class: Aws::BedrockAgentRuntime::Types::VideoSegment

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains information about a video segment retrieved from a knowledge base, including its location and summary.

This data type is used in the following API operations:

  • Retrieve response][1

    – in the ‘video` field

^

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_Retrieve.html#API_agent-runtime_Retrieve_ResponseSyntax

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#s3_uriString

The S3 URI where this specific video segment is stored in the multimodal storage destination.

Returns:

  • (String)


9162
9163
9164
9165
9166
9167
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9162

class VideoSegment < Struct.new(
  :s3_uri,
  :summary)
  SENSITIVE = []
  include Aws::Structure
end

#summaryString

A text summary describing the content of the video segment.

Returns:

  • (String)


9162
9163
9164
9165
9166
9167
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9162

class VideoSegment < Struct.new(
  :s3_uri,
  :summary)
  SENSITIVE = []
  include Aws::Structure
end