Class: Aws::BedrockAgentRuntime::Types::APISchema
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::APISchema
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
APISchema is a union - when making an API calls you must set exactly one of the members.
Contains details about the OpenAPI schema for the action group. For more information, see [Action group OpenAPI schemas]. You can either include the schema directly in the payload field or you can upload it to an S3 bucket and specify the S3 bucket location in the s3 field.
[1]: docs.aws.amazon.com/bedrock/latest/userguide/agents-api-schema.html
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[:payload]
Instance Attribute Summary collapse
-
#payload ⇒ String
The JSON or YAML-formatted payload defining the OpenAPI schema for the action group.
-
#s3 ⇒ Types::S3Identifier
Contains details about the S3 object containing the OpenAPI schema for the action group.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#payload ⇒ String
The JSON or YAML-formatted payload defining the OpenAPI schema for the action group.
37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 37 class APISchema < Struct.new( :payload, :s3, :unknown) SENSITIVE = [:payload] include Aws::Structure include Aws::Structure::Union class Payload < APISchema; end class S3 < APISchema; end class Unknown < APISchema; end end |
#s3 ⇒ Types::S3Identifier
Contains details about the S3 object containing the OpenAPI schema for the action group.
37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 37 class APISchema < Struct.new( :payload, :s3, :unknown) SENSITIVE = [:payload] include Aws::Structure include Aws::Structure::Union class Payload < APISchema; end class S3 < APISchema; end class Unknown < APISchema; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
37 38 39 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 37 def unknown @unknown end |