Class: Aws::BedrockAgentRuntime::Types::ActionGroupInvocationInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::ActionGroupInvocationInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains information about the action group being invoked. For more information about the possible structures, see the InvocationInput tab in [OrchestrationTrace] in the [Amazon Bedrock User Guide].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/trace-orchestration.html [2]: docs.aws.amazon.com/bedrock/latest/userguide/what-is-service.html
Constant Summary collapse
- SENSITIVE =
[:action_group_name, :api_path, :function, :verb]
Instance Attribute Summary collapse
-
#action_group_name ⇒ String
The name of the action group.
-
#api_path ⇒ String
The path to the API to call, based off the action group.
-
#execution_type ⇒ String
How fulfillment of the action is handled.
-
#function ⇒ String
The function in the action group to call.
-
#invocation_id ⇒ String
The unique identifier of the invocation.
-
#parameters ⇒ Array<Types::Parameter>
The parameters in the Lambda input event.
-
#request_body ⇒ Types::RequestBody
The parameters in the request body for the Lambda input event.
-
#verb ⇒ String
The API method being used, based off the action group.
Instance Attribute Details
#action_group_name ⇒ String
The name of the action group.
145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 145 class ActionGroupInvocationInput < Struct.new( :action_group_name, :api_path, :execution_type, :function, :invocation_id, :parameters, :request_body, :verb) SENSITIVE = [:action_group_name, :api_path, :function, :verb] include Aws::Structure end |
#api_path ⇒ String
The path to the API to call, based off the action group.
145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 145 class ActionGroupInvocationInput < Struct.new( :action_group_name, :api_path, :execution_type, :function, :invocation_id, :parameters, :request_body, :verb) SENSITIVE = [:action_group_name, :api_path, :function, :verb] include Aws::Structure end |
#execution_type ⇒ String
How fulfillment of the action is handled. For more information, see [Handling fulfillment of the action].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/action-handle.html
145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 145 class ActionGroupInvocationInput < Struct.new( :action_group_name, :api_path, :execution_type, :function, :invocation_id, :parameters, :request_body, :verb) SENSITIVE = [:action_group_name, :api_path, :function, :verb] include Aws::Structure end |
#function ⇒ String
The function in the action group to call.
145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 145 class ActionGroupInvocationInput < Struct.new( :action_group_name, :api_path, :execution_type, :function, :invocation_id, :parameters, :request_body, :verb) SENSITIVE = [:action_group_name, :api_path, :function, :verb] include Aws::Structure end |
#invocation_id ⇒ String
The unique identifier of the invocation. Only returned if the executionType is RETURN_CONTROL.
145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 145 class ActionGroupInvocationInput < Struct.new( :action_group_name, :api_path, :execution_type, :function, :invocation_id, :parameters, :request_body, :verb) SENSITIVE = [:action_group_name, :api_path, :function, :verb] include Aws::Structure end |
#parameters ⇒ Array<Types::Parameter>
The parameters in the Lambda input event.
145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 145 class ActionGroupInvocationInput < Struct.new( :action_group_name, :api_path, :execution_type, :function, :invocation_id, :parameters, :request_body, :verb) SENSITIVE = [:action_group_name, :api_path, :function, :verb] include Aws::Structure end |
#request_body ⇒ Types::RequestBody
The parameters in the request body for the Lambda input event.
145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 145 class ActionGroupInvocationInput < Struct.new( :action_group_name, :api_path, :execution_type, :function, :invocation_id, :parameters, :request_body, :verb) SENSITIVE = [:action_group_name, :api_path, :function, :verb] include Aws::Structure end |
#verb ⇒ String
The API method being used, based off the action group.
145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 145 class ActionGroupInvocationInput < Struct.new( :action_group_name, :api_path, :execution_type, :function, :invocation_id, :parameters, :request_body, :verb) SENSITIVE = [:action_group_name, :api_path, :function, :verb] include Aws::Structure end |