Class: Aws::BedrockAgentRuntime::Types::AgenticRetrieveActionDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::AgenticRetrieveActionDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Details of a retrieve action including the query and target retrievers.
Constant Summary collapse
- SENSITIVE =
[:input_query]
Instance Attribute Summary collapse
-
#input_query ⇒ Types::AgenticRetrieveMessageContent
The input query used for retrieval.
-
#source_retrievers ⇒ Array<Types::AgenticRetrieveSourceRetriever>
The list of source retrievers targeted by this action.
Instance Attribute Details
#input_query ⇒ Types::AgenticRetrieveMessageContent
The input query used for retrieval.
413 414 415 416 417 418 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 413 class AgenticRetrieveActionDetails < Struct.new( :input_query, :source_retrievers) SENSITIVE = [:input_query] include Aws::Structure end |
#source_retrievers ⇒ Array<Types::AgenticRetrieveSourceRetriever>
The list of source retrievers targeted by this action.
413 414 415 416 417 418 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 413 class AgenticRetrieveActionDetails < Struct.new( :input_query, :source_retrievers) SENSITIVE = [:input_query] include Aws::Structure end |