Class: Aws::BedrockAgentRuntime::Types::AgenticRetrieveGeneratedResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::AgenticRetrieveGeneratedResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
The generated response synthesized from retrieved results.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#answer ⇒ String
The generated answer text.
-
#citations ⇒ Array<Types::AgenticRetrieveCitation>
Citations mapping spans of the answer to supporting results.
Instance Attribute Details
#answer ⇒ String
The generated answer text.
592 593 594 595 596 597 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 592 class AgenticRetrieveGeneratedResponse < Struct.new( :answer, :citations) SENSITIVE = [] include Aws::Structure end |
#citations ⇒ Array<Types::AgenticRetrieveCitation>
Citations mapping spans of the answer to supporting results.
592 593 594 595 596 597 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 592 class AgenticRetrieveGeneratedResponse < Struct.new( :answer, :citations) SENSITIVE = [] include Aws::Structure end |