Class: Aws::BedrockAgentRuntime::Types::AgenticRetrieveMemoryRetrievalConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::AgenticRetrieveMemoryRetrievalConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
The long-term memory namespace that the agent might retrieve memory records from, and the filters applied to that retrieval. You must specify either namespace or namespacePath.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#metadata_filters ⇒ Array<Types::AgenticRetrieveMemoryMetadataFilter>
The metadata filter expressions that restrict retrieval to matching memory records.
-
#namespace ⇒ String
The namespace prefix to filter memory records by.
-
#namespace_path ⇒ String
The parent namespace to use for hierarchical retrievals.
-
#strategy_id ⇒ String
The extraction strategy ID that restricts retrieval to memory records produced by a single strategy.
Instance Attribute Details
#metadata_filters ⇒ Array<Types::AgenticRetrieveMemoryMetadataFilter>
The metadata filter expressions that restrict retrieval to matching memory records. You can specify a maximum of 5 expressions.
825 826 827 828 829 830 831 832 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 825 class AgenticRetrieveMemoryRetrievalConfig < Struct.new( :metadata_filters, :namespace, :namespace_path, :strategy_id) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace prefix to filter memory records by. The agent retrieves memory records in namespaces that start with the provided prefix. You must specify either namespace or namespacePath.
825 826 827 828 829 830 831 832 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 825 class AgenticRetrieveMemoryRetrievalConfig < Struct.new( :metadata_filters, :namespace, :namespace_path, :strategy_id) SENSITIVE = [] include Aws::Structure end |
#namespace_path ⇒ String
The parent namespace to use for hierarchical retrievals. The agent retrieves all memory records whose namespace falls under the same parent hierarchy. You must specify either namespace or namespacePath.
825 826 827 828 829 830 831 832 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 825 class AgenticRetrieveMemoryRetrievalConfig < Struct.new( :metadata_filters, :namespace, :namespace_path, :strategy_id) SENSITIVE = [] include Aws::Structure end |
#strategy_id ⇒ String
The extraction strategy ID that restricts retrieval to memory records produced by a single strategy. Omit this parameter to retrieve records from every strategy on the memory resource.
825 826 827 828 829 830 831 832 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 825 class AgenticRetrieveMemoryRetrievalConfig < Struct.new( :metadata_filters, :namespace, :namespace_path, :strategy_id) SENSITIVE = [] include Aws::Structure end |