Class: Aws::BedrockAgentRuntime::Types::AgenticRetrieveMemoryRetrieveDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::AgenticRetrieveMemoryRetrieveDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
A long-term memory retrieval that the agent chose to perform. The record reports the query and the namespace. The corresponding Retrieval step reports the results.
Constant Summary collapse
- SENSITIVE =
[:input_query]
Instance Attribute Summary collapse
-
#input_query ⇒ Types::AgenticRetrieveMessageContent
The query that the agent composed.
-
#memory_id ⇒ String
The identifier of the AgentCore Memory resource retrieved from.
-
#namespace ⇒ String
The namespace prefix retrieved from, as supplied in the request.
-
#namespace_path ⇒ String
The parent namespace retrieved from hierarchically, as supplied in the request.
-
#strategy_id ⇒ String
The extraction strategy that restricted retrieval, if the request specified one.
Instance Attribute Details
#input_query ⇒ Types::AgenticRetrieveMessageContent
The query that the agent composed.
864 865 866 867 868 869 870 871 872 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 864 class AgenticRetrieveMemoryRetrieveDetails < Struct.new( :input_query, :memory_id, :namespace, :namespace_path, :strategy_id) SENSITIVE = [:input_query] include Aws::Structure end |
#memory_id ⇒ String
The identifier of the AgentCore Memory resource retrieved from.
864 865 866 867 868 869 870 871 872 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 864 class AgenticRetrieveMemoryRetrieveDetails < Struct.new( :input_query, :memory_id, :namespace, :namespace_path, :strategy_id) SENSITIVE = [:input_query] include Aws::Structure end |
#namespace ⇒ String
The namespace prefix retrieved from, as supplied in the request. This field is present when the request specified namespace.
864 865 866 867 868 869 870 871 872 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 864 class AgenticRetrieveMemoryRetrieveDetails < Struct.new( :input_query, :memory_id, :namespace, :namespace_path, :strategy_id) SENSITIVE = [:input_query] include Aws::Structure end |
#namespace_path ⇒ String
The parent namespace retrieved from hierarchically, as supplied in the request. This field is present when the request specified namespacePath.
864 865 866 867 868 869 870 871 872 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 864 class AgenticRetrieveMemoryRetrieveDetails < Struct.new( :input_query, :memory_id, :namespace, :namespace_path, :strategy_id) SENSITIVE = [:input_query] include Aws::Structure end |
#strategy_id ⇒ String
The extraction strategy that restricted retrieval, if the request specified one.
864 865 866 867 868 869 870 871 872 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 864 class AgenticRetrieveMemoryRetrieveDetails < Struct.new( :input_query, :memory_id, :namespace, :namespace_path, :strategy_id) SENSITIVE = [:input_query] include Aws::Structure end |