Class: Aws::BedrockAgentRuntime::Types::AgenticRetrieveStreamResponseOutput

Inherits:
Enumerator
  • Object
show all
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

The streaming output for agentic retrieval, containing results, traces, and errors.

EventStream is an Enumerator of Events.

#event_types #=> Array, returns all modeled event types in the stream

Instance Method Summary collapse

Instance Method Details

#event_typesObject



10209
10210
10211
10212
10213
10214
10215
10216
10217
10218
10219
10220
10221
10222
10223
10224
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10209

def event_types
  [
    :access_denied_exception,
    :bad_gateway_exception,
    :conflict_exception,
    :dependency_failed_exception,
    :internal_server_exception,
    :resource_not_found_exception,
    :response_event,
    :result,
    :service_quota_exceeded_exception,
    :throttling_exception,
    :trace_event,
    :validation_exception
  ]
end