Class: Aws::BedrockAgentRuntime::Types::AgenticRetrieveWarning
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::AgenticRetrieveWarning
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Note:
AgenticRetrieveWarning is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of AgenticRetrieveWarning corresponding to the set member.
A warning generated during agentic retrieval.
Defined Under Namespace
Classes: Guardrail, Message, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#guardrail ⇒ Types::AgenticRetrieveGuardrailWarning
A warning from a guardrail evaluation.
-
#message ⇒ Types::AgenticRetrieveWarningMessage
A general warning message.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#guardrail ⇒ Types::AgenticRetrieveGuardrailWarning
A warning from a guardrail evaluation.
1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1239 class AgenticRetrieveWarning < Struct.new( :guardrail, :message, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Guardrail < AgenticRetrieveWarning; end class Message < AgenticRetrieveWarning; end class Unknown < AgenticRetrieveWarning; end end |
#message ⇒ Types::AgenticRetrieveWarningMessage
A general warning message.
1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1239 class AgenticRetrieveWarning < Struct.new( :guardrail, :message, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Guardrail < AgenticRetrieveWarning; end class Message < AgenticRetrieveWarning; end class Unknown < AgenticRetrieveWarning; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
1239 1240 1241 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1239 def unknown @unknown end |