Class: Aws::BedrockAgentRuntime::Types::AgenticRetrieveWarning
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::AgenticRetrieveWarning
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Note:
AgenticRetrieveWarning is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of AgenticRetrieveWarning corresponding to the set member.
A warning generated during agentic retrieval.
Defined Under Namespace
Classes: Guardrail, Message, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#guardrail ⇒ Types::AgenticRetrieveGuardrailWarning
A warning from a guardrail evaluation.
-
#message ⇒ Types::AgenticRetrieveWarningMessage
A general warning message.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#guardrail ⇒ Types::AgenticRetrieveGuardrailWarning
A warning from a guardrail evaluation.
963 964 965 966 967 968 969 970 971 972 973 974 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 963 class AgenticRetrieveWarning < Struct.new( :guardrail, :message, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Guardrail < AgenticRetrieveWarning; end class Message < AgenticRetrieveWarning; end class Unknown < AgenticRetrieveWarning; end end |
#message ⇒ Types::AgenticRetrieveWarningMessage
A general warning message.
963 964 965 966 967 968 969 970 971 972 973 974 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 963 class AgenticRetrieveWarning < Struct.new( :guardrail, :message, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Guardrail < AgenticRetrieveWarning; end class Message < AgenticRetrieveWarning; end class Unknown < AgenticRetrieveWarning; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
963 964 965 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 963 def unknown @unknown end |