Class: Aws::BedrockAgentRuntime::Types::ApiRequestBody
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::ApiRequestBody
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
The request body to provide for the API request, as the agent elicited from the user.
This data type is used in the following API operations:
- InvokeAgent response][1
^
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content ⇒ Hash<String,Types::PropertyParameters>
The content of the request body.
Instance Attribute Details
#content ⇒ Hash<String,Types::PropertyParameters>
The content of the request body. The key of the object in this field is a media type defining the format of the request body.
513 514 515 516 517 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 513 class ApiRequestBody < Struct.new( :content) SENSITIVE = [] include Aws::Structure end |