Class: Aws::BedrockAgentRuntime::Types::Attribution
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::Attribution
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains citations for a part of an agent response.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#citations ⇒ Array<Types::Citation>
A list of citations and related information for a part of an agent response.
Instance Attribute Details
#citations ⇒ Array<Types::Citation>
A list of citations and related information for a part of an agent response.
597 598 599 600 601 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 597 class Attribution < Struct.new( :citations) SENSITIVE = [] include Aws::Structure end |