Class: Aws::BedrockAgentRuntime::Types::BedrockSessionContentBlock

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Note:

BedrockSessionContentBlock is a union - when making an API calls you must set exactly one of the members.

Note:

BedrockSessionContentBlock is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of BedrockSessionContentBlock corresponding to the set member.

A block of content that you pass to, or receive from, a Amazon Bedrock session in an invocation step. You pass the content to a session in the ‘payLoad` of the [PutInvocationStep] API operation. You retrieve the content with the [GetInvocationStep] API operation.

For more information about sessions, see [Store and retrieve conversation history and context with Amazon Bedrock sessions].

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_PutInvocationStep.html [2]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_GetInvocationStep.html [3]: docs.aws.amazon.com/bedrock/latest/userguide/sessions.html

Direct Known Subclasses

Image, Text, Unknown

Defined Under Namespace

Classes: Image, Text, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#imageTypes::ImageBlock

The image in the invocation step.

Returns:



736
737
738
739
740
741
742
743
744
745
746
747
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 736

class BedrockSessionContentBlock < Struct.new(
  :image,
  :text,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Image < BedrockSessionContentBlock; end
  class Text < BedrockSessionContentBlock; end
  class Unknown < BedrockSessionContentBlock; end
end

#textString

The text in the invocation step.

Returns:

  • (String)


736
737
738
739
740
741
742
743
744
745
746
747
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 736

class BedrockSessionContentBlock < Struct.new(
  :image,
  :text,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Image < BedrockSessionContentBlock; end
  class Text < BedrockSessionContentBlock; end
  class Unknown < BedrockSessionContentBlock; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



736
737
738
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 736

def unknown
  @unknown
end