Class: Aws::BedrockAgentRuntime::Types::CheckIngestedDocumentAclResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#has_accessBoolean

Specifies whether the user has access to the document based on the ingested access control list (ACL). Returns true if the user is allowed access, and false otherwise.

Returns:

  • (Boolean)


1510
1511
1512
1513
1514
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1510

class CheckIngestedDocumentAclResponse < Struct.new(
  :has_access)
  SENSITIVE = []
  include Aws::Structure
end