Class: Aws::BedrockAgentRuntime::Types::Citation
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::Citation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
An object containing a segment of the generated response that is based on a source in the knowledge base, alongside information about the source.
This data type is used in the following API operations:
- InvokeAgent response][1
-
– in the ‘citations` field
- RetrieveAndGenerate response][2
-
– in the ‘citations` field
[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_InvokeAgent.html#API_agent-runtime_InvokeAgent_ResponseSyntax [2]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_RetrieveAndGenerate.html#API_agent-runtime_RetrieveAndGenerate_ResponseSyntax
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#generated_response_part ⇒ Types::GeneratedResponsePart
Contains the generated response and metadata.
-
#retrieved_references ⇒ Array<Types::RetrievedReference>
Contains metadata about the sources cited for the generated response.
Instance Attribute Details
#generated_response_part ⇒ Types::GeneratedResponsePart
Contains the generated response and metadata
842 843 844 845 846 847 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 842 class Citation < Struct.new( :generated_response_part, :retrieved_references) SENSITIVE = [] include Aws::Structure end |
#retrieved_references ⇒ Array<Types::RetrievedReference>
Contains metadata about the sources cited for the generated response.
842 843 844 845 846 847 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 842 class Citation < Struct.new( :generated_response_part, :retrieved_references) SENSITIVE = [] include Aws::Structure end |