Class: Aws::BedrockAgentRuntime::Types::Collaborator
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::Collaborator
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
List of inline collaborators.
Constant Summary collapse
- SENSITIVE =
[:agent_name, :instruction, :prompt_override_configuration]
Instance Attribute Summary collapse
-
#action_groups ⇒ Array<Types::AgentActionGroup>
List of action groups with each action group defining tasks the inline collaborator agent needs to carry out.
-
#agent_collaboration ⇒ String
Defines how the inline supervisor agent handles information across multiple collaborator agents to coordinate a final response.
-
#agent_name ⇒ String
Name of the inline collaborator agent which must be the same name as specified for
collaboratorName. -
#collaborator_configurations ⇒ Array<Types::CollaboratorConfiguration>
Settings of the collaborator agent.
-
#customer_encryption_key_arn ⇒ String
The Amazon Resource Name (ARN) of the AWS KMS key that encrypts the inline collaborator.
-
#foundation_model ⇒ String
The foundation model used by the inline collaborator agent.
-
#guardrail_configuration ⇒ Types::GuardrailConfigurationWithArn
Details of the guardwrail associated with the inline collaborator.
-
#idle_session_ttl_in_seconds ⇒ Integer
The number of seconds for which the Amazon Bedrock keeps information about the user's conversation with the inline collaborator agent.
-
#instruction ⇒ String
Instruction that tell the inline collaborator agent what it should do and how it should interact with users.
-
#knowledge_bases ⇒ Array<Types::KnowledgeBase>
Knowledge base associated with the inline collaborator agent.
-
#prompt_override_configuration ⇒ Types::PromptOverrideConfiguration
Contains configurations to override prompt templates in different parts of an inline collaborator sequence.
Instance Attribute Details
#action_groups ⇒ Array<Types::AgentActionGroup>
List of action groups with each action group defining tasks the inline collaborator agent needs to carry out.
1968 1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1968 class Collaborator < Struct.new( :action_groups, :agent_collaboration, :agent_name, :collaborator_configurations, :customer_encryption_key_arn, :foundation_model, :guardrail_configuration, :idle_session_ttl_in_seconds, :instruction, :knowledge_bases, :prompt_override_configuration) SENSITIVE = [:agent_name, :instruction, :prompt_override_configuration] include Aws::Structure end |
#agent_collaboration ⇒ String
Defines how the inline supervisor agent handles information across multiple collaborator agents to coordinate a final response.
1968 1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1968 class Collaborator < Struct.new( :action_groups, :agent_collaboration, :agent_name, :collaborator_configurations, :customer_encryption_key_arn, :foundation_model, :guardrail_configuration, :idle_session_ttl_in_seconds, :instruction, :knowledge_bases, :prompt_override_configuration) SENSITIVE = [:agent_name, :instruction, :prompt_override_configuration] include Aws::Structure end |
#agent_name ⇒ String
Name of the inline collaborator agent which must be the same name as
specified for collaboratorName.
1968 1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1968 class Collaborator < Struct.new( :action_groups, :agent_collaboration, :agent_name, :collaborator_configurations, :customer_encryption_key_arn, :foundation_model, :guardrail_configuration, :idle_session_ttl_in_seconds, :instruction, :knowledge_bases, :prompt_override_configuration) SENSITIVE = [:agent_name, :instruction, :prompt_override_configuration] include Aws::Structure end |
#collaborator_configurations ⇒ Array<Types::CollaboratorConfiguration>
Settings of the collaborator agent.
1968 1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1968 class Collaborator < Struct.new( :action_groups, :agent_collaboration, :agent_name, :collaborator_configurations, :customer_encryption_key_arn, :foundation_model, :guardrail_configuration, :idle_session_ttl_in_seconds, :instruction, :knowledge_bases, :prompt_override_configuration) SENSITIVE = [:agent_name, :instruction, :prompt_override_configuration] include Aws::Structure end |
#customer_encryption_key_arn ⇒ String
The Amazon Resource Name (ARN) of the AWS KMS key that encrypts the inline collaborator.
1968 1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1968 class Collaborator < Struct.new( :action_groups, :agent_collaboration, :agent_name, :collaborator_configurations, :customer_encryption_key_arn, :foundation_model, :guardrail_configuration, :idle_session_ttl_in_seconds, :instruction, :knowledge_bases, :prompt_override_configuration) SENSITIVE = [:agent_name, :instruction, :prompt_override_configuration] include Aws::Structure end |
#foundation_model ⇒ String
The foundation model used by the inline collaborator agent.
1968 1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1968 class Collaborator < Struct.new( :action_groups, :agent_collaboration, :agent_name, :collaborator_configurations, :customer_encryption_key_arn, :foundation_model, :guardrail_configuration, :idle_session_ttl_in_seconds, :instruction, :knowledge_bases, :prompt_override_configuration) SENSITIVE = [:agent_name, :instruction, :prompt_override_configuration] include Aws::Structure end |
#guardrail_configuration ⇒ Types::GuardrailConfigurationWithArn
Details of the guardwrail associated with the inline collaborator.
1968 1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1968 class Collaborator < Struct.new( :action_groups, :agent_collaboration, :agent_name, :collaborator_configurations, :customer_encryption_key_arn, :foundation_model, :guardrail_configuration, :idle_session_ttl_in_seconds, :instruction, :knowledge_bases, :prompt_override_configuration) SENSITIVE = [:agent_name, :instruction, :prompt_override_configuration] include Aws::Structure end |
#idle_session_ttl_in_seconds ⇒ Integer
The number of seconds for which the Amazon Bedrock keeps information about the user's conversation with the inline collaborator agent.
A user interaction remains active for the amount of time specified. If no conversation occurs during this time, the session expires and Amazon Bedrock deletes any data provided before the timeout.
1968 1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1968 class Collaborator < Struct.new( :action_groups, :agent_collaboration, :agent_name, :collaborator_configurations, :customer_encryption_key_arn, :foundation_model, :guardrail_configuration, :idle_session_ttl_in_seconds, :instruction, :knowledge_bases, :prompt_override_configuration) SENSITIVE = [:agent_name, :instruction, :prompt_override_configuration] include Aws::Structure end |
#instruction ⇒ String
Instruction that tell the inline collaborator agent what it should do and how it should interact with users.
1968 1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1968 class Collaborator < Struct.new( :action_groups, :agent_collaboration, :agent_name, :collaborator_configurations, :customer_encryption_key_arn, :foundation_model, :guardrail_configuration, :idle_session_ttl_in_seconds, :instruction, :knowledge_bases, :prompt_override_configuration) SENSITIVE = [:agent_name, :instruction, :prompt_override_configuration] include Aws::Structure end |
#knowledge_bases ⇒ Array<Types::KnowledgeBase>
Knowledge base associated with the inline collaborator agent.
1968 1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1968 class Collaborator < Struct.new( :action_groups, :agent_collaboration, :agent_name, :collaborator_configurations, :customer_encryption_key_arn, :foundation_model, :guardrail_configuration, :idle_session_ttl_in_seconds, :instruction, :knowledge_bases, :prompt_override_configuration) SENSITIVE = [:agent_name, :instruction, :prompt_override_configuration] include Aws::Structure end |
#prompt_override_configuration ⇒ Types::PromptOverrideConfiguration
Contains configurations to override prompt templates in different parts of an inline collaborator sequence. For more information, see Advanced prompts.
1968 1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1968 class Collaborator < Struct.new( :action_groups, :agent_collaboration, :agent_name, :collaborator_configurations, :customer_encryption_key_arn, :foundation_model, :guardrail_configuration, :idle_session_ttl_in_seconds, :instruction, :knowledge_bases, :prompt_override_configuration) SENSITIVE = [:agent_name, :instruction, :prompt_override_configuration] include Aws::Structure end |