Class: Aws::BedrockAgentRuntime::Types::ContentBody
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::ContentBody
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains the body of the API response.
This data type is used in the following API operations:
-
In the ‘returnControlInvocationResults` field of the [InvokeAgent request]
^
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#body ⇒ String
The body of the API response.
-
#images ⇒ Array<Types::ImageInput>
Lists details, including format and source, for the image in the response from the function call.
Instance Attribute Details
#body ⇒ String
The body of the API response.
1137 1138 1139 1140 1141 1142 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1137 class ContentBody < Struct.new( :body, :images) SENSITIVE = [] include Aws::Structure end |
#images ⇒ Array<Types::ImageInput>
Lists details, including format and source, for the image in the response from the function call. You can specify only one image and the function in the ‘returnControlInvocationResults` must be a computer use action. For more information, see [Configure an Amazon Bedrock Agent to complete tasks with computer use tools].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/agent-computer-use.html
1137 1138 1139 1140 1141 1142 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1137 class ContentBody < Struct.new( :body, :images) SENSITIVE = [] include Aws::Structure end |