Class: Aws::BedrockAgentRuntime::Types::CreateInvocationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::CreateInvocationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description for the interactions in the invocation.
-
#invocation_id ⇒ String
A unique identifier for the invocation in UUID format.
-
#session_identifier ⇒ String
The unique identifier for the associated session for the invocation.
Instance Attribute Details
#description ⇒ String
A description for the interactions in the invocation. For example, “User asking about weather in Seattle”.
1175 1176 1177 1178 1179 1180 1181 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1175 class CreateInvocationRequest < Struct.new( :description, :invocation_id, :session_identifier) SENSITIVE = [] include Aws::Structure end |
#invocation_id ⇒ String
A unique identifier for the invocation in UUID format.
1175 1176 1177 1178 1179 1180 1181 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1175 class CreateInvocationRequest < Struct.new( :description, :invocation_id, :session_identifier) SENSITIVE = [] include Aws::Structure end |
#session_identifier ⇒ String
The unique identifier for the associated session for the invocation. You can specify either the session’s ‘sessionId` or its Amazon Resource Name (ARN).
1175 1176 1177 1178 1179 1180 1181 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1175 class CreateInvocationRequest < Struct.new( :description, :invocation_id, :session_identifier) SENSITIVE = [] include Aws::Structure end |