Class: Aws::BedrockAgentRuntime::Types::CreateSessionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#encryption_key_arnString

The Amazon Resource Name (ARN) of the KMS key to use to encrypt the session data. The user or role creating the session must have permission to use the key. For more information, see [Amazon Bedrock session encryption].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/session-encryption.html

Returns:

  • (String)


1886
1887
1888
1889
1890
1891
1892
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1886

class CreateSessionRequest < Struct.new(
  :encryption_key_arn,
  :session_metadata,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#session_metadataHash<String,String>

A map of key-value pairs containing attributes to be persisted across the session. For example, the user’s ID, their language preference, and the type of device they are using.

Returns:

  • (Hash<String,String>)


1886
1887
1888
1889
1890
1891
1892
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1886

class CreateSessionRequest < Struct.new(
  :encryption_key_arn,
  :session_metadata,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Specify the key-value pairs for the tags that you want to attach to the session.

Returns:

  • (Hash<String,String>)


1886
1887
1888
1889
1890
1891
1892
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1886

class CreateSessionRequest < Struct.new(
  :encryption_key_arn,
  :session_metadata,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end