Class: Aws::BedrockAgentRuntime::Types::DeleteAgentMemoryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_alias_idString

The unique identifier of an alias of an agent.

Returns:

  • (String)


1333
1334
1335
1336
1337
1338
1339
1340
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1333

class DeleteAgentMemoryRequest < Struct.new(
  :agent_alias_id,
  :agent_id,
  :memory_id,
  :session_id)
  SENSITIVE = []
  include Aws::Structure
end

#agent_idString

The unique identifier of the agent to which the alias belongs.

Returns:

  • (String)


1333
1334
1335
1336
1337
1338
1339
1340
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1333

class DeleteAgentMemoryRequest < Struct.new(
  :agent_alias_id,
  :agent_id,
  :memory_id,
  :session_id)
  SENSITIVE = []
  include Aws::Structure
end

#memory_idString

The unique identifier of the memory.

Returns:

  • (String)


1333
1334
1335
1336
1337
1338
1339
1340
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1333

class DeleteAgentMemoryRequest < Struct.new(
  :agent_alias_id,
  :agent_id,
  :memory_id,
  :session_id)
  SENSITIVE = []
  include Aws::Structure
end

#session_idString

The unique session identifier of the memory.

Returns:

  • (String)


1333
1334
1335
1336
1337
1338
1339
1340
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1333

class DeleteAgentMemoryRequest < Struct.new(
  :agent_alias_id,
  :agent_id,
  :memory_id,
  :session_id)
  SENSITIVE = []
  include Aws::Structure
end