Class: Aws::BedrockAgentRuntime::Types::DeleteAgentMemoryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_alias_idString

The unique identifier of an alias of an agent.

Returns:

  • (String)


929
930
931
932
933
934
935
936
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 929

class DeleteAgentMemoryRequest < Struct.new(
  :agent_alias_id,
  :agent_id,
  :memory_id,
  :session_id)
  SENSITIVE = []
  include Aws::Structure
end

#agent_idString

The unique identifier of the agent to which the alias belongs.

Returns:

  • (String)


929
930
931
932
933
934
935
936
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 929

class DeleteAgentMemoryRequest < Struct.new(
  :agent_alias_id,
  :agent_id,
  :memory_id,
  :session_id)
  SENSITIVE = []
  include Aws::Structure
end

#memory_idString

The unique identifier of the memory.

Returns:

  • (String)


929
930
931
932
933
934
935
936
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 929

class DeleteAgentMemoryRequest < Struct.new(
  :agent_alias_id,
  :agent_id,
  :memory_id,
  :session_id)
  SENSITIVE = []
  include Aws::Structure
end

#session_idString

The unique session identifier of the memory.

Returns:

  • (String)


929
930
931
932
933
934
935
936
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 929

class DeleteAgentMemoryRequest < Struct.new(
  :agent_alias_id,
  :agent_id,
  :memory_id,
  :session_id)
  SENSITIVE = []
  include Aws::Structure
end