Class: Aws::BedrockAgentRuntime::Types::DocumentAcl
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::DocumentAcl
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
The access control list for a document, containing allow and deny membership lists. Each list specifies conditions that determine which users and groups are granted or denied access.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allow_list ⇒ Types::DocumentAclMembership
The list of principals allowed access to the document.
-
#deny_list ⇒ Types::DocumentAclMembership
The list of principals denied access to the document.
Instance Attribute Details
#allow_list ⇒ Types::DocumentAclMembership
The list of principals allowed access to the document.
2098 2099 2100 2101 2102 2103 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2098 class DocumentAcl < Struct.new( :allow_list, :deny_list) SENSITIVE = [] include Aws::Structure end |
#deny_list ⇒ Types::DocumentAclMembership
The list of principals denied access to the document.
2098 2099 2100 2101 2102 2103 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2098 class DocumentAcl < Struct.new( :allow_list, :deny_list) SENSITIVE = [] include Aws::Structure end |