Class: Aws::BedrockAgentRuntime::Types::DocumentAclCondition
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::DocumentAclCondition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
A condition within a document access control list (ACL) membership, specifying users and groups that are evaluated together.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#condition_operator ⇒ String
The logical operator for combining users and groups within this condition.
-
#groups ⇒ Array<Types::DocumentAclGroup>
The list of group entries in this condition.
-
#users ⇒ Array<Types::DocumentAclUser>
The list of user entries in this condition.
Instance Attribute Details
#condition_operator ⇒ String
The logical operator for combining users and groups within this
condition. Valid values: AND – Both a user match and a group match
are required. OR – Either a user match or a group match is
sufficient.
2125 2126 2127 2128 2129 2130 2131 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2125 class DocumentAclCondition < Struct.new( :condition_operator, :groups, :users) SENSITIVE = [] include Aws::Structure end |
#groups ⇒ Array<Types::DocumentAclGroup>
The list of group entries in this condition.
2125 2126 2127 2128 2129 2130 2131 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2125 class DocumentAclCondition < Struct.new( :condition_operator, :groups, :users) SENSITIVE = [] include Aws::Structure end |
#users ⇒ Array<Types::DocumentAclUser>
The list of user entries in this condition.
2125 2126 2127 2128 2129 2130 2131 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2125 class DocumentAclCondition < Struct.new( :condition_operator, :groups, :users) SENSITIVE = [] include Aws::Structure end |