Class: Aws::BedrockAgentRuntime::Types::DocumentAclUser
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::DocumentAclUser
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
A user entry within a document access control list (ACL) condition.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
The identifier of the user.
-
#type ⇒ String
The membership type indicating the scope of the user entry.
Instance Attribute Details
#id ⇒ String
The identifier of the user.
2185 2186 2187 2188 2189 2190 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2185 class DocumentAclUser < Struct.new( :id, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The membership type indicating the scope of the user entry.
2185 2186 2187 2188 2189 2190 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2185 class DocumentAclUser < Struct.new( :id, :type) SENSITIVE = [] include Aws::Structure end |