Class: Aws::BedrockAgentRuntime::Types::ExternalSourcesGenerationConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::ExternalSourcesGenerationConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains the generation configuration of the external source wrapper object.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_model_request_fields ⇒ Hash<String,Hash,Array,String,Numeric,Boolean>
Additional model parameters and their corresponding values not included in the textInferenceConfig structure for an external source.
-
#guardrail_configuration ⇒ Types::GuardrailConfiguration
The configuration details for the guardrail.
-
#inference_config ⇒ Types::InferenceConfig
Configuration settings for inference when using RetrieveAndGenerate to generate responses while using an external source.
-
#performance_config ⇒ Types::PerformanceConfiguration
The latency configuration for the model.
-
#prompt_template ⇒ Types::PromptTemplate
Contain the textPromptTemplate string for the external source wrapper object.
Instance Attribute Details
#additional_model_request_fields ⇒ Hash<String,Hash,Array,String,Numeric,Boolean>
Additional model parameters and their corresponding values not included in the textInferenceConfig structure for an external source. Takes in custom model parameters specific to the language model being used.
2283 2284 2285 2286 2287 2288 2289 2290 2291 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2283 class ExternalSourcesGenerationConfiguration < Struct.new( :additional_model_request_fields, :guardrail_configuration, :inference_config, :performance_config, :prompt_template) SENSITIVE = [] include Aws::Structure end |
#guardrail_configuration ⇒ Types::GuardrailConfiguration
The configuration details for the guardrail.
2283 2284 2285 2286 2287 2288 2289 2290 2291 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2283 class ExternalSourcesGenerationConfiguration < Struct.new( :additional_model_request_fields, :guardrail_configuration, :inference_config, :performance_config, :prompt_template) SENSITIVE = [] include Aws::Structure end |
#inference_config ⇒ Types::InferenceConfig
Configuration settings for inference when using RetrieveAndGenerate to generate responses while using an external source.
2283 2284 2285 2286 2287 2288 2289 2290 2291 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2283 class ExternalSourcesGenerationConfiguration < Struct.new( :additional_model_request_fields, :guardrail_configuration, :inference_config, :performance_config, :prompt_template) SENSITIVE = [] include Aws::Structure end |
#performance_config ⇒ Types::PerformanceConfiguration
The latency configuration for the model.
2283 2284 2285 2286 2287 2288 2289 2290 2291 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2283 class ExternalSourcesGenerationConfiguration < Struct.new( :additional_model_request_fields, :guardrail_configuration, :inference_config, :performance_config, :prompt_template) SENSITIVE = [] include Aws::Structure end |
#prompt_template ⇒ Types::PromptTemplate
Contain the textPromptTemplate string for the external source wrapper object.
2283 2284 2285 2286 2287 2288 2289 2290 2291 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2283 class ExternalSourcesGenerationConfiguration < Struct.new( :additional_model_request_fields, :guardrail_configuration, :inference_config, :performance_config, :prompt_template) SENSITIVE = [] include Aws::Structure end |