Class: Aws::BedrockAgentRuntime::Types::ExternalSourcesRetrieveAndGenerateConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

The configurations of the external source wrapper object in the ‘retrieveAndGenerate` function.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#generation_configurationTypes::ExternalSourcesGenerationConfiguration

The prompt used with the external source wrapper object with the ‘retrieveAndGenerate` function.



2161
2162
2163
2164
2165
2166
2167
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2161

class ExternalSourcesRetrieveAndGenerateConfiguration < Struct.new(
  :generation_configuration,
  :model_arn,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end

#model_arnString

The model Amazon Resource Name (ARN) for the external source wrapper object in the ‘retrieveAndGenerate` function.

Returns:

  • (String)


2161
2162
2163
2164
2165
2166
2167
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2161

class ExternalSourcesRetrieveAndGenerateConfiguration < Struct.new(
  :generation_configuration,
  :model_arn,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end

#sourcesArray<Types::ExternalSource>

The document for the external source wrapper object in the ‘retrieveAndGenerate` function.

Returns:



2161
2162
2163
2164
2165
2166
2167
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2161

class ExternalSourcesRetrieveAndGenerateConfiguration < Struct.new(
  :generation_configuration,
  :model_arn,
  :sources)
  SENSITIVE = []
  include Aws::Structure
end