Class: Aws::BedrockAgentRuntime::Types::FieldForReranking
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::FieldForReranking
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains information for a metadata field to include in or exclude from consideration when reranking.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#field_name ⇒ String
The name of a metadata field to include in or exclude from consideration when reranking.
Instance Attribute Details
#field_name ⇒ String
The name of a metadata field to include in or exclude from consideration when reranking.
2208 2209 2210 2211 2212 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2208 class FieldForReranking < Struct.new( :field_name) SENSITIVE = [] include Aws::Structure end |