Class: Aws::BedrockAgentRuntime::Types::FieldForReranking

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains information for a metadata field to include in or exclude from consideration when reranking.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#field_nameString

The name of a metadata field to include in or exclude from consideration when reranking.

Returns:

  • (String)


1552
1553
1554
1555
1556
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1552

class FieldForReranking < Struct.new(
  :field_name)
  SENSITIVE = []
  include Aws::Structure
end