Class: Aws::BedrockAgentRuntime::Types::FileSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::FileSource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
The source file of the content contained in the wrapper object.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#byte_content ⇒ Types::ByteContentFile
The data and the text of the attached files.
-
#s3_location ⇒ Types::S3ObjectFile
The s3 location of the files to attach.
-
#source_type ⇒ String
The source type of the files to attach.
Instance Attribute Details
#byte_content ⇒ Types::ByteContentFile
The data and the text of the attached files.
1124 1125 1126 1127 1128 1129 1130 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1124 class FileSource < Struct.new( :byte_content, :s3_location, :source_type) SENSITIVE = [] include Aws::Structure end |
#s3_location ⇒ Types::S3ObjectFile
The s3 location of the files to attach.
1124 1125 1126 1127 1128 1129 1130 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1124 class FileSource < Struct.new( :byte_content, :s3_location, :source_type) SENSITIVE = [] include Aws::Structure end |
#source_type ⇒ String
The source type of the files to attach.
1124 1125 1126 1127 1128 1129 1130 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1124 class FileSource < Struct.new( :byte_content, :s3_location, :source_type) SENSITIVE = [] include Aws::Structure end |