Class: Aws::BedrockAgentRuntime::Types::FlowExecutionContent
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::FlowExecutionContent
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Note:
FlowExecutionContent is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of FlowExecutionContent corresponding to the set member.
Contains the content of an flow execution input or output field.
<note markdown=“1”> Flow executions is in preview release for Amazon Bedrock and is subject to change.
</note>
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#document ⇒ Hash, ...
The document content of the field, which can contain text or structured data.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#document ⇒ Hash, ...
The document content of the field, which can contain text or structured data.
2336 2337 2338 2339 2340 2341 2342 2343 2344 2345 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2336 class FlowExecutionContent < Struct.new( :document, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Document < FlowExecutionContent; end class Unknown < FlowExecutionContent; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
2336 2337 2338 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2336 def unknown @unknown end |