Class: Aws::BedrockAgentRuntime::Types::FlowExecutionContent

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Note:

FlowExecutionContent is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of FlowExecutionContent corresponding to the set member.

Contains the content of an flow execution input or output field.

<note markdown=“1”> Flow executions is in preview release for Amazon Bedrock and is subject to change.

</note>

Direct Known Subclasses

Document, Unknown

Defined Under Namespace

Classes: Document, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#documentHash, ...

The document content of the field, which can contain text or structured data.

Returns:

  • (Hash, Array, String, Numeric, Boolean)


1680
1681
1682
1683
1684
1685
1686
1687
1688
1689
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1680

class FlowExecutionContent < Struct.new(
  :document,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Document < FlowExecutionContent; end
  class Unknown < FlowExecutionContent; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



1680
1681
1682
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1680

def unknown
  @unknown
end