Class: Aws::BedrockAgentRuntime::Types::FlowExecutionEvent
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::FlowExecutionEvent
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
FlowExecutionEvent is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of FlowExecutionEvent corresponding to the set member.
Represents an event that occurred during an flow execution. This is a union type that can contain one of several event types, such as node input and output events; flow input and output events; condition node result events, or failure events.
<note markdown=“1”> Flow executions is in preview release for Amazon Bedrock and is subject to change.
</note>
Direct Known Subclasses
ConditionResultEvent, FlowFailureEvent, FlowInputEvent, FlowOutputEvent, NodeActionEvent, NodeDependencyEvent, NodeFailureEvent, NodeInputEvent, NodeOutputEvent, Unknown
Defined Under Namespace
Classes: ConditionResultEvent, FlowFailureEvent, FlowInputEvent, FlowOutputEvent, NodeActionEvent, NodeDependencyEvent, NodeFailureEvent, NodeInputEvent, NodeOutputEvent, Unknown
Constant Summary collapse
- SENSITIVE =
[:condition_result_event, :flow_failure_event, :flow_input_event, :flow_output_event, :node_action_event, :node_dependency_event, :node_failure_event, :node_input_event, :node_output_event]
Instance Attribute Summary collapse
-
#condition_result_event ⇒ Types::ConditionResultEvent
Contains information about a condition evaluation result during the flow execution.
-
#flow_failure_event ⇒ Types::FlowFailureEvent
Contains information about a failure that occurred at the flow level during execution.
-
#flow_input_event ⇒ Types::FlowExecutionInputEvent
Contains information about the inputs provided to the flow at the start of execution.
-
#flow_output_event ⇒ Types::FlowExecutionOutputEvent
Contains information about the outputs produced by the flow at the end of execution.
-
#node_action_event ⇒ Types::NodeActionEvent
Contains information about an action (operation) called by a node during execution.
-
#node_dependency_event ⇒ Types::NodeDependencyEvent
Contains information about an internal trace of a specific node during execution.
-
#node_failure_event ⇒ Types::NodeFailureEvent
Contains information about a failure that occurred at a specific node during execution.
-
#node_input_event ⇒ Types::NodeInputEvent
Contains information about the inputs provided to a specific node during execution.
-
#node_output_event ⇒ Types::NodeOutputEvent
Contains information about the outputs produced by a specific node during execution.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#condition_result_event ⇒ Types::ConditionResultEvent
Contains information about a condition evaluation result during the flow execution. This event is generated when a condition node in the flow evaluates its conditions.
2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 2463 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2438 class FlowExecutionEvent < Struct.new( :condition_result_event, :flow_failure_event, :flow_input_event, :flow_output_event, :node_action_event, :node_dependency_event, :node_failure_event, :node_input_event, :node_output_event, :unknown) SENSITIVE = [:condition_result_event, :flow_failure_event, :flow_input_event, :flow_output_event, :node_action_event, :node_dependency_event, :node_failure_event, :node_input_event, :node_output_event] include Aws::Structure include Aws::Structure::Union class ConditionResultEvent < FlowExecutionEvent; end class FlowFailureEvent < FlowExecutionEvent; end class FlowInputEvent < FlowExecutionEvent; end class FlowOutputEvent < FlowExecutionEvent; end class NodeActionEvent < FlowExecutionEvent; end class NodeDependencyEvent < FlowExecutionEvent; end class NodeFailureEvent < FlowExecutionEvent; end class NodeInputEvent < FlowExecutionEvent; end class NodeOutputEvent < FlowExecutionEvent; end class Unknown < FlowExecutionEvent; end end |
#flow_failure_event ⇒ Types::FlowFailureEvent
Contains information about a failure that occurred at the flow level during execution.
2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 2463 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2438 class FlowExecutionEvent < Struct.new( :condition_result_event, :flow_failure_event, :flow_input_event, :flow_output_event, :node_action_event, :node_dependency_event, :node_failure_event, :node_input_event, :node_output_event, :unknown) SENSITIVE = [:condition_result_event, :flow_failure_event, :flow_input_event, :flow_output_event, :node_action_event, :node_dependency_event, :node_failure_event, :node_input_event, :node_output_event] include Aws::Structure include Aws::Structure::Union class ConditionResultEvent < FlowExecutionEvent; end class FlowFailureEvent < FlowExecutionEvent; end class FlowInputEvent < FlowExecutionEvent; end class FlowOutputEvent < FlowExecutionEvent; end class NodeActionEvent < FlowExecutionEvent; end class NodeDependencyEvent < FlowExecutionEvent; end class NodeFailureEvent < FlowExecutionEvent; end class NodeInputEvent < FlowExecutionEvent; end class NodeOutputEvent < FlowExecutionEvent; end class Unknown < FlowExecutionEvent; end end |
#flow_input_event ⇒ Types::FlowExecutionInputEvent
Contains information about the inputs provided to the flow at the start of execution.
2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 2463 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2438 class FlowExecutionEvent < Struct.new( :condition_result_event, :flow_failure_event, :flow_input_event, :flow_output_event, :node_action_event, :node_dependency_event, :node_failure_event, :node_input_event, :node_output_event, :unknown) SENSITIVE = [:condition_result_event, :flow_failure_event, :flow_input_event, :flow_output_event, :node_action_event, :node_dependency_event, :node_failure_event, :node_input_event, :node_output_event] include Aws::Structure include Aws::Structure::Union class ConditionResultEvent < FlowExecutionEvent; end class FlowFailureEvent < FlowExecutionEvent; end class FlowInputEvent < FlowExecutionEvent; end class FlowOutputEvent < FlowExecutionEvent; end class NodeActionEvent < FlowExecutionEvent; end class NodeDependencyEvent < FlowExecutionEvent; end class NodeFailureEvent < FlowExecutionEvent; end class NodeInputEvent < FlowExecutionEvent; end class NodeOutputEvent < FlowExecutionEvent; end class Unknown < FlowExecutionEvent; end end |
#flow_output_event ⇒ Types::FlowExecutionOutputEvent
Contains information about the outputs produced by the flow at the end of execution.
2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 2463 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2438 class FlowExecutionEvent < Struct.new( :condition_result_event, :flow_failure_event, :flow_input_event, :flow_output_event, :node_action_event, :node_dependency_event, :node_failure_event, :node_input_event, :node_output_event, :unknown) SENSITIVE = [:condition_result_event, :flow_failure_event, :flow_input_event, :flow_output_event, :node_action_event, :node_dependency_event, :node_failure_event, :node_input_event, :node_output_event] include Aws::Structure include Aws::Structure::Union class ConditionResultEvent < FlowExecutionEvent; end class FlowFailureEvent < FlowExecutionEvent; end class FlowInputEvent < FlowExecutionEvent; end class FlowOutputEvent < FlowExecutionEvent; end class NodeActionEvent < FlowExecutionEvent; end class NodeDependencyEvent < FlowExecutionEvent; end class NodeFailureEvent < FlowExecutionEvent; end class NodeInputEvent < FlowExecutionEvent; end class NodeOutputEvent < FlowExecutionEvent; end class Unknown < FlowExecutionEvent; end end |
#node_action_event ⇒ Types::NodeActionEvent
Contains information about an action (operation) called by a node during execution.
2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 2463 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2438 class FlowExecutionEvent < Struct.new( :condition_result_event, :flow_failure_event, :flow_input_event, :flow_output_event, :node_action_event, :node_dependency_event, :node_failure_event, :node_input_event, :node_output_event, :unknown) SENSITIVE = [:condition_result_event, :flow_failure_event, :flow_input_event, :flow_output_event, :node_action_event, :node_dependency_event, :node_failure_event, :node_input_event, :node_output_event] include Aws::Structure include Aws::Structure::Union class ConditionResultEvent < FlowExecutionEvent; end class FlowFailureEvent < FlowExecutionEvent; end class FlowInputEvent < FlowExecutionEvent; end class FlowOutputEvent < FlowExecutionEvent; end class NodeActionEvent < FlowExecutionEvent; end class NodeDependencyEvent < FlowExecutionEvent; end class NodeFailureEvent < FlowExecutionEvent; end class NodeInputEvent < FlowExecutionEvent; end class NodeOutputEvent < FlowExecutionEvent; end class Unknown < FlowExecutionEvent; end end |
#node_dependency_event ⇒ Types::NodeDependencyEvent
Contains information about an internal trace of a specific node during execution.
2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 2463 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2438 class FlowExecutionEvent < Struct.new( :condition_result_event, :flow_failure_event, :flow_input_event, :flow_output_event, :node_action_event, :node_dependency_event, :node_failure_event, :node_input_event, :node_output_event, :unknown) SENSITIVE = [:condition_result_event, :flow_failure_event, :flow_input_event, :flow_output_event, :node_action_event, :node_dependency_event, :node_failure_event, :node_input_event, :node_output_event] include Aws::Structure include Aws::Structure::Union class ConditionResultEvent < FlowExecutionEvent; end class FlowFailureEvent < FlowExecutionEvent; end class FlowInputEvent < FlowExecutionEvent; end class FlowOutputEvent < FlowExecutionEvent; end class NodeActionEvent < FlowExecutionEvent; end class NodeDependencyEvent < FlowExecutionEvent; end class NodeFailureEvent < FlowExecutionEvent; end class NodeInputEvent < FlowExecutionEvent; end class NodeOutputEvent < FlowExecutionEvent; end class Unknown < FlowExecutionEvent; end end |
#node_failure_event ⇒ Types::NodeFailureEvent
Contains information about a failure that occurred at a specific node during execution.
2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 2463 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2438 class FlowExecutionEvent < Struct.new( :condition_result_event, :flow_failure_event, :flow_input_event, :flow_output_event, :node_action_event, :node_dependency_event, :node_failure_event, :node_input_event, :node_output_event, :unknown) SENSITIVE = [:condition_result_event, :flow_failure_event, :flow_input_event, :flow_output_event, :node_action_event, :node_dependency_event, :node_failure_event, :node_input_event, :node_output_event] include Aws::Structure include Aws::Structure::Union class ConditionResultEvent < FlowExecutionEvent; end class FlowFailureEvent < FlowExecutionEvent; end class FlowInputEvent < FlowExecutionEvent; end class FlowOutputEvent < FlowExecutionEvent; end class NodeActionEvent < FlowExecutionEvent; end class NodeDependencyEvent < FlowExecutionEvent; end class NodeFailureEvent < FlowExecutionEvent; end class NodeInputEvent < FlowExecutionEvent; end class NodeOutputEvent < FlowExecutionEvent; end class Unknown < FlowExecutionEvent; end end |
#node_input_event ⇒ Types::NodeInputEvent
Contains information about the inputs provided to a specific node during execution.
2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 2463 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2438 class FlowExecutionEvent < Struct.new( :condition_result_event, :flow_failure_event, :flow_input_event, :flow_output_event, :node_action_event, :node_dependency_event, :node_failure_event, :node_input_event, :node_output_event, :unknown) SENSITIVE = [:condition_result_event, :flow_failure_event, :flow_input_event, :flow_output_event, :node_action_event, :node_dependency_event, :node_failure_event, :node_input_event, :node_output_event] include Aws::Structure include Aws::Structure::Union class ConditionResultEvent < FlowExecutionEvent; end class FlowFailureEvent < FlowExecutionEvent; end class FlowInputEvent < FlowExecutionEvent; end class FlowOutputEvent < FlowExecutionEvent; end class NodeActionEvent < FlowExecutionEvent; end class NodeDependencyEvent < FlowExecutionEvent; end class NodeFailureEvent < FlowExecutionEvent; end class NodeInputEvent < FlowExecutionEvent; end class NodeOutputEvent < FlowExecutionEvent; end class Unknown < FlowExecutionEvent; end end |
#node_output_event ⇒ Types::NodeOutputEvent
Contains information about the outputs produced by a specific node during execution.
2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 2463 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2438 class FlowExecutionEvent < Struct.new( :condition_result_event, :flow_failure_event, :flow_input_event, :flow_output_event, :node_action_event, :node_dependency_event, :node_failure_event, :node_input_event, :node_output_event, :unknown) SENSITIVE = [:condition_result_event, :flow_failure_event, :flow_input_event, :flow_output_event, :node_action_event, :node_dependency_event, :node_failure_event, :node_input_event, :node_output_event] include Aws::Structure include Aws::Structure::Union class ConditionResultEvent < FlowExecutionEvent; end class FlowFailureEvent < FlowExecutionEvent; end class FlowInputEvent < FlowExecutionEvent; end class FlowOutputEvent < FlowExecutionEvent; end class NodeActionEvent < FlowExecutionEvent; end class NodeDependencyEvent < FlowExecutionEvent; end class NodeFailureEvent < FlowExecutionEvent; end class NodeInputEvent < FlowExecutionEvent; end class NodeOutputEvent < FlowExecutionEvent; end class Unknown < FlowExecutionEvent; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
2438 2439 2440 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2438 def unknown @unknown end |