Class: Aws::BedrockAgentRuntime::Types::FlowExecutionOutputEvent
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::FlowExecutionOutputEvent
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains information about the outputs produced by the flow during a flow execution.
<note markdown=“1”> Flow executions is in preview release for Amazon Bedrock and is subject to change.
</note>
Constant Summary collapse
- SENSITIVE =
[:fields]
Instance Attribute Summary collapse
-
#fields ⇒ Array<Types::FlowOutputField>
A list of output fields produced by the flow.
-
#node_name ⇒ String
The name of the node that produces the outputs.
-
#timestamp ⇒ Time
The timestamp when the outputs are produced.
Instance Attribute Details
#fields ⇒ Array<Types::FlowOutputField>
A list of output fields produced by the flow.
1861 1862 1863 1864 1865 1866 1867 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1861 class FlowExecutionOutputEvent < Struct.new( :fields, :node_name, :timestamp) SENSITIVE = [:fields] include Aws::Structure end |
#node_name ⇒ String
The name of the node that produces the outputs.
1861 1862 1863 1864 1865 1866 1867 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1861 class FlowExecutionOutputEvent < Struct.new( :fields, :node_name, :timestamp) SENSITIVE = [:fields] include Aws::Structure end |
#timestamp ⇒ Time
The timestamp when the outputs are produced.
1861 1862 1863 1864 1865 1866 1867 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1861 class FlowExecutionOutputEvent < Struct.new( :fields, :node_name, :timestamp) SENSITIVE = [:fields] include Aws::Structure end |