Class: Aws::BedrockAgentRuntime::Types::FlowExecutionSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::FlowExecutionSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains summary information about a flow execution, including its status, timestamps, and identifiers.
<note markdown=“1”> Flow executions is in preview release for Amazon Bedrock and is subject to change.
</note>
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp when the flow execution was created.
-
#ended_at ⇒ Time
The timestamp when the flow execution ended.
-
#execution_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the flow execution.
-
#flow_alias_identifier ⇒ String
The unique identifier of the flow alias used for the execution.
-
#flow_identifier ⇒ String
The unique identifier of the flow.
-
#flow_version ⇒ String
The version of the flow used for the execution.
-
#status ⇒ String
The current status of the flow execution.
Instance Attribute Details
#created_at ⇒ Time
The timestamp when the flow execution was created.
2568 2569 2570 2571 2572 2573 2574 2575 2576 2577 2578 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2568 class FlowExecutionSummary < Struct.new( :created_at, :ended_at, :execution_arn, :flow_alias_identifier, :flow_identifier, :flow_version, :status) SENSITIVE = [] include Aws::Structure end |
#ended_at ⇒ Time
The timestamp when the flow execution ended. This field is only populated when the execution has completed, failed, timed out, or been aborted.
2568 2569 2570 2571 2572 2573 2574 2575 2576 2577 2578 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2568 class FlowExecutionSummary < Struct.new( :created_at, :ended_at, :execution_arn, :flow_alias_identifier, :flow_identifier, :flow_version, :status) SENSITIVE = [] include Aws::Structure end |
#execution_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the flow execution.
2568 2569 2570 2571 2572 2573 2574 2575 2576 2577 2578 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2568 class FlowExecutionSummary < Struct.new( :created_at, :ended_at, :execution_arn, :flow_alias_identifier, :flow_identifier, :flow_version, :status) SENSITIVE = [] include Aws::Structure end |
#flow_alias_identifier ⇒ String
The unique identifier of the flow alias used for the execution.
2568 2569 2570 2571 2572 2573 2574 2575 2576 2577 2578 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2568 class FlowExecutionSummary < Struct.new( :created_at, :ended_at, :execution_arn, :flow_alias_identifier, :flow_identifier, :flow_version, :status) SENSITIVE = [] include Aws::Structure end |
#flow_identifier ⇒ String
The unique identifier of the flow.
2568 2569 2570 2571 2572 2573 2574 2575 2576 2577 2578 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2568 class FlowExecutionSummary < Struct.new( :created_at, :ended_at, :execution_arn, :flow_alias_identifier, :flow_identifier, :flow_version, :status) SENSITIVE = [] include Aws::Structure end |
#flow_version ⇒ String
The version of the flow used for the execution.
2568 2569 2570 2571 2572 2573 2574 2575 2576 2577 2578 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2568 class FlowExecutionSummary < Struct.new( :created_at, :ended_at, :execution_arn, :flow_alias_identifier, :flow_identifier, :flow_version, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the flow execution.
Flow executions time out after 24 hours.
2568 2569 2570 2571 2572 2573 2574 2575 2576 2577 2578 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2568 class FlowExecutionSummary < Struct.new( :created_at, :ended_at, :execution_arn, :flow_alias_identifier, :flow_identifier, :flow_version, :status) SENSITIVE = [] include Aws::Structure end |