Class: Aws::BedrockAgentRuntime::Types::FlowInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains information about an input into the prompt flow and where to send it.

Constant Summary collapse

SENSITIVE =
[:content]

Instance Attribute Summary collapse

Instance Attribute Details

#contentTypes::FlowInputContent

Contains information about an input into the prompt flow.



1211
1212
1213
1214
1215
1216
1217
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1211

class FlowInput < Struct.new(
  :content,
  :node_name,
  :node_output_name)
  SENSITIVE = [:content]
  include Aws::Structure
end

#node_nameString

The name of the flow input node that begins the prompt flow.

Returns:

  • (String)


1211
1212
1213
1214
1215
1216
1217
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1211

class FlowInput < Struct.new(
  :content,
  :node_name,
  :node_output_name)
  SENSITIVE = [:content]
  include Aws::Structure
end

#node_output_nameString

The name of the output from the flow input node that begins the prompt flow.

Returns:

  • (String)


1211
1212
1213
1214
1215
1216
1217
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1211

class FlowInput < Struct.new(
  :content,
  :node_name,
  :node_output_name)
  SENSITIVE = [:content]
  include Aws::Structure
end