Class: Aws::BedrockAgentRuntime::Types::FlowInputContent

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Note:

FlowInputContent is a union - when making an API calls you must set exactly one of the members.

Contains information about an input into the flow.

Direct Known Subclasses

Document, Unknown

Defined Under Namespace

Classes: Document, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#documentHash, ...

The input to send to the prompt flow input node.

Returns:

  • (Hash, Array, String, Numeric, Boolean)


1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1229

class FlowInputContent < Struct.new(
  :document,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Document < FlowInputContent; end
  class Unknown < FlowInputContent; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



1229
1230
1231
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1229

def unknown
  @unknown
end