Class: Aws::BedrockAgentRuntime::Types::FlowOutputEvent

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains information about an output from prompt flow invoction.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contentTypes::FlowOutputContent

The content in the output.



1278
1279
1280
1281
1282
1283
1284
1285
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1278

class FlowOutputEvent < Struct.new(
  :content,
  :node_name,
  :node_type,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#event_typeObject

Returns the value of attribute event_type

Returns:

  • (Object)

    the current value of event_type



1278
1279
1280
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1278

def event_type
  @event_type
end

#node_nameString

The name of the flow output node that the output is from.

Returns:

  • (String)


1278
1279
1280
1281
1282
1283
1284
1285
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1278

class FlowOutputEvent < Struct.new(
  :content,
  :node_name,
  :node_type,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#node_typeString

The type of the node that the output is from.

Returns:

  • (String)


1278
1279
1280
1281
1282
1283
1284
1285
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1278

class FlowOutputEvent < Struct.new(
  :content,
  :node_name,
  :node_type,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end