Class: Aws::BedrockAgentRuntime::Types::FlowTraceNodeInputEvent
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::FlowTraceNodeInputEvent
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains information about the input into a node. For more information, see [Track each step in your prompt flow by viewing its trace in Amazon Bedrock].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/flows-trace.html
Constant Summary collapse
- SENSITIVE =
[:fields]
Instance Attribute Summary collapse
-
#fields ⇒ Array<Types::FlowTraceNodeInputField>
An array of objects containing information about each field in the input.
-
#node_name ⇒ String
The name of the node that received the input.
-
#timestamp ⇒ Time
The date and time that the trace was returned.
Instance Attribute Details
#fields ⇒ Array<Types::FlowTraceNodeInputField>
An array of objects containing information about each field in the input.
1449 1450 1451 1452 1453 1454 1455 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1449 class FlowTraceNodeInputEvent < Struct.new( :fields, :node_name, :timestamp) SENSITIVE = [:fields] include Aws::Structure end |
#node_name ⇒ String
The name of the node that received the input.
1449 1450 1451 1452 1453 1454 1455 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1449 class FlowTraceNodeInputEvent < Struct.new( :fields, :node_name, :timestamp) SENSITIVE = [:fields] include Aws::Structure end |
#timestamp ⇒ Time
The date and time that the trace was returned.
1449 1450 1451 1452 1453 1454 1455 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1449 class FlowTraceNodeInputEvent < Struct.new( :fields, :node_name, :timestamp) SENSITIVE = [:fields] include Aws::Structure end |