Class: Aws::BedrockAgentRuntime::Types::FlowTraceNodeOutputContent
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::FlowTraceNodeOutputContent
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Note:
FlowTraceNodeOutputContent is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of FlowTraceNodeOutputContent corresponding to the set member.
Contains the content of the node output. For more information, see Track each step in your prompt flow by viewing its trace in Amazon Bedrock.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#document ⇒ Hash, ...
The content of the node output.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#document ⇒ Hash, ...
The content of the node output.
3603 3604 3605 3606 3607 3608 3609 3610 3611 3612 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3603 class FlowTraceNodeOutputContent < Struct.new( :document, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Document < FlowTraceNodeOutputContent; end class Unknown < FlowTraceNodeOutputContent; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
3603 3604 3605 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3603 def unknown @unknown end |