Class: Aws::BedrockAgentRuntime::Types::FlowTraceNodeOutputContent
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::FlowTraceNodeOutputContent
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Note:
FlowTraceNodeOutputContent is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of FlowTraceNodeOutputContent corresponding to the set member.
Contains the content of the node output. For more information, see [Track each step in your prompt flow by viewing its trace in Amazon Bedrock].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/flows-trace.html
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#document ⇒ Hash, ...
The content of the node output.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#document ⇒ Hash, ...
The content of the node output.
1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1498 class FlowTraceNodeOutputContent < Struct.new( :document, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Document < FlowTraceNodeOutputContent; end class Unknown < FlowTraceNodeOutputContent; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
1498 1499 1500 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1498 def unknown @unknown end |