Class: Aws::BedrockAgentRuntime::Types::FlowTraceNodeOutputEvent

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains information about the output from a node. For more information, see [Track each step in your prompt flow by viewing its trace in Amazon Bedrock].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/flows-trace.html

Constant Summary collapse

SENSITIVE =
[:fields]

Instance Attribute Summary collapse

Instance Attribute Details

#fieldsArray<Types::FlowTraceNodeOutputField>

An array of objects containing information about each field in the output.



1532
1533
1534
1535
1536
1537
1538
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1532

class FlowTraceNodeOutputEvent < Struct.new(
  :fields,
  :node_name,
  :timestamp)
  SENSITIVE = [:fields]
  include Aws::Structure
end

#node_nameString

The name of the node that yielded the output.

Returns:

  • (String)


1532
1533
1534
1535
1536
1537
1538
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1532

class FlowTraceNodeOutputEvent < Struct.new(
  :fields,
  :node_name,
  :timestamp)
  SENSITIVE = [:fields]
  include Aws::Structure
end

#timestampTime

The date and time that the trace was returned.

Returns:

  • (Time)


1532
1533
1534
1535
1536
1537
1538
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1532

class FlowTraceNodeOutputEvent < Struct.new(
  :fields,
  :node_name,
  :timestamp)
  SENSITIVE = [:fields]
  include Aws::Structure
end