Class: Aws::BedrockAgentRuntime::Types::FlowTraceNodeOutputField

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains information about a field in the output from a node. For more information, see [Track each step in your prompt flow by viewing its trace in Amazon Bedrock].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/flows-trace.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contentTypes::FlowTraceNodeOutputContent

The content of the node output.



1558
1559
1560
1561
1562
1563
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1558

class FlowTraceNodeOutputField < Struct.new(
  :content,
  :node_output_name)
  SENSITIVE = []
  include Aws::Structure
end

#node_output_nameString

The name of the node output.

Returns:

  • (String)


1558
1559
1560
1561
1562
1563
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1558

class FlowTraceNodeOutputField < Struct.new(
  :content,
  :node_output_name)
  SENSITIVE = []
  include Aws::Structure
end