Class: Aws::BedrockAgentRuntime::Types::FunctionResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::FunctionResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains information about the function that was called from the action group and the response that was returned.
This data type is used in the following API operations:
-
In the ‘returnControlInvocationResults` of the [InvokeAgent request]
^
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_group ⇒ String
The action group that the function belongs to.
-
#agent_id ⇒ String
The agent’s ID.
-
#confirmation_state ⇒ String
Contains the user confirmation information about the function that was called.
-
#function ⇒ String
The name of the function that was called.
-
#response_body ⇒ Hash<String,Types::ContentBody>
The response from the function call using the parameters.
-
#response_state ⇒ String
Controls the final response state returned to end user when API/Function execution failed.
Instance Attribute Details
#action_group ⇒ String
The action group that the function belongs to.
2787 2788 2789 2790 2791 2792 2793 2794 2795 2796 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2787 class FunctionResult < Struct.new( :action_group, :agent_id, :confirmation_state, :function, :response_body, :response_state) SENSITIVE = [] include Aws::Structure end |
#agent_id ⇒ String
The agent’s ID.
2787 2788 2789 2790 2791 2792 2793 2794 2795 2796 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2787 class FunctionResult < Struct.new( :action_group, :agent_id, :confirmation_state, :function, :response_body, :response_state) SENSITIVE = [] include Aws::Structure end |
#confirmation_state ⇒ String
Contains the user confirmation information about the function that was called.
2787 2788 2789 2790 2791 2792 2793 2794 2795 2796 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2787 class FunctionResult < Struct.new( :action_group, :agent_id, :confirmation_state, :function, :response_body, :response_state) SENSITIVE = [] include Aws::Structure end |
#function ⇒ String
The name of the function that was called.
2787 2788 2789 2790 2791 2792 2793 2794 2795 2796 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2787 class FunctionResult < Struct.new( :action_group, :agent_id, :confirmation_state, :function, :response_body, :response_state) SENSITIVE = [] include Aws::Structure end |
#response_body ⇒ Hash<String,Types::ContentBody>
The response from the function call using the parameters. The response might be returned directly or from the Lambda function. Specify ‘TEXT` or `IMAGES`. The key of the object is the content type. You can only specify one type. If you specify `IMAGES`, you can specify only one image. You can specify images only when the function in the `returnControlInvocationResults` is a computer use action. For more information, see [Configure an Amazon Bedrock Agent to complete tasks with computer use tools].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/agent-computer-use.html
2787 2788 2789 2790 2791 2792 2793 2794 2795 2796 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2787 class FunctionResult < Struct.new( :action_group, :agent_id, :confirmation_state, :function, :response_body, :response_state) SENSITIVE = [] include Aws::Structure end |
#response_state ⇒ String
Controls the final response state returned to end user when API/Function execution failed. When this state is FAILURE, the request would fail with dependency failure exception. When this state is REPROMPT, the API/function response will be sent to model for re-prompt
2787 2788 2789 2790 2791 2792 2793 2794 2795 2796 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2787 class FunctionResult < Struct.new( :action_group, :agent_id, :confirmation_state, :function, :response_body, :response_state) SENSITIVE = [] include Aws::Structure end |