Class: Aws::BedrockAgentRuntime::Types::FunctionResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains information about the function that was called from the action group and the response that was returned.

This data type is used in the following API operations:

  • In the returnControlInvocationResults of the [InvokeAgent request][1]

^

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_InvokeAgent.html#API_agent-runtime_InvokeAgent_RequestSyntax

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#action_groupString

The action group that the function belongs to.



1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1729

class FunctionResult < Struct.new(
  :action_group,
  :agent_id,
  :confirmation_state,
  :function,
  :response_body,
  :response_state)
  SENSITIVE = []
  include Aws::Structure
end

#agent_idString

The agent’s ID.



1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1729

class FunctionResult < Struct.new(
  :action_group,
  :agent_id,
  :confirmation_state,
  :function,
  :response_body,
  :response_state)
  SENSITIVE = []
  include Aws::Structure
end

#confirmation_stateString

Contains the user confirmation information about the function that was called.



1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1729

class FunctionResult < Struct.new(
  :action_group,
  :agent_id,
  :confirmation_state,
  :function,
  :response_body,
  :response_state)
  SENSITIVE = []
  include Aws::Structure
end

#functionString

The name of the function that was called.



1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1729

class FunctionResult < Struct.new(
  :action_group,
  :agent_id,
  :confirmation_state,
  :function,
  :response_body,
  :response_state)
  SENSITIVE = []
  include Aws::Structure
end

#response_bodyHash<String,Types::ContentBody>

The response from the function call using the parameters. The key of the object is the content type (currently, only TEXT is supported). The response may be returned directly or from the Lambda function.



1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1729

class FunctionResult < Struct.new(
  :action_group,
  :agent_id,
  :confirmation_state,
  :function,
  :response_body,
  :response_state)
  SENSITIVE = []
  include Aws::Structure
end

#response_stateString

Controls the final response state returned to end user when API/Function execution failed. When this state is FAILURE, the request would fail with dependency failure exception. When this state is REPROMPT, the API/function response will be sent to model for re-prompt



1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1729

class FunctionResult < Struct.new(
  :action_group,
  :agent_id,
  :confirmation_state,
  :function,
  :response_body,
  :response_state)
  SENSITIVE = []
  include Aws::Structure
end