Class: Aws::BedrockAgentRuntime::Types::FunctionSchema
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::FunctionSchema
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Note:
FunctionSchema is a union - when making an API calls you must set exactly one of the members.
Contains details about the function schema for the action group or the JSON or YAML-formatted payload defining the schema.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#functions ⇒ Array<Types::FunctionDefinition>
A list of functions that each define an action in the action group.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#functions ⇒ Array<Types::FunctionDefinition>
A list of functions that each define an action in the action group.
3484 3485 3486 3487 3488 3489 3490 3491 3492 3493 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3484 class FunctionSchema < Struct.new( :functions, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Functions < FunctionSchema; end class Unknown < FunctionSchema; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
3484 3485 3486 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3484 def unknown @unknown end |