Class: Aws::BedrockAgentRuntime::Types::FunctionSchema

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Note:

FunctionSchema is a union - when making an API calls you must set exactly one of the members.

Contains details about the function schema for the action group or the JSON or YAML-formatted payload defining the schema.

Direct Known Subclasses

Functions, Unknown

Defined Under Namespace

Classes: Functions, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#functionsArray<Types::FunctionDefinition>

A list of functions that each define an action in the action group.

Returns:



1751
1752
1753
1754
1755
1756
1757
1758
1759
1760
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1751

class FunctionSchema < Struct.new(
  :functions,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Functions < FunctionSchema; end
  class Unknown < FunctionSchema; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



1751
1752
1753
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1751

def unknown
  @unknown
end