Class: Aws::BedrockAgentRuntime::Types::GenerateQueryResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::GenerateQueryResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:queries]
Instance Attribute Summary collapse
-
#queries ⇒ Array<Types::GeneratedQuery>
A list of objects, each of which defines a generated query that can correspond to the natural language queries.
Instance Attribute Details
#queries ⇒ Array<Types::GeneratedQuery>
A list of objects, each of which defines a generated query that can correspond to the natural language queries.
1788 1789 1790 1791 1792 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1788 class GenerateQueryResponse < Struct.new( :queries) SENSITIVE = [:queries] include Aws::Structure end |