Class: Aws::BedrockAgentRuntime::Types::GenerationConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::GenerationConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains configurations for response generation based on the knowledge base query results.
This data type is used in the following API operations:
- RetrieveAndGenerate request][1
^
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_model_request_fields ⇒ Hash<String,Hash,Array,String,Numeric,Boolean>
Additional model parameters and corresponding values not included in the textInferenceConfig structure for a knowledge base.
-
#guardrail_configuration ⇒ Types::GuardrailConfiguration
The configuration details for the guardrail.
-
#inference_config ⇒ Types::InferenceConfig
Configuration settings for inference when using RetrieveAndGenerate to generate responses while using a knowledge base as a source.
-
#performance_config ⇒ Types::PerformanceConfiguration
The latency configuration for the model.
-
#prompt_template ⇒ Types::PromptTemplate
Contains the template for the prompt that’s sent to the model for response generation.
Instance Attribute Details
#additional_model_request_fields ⇒ Hash<String,Hash,Array,String,Numeric,Boolean>
Additional model parameters and corresponding values not included in the textInferenceConfig structure for a knowledge base. This allows users to provide custom model parameters specific to the language model being used.
1888 1889 1890 1891 1892 1893 1894 1895 1896 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1888 class GenerationConfiguration < Struct.new( :additional_model_request_fields, :guardrail_configuration, :inference_config, :performance_config, :prompt_template) SENSITIVE = [] include Aws::Structure end |
#guardrail_configuration ⇒ Types::GuardrailConfiguration
The configuration details for the guardrail.
1888 1889 1890 1891 1892 1893 1894 1895 1896 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1888 class GenerationConfiguration < Struct.new( :additional_model_request_fields, :guardrail_configuration, :inference_config, :performance_config, :prompt_template) SENSITIVE = [] include Aws::Structure end |
#inference_config ⇒ Types::InferenceConfig
Configuration settings for inference when using RetrieveAndGenerate to generate responses while using a knowledge base as a source.
1888 1889 1890 1891 1892 1893 1894 1895 1896 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1888 class GenerationConfiguration < Struct.new( :additional_model_request_fields, :guardrail_configuration, :inference_config, :performance_config, :prompt_template) SENSITIVE = [] include Aws::Structure end |
#performance_config ⇒ Types::PerformanceConfiguration
The latency configuration for the model.
1888 1889 1890 1891 1892 1893 1894 1895 1896 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1888 class GenerationConfiguration < Struct.new( :additional_model_request_fields, :guardrail_configuration, :inference_config, :performance_config, :prompt_template) SENSITIVE = [] include Aws::Structure end |
#prompt_template ⇒ Types::PromptTemplate
Contains the template for the prompt that’s sent to the model for response generation. Generation prompts must include the ‘$search_results$` variable. For more information, see [Use placeholder variables] in the user guide.
[1]: docs.aws.amazon.com/bedrock/latest/userguide/prompt-placeholders.html
1888 1889 1890 1891 1892 1893 1894 1895 1896 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 1888 class GenerationConfiguration < Struct.new( :additional_model_request_fields, :guardrail_configuration, :inference_config, :performance_config, :prompt_template) SENSITIVE = [] include Aws::Structure end |