Class: Aws::BedrockAgentRuntime::Types::GetIngestedDocumentAclRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::GetIngestedDocumentAclRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_source_id ⇒ String
The unique identifier of the data source that contains the document.
-
#document_id ⇒ String
The unique identifier of the document to retrieve the ingested access control list (ACL) for.
-
#knowledge_base_id ⇒ String
The unique identifier of the knowledge base that contains the document.
Instance Attribute Details
#data_source_id ⇒ String
The unique identifier of the data source that contains the document.
4070 4071 4072 4073 4074 4075 4076 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4070 class GetIngestedDocumentAclRequest < Struct.new( :data_source_id, :document_id, :knowledge_base_id) SENSITIVE = [] include Aws::Structure end |
#document_id ⇒ String
The unique identifier of the document to retrieve the ingested access control list (ACL) for.
4070 4071 4072 4073 4074 4075 4076 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4070 class GetIngestedDocumentAclRequest < Struct.new( :data_source_id, :document_id, :knowledge_base_id) SENSITIVE = [] include Aws::Structure end |
#knowledge_base_id ⇒ String
The unique identifier of the knowledge base that contains the document.
4070 4071 4072 4073 4074 4075 4076 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4070 class GetIngestedDocumentAclRequest < Struct.new( :data_source_id, :document_id, :knowledge_base_id) SENSITIVE = [] include Aws::Structure end |