Class: Aws::BedrockAgentRuntime::Types::GetSessionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp for when the session was created.

Returns:

  • (Time)


3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3990

class GetSessionResponse < Struct.new(
  :created_at,
  :encryption_key_arn,
  :last_updated_at,
  :session_arn,
  :session_id,
  :session_metadata,
  :session_status)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_key_arnString

The Amazon Resource Name (ARN) of the Key Management Service key used to encrypt the session data. For more information, see [Amazon Bedrock session encryption].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/session-encryption.html

Returns:

  • (String)


3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3990

class GetSessionResponse < Struct.new(
  :created_at,
  :encryption_key_arn,
  :last_updated_at,
  :session_arn,
  :session_id,
  :session_metadata,
  :session_status)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_atTime

The timestamp for when the session was last modified.

Returns:

  • (Time)


3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3990

class GetSessionResponse < Struct.new(
  :created_at,
  :encryption_key_arn,
  :last_updated_at,
  :session_arn,
  :session_id,
  :session_metadata,
  :session_status)
  SENSITIVE = []
  include Aws::Structure
end

#session_arnString

The Amazon Resource Name (ARN) of the session.

Returns:

  • (String)


3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3990

class GetSessionResponse < Struct.new(
  :created_at,
  :encryption_key_arn,
  :last_updated_at,
  :session_arn,
  :session_id,
  :session_metadata,
  :session_status)
  SENSITIVE = []
  include Aws::Structure
end

#session_idString

The unique identifier for the session in UUID format.

Returns:

  • (String)


3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3990

class GetSessionResponse < Struct.new(
  :created_at,
  :encryption_key_arn,
  :last_updated_at,
  :session_arn,
  :session_id,
  :session_metadata,
  :session_status)
  SENSITIVE = []
  include Aws::Structure
end

#session_metadataHash<String,String>

A map of key-value pairs containing attributes persisted across the session.

Returns:

  • (Hash<String,String>)


3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3990

class GetSessionResponse < Struct.new(
  :created_at,
  :encryption_key_arn,
  :last_updated_at,
  :session_arn,
  :session_id,
  :session_metadata,
  :session_status)
  SENSITIVE = []
  include Aws::Structure
end

#session_statusString

The current status of the session.

Returns:

  • (String)


3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3990

class GetSessionResponse < Struct.new(
  :created_at,
  :encryption_key_arn,
  :last_updated_at,
  :session_arn,
  :session_id,
  :session_metadata,
  :session_status)
  SENSITIVE = []
  include Aws::Structure
end