Class: Aws::BedrockAgentRuntime::Types::GetSessionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::GetSessionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp for when the session was created.
-
#encryption_key_arn ⇒ String
The Amazon Resource Name (ARN) of the Key Management Service key used to encrypt the session data.
-
#last_updated_at ⇒ Time
The timestamp for when the session was last modified.
-
#session_arn ⇒ String
The Amazon Resource Name (ARN) of the session.
-
#session_id ⇒ String
The unique identifier for the session in UUID format.
-
#session_metadata ⇒ Hash<String,String>
A map of key-value pairs containing attributes persisted across the session.
-
#session_status ⇒ String
The current status of the session.
Instance Attribute Details
#created_at ⇒ Time
The timestamp for when the session was created.
3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 3261 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3251 class GetSessionResponse < Struct.new( :created_at, :encryption_key_arn, :last_updated_at, :session_arn, :session_id, :session_metadata, :session_status) SENSITIVE = [] include Aws::Structure end |
#encryption_key_arn ⇒ String
The Amazon Resource Name (ARN) of the Key Management Service key used to encrypt the session data. For more information, see [Amazon Bedrock session encryption].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/session-encryption.html
3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 3261 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3251 class GetSessionResponse < Struct.new( :created_at, :encryption_key_arn, :last_updated_at, :session_arn, :session_id, :session_metadata, :session_status) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp for when the session was last modified.
3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 3261 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3251 class GetSessionResponse < Struct.new( :created_at, :encryption_key_arn, :last_updated_at, :session_arn, :session_id, :session_metadata, :session_status) SENSITIVE = [] include Aws::Structure end |
#session_arn ⇒ String
The Amazon Resource Name (ARN) of the session.
3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 3261 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3251 class GetSessionResponse < Struct.new( :created_at, :encryption_key_arn, :last_updated_at, :session_arn, :session_id, :session_metadata, :session_status) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
The unique identifier for the session in UUID format.
3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 3261 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3251 class GetSessionResponse < Struct.new( :created_at, :encryption_key_arn, :last_updated_at, :session_arn, :session_id, :session_metadata, :session_status) SENSITIVE = [] include Aws::Structure end |
#session_metadata ⇒ Hash<String,String>
A map of key-value pairs containing attributes persisted across the session.
3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 3261 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3251 class GetSessionResponse < Struct.new( :created_at, :encryption_key_arn, :last_updated_at, :session_arn, :session_id, :session_metadata, :session_status) SENSITIVE = [] include Aws::Structure end |
#session_status ⇒ String
The current status of the session.
3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 3261 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3251 class GetSessionResponse < Struct.new( :created_at, :encryption_key_arn, :last_updated_at, :session_arn, :session_id, :session_metadata, :session_status) SENSITIVE = [] include Aws::Structure end |