Class: Aws::BedrockAgentRuntime::Types::ImageSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::ImageSource
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Note:
ImageSource is a union - when making an API calls you must set exactly one of the members.
Note:
ImageSource is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ImageSource corresponding to the set member.
The source for an image.
Direct Known Subclasses
Defined Under Namespace
Classes: Bytes, S3Location, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bytes ⇒ String
The raw image bytes for the image.
-
#s3_location ⇒ Types::S3Location
The path to the Amazon S3 bucket where the image is stored.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#bytes ⇒ String
The raw image bytes for the image. If you use an Amazon Web Services SDK, you don’t need to encode the image bytes in base64.
4421 4422 4423 4424 4425 4426 4427 4428 4429 4430 4431 4432 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4421 class ImageSource < Struct.new( :bytes, :s3_location, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Bytes < ImageSource; end class S3Location < ImageSource; end class Unknown < ImageSource; end end |
#s3_location ⇒ Types::S3Location
The path to the Amazon S3 bucket where the image is stored.
4421 4422 4423 4424 4425 4426 4427 4428 4429 4430 4431 4432 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4421 class ImageSource < Struct.new( :bytes, :s3_location, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Bytes < ImageSource; end class S3Location < ImageSource; end class Unknown < ImageSource; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
4421 4422 4423 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4421 def unknown @unknown end |