Class: Aws::BedrockAgentRuntime::Types::InlineAgentTracePart
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::InlineAgentTracePart
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains information about the agent and session, alongside the agent's reasoning process and results from calling API actions and querying knowledge bases and metadata about the trace. You can use the trace to understand how the agent arrived at the response it provided the customer. For more information, see Trace enablement.
Constant Summary collapse
- SENSITIVE =
[:collaborator_name, :trace]
Instance Attribute Summary collapse
-
#caller_chain ⇒ Array<Types::Caller>
The caller chain for the trace part.
-
#collaborator_name ⇒ String
The collaborator name for the trace part.
-
#event_time ⇒ Time
The time that trace occurred.
-
#event_type ⇒ Object
Returns the value of attribute event_type.
-
#session_id ⇒ String
The unique identifier of the session with the agent.
-
#trace ⇒ Types::Trace
Contains one part of the agent's reasoning process and results from calling API actions and querying knowledge bases.
Instance Attribute Details
#caller_chain ⇒ Array<Types::Caller>
The caller chain for the trace part.
5096 5097 5098 5099 5100 5101 5102 5103 5104 5105 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5096 class InlineAgentTracePart < Struct.new( :caller_chain, :collaborator_name, :event_time, :session_id, :trace, :event_type) SENSITIVE = [:collaborator_name, :trace] include Aws::Structure end |
#collaborator_name ⇒ String
The collaborator name for the trace part.
5096 5097 5098 5099 5100 5101 5102 5103 5104 5105 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5096 class InlineAgentTracePart < Struct.new( :caller_chain, :collaborator_name, :event_time, :session_id, :trace, :event_type) SENSITIVE = [:collaborator_name, :trace] include Aws::Structure end |
#event_time ⇒ Time
The time that trace occurred.
5096 5097 5098 5099 5100 5101 5102 5103 5104 5105 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5096 class InlineAgentTracePart < Struct.new( :caller_chain, :collaborator_name, :event_time, :session_id, :trace, :event_type) SENSITIVE = [:collaborator_name, :trace] include Aws::Structure end |
#event_type ⇒ Object
Returns the value of attribute event_type
5096 5097 5098 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5096 def event_type @event_type end |
#session_id ⇒ String
The unique identifier of the session with the agent.
5096 5097 5098 5099 5100 5101 5102 5103 5104 5105 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5096 class InlineAgentTracePart < Struct.new( :caller_chain, :collaborator_name, :event_time, :session_id, :trace, :event_type) SENSITIVE = [:collaborator_name, :trace] include Aws::Structure end |
#trace ⇒ Types::Trace
Contains one part of the agent's reasoning process and results from calling API actions and querying knowledge bases. You can use the trace to understand how the agent arrived at the response it provided the customer. For more information, see Trace enablement.
5096 5097 5098 5099 5100 5101 5102 5103 5104 5105 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5096 class InlineAgentTracePart < Struct.new( :caller_chain, :collaborator_name, :event_time, :session_id, :trace, :event_type) SENSITIVE = [:collaborator_name, :trace] include Aws::Structure end |