Class: Aws::BedrockAgentRuntime::Types::InlineAgentTracePart
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::InlineAgentTracePart
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains information about the agent and session, alongside the agent’s reasoning process and results from calling API actions and querying knowledge bases and metadata about the trace. You can use the trace to understand how the agent arrived at the response it provided the customer. For more information, see [Trace enablement].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/agents-test.html#trace-enablement
Constant Summary collapse
- SENSITIVE =
[:collaborator_name, :trace]
Instance Attribute Summary collapse
-
#caller_chain ⇒ Array<Types::Caller>
The caller chain for the trace part.
-
#collaborator_name ⇒ String
The collaborator name for the trace part.
-
#event_time ⇒ Time
The time that trace occurred.
-
#event_type ⇒ Object
Returns the value of attribute event_type.
-
#session_id ⇒ String
The unique identifier of the session with the agent.
-
#trace ⇒ Types::Trace
Contains one part of the agent’s reasoning process and results from calling API actions and querying knowledge bases.
Instance Attribute Details
#caller_chain ⇒ Array<Types::Caller>
The caller chain for the trace part.
4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4632 class InlineAgentTracePart < Struct.new( :caller_chain, :collaborator_name, :event_time, :session_id, :trace, :event_type) SENSITIVE = [:collaborator_name, :trace] include Aws::Structure end |
#collaborator_name ⇒ String
The collaborator name for the trace part.
4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4632 class InlineAgentTracePart < Struct.new( :caller_chain, :collaborator_name, :event_time, :session_id, :trace, :event_type) SENSITIVE = [:collaborator_name, :trace] include Aws::Structure end |
#event_time ⇒ Time
The time that trace occurred.
4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4632 class InlineAgentTracePart < Struct.new( :caller_chain, :collaborator_name, :event_time, :session_id, :trace, :event_type) SENSITIVE = [:collaborator_name, :trace] include Aws::Structure end |
#event_type ⇒ Object
Returns the value of attribute event_type
4632 4633 4634 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4632 def event_type @event_type end |
#session_id ⇒ String
The unique identifier of the session with the agent.
4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4632 class InlineAgentTracePart < Struct.new( :caller_chain, :collaborator_name, :event_time, :session_id, :trace, :event_type) SENSITIVE = [:collaborator_name, :trace] include Aws::Structure end |
#trace ⇒ Types::Trace
Contains one part of the agent’s reasoning process and results from calling API actions and querying knowledge bases. You can use the trace to understand how the agent arrived at the response it provided the customer. For more information, see [Trace enablement].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/agents-test.html#trace-enablement
4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4632 class InlineAgentTracePart < Struct.new( :caller_chain, :collaborator_name, :event_time, :session_id, :trace, :event_type) SENSITIVE = [:collaborator_name, :trace] include Aws::Structure end |