Class: Aws::BedrockAgentRuntime::Types::InlineSessionState

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains parameters that specify various attributes that persist across a session or prompt. You can define session state attributes as key-value pairs when writing a [Lambda function] for an action group or pass them when making an ‘InvokeInlineAgent` request. Use session state attributes to control and provide conversational context for your inline agent and to help customize your agent’s behavior. For more information, see [Control session context]

[1]: docs.aws.amazon.com/bedrock/latest/userguide/agents-lambda.html [2]: docs.aws.amazon.com/bedrock/latest/userguide/agents-session-state.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#conversation_historyTypes::ConversationHistory

Contains the conversation history that persist across sessions.



3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3978

class InlineSessionState < Struct.new(
  :conversation_history,
  :files,
  :invocation_id,
  :prompt_session_attributes,
  :return_control_invocation_results,
  :session_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#filesArray<Types::InputFile>

Contains information about the files used by code interpreter.

Returns:



3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3978

class InlineSessionState < Struct.new(
  :conversation_history,
  :files,
  :invocation_id,
  :prompt_session_attributes,
  :return_control_invocation_results,
  :session_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#invocation_idString

The identifier of the invocation of an action. This value must match the ‘invocationId` returned in the `InvokeInlineAgent` response for the action whose results are provided in the `returnControlInvocationResults` field. For more information, see [Return control to the agent developer].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/agents-returncontrol.html

Returns:

  • (String)


3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3978

class InlineSessionState < Struct.new(
  :conversation_history,
  :files,
  :invocation_id,
  :prompt_session_attributes,
  :return_control_invocation_results,
  :session_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#prompt_session_attributesHash<String,String>

Contains attributes that persist across a session and the values of those attributes.

Returns:

  • (Hash<String,String>)


3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3978

class InlineSessionState < Struct.new(
  :conversation_history,
  :files,
  :invocation_id,
  :prompt_session_attributes,
  :return_control_invocation_results,
  :session_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#return_control_invocation_resultsArray<Types::InvocationResultMember>

Contains information about the results from the action group invocation. For more information, see [Return control to the agent developer].

<note markdown=“1”> If you include this field in the ‘sessionState` field, the `inputText` field will be ignored.

</note>

[1]: docs.aws.amazon.com/bedrock/latest/userguide/agents-returncontrol.html

Returns:



3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3978

class InlineSessionState < Struct.new(
  :conversation_history,
  :files,
  :invocation_id,
  :prompt_session_attributes,
  :return_control_invocation_results,
  :session_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#session_attributesHash<String,String>

Contains attributes that persist across a session and the values of those attributes.

Returns:

  • (Hash<String,String>)


3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3978

class InlineSessionState < Struct.new(
  :conversation_history,
  :files,
  :invocation_id,
  :prompt_session_attributes,
  :return_control_invocation_results,
  :session_attributes)
  SENSITIVE = []
  include Aws::Structure
end