Class: Aws::BedrockAgentRuntime::Types::InputImage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains the image data for multimodal knowledge base queries, including format and content.

This data type is used in the following API operations:

  • Retrieve request][1

    – in the ‘image` field

^

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_Retrieve.html#API_agent-runtime_Retrieve_RequestSyntax

Constant Summary collapse

SENSITIVE =
[:inline_content]

Instance Attribute Summary collapse

Instance Attribute Details

#formatString

The format of the input image. Supported formats include png, gif, jpeg, and webp.

Returns:

  • (String)


4038
4039
4040
4041
4042
4043
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4038

class InputImage < Struct.new(
  :format,
  :inline_content)
  SENSITIVE = [:inline_content]
  include Aws::Structure
end

#inline_contentString

The base64-encoded image data for inline image content. Maximum size is 5MB.

Returns:

  • (String)


4038
4039
4040
4041
4042
4043
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4038

class InputImage < Struct.new(
  :format,
  :inline_content)
  SENSITIVE = [:inline_content]
  include Aws::Structure
end