Class: Aws::BedrockAgentRuntime::Types::InvocationInputMember

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Note:

InvocationInputMember is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of InvocationInputMember corresponding to the set member.

Contains details about the API operation or function that the agent predicts should be called.

This data type is used in the following API operations:

  • In the ‘returnControl` field of the [InvokeAgent response]

^

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_InvokeAgent.html#API_agent-runtime_InvokeAgent_ResponseSyntax

Defined Under Namespace

Classes: ApiInvocationInput, FunctionInvocationInput, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#api_invocation_inputTypes::ApiInvocationInput

Contains information about the API operation that the agent predicts should be called.



4895
4896
4897
4898
4899
4900
4901
4902
4903
4904
4905
4906
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4895

class InvocationInputMember < Struct.new(
  :api_invocation_input,
  :function_invocation_input,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ApiInvocationInput < InvocationInputMember; end
  class FunctionInvocationInput < InvocationInputMember; end
  class Unknown < InvocationInputMember; end
end

#function_invocation_inputTypes::FunctionInvocationInput

Contains information about the function that the agent predicts should be called.



4895
4896
4897
4898
4899
4900
4901
4902
4903
4904
4905
4906
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4895

class InvocationInputMember < Struct.new(
  :api_invocation_input,
  :function_invocation_input,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ApiInvocationInput < InvocationInputMember; end
  class FunctionInvocationInput < InvocationInputMember; end
  class Unknown < InvocationInputMember; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



4895
4896
4897
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4895

def unknown
  @unknown
end