Class: Aws::BedrockAgentRuntime::Types::InvocationInputMember

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Note:

InvocationInputMember is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of InvocationInputMember corresponding to the set member.

Contains details about the API operation or function that the agent predicts should be called.

This data type is used in the following API operations:

  • In the returnControl field of the [InvokeAgent response]

^

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_InvokeAgent.html#API_agent-runtime_InvokeAgent_ResponseSyntax

Defined Under Namespace

Classes: ApiInvocationInput, FunctionInvocationInput, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#api_invocation_inputTypes::ApiInvocationInput

Contains information about the API operation that the agent predicts should be called.



2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
2699
2700
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2689

class InvocationInputMember < Struct.new(
  :api_invocation_input,
  :function_invocation_input,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ApiInvocationInput < InvocationInputMember; end
  class FunctionInvocationInput < InvocationInputMember; end
  class Unknown < InvocationInputMember; end
end

#function_invocation_inputTypes::FunctionInvocationInput

Contains information about the function that the agent predicts should be called.



2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
2699
2700
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2689

class InvocationInputMember < Struct.new(
  :api_invocation_input,
  :function_invocation_input,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ApiInvocationInput < InvocationInputMember; end
  class FunctionInvocationInput < InvocationInputMember; end
  class Unknown < InvocationInputMember; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



2689
2690
2691
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2689

def unknown
  @unknown
end