Class: Aws::BedrockAgentRuntime::Types::InvocationResultMember

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Note:

InvocationResultMember is a union - when making an API calls you must set exactly one of the members.

Note:

InvocationResultMember is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of InvocationResultMember corresponding to the set member.

A result from the invocation of an action. For more information, see Return control to the agent developer and Control session context.

This data type is used in the following API operations:

^

Defined Under Namespace

Classes: ApiResult, FunctionResult, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#api_resultTypes::ApiResult

The result from the API response from the action group invocation.

Returns:



5126
5127
5128
5129
5130
5131
5132
5133
5134
5135
5136
5137
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5126

class InvocationResultMember < Struct.new(
  :api_result,
  :function_result,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ApiResult < InvocationResultMember; end
  class FunctionResult < InvocationResultMember; end
  class Unknown < InvocationResultMember; end
end

#function_resultTypes::FunctionResult

The result from the function from the action group invocation.



5126
5127
5128
5129
5130
5131
5132
5133
5134
5135
5136
5137
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5126

class InvocationResultMember < Struct.new(
  :api_result,
  :function_result,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ApiResult < InvocationResultMember; end
  class FunctionResult < InvocationResultMember; end
  class Unknown < InvocationResultMember; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



5126
5127
5128
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5126

def unknown
  @unknown
end