Class: Aws::BedrockAgentRuntime::Types::InvocationResultMember
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::InvocationResultMember
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
InvocationResultMember is a union - when making an API calls you must set exactly one of the members.
InvocationResultMember is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of InvocationResultMember corresponding to the set member.
A result from the invocation of an action. For more information, see
- Return control to the agent developer][1
-
and [Control session
This data type is used in the following API operations:
- InvokeAgent request][3
^
[1]: docs.aws.amazon.com/bedrock/latest/userguide/agents-returncontrol.html [2]: docs.aws.amazon.com/bedrock/latest/userguide/agents-session-state.html [3]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_InvokeAgent.html#API_agent-runtime_InvokeAgent_RequestSyntax
Direct Known Subclasses
Defined Under Namespace
Classes: ApiResult, FunctionResult, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#api_result ⇒ Types::ApiResult
The result from the API response from the action group invocation.
-
#function_result ⇒ Types::FunctionResult
The result from the function from the action group invocation.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#api_result ⇒ Types::ApiResult
The result from the API response from the action group invocation.
2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 2742 2743 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2732 class InvocationResultMember < Struct.new( :api_result, :function_result, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ApiResult < InvocationResultMember; end class FunctionResult < InvocationResultMember; end class Unknown < InvocationResultMember; end end |
#function_result ⇒ Types::FunctionResult
The result from the function from the action group invocation.
2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 2742 2743 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2732 class InvocationResultMember < Struct.new( :api_result, :function_result, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ApiResult < InvocationResultMember; end class FunctionResult < InvocationResultMember; end class Unknown < InvocationResultMember; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
2732 2733 2734 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2732 def unknown @unknown end |