Class: Aws::BedrockAgentRuntime::Types::InvokeAgentRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:input_text]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_alias_idString

The alias of the agent to use.

Returns:

  • (String)


4425
4426
4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
4437
4438
4439
4440
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4425

class InvokeAgentRequest < Struct.new(
  :agent_alias_id,
  :agent_id,
  :bedrock_model_configurations,
  :enable_trace,
  :end_session,
  :input_text,
  :memory_id,
  :prompt_creation_configurations,
  :session_id,
  :session_state,
  :source_arn,
  :streaming_configurations)
  SENSITIVE = [:input_text]
  include Aws::Structure
end

#agent_idString

The unique identifier of the agent to use.

Returns:

  • (String)


4425
4426
4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
4437
4438
4439
4440
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4425

class InvokeAgentRequest < Struct.new(
  :agent_alias_id,
  :agent_id,
  :bedrock_model_configurations,
  :enable_trace,
  :end_session,
  :input_text,
  :memory_id,
  :prompt_creation_configurations,
  :session_id,
  :session_state,
  :source_arn,
  :streaming_configurations)
  SENSITIVE = [:input_text]
  include Aws::Structure
end

#bedrock_model_configurationsTypes::BedrockModelConfigurations

Model performance settings for the request.



4425
4426
4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
4437
4438
4439
4440
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4425

class InvokeAgentRequest < Struct.new(
  :agent_alias_id,
  :agent_id,
  :bedrock_model_configurations,
  :enable_trace,
  :end_session,
  :input_text,
  :memory_id,
  :prompt_creation_configurations,
  :session_id,
  :session_state,
  :source_arn,
  :streaming_configurations)
  SENSITIVE = [:input_text]
  include Aws::Structure
end

#enable_traceBoolean

Specifies whether to turn on the trace or not to track the agent’s reasoning process. For more information, see [Trace enablement].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/agents-test.html#trace-events

Returns:

  • (Boolean)


4425
4426
4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
4437
4438
4439
4440
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4425

class InvokeAgentRequest < Struct.new(
  :agent_alias_id,
  :agent_id,
  :bedrock_model_configurations,
  :enable_trace,
  :end_session,
  :input_text,
  :memory_id,
  :prompt_creation_configurations,
  :session_id,
  :session_state,
  :source_arn,
  :streaming_configurations)
  SENSITIVE = [:input_text]
  include Aws::Structure
end

#end_sessionBoolean

Specifies whether to end the session with the agent or not.

Returns:

  • (Boolean)


4425
4426
4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
4437
4438
4439
4440
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4425

class InvokeAgentRequest < Struct.new(
  :agent_alias_id,
  :agent_id,
  :bedrock_model_configurations,
  :enable_trace,
  :end_session,
  :input_text,
  :memory_id,
  :prompt_creation_configurations,
  :session_id,
  :session_state,
  :source_arn,
  :streaming_configurations)
  SENSITIVE = [:input_text]
  include Aws::Structure
end

#input_textString

The prompt text to send the agent.

<note markdown=“1”> If you include ‘returnControlInvocationResults` in the `sessionState` field, the `inputText` field will be ignored.

</note>

Returns:

  • (String)


4425
4426
4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
4437
4438
4439
4440
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4425

class InvokeAgentRequest < Struct.new(
  :agent_alias_id,
  :agent_id,
  :bedrock_model_configurations,
  :enable_trace,
  :end_session,
  :input_text,
  :memory_id,
  :prompt_creation_configurations,
  :session_id,
  :session_state,
  :source_arn,
  :streaming_configurations)
  SENSITIVE = [:input_text]
  include Aws::Structure
end

#memory_idString

The unique identifier of the agent memory.

Returns:

  • (String)


4425
4426
4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
4437
4438
4439
4440
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4425

class InvokeAgentRequest < Struct.new(
  :agent_alias_id,
  :agent_id,
  :bedrock_model_configurations,
  :enable_trace,
  :end_session,
  :input_text,
  :memory_id,
  :prompt_creation_configurations,
  :session_id,
  :session_state,
  :source_arn,
  :streaming_configurations)
  SENSITIVE = [:input_text]
  include Aws::Structure
end

#prompt_creation_configurationsTypes::PromptCreationConfigurations

Specifies parameters that control how the service populates the agent prompt for an ‘InvokeAgent` request. You can control which aspects of previous invocations in the same agent session the service uses to populate the agent prompt. This gives you more granular control over the contextual history that is used to process the current request.



4425
4426
4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
4437
4438
4439
4440
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4425

class InvokeAgentRequest < Struct.new(
  :agent_alias_id,
  :agent_id,
  :bedrock_model_configurations,
  :enable_trace,
  :end_session,
  :input_text,
  :memory_id,
  :prompt_creation_configurations,
  :session_id,
  :session_state,
  :source_arn,
  :streaming_configurations)
  SENSITIVE = [:input_text]
  include Aws::Structure
end

#session_idString

The unique identifier of the session. Use the same value across requests to continue the same conversation.

Returns:

  • (String)


4425
4426
4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
4437
4438
4439
4440
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4425

class InvokeAgentRequest < Struct.new(
  :agent_alias_id,
  :agent_id,
  :bedrock_model_configurations,
  :enable_trace,
  :end_session,
  :input_text,
  :memory_id,
  :prompt_creation_configurations,
  :session_id,
  :session_state,
  :source_arn,
  :streaming_configurations)
  SENSITIVE = [:input_text]
  include Aws::Structure
end

#session_stateTypes::SessionState

Contains parameters that specify various attributes of the session. For more information, see [Control session context].

<note markdown=“1”> If you include ‘returnControlInvocationResults` in the `sessionState` field, the `inputText` field will be ignored.

</note>

[1]: docs.aws.amazon.com/bedrock/latest/userguide/agents-session-state.html

Returns:



4425
4426
4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
4437
4438
4439
4440
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4425

class InvokeAgentRequest < Struct.new(
  :agent_alias_id,
  :agent_id,
  :bedrock_model_configurations,
  :enable_trace,
  :end_session,
  :input_text,
  :memory_id,
  :prompt_creation_configurations,
  :session_id,
  :session_state,
  :source_arn,
  :streaming_configurations)
  SENSITIVE = [:input_text]
  include Aws::Structure
end

#source_arnString

The ARN of the resource making the request.

Returns:

  • (String)


4425
4426
4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
4437
4438
4439
4440
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4425

class InvokeAgentRequest < Struct.new(
  :agent_alias_id,
  :agent_id,
  :bedrock_model_configurations,
  :enable_trace,
  :end_session,
  :input_text,
  :memory_id,
  :prompt_creation_configurations,
  :session_id,
  :session_state,
  :source_arn,
  :streaming_configurations)
  SENSITIVE = [:input_text]
  include Aws::Structure
end

#streaming_configurationsTypes::StreamingConfigurations

Specifies the configurations for streaming.

<note markdown=“1”> To use agent streaming, you need permissions to perform the ‘bedrock:InvokeModelWithResponseStream` action.

</note>


4425
4426
4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
4437
4438
4439
4440
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4425

class InvokeAgentRequest < Struct.new(
  :agent_alias_id,
  :agent_id,
  :bedrock_model_configurations,
  :enable_trace,
  :end_session,
  :input_text,
  :memory_id,
  :prompt_creation_configurations,
  :session_id,
  :session_state,
  :source_arn,
  :streaming_configurations)
  SENSITIVE = [:input_text]
  include Aws::Structure
end