Class: Aws::BedrockAgentRuntime::Types::InvokeAgentResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::InvokeAgentResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#completion ⇒ Types::ResponseStream
The agent’s response to the user prompt.
-
#content_type ⇒ String
The MIME type of the input data in the request.
-
#memory_id ⇒ String
The unique identifier of the agent memory.
-
#session_id ⇒ String
The unique identifier of the session with the agent.
Instance Attribute Details
#completion ⇒ Types::ResponseStream
The agent’s response to the user prompt.
5200 5201 5202 5203 5204 5205 5206 5207 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5200 class InvokeAgentResponse < Struct.new( :completion, :content_type, :memory_id, :session_id) SENSITIVE = [] include Aws::Structure end |
#content_type ⇒ String
The MIME type of the input data in the request. The default value is ‘application/json`.
5200 5201 5202 5203 5204 5205 5206 5207 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5200 class InvokeAgentResponse < Struct.new( :completion, :content_type, :memory_id, :session_id) SENSITIVE = [] include Aws::Structure end |
#memory_id ⇒ String
The unique identifier of the agent memory.
5200 5201 5202 5203 5204 5205 5206 5207 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5200 class InvokeAgentResponse < Struct.new( :completion, :content_type, :memory_id, :session_id) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
The unique identifier of the session with the agent.
5200 5201 5202 5203 5204 5205 5206 5207 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5200 class InvokeAgentResponse < Struct.new( :completion, :content_type, :memory_id, :session_id) SENSITIVE = [] include Aws::Structure end |