Class: Aws::BedrockAgentRuntime::Types::InvokeFlowRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::InvokeFlowRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enable_trace ⇒ Boolean
Specifies whether to return the trace for the flow or not.
-
#execution_id ⇒ String
The unique identifier for the current flow execution.
-
#flow_alias_identifier ⇒ String
The unique identifier of the flow alias.
-
#flow_identifier ⇒ String
The unique identifier of the flow.
-
#inputs ⇒ Array<Types::FlowInput>
A list of objects, each containing information about an input into the flow.
-
#model_performance_configuration ⇒ Types::ModelPerformanceConfiguration
Model performance settings for the request.
Instance Attribute Details
#enable_trace ⇒ Boolean
Specifies whether to return the trace for the flow or not. Traces track inputs and outputs for nodes in the flow. For more information, see [Track each step in your prompt flow by viewing its trace in Amazon Bedrock].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/flows-trace.html
4505 4506 4507 4508 4509 4510 4511 4512 4513 4514 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4505 class InvokeFlowRequest < Struct.new( :enable_trace, :execution_id, :flow_alias_identifier, :flow_identifier, :inputs, :model_performance_configuration) SENSITIVE = [] include Aws::Structure end |
#execution_id ⇒ String
The unique identifier for the current flow execution. If you don’t provide a value, Amazon Bedrock creates the identifier for you.
4505 4506 4507 4508 4509 4510 4511 4512 4513 4514 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4505 class InvokeFlowRequest < Struct.new( :enable_trace, :execution_id, :flow_alias_identifier, :flow_identifier, :inputs, :model_performance_configuration) SENSITIVE = [] include Aws::Structure end |
#flow_alias_identifier ⇒ String
The unique identifier of the flow alias.
4505 4506 4507 4508 4509 4510 4511 4512 4513 4514 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4505 class InvokeFlowRequest < Struct.new( :enable_trace, :execution_id, :flow_alias_identifier, :flow_identifier, :inputs, :model_performance_configuration) SENSITIVE = [] include Aws::Structure end |
#flow_identifier ⇒ String
The unique identifier of the flow.
4505 4506 4507 4508 4509 4510 4511 4512 4513 4514 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4505 class InvokeFlowRequest < Struct.new( :enable_trace, :execution_id, :flow_alias_identifier, :flow_identifier, :inputs, :model_performance_configuration) SENSITIVE = [] include Aws::Structure end |
#inputs ⇒ Array<Types::FlowInput>
A list of objects, each containing information about an input into the flow.
4505 4506 4507 4508 4509 4510 4511 4512 4513 4514 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4505 class InvokeFlowRequest < Struct.new( :enable_trace, :execution_id, :flow_alias_identifier, :flow_identifier, :inputs, :model_performance_configuration) SENSITIVE = [] include Aws::Structure end |
#model_performance_configuration ⇒ Types::ModelPerformanceConfiguration
Model performance settings for the request.
4505 4506 4507 4508 4509 4510 4511 4512 4513 4514 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4505 class InvokeFlowRequest < Struct.new( :enable_trace, :execution_id, :flow_alias_identifier, :flow_identifier, :inputs, :model_performance_configuration) SENSITIVE = [] include Aws::Structure end |