Class: Aws::BedrockAgentRuntime::Types::InvokeFlowRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enable_traceBoolean

Specifies whether to return the trace for the flow or not. Traces track inputs and outputs for nodes in the flow. For more information, see [Track each step in your prompt flow by viewing its trace in Amazon Bedrock].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/flows-trace.html

Returns:

  • (Boolean)


2891
2892
2893
2894
2895
2896
2897
2898
2899
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2891

class InvokeFlowRequest < Struct.new(
  :enable_trace,
  :flow_alias_identifier,
  :flow_identifier,
  :inputs,
  :model_performance_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#flow_alias_identifierString

The unique identifier of the flow alias.

Returns:

  • (String)


2891
2892
2893
2894
2895
2896
2897
2898
2899
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2891

class InvokeFlowRequest < Struct.new(
  :enable_trace,
  :flow_alias_identifier,
  :flow_identifier,
  :inputs,
  :model_performance_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#flow_identifierString

The unique identifier of the flow.

Returns:

  • (String)


2891
2892
2893
2894
2895
2896
2897
2898
2899
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2891

class InvokeFlowRequest < Struct.new(
  :enable_trace,
  :flow_alias_identifier,
  :flow_identifier,
  :inputs,
  :model_performance_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#inputsArray<Types::FlowInput>

A list of objects, each containing information about an input into the flow.

Returns:



2891
2892
2893
2894
2895
2896
2897
2898
2899
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2891

class InvokeFlowRequest < Struct.new(
  :enable_trace,
  :flow_alias_identifier,
  :flow_identifier,
  :inputs,
  :model_performance_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#model_performance_configurationTypes::ModelPerformanceConfiguration

Model performance settings for the request.



2891
2892
2893
2894
2895
2896
2897
2898
2899
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 2891

class InvokeFlowRequest < Struct.new(
  :enable_trace,
  :flow_alias_identifier,
  :flow_identifier,
  :inputs,
  :model_performance_configuration)
  SENSITIVE = []
  include Aws::Structure
end