Class: Aws::BedrockAgentRuntime::Types::KnowledgeBase

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Details of the knowledge base associated withe inline agent.

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the knowledge base associated with the inline agent.

Returns:

  • (String)


3081
3082
3083
3084
3085
3086
3087
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3081

class KnowledgeBase < Struct.new(
  :description,
  :knowledge_base_id,
  :retrieval_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#knowledge_base_idString

The unique identifier for a knowledge base associated with the inline agent.

Returns:

  • (String)


3081
3082
3083
3084
3085
3086
3087
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3081

class KnowledgeBase < Struct.new(
  :description,
  :knowledge_base_id,
  :retrieval_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#retrieval_configurationTypes::KnowledgeBaseRetrievalConfiguration

The configurations to apply to the knowledge base during query. For more information, see [Query configurations].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/kb-test-config.html



3081
3082
3083
3084
3085
3086
3087
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3081

class KnowledgeBase < Struct.new(
  :description,
  :knowledge_base_id,
  :retrieval_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end