Class: Aws::BedrockAgentRuntime::Types::KnowledgeBaseConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::KnowledgeBaseConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Configurations to apply to a knowledge base attached to the agent during query. For more information, see [Knowledge base retrieval configurations].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/agents-session-state.html#session-state-kb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#knowledge_base_id ⇒ String
The unique identifier for a knowledge base attached to the agent.
-
#retrieval_configuration ⇒ Types::KnowledgeBaseRetrievalConfiguration
The configurations to apply to the knowledge base during query.
Instance Attribute Details
#knowledge_base_id ⇒ String
The unique identifier for a knowledge base attached to the agent.
3112 3113 3114 3115 3116 3117 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3112 class KnowledgeBaseConfiguration < Struct.new( :knowledge_base_id, :retrieval_configuration) SENSITIVE = [] include Aws::Structure end |
#retrieval_configuration ⇒ Types::KnowledgeBaseRetrievalConfiguration
The configurations to apply to the knowledge base during query. For more information, see [Query configurations].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/kb-test-config.html
3112 3113 3114 3115 3116 3117 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3112 class KnowledgeBaseConfiguration < Struct.new( :knowledge_base_id, :retrieval_configuration) SENSITIVE = [] include Aws::Structure end |