Class: Aws::BedrockAgentRuntime::Types::KnowledgeBaseQuery
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::KnowledgeBaseQuery
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains the query made to the knowledge base.
This data type is used in the following API operations:
- Retrieve request][1
-
– in the
retrievalQueryfield
^
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#text ⇒ String
The text of the query made to the knowledge base.
Instance Attribute Details
#text ⇒ String
The text of the query made to the knowledge base.
3172 3173 3174 3175 3176 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3172 class KnowledgeBaseQuery < Struct.new( :text) SENSITIVE = [] include Aws::Structure end |