Class: Aws::BedrockAgentRuntime::Types::KnowledgeBaseRetrievalResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::KnowledgeBaseRetrievalResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Details about a result from querying the knowledge base.
This data type is used in the following API operations:
- Retrieve response][1
-
– in the ‘retrievalResults` field
^
Constant Summary collapse
- SENSITIVE =
[:content, :location, :metadata]
Instance Attribute Summary collapse
-
#content ⇒ Types::RetrievalResultContent
Contains information about the content of the chunk.
-
#document_id ⇒ String
The unique identifier of the document.
-
#location ⇒ Types::RetrievalResultLocation
Contains information about the location of the data source.
-
#metadata ⇒ Hash<String,Hash,Array,String,Numeric,Boolean>
Contains metadata attributes and their values for the file in the data source.
-
#score ⇒ Float
The level of relevance of the result to the query.
Instance Attribute Details
#content ⇒ Types::RetrievalResultContent
Contains information about the content of the chunk.
5694 5695 5696 5697 5698 5699 5700 5701 5702 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5694 class KnowledgeBaseRetrievalResult < Struct.new( :content, :document_id, :location, :metadata, :score) SENSITIVE = [:content, :location, :metadata] include Aws::Structure end |
#document_id ⇒ String
The unique identifier of the document. Use with ‘GetDocumentContent` to retrieve the full document.
5694 5695 5696 5697 5698 5699 5700 5701 5702 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5694 class KnowledgeBaseRetrievalResult < Struct.new( :content, :document_id, :location, :metadata, :score) SENSITIVE = [:content, :location, :metadata] include Aws::Structure end |
#location ⇒ Types::RetrievalResultLocation
Contains information about the location of the data source.
5694 5695 5696 5697 5698 5699 5700 5701 5702 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5694 class KnowledgeBaseRetrievalResult < Struct.new( :content, :document_id, :location, :metadata, :score) SENSITIVE = [:content, :location, :metadata] include Aws::Structure end |
#metadata ⇒ Hash<String,Hash,Array,String,Numeric,Boolean>
Contains metadata attributes and their values for the file in the data source. For more information, see [Metadata and filtering].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/knowledge-base-ds.html#kb-ds-metadata
5694 5695 5696 5697 5698 5699 5700 5701 5702 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5694 class KnowledgeBaseRetrievalResult < Struct.new( :content, :document_id, :location, :metadata, :score) SENSITIVE = [:content, :location, :metadata] include Aws::Structure end |
#score ⇒ Float
The level of relevance of the result to the query.
5694 5695 5696 5697 5698 5699 5700 5701 5702 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5694 class KnowledgeBaseRetrievalResult < Struct.new( :content, :document_id, :location, :metadata, :score) SENSITIVE = [:content, :location, :metadata] include Aws::Structure end |