Class: Aws::BedrockAgentRuntime::Types::KnowledgeBaseRetrievalResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Details about a result from querying the knowledge base.

This data type is used in the following API operations:

  • Retrieve response][1

    – in the retrievalResults field

^

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_Retrieve.html#API_agent-runtime_Retrieve_ResponseSyntax

Constant Summary collapse

SENSITIVE =
[:content, :location, :metadata]

Instance Attribute Summary collapse

Instance Attribute Details

#contentTypes::RetrievalResultContent

Contains information about the content of the chunk.



3246
3247
3248
3249
3250
3251
3252
3253
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3246

class KnowledgeBaseRetrievalResult < Struct.new(
  :content,
  :location,
  :metadata,
  :score)
  SENSITIVE = [:content, :location, :metadata]
  include Aws::Structure
end

#locationTypes::RetrievalResultLocation

Contains information about the location of the data source.



3246
3247
3248
3249
3250
3251
3252
3253
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3246

class KnowledgeBaseRetrievalResult < Struct.new(
  :content,
  :location,
  :metadata,
  :score)
  SENSITIVE = [:content, :location, :metadata]
  include Aws::Structure
end

#metadataHash<String,Hash,Array,String,Numeric,Boolean>

Contains metadata attributes and their values for the file in the data source. For more information, see [Metadata and filtering].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/knowledge-base-ds.html#kb-ds-metadata

Returns:

  • (Hash<String,Hash,Array,String,Numeric,Boolean>)


3246
3247
3248
3249
3250
3251
3252
3253
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3246

class KnowledgeBaseRetrievalResult < Struct.new(
  :content,
  :location,
  :metadata,
  :score)
  SENSITIVE = [:content, :location, :metadata]
  include Aws::Structure
end

#scoreFloat

The level of relevance of the result to the query.

Returns:

  • (Float)


3246
3247
3248
3249
3250
3251
3252
3253
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3246

class KnowledgeBaseRetrievalResult < Struct.new(
  :content,
  :location,
  :metadata,
  :score)
  SENSITIVE = [:content, :location, :metadata]
  include Aws::Structure
end