Class: Aws::BedrockAgentRuntime::Types::KnowledgeBaseVectorSearchConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Configurations for how to perform the search query and return results. For more information, see [Query configurations].

This data type is used in the following API operations:

  • Retrieve request][2

    – in the vectorSearchConfiguration field

  • RetrieveAndGenerate request][3

    – in the

    vectorSearchConfiguration field

[1]: docs.aws.amazon.com/bedrock/latest/userguide/kb-test-config.html [2]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_Retrieve.html#API_agent-runtime_Retrieve_RequestSyntax [3]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_RetrieveAndGenerate.html#API_agent-runtime_RetrieveAndGenerate_RequestSyntax

Constant Summary collapse

SENSITIVE =
[:filter]

Instance Attribute Summary collapse

Instance Attribute Details

#filterTypes::RetrievalFilter

Specifies the filters to use on the metadata in the knowledge base data sources before returning results. For more information, see [Query configurations].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/kb-test-config.html



3370
3371
3372
3373
3374
3375
3376
3377
3378
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3370

class KnowledgeBaseVectorSearchConfiguration < Struct.new(
  :filter,
  :implicit_filter_configuration,
  :number_of_results,
  :override_search_type,
  :reranking_configuration)
  SENSITIVE = [:filter]
  include Aws::Structure
end

#implicit_filter_configurationTypes::ImplicitFilterConfiguration

Settings for implicit filtering.



3370
3371
3372
3373
3374
3375
3376
3377
3378
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3370

class KnowledgeBaseVectorSearchConfiguration < Struct.new(
  :filter,
  :implicit_filter_configuration,
  :number_of_results,
  :override_search_type,
  :reranking_configuration)
  SENSITIVE = [:filter]
  include Aws::Structure
end

#number_of_resultsInteger

The number of source chunks to retrieve.

Returns:

  • (Integer)


3370
3371
3372
3373
3374
3375
3376
3377
3378
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3370

class KnowledgeBaseVectorSearchConfiguration < Struct.new(
  :filter,
  :implicit_filter_configuration,
  :number_of_results,
  :override_search_type,
  :reranking_configuration)
  SENSITIVE = [:filter]
  include Aws::Structure
end

#override_search_typeString

By default, Amazon Bedrock decides a search strategy for you. If you’re using an Amazon OpenSearch Serverless vector store that contains a filterable text field, you can specify whether to query the knowledge base with a HYBRID search using both vector embeddings and raw text, or SEMANTIC search using only vector embeddings. For other vector store configurations, only SEMANTIC search is available. For more information, see [Test a knowledge base].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/knowledge-base-test.html

Returns:

  • (String)


3370
3371
3372
3373
3374
3375
3376
3377
3378
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3370

class KnowledgeBaseVectorSearchConfiguration < Struct.new(
  :filter,
  :implicit_filter_configuration,
  :number_of_results,
  :override_search_type,
  :reranking_configuration)
  SENSITIVE = [:filter]
  include Aws::Structure
end

#reranking_configurationTypes::VectorSearchRerankingConfiguration

Contains configurations for reranking the retrieved results. For more information, see [Improve the relevance of query responses with a reranker model].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/rerank.html



3370
3371
3372
3373
3374
3375
3376
3377
3378
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3370

class KnowledgeBaseVectorSearchConfiguration < Struct.new(
  :filter,
  :implicit_filter_configuration,
  :number_of_results,
  :override_search_type,
  :reranking_configuration)
  SENSITIVE = [:filter]
  include Aws::Structure
end