Class: Aws::BedrockAgentRuntime::Types::ListFlowExecutionEventsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::ListFlowExecutionEventsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#event_type ⇒ String
The type of events to retrieve.
-
#execution_identifier ⇒ String
The unique identifier of the flow execution.
-
#flow_alias_identifier ⇒ String
The unique identifier of the flow alias used for the execution.
-
#flow_identifier ⇒ String
The unique identifier of the flow.
-
#max_results ⇒ Integer
The maximum number of events to return in a single response.
-
#next_token ⇒ String
A token to retrieve the next set of results.
Instance Attribute Details
#event_type ⇒ String
The type of events to retrieve. Specify Node for node-level events
or Flow for flow-level events.
6343 6344 6345 6346 6347 6348 6349 6350 6351 6352 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6343 class ListFlowExecutionEventsRequest < Struct.new( :event_type, :execution_identifier, :flow_alias_identifier, :flow_identifier, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#execution_identifier ⇒ String
The unique identifier of the flow execution.
6343 6344 6345 6346 6347 6348 6349 6350 6351 6352 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6343 class ListFlowExecutionEventsRequest < Struct.new( :event_type, :execution_identifier, :flow_alias_identifier, :flow_identifier, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#flow_alias_identifier ⇒ String
The unique identifier of the flow alias used for the execution.
6343 6344 6345 6346 6347 6348 6349 6350 6351 6352 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6343 class ListFlowExecutionEventsRequest < Struct.new( :event_type, :execution_identifier, :flow_alias_identifier, :flow_identifier, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#flow_identifier ⇒ String
The unique identifier of the flow.
6343 6344 6345 6346 6347 6348 6349 6350 6351 6352 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6343 class ListFlowExecutionEventsRequest < Struct.new( :event_type, :execution_identifier, :flow_alias_identifier, :flow_identifier, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of events to return in a single response. If more events exist than the specified maxResults value, a token is included in the response so that the remaining results can be retrieved.
6343 6344 6345 6346 6347 6348 6349 6350 6351 6352 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6343 class ListFlowExecutionEventsRequest < Struct.new( :event_type, :execution_identifier, :flow_alias_identifier, :flow_identifier, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to retrieve the next set of results. This value is returned in the response if more results are available.
6343 6344 6345 6346 6347 6348 6349 6350 6351 6352 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6343 class ListFlowExecutionEventsRequest < Struct.new( :event_type, :execution_identifier, :flow_alias_identifier, :flow_identifier, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |