Class: Aws::BedrockAgentRuntime::Types::ListFlowExecutionEventsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::ListFlowExecutionEventsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#flow_execution_events ⇒ Array<Types::FlowExecutionEvent>
A list of events that occurred during the flow execution.
-
#next_token ⇒ String
A token to retrieve the next set of results.
Instance Attribute Details
#flow_execution_events ⇒ Array<Types::FlowExecutionEvent>
A list of events that occurred during the flow execution. Events can include node inputs and outputs, flow inputs and outputs, condition results, and failure events.
6367 6368 6369 6370 6371 6372 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6367 class ListFlowExecutionEventsResponse < Struct.new( :flow_execution_events, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to retrieve the next set of results. This value is returned if more results are available.
6367 6368 6369 6370 6371 6372 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6367 class ListFlowExecutionEventsResponse < Struct.new( :flow_execution_events, :next_token) SENSITIVE = [] include Aws::Structure end |