Class: Aws::BedrockAgentRuntime::Types::ListInvocationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::ListInvocationsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#invocation_summaries ⇒ Array<Types::InvocationSummary>
A list of invocation summaries associated with the session.
-
#next_token ⇒ String
If the total number of results is greater than the
maxResultsvalue provided in the request, use this token when making another request in thenextTokenfield to return the next batch of results.
Instance Attribute Details
#invocation_summaries ⇒ Array<Types::InvocationSummary>
A list of invocation summaries associated with the session.
6525 6526 6527 6528 6529 6530 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6525 class ListInvocationsResponse < Struct.new( :invocation_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the total number of results is greater than the maxResults
value provided in the request, use this token when making another
request in the nextToken field to return the next batch of
results.
6525 6526 6527 6528 6529 6530 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6525 class ListInvocationsResponse < Struct.new( :invocation_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |