Class: Aws::BedrockAgentRuntime::Types::ManagedSearchConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::ManagedSearchConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Configuration for managed search in a knowledge base. Managed search automatically determines the best search strategy based on your data store configuration.
Constant Summary collapse
- SENSITIVE =
[:filter]
Instance Attribute Summary collapse
-
#filter ⇒ Types::RetrievalFilter
Filters the metadata of the retrieved results so that Amazon Bedrock returns only results that match the filter.
-
#number_of_results ⇒ Integer
The number of results to retrieve.
-
#reranking_configuration ⇒ Types::ManagedSearchRerankingConfiguration
Contains configurations for reranking the results retrieved from the managed search.
-
#reranking_model_type ⇒ String
The type of reranking model to use when reranking results retrieved from the managed search.
Instance Attribute Details
#filter ⇒ Types::RetrievalFilter
Filters the metadata of the retrieved results so that Amazon Bedrock returns only results that match the filter.
6395 6396 6397 6398 6399 6400 6401 6402 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6395 class ManagedSearchConfiguration < Struct.new( :filter, :number_of_results, :reranking_configuration, :reranking_model_type) SENSITIVE = [:filter] include Aws::Structure end |
#number_of_results ⇒ Integer
The number of results to retrieve.
6395 6396 6397 6398 6399 6400 6401 6402 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6395 class ManagedSearchConfiguration < Struct.new( :filter, :number_of_results, :reranking_configuration, :reranking_model_type) SENSITIVE = [:filter] include Aws::Structure end |
#reranking_configuration ⇒ Types::ManagedSearchRerankingConfiguration
Contains configurations for reranking the results retrieved from the managed search.
6395 6396 6397 6398 6399 6400 6401 6402 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6395 class ManagedSearchConfiguration < Struct.new( :filter, :number_of_results, :reranking_configuration, :reranking_model_type) SENSITIVE = [:filter] include Aws::Structure end |
#reranking_model_type ⇒ String
The type of reranking model to use when reranking results retrieved
from the managed search. Use CUSTOM to specify a model, MANAGED
to use the service default, or NONE to disable reranking.
6395 6396 6397 6398 6399 6400 6401 6402 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6395 class ManagedSearchConfiguration < Struct.new( :filter, :number_of_results, :reranking_configuration, :reranking_model_type) SENSITIVE = [:filter] include Aws::Structure end |