Class: Aws::BedrockAgentRuntime::Types::ManagedSearchConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Configuration for managed search in a knowledge base. Managed search automatically determines the best search strategy based on your data store configuration.

Constant Summary collapse

SENSITIVE =
[:filter]

Instance Attribute Summary collapse

Instance Attribute Details

#filterTypes::RetrievalFilter

Specifies the filters to use on the metadata attributes in the knowledge base data sources before returning results. For more information, see [Query configurations]. See the examples below to see how to use these filters.

This data type is used in the following API operations:

  • Retrieve request][2

    – in the ‘filter` field

  • RetrieveAndGenerate request][3

    – in the ‘filter` field

[1]: docs.aws.amazon.com/bedrock/latest/userguide/kb-test-config.html [2]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_Retrieve.html#API_agent-runtime_Retrieve_RequestSyntax [3]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_RetrieveAndGenerate.html#API_agent-runtime_RetrieveAndGenerate_RequestSyntax



6221
6222
6223
6224
6225
6226
6227
6228
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6221

class ManagedSearchConfiguration < Struct.new(
  :filter,
  :number_of_results,
  :reranking_configuration,
  :reranking_model_type)
  SENSITIVE = [:filter]
  include Aws::Structure
end

#number_of_resultsInteger

The number of results to retrieve.

Returns:

  • (Integer)


6221
6222
6223
6224
6225
6226
6227
6228
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6221

class ManagedSearchConfiguration < Struct.new(
  :filter,
  :number_of_results,
  :reranking_configuration,
  :reranking_model_type)
  SENSITIVE = [:filter]
  include Aws::Structure
end

#reranking_configurationTypes::ManagedSearchRerankingConfiguration

Contains configurations for reranking the results retrieved from the managed search.



6221
6222
6223
6224
6225
6226
6227
6228
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6221

class ManagedSearchConfiguration < Struct.new(
  :filter,
  :number_of_results,
  :reranking_configuration,
  :reranking_model_type)
  SENSITIVE = [:filter]
  include Aws::Structure
end

#reranking_model_typeString

The type of reranking model to use when reranking results retrieved from the managed search. Use ‘CUSTOM` to specify a model, `MANAGED` to use the service default, or `NONE` to disable reranking.

Returns:

  • (String)


6221
6222
6223
6224
6225
6226
6227
6228
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6221

class ManagedSearchConfiguration < Struct.new(
  :filter,
  :number_of_results,
  :reranking_configuration,
  :reranking_model_type)
  SENSITIVE = [:filter]
  include Aws::Structure
end