Class: Aws::BedrockAgentRuntime::Types::MemorySessionSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains details of a session summary.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#memory_idString

The unique identifier of the memory where the session summary is stored.

Returns:

  • (String)


3426
3427
3428
3429
3430
3431
3432
3433
3434
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3426

class MemorySessionSummary < Struct.new(
  :memory_id,
  :session_expiry_time,
  :session_id,
  :session_start_time,
  :summary_text)
  SENSITIVE = []
  include Aws::Structure
end

#session_expiry_timeTime

The time when the memory duration for the session is set to end.

Returns:

  • (Time)


3426
3427
3428
3429
3430
3431
3432
3433
3434
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3426

class MemorySessionSummary < Struct.new(
  :memory_id,
  :session_expiry_time,
  :session_id,
  :session_start_time,
  :summary_text)
  SENSITIVE = []
  include Aws::Structure
end

#session_idString

The identifier for this session.

Returns:

  • (String)


3426
3427
3428
3429
3430
3431
3432
3433
3434
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3426

class MemorySessionSummary < Struct.new(
  :memory_id,
  :session_expiry_time,
  :session_id,
  :session_start_time,
  :summary_text)
  SENSITIVE = []
  include Aws::Structure
end

#session_start_timeTime

The start time for this session.

Returns:

  • (Time)


3426
3427
3428
3429
3430
3431
3432
3433
3434
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3426

class MemorySessionSummary < Struct.new(
  :memory_id,
  :session_expiry_time,
  :session_id,
  :session_start_time,
  :summary_text)
  SENSITIVE = []
  include Aws::Structure
end

#summary_textString

The summarized text for this session.

Returns:

  • (String)


3426
3427
3428
3429
3430
3431
3432
3433
3434
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3426

class MemorySessionSummary < Struct.new(
  :memory_id,
  :session_expiry_time,
  :session_id,
  :session_start_time,
  :summary_text)
  SENSITIVE = []
  include Aws::Structure
end