Class: Aws::BedrockAgentRuntime::Types::Metadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::Metadata
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Provides information about the execution process for different types of invocations, such as model invocation, knowledge base invocation, agent collaborator invocation, guardrail invocation, and code interpreter Invocation.
Constant Summary collapse
- SENSITIVE =
[:usage]
Instance Attribute Summary collapse
-
#client_request_id ⇒ String
A unique identifier associated with the downstream invocation.
-
#end_time ⇒ Time
In the final response, ‘endTime` is the end time of the agent invocation operation.
-
#operation_total_time_ms ⇒ Integer
The total time it took for the agent to complete execution.
-
#start_time ⇒ Time
In the final response, ‘startTime` is the start time of the agent invocation operation.
-
#total_time_ms ⇒ Integer
The total execution time for the specific invocation being processed (model, knowledge base, guardrail, agent collaborator, or code interpreter).
-
#usage ⇒ Types::Usage
Specific to model invocation and contains details about the usage of a foundation model.
Instance Attribute Details
#client_request_id ⇒ String
A unique identifier associated with the downstream invocation. This ID can be used for tracing, debugging, and identifying specific invocations in customer logs or systems.
6363 6364 6365 6366 6367 6368 6369 6370 6371 6372 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6363 class Metadata < Struct.new( :client_request_id, :end_time, :operation_total_time_ms, :start_time, :total_time_ms, :usage) SENSITIVE = [:usage] include Aws::Structure end |
#end_time ⇒ Time
In the final response, ‘endTime` is the end time of the agent invocation operation.
6363 6364 6365 6366 6367 6368 6369 6370 6371 6372 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6363 class Metadata < Struct.new( :client_request_id, :end_time, :operation_total_time_ms, :start_time, :total_time_ms, :usage) SENSITIVE = [:usage] include Aws::Structure end |
#operation_total_time_ms ⇒ Integer
The total time it took for the agent to complete execution. This field is only set for the final response.
6363 6364 6365 6366 6367 6368 6369 6370 6371 6372 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6363 class Metadata < Struct.new( :client_request_id, :end_time, :operation_total_time_ms, :start_time, :total_time_ms, :usage) SENSITIVE = [:usage] include Aws::Structure end |
#start_time ⇒ Time
In the final response, ‘startTime` is the start time of the agent invocation operation.
6363 6364 6365 6366 6367 6368 6369 6370 6371 6372 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6363 class Metadata < Struct.new( :client_request_id, :end_time, :operation_total_time_ms, :start_time, :total_time_ms, :usage) SENSITIVE = [:usage] include Aws::Structure end |
#total_time_ms ⇒ Integer
The total execution time for the specific invocation being processed (model, knowledge base, guardrail, agent collaborator, or code interpreter). It represents how long the individual invocation took.
6363 6364 6365 6366 6367 6368 6369 6370 6371 6372 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6363 class Metadata < Struct.new( :client_request_id, :end_time, :operation_total_time_ms, :start_time, :total_time_ms, :usage) SENSITIVE = [:usage] include Aws::Structure end |
#usage ⇒ Types::Usage
Specific to model invocation and contains details about the usage of a foundation model.
6363 6364 6365 6366 6367 6368 6369 6370 6371 6372 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6363 class Metadata < Struct.new( :client_request_id, :end_time, :operation_total_time_ms, :start_time, :total_time_ms, :usage) SENSITIVE = [:usage] include Aws::Structure end |