Class: Aws::BedrockAgentRuntime::Types::MetadataConfigurationForReranking
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::MetadataConfigurationForReranking
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains configurations for the metadata to use in reranking.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#selection_mode ⇒ String
Specifies whether to consider all metadata when reranking, or only the metadata that you select.
-
#selective_mode_configuration ⇒ Types::RerankingMetadataSelectiveModeConfiguration
Contains configurations for the metadata fields to include or exclude when considering reranking.
Instance Attribute Details
#selection_mode ⇒ String
Specifies whether to consider all metadata when reranking, or only the metadata that you select. If you specify SELECTIVE, include the selectiveModeConfiguration field.
3508 3509 3510 3511 3512 3513 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3508 class MetadataConfigurationForReranking < Struct.new( :selection_mode, :selective_mode_configuration) SENSITIVE = [] include Aws::Structure end |
#selective_mode_configuration ⇒ Types::RerankingMetadataSelectiveModeConfiguration
Contains configurations for the metadata fields to include or exclude when considering reranking.
3508 3509 3510 3511 3512 3513 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3508 class MetadataConfigurationForReranking < Struct.new( :selection_mode, :selective_mode_configuration) SENSITIVE = [] include Aws::Structure end |