Class: Aws::BedrockAgentRuntime::Types::ModelInvocationInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::ModelInvocationInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
The input for the pre-processing step.
-
The ‘type` matches the agent step.
-
The ‘text` contains the prompt.
-
The ‘inferenceConfiguration`, `parserMode`, and `overrideLambda` values are set in the [PromptOverrideConfiguration] object that was set when the agent was created or updated.
[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent_PromptOverrideConfiguration.html
Constant Summary collapse
- SENSITIVE =
[:text]
Instance Attribute Summary collapse
-
#foundation_model ⇒ String
The identifier of a foundation model.
-
#inference_configuration ⇒ Types::InferenceConfiguration
Specifications about the inference parameters that were provided alongside the prompt.
-
#override_lambda ⇒ String
The ARN of the Lambda function to use when parsing the raw foundation model output in parts of the agent sequence.
-
#parser_mode ⇒ String
Specifies whether to override the default parser Lambda function when parsing the raw foundation model output in the part of the agent sequence defined by the ‘promptType`.
-
#prompt_creation_mode ⇒ String
Specifies whether the default prompt template was ‘OVERRIDDEN`.
-
#text ⇒ String
The text that prompted the agent at this step.
-
#trace_id ⇒ String
The unique identifier of the trace.
-
#type ⇒ String
The step in the agent sequence.
Instance Attribute Details
#foundation_model ⇒ String
The identifier of a foundation model.
6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 6497 6498 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6487 class ModelInvocationInput < Struct.new( :foundation_model, :inference_configuration, :override_lambda, :parser_mode, :prompt_creation_mode, :text, :trace_id, :type) SENSITIVE = [:text] include Aws::Structure end |
#inference_configuration ⇒ Types::InferenceConfiguration
Specifications about the inference parameters that were provided alongside the prompt. These are specified in the
- PromptOverrideConfiguration][1
-
object that was set when the agent
was created or updated. For more information, see [Inference parameters for foundation models].
[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent_PromptOverrideConfiguration.html [2]: docs.aws.amazon.com/bedrock/latest/userguide/model-parameters.html
6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 6497 6498 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6487 class ModelInvocationInput < Struct.new( :foundation_model, :inference_configuration, :override_lambda, :parser_mode, :prompt_creation_mode, :text, :trace_id, :type) SENSITIVE = [:text] include Aws::Structure end |
#override_lambda ⇒ String
The ARN of the Lambda function to use when parsing the raw foundation model output in parts of the agent sequence.
6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 6497 6498 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6487 class ModelInvocationInput < Struct.new( :foundation_model, :inference_configuration, :override_lambda, :parser_mode, :prompt_creation_mode, :text, :trace_id, :type) SENSITIVE = [:text] include Aws::Structure end |
#parser_mode ⇒ String
Specifies whether to override the default parser Lambda function when parsing the raw foundation model output in the part of the agent sequence defined by the ‘promptType`.
6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 6497 6498 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6487 class ModelInvocationInput < Struct.new( :foundation_model, :inference_configuration, :override_lambda, :parser_mode, :prompt_creation_mode, :text, :trace_id, :type) SENSITIVE = [:text] include Aws::Structure end |
#prompt_creation_mode ⇒ String
Specifies whether the default prompt template was ‘OVERRIDDEN`. If it was, the `basePromptTemplate` that was set in the
- PromptOverrideConfiguration][1
-
object when the agent was created
or updated is used instead.
[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent_PromptOverrideConfiguration.html
6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 6497 6498 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6487 class ModelInvocationInput < Struct.new( :foundation_model, :inference_configuration, :override_lambda, :parser_mode, :prompt_creation_mode, :text, :trace_id, :type) SENSITIVE = [:text] include Aws::Structure end |
#text ⇒ String
The text that prompted the agent at this step.
6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 6497 6498 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6487 class ModelInvocationInput < Struct.new( :foundation_model, :inference_configuration, :override_lambda, :parser_mode, :prompt_creation_mode, :text, :trace_id, :type) SENSITIVE = [:text] include Aws::Structure end |
#trace_id ⇒ String
The unique identifier of the trace.
6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 6497 6498 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6487 class ModelInvocationInput < Struct.new( :foundation_model, :inference_configuration, :override_lambda, :parser_mode, :prompt_creation_mode, :text, :trace_id, :type) SENSITIVE = [:text] include Aws::Structure end |
#type ⇒ String
The step in the agent sequence.
6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 6497 6498 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6487 class ModelInvocationInput < Struct.new( :foundation_model, :inference_configuration, :override_lambda, :parser_mode, :prompt_creation_mode, :text, :trace_id, :type) SENSITIVE = [:text] include Aws::Structure end |