Class: Aws::BedrockAgentRuntime::Types::ModelNotReadyException
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::ModelNotReadyException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
The model specified in the request is not ready to serve inference requests. The AWS SDK will automatically retry the operation up to 5 times. For information about configuring automatic retries, see [Retry behavior] in the *AWS SDKs and Tools* reference guide.
[1]: docs.aws.amazon.com/sdkref/latest/guide/feature-retry-behavior.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#event_type ⇒ Object
Returns the value of attribute event_type.
- #message ⇒ String
Instance Attribute Details
#event_type ⇒ Object
Returns the value of attribute event_type
3609 3610 3611 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3609 def event_type @event_type end |
#message ⇒ String
3609 3610 3611 3612 3613 3614 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3609 class ModelNotReadyException < Struct.new( :message, :event_type) SENSITIVE = [] include Aws::Structure end |