Class: Aws::BedrockAgentRuntime::Types::NodeTraceElements
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::NodeTraceElements
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Note:
NodeTraceElements is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of NodeTraceElements corresponding to the set member.
Contains trace elements for node execution tracking.
Direct Known Subclasses
Defined Under Namespace
Classes: AgentTraces, Unknown
Constant Summary collapse
- SENSITIVE =
[:agent_traces]
Instance Attribute Summary collapse
-
#agent_traces ⇒ Array<Types::TracePart>
Agent trace information for the node execution.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#agent_traces ⇒ Array<Types::TracePart>
Agent trace information for the node execution.
6884 6885 6886 6887 6888 6889 6890 6891 6892 6893 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6884 class NodeTraceElements < Struct.new( :agent_traces, :unknown) SENSITIVE = [:agent_traces] include Aws::Structure include Aws::Structure::Union class AgentTraces < NodeTraceElements; end class Unknown < NodeTraceElements; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
6884 6885 6886 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6884 def unknown @unknown end |