Class: Aws::BedrockAgentRuntime::Types::OptimizedPromptStream
- Inherits:
-
Enumerator
- Object
- Enumerator
- Aws::BedrockAgentRuntime::Types::OptimizedPromptStream
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
The stream containing events in the prompt optimization process.
EventStream is an Enumerator of Events. #event_types #=> Array, returns all modeled event types in the stream
Instance Method Summary collapse
Instance Method Details
#event_types ⇒ Object
10467 10468 10469 10470 10471 10472 10473 10474 10475 10476 10477 10478 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10467 def event_types [ :access_denied_exception, :analyze_prompt_event, :bad_gateway_exception, :dependency_failed_exception, :internal_server_exception, :optimized_prompt_event, :throttling_exception, :validation_exception ] end |