Class: Aws::BedrockAgentRuntime::Types::OptimizedPromptStream

Inherits:
Enumerator
  • Object
show all
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

The stream containing events in the prompt optimization process.

EventStream is an Enumerator of Events.

#event_types #=> Array, returns all modeled event types in the stream

Instance Method Summary collapse

Instance Method Details

#event_typesObject



6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6300

def event_types
  [
    :access_denied_exception,
    :analyze_prompt_event,
    :bad_gateway_exception,
    :dependency_failed_exception,
    :internal_server_exception,
    :optimized_prompt_event,
    :throttling_exception,
    :validation_exception
  ]
end