Class: Aws::BedrockAgentRuntime::Types::OrchestrationExecutor
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::OrchestrationExecutor
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Note:
OrchestrationExecutor is a union - when making an API calls you must set exactly one of the members.
The structure of the executor invoking the actions in custom orchestration.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#lambda ⇒ String
The Amazon Resource Name (ARN) of the Lambda function containing the business logic that is carried out upon invoking the action.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#lambda ⇒ String
The Amazon Resource Name (ARN) of the Lambda function containing the business logic that is carried out upon invoking the action.
7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7262 class OrchestrationExecutor < Struct.new( :lambda, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Lambda < OrchestrationExecutor; end class Unknown < OrchestrationExecutor; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
7262 7263 7264 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7262 def unknown @unknown end |