Class: Aws::BedrockAgentRuntime::Types::OrchestrationExecutor

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Note:

OrchestrationExecutor is a union - when making an API calls you must set exactly one of the members.

The structure of the executor invoking the actions in custom orchestration.

Direct Known Subclasses

Lambda, Unknown

Defined Under Namespace

Classes: Lambda, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#lambdaString

The Amazon Resource Name (ARN) of the Lambda function containing the business logic that is carried out upon invoking the action.

Returns:

  • (String)


7088
7089
7090
7091
7092
7093
7094
7095
7096
7097
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7088

class OrchestrationExecutor < Struct.new(
  :lambda,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Lambda < OrchestrationExecutor; end
  class Unknown < OrchestrationExecutor; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



7088
7089
7090
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7088

def unknown
  @unknown
end