Class: Aws::BedrockAgentRuntime::Types::OrchestrationModelInvocationOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::OrchestrationModelInvocationOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
The foundation model output from the orchestration step.
Constant Summary collapse
- SENSITIVE =
[:metadata, :raw_response]
Instance Attribute Summary collapse
-
#metadata ⇒ Types::Metadata
Contains information about the foundation model output from the orchestration step.
-
#raw_response ⇒ Types::RawResponse
Contains details of the raw response from the foundation model output.
-
#trace_id ⇒ String
The unique identifier of the trace.
Instance Attribute Details
#metadata ⇒ Types::Metadata
Contains information about the foundation model output from the orchestration step.
3829 3830 3831 3832 3833 3834 3835 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3829 class OrchestrationModelInvocationOutput < Struct.new( :metadata, :raw_response, :trace_id) SENSITIVE = [:metadata, :raw_response] include Aws::Structure end |
#raw_response ⇒ Types::RawResponse
Contains details of the raw response from the foundation model output.
3829 3830 3831 3832 3833 3834 3835 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3829 class OrchestrationModelInvocationOutput < Struct.new( :metadata, :raw_response, :trace_id) SENSITIVE = [:metadata, :raw_response] include Aws::Structure end |
#trace_id ⇒ String
The unique identifier of the trace.
3829 3830 3831 3832 3833 3834 3835 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 3829 class OrchestrationModelInvocationOutput < Struct.new( :metadata, :raw_response, :trace_id) SENSITIVE = [:metadata, :raw_response] include Aws::Structure end |