Class: Aws::BedrockAgentRuntime::Types::OrchestrationTrace

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Note:

OrchestrationTrace is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of OrchestrationTrace corresponding to the set member.

Details about the orchestration step, in which the agent determines the order in which actions are executed and which knowledge bases are retrieved.

Defined Under Namespace

Classes: InvocationInput, ModelInvocationInput, ModelInvocationOutput, Observation, Rationale, Unknown

Constant Summary collapse

SENSITIVE =
[:invocation_input, :model_invocation_input, :model_invocation_output, :observation, :rationale]

Instance Attribute Summary collapse

Instance Attribute Details

#invocation_inputTypes::InvocationInput

Contains information pertaining to the action group or knowledge base that is being invoked.



7176
7177
7178
7179
7180
7181
7182
7183
7184
7185
7186
7187
7188
7189
7190
7191
7192
7193
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7176

class OrchestrationTrace < Struct.new(
  :invocation_input,
  :model_invocation_input,
  :model_invocation_output,
  :observation,
  :rationale,
  :unknown)
  SENSITIVE = [:invocation_input, :model_invocation_input, :model_invocation_output, :observation, :rationale]
  include Aws::Structure
  include Aws::Structure::Union

  class InvocationInput < OrchestrationTrace; end
  class ModelInvocationInput < OrchestrationTrace; end
  class ModelInvocationOutput < OrchestrationTrace; end
  class Observation < OrchestrationTrace; end
  class Rationale < OrchestrationTrace; end
  class Unknown < OrchestrationTrace; end
end

#model_invocation_inputTypes::ModelInvocationInput

The input for the orchestration step.

  • The ‘type` is `ORCHESTRATION`.

  • The ‘text` contains the prompt.

  • The ‘inferenceConfiguration`, `parserMode`, and `overrideLambda` values are set in the [PromptOverrideConfiguration] object that was set when the agent was created or updated.

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent_PromptOverrideConfiguration.html



7176
7177
7178
7179
7180
7181
7182
7183
7184
7185
7186
7187
7188
7189
7190
7191
7192
7193
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7176

class OrchestrationTrace < Struct.new(
  :invocation_input,
  :model_invocation_input,
  :model_invocation_output,
  :observation,
  :rationale,
  :unknown)
  SENSITIVE = [:invocation_input, :model_invocation_input, :model_invocation_output, :observation, :rationale]
  include Aws::Structure
  include Aws::Structure::Union

  class InvocationInput < OrchestrationTrace; end
  class ModelInvocationInput < OrchestrationTrace; end
  class ModelInvocationOutput < OrchestrationTrace; end
  class Observation < OrchestrationTrace; end
  class Rationale < OrchestrationTrace; end
  class Unknown < OrchestrationTrace; end
end

#model_invocation_outputTypes::OrchestrationModelInvocationOutput

Contains information pertaining to the output from the foundation model that is being invoked.



7176
7177
7178
7179
7180
7181
7182
7183
7184
7185
7186
7187
7188
7189
7190
7191
7192
7193
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7176

class OrchestrationTrace < Struct.new(
  :invocation_input,
  :model_invocation_input,
  :model_invocation_output,
  :observation,
  :rationale,
  :unknown)
  SENSITIVE = [:invocation_input, :model_invocation_input, :model_invocation_output, :observation, :rationale]
  include Aws::Structure
  include Aws::Structure::Union

  class InvocationInput < OrchestrationTrace; end
  class ModelInvocationInput < OrchestrationTrace; end
  class ModelInvocationOutput < OrchestrationTrace; end
  class Observation < OrchestrationTrace; end
  class Rationale < OrchestrationTrace; end
  class Unknown < OrchestrationTrace; end
end

#observationTypes::Observation

Details about the observation (the output of the action group Lambda or knowledge base) made by the agent.

Returns:



7176
7177
7178
7179
7180
7181
7182
7183
7184
7185
7186
7187
7188
7189
7190
7191
7192
7193
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7176

class OrchestrationTrace < Struct.new(
  :invocation_input,
  :model_invocation_input,
  :model_invocation_output,
  :observation,
  :rationale,
  :unknown)
  SENSITIVE = [:invocation_input, :model_invocation_input, :model_invocation_output, :observation, :rationale]
  include Aws::Structure
  include Aws::Structure::Union

  class InvocationInput < OrchestrationTrace; end
  class ModelInvocationInput < OrchestrationTrace; end
  class ModelInvocationOutput < OrchestrationTrace; end
  class Observation < OrchestrationTrace; end
  class Rationale < OrchestrationTrace; end
  class Unknown < OrchestrationTrace; end
end

#rationaleTypes::Rationale

Details about the reasoning, based on the input, that the agent uses to justify carrying out an action group or getting information from a knowledge base.

Returns:



7176
7177
7178
7179
7180
7181
7182
7183
7184
7185
7186
7187
7188
7189
7190
7191
7192
7193
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7176

class OrchestrationTrace < Struct.new(
  :invocation_input,
  :model_invocation_input,
  :model_invocation_output,
  :observation,
  :rationale,
  :unknown)
  SENSITIVE = [:invocation_input, :model_invocation_input, :model_invocation_output, :observation, :rationale]
  include Aws::Structure
  include Aws::Structure::Union

  class InvocationInput < OrchestrationTrace; end
  class ModelInvocationInput < OrchestrationTrace; end
  class ModelInvocationOutput < OrchestrationTrace; end
  class Observation < OrchestrationTrace; end
  class Rationale < OrchestrationTrace; end
  class Unknown < OrchestrationTrace; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



7176
7177
7178
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7176

def unknown
  @unknown
end