Class: Aws::BedrockAgentRuntime::Types::PostProcessingTrace

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Note:

PostProcessingTrace is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of PostProcessingTrace corresponding to the set member.

Details about the post-processing step, in which the agent shapes the response.

Defined Under Namespace

Classes: ModelInvocationInput, ModelInvocationOutput, Unknown

Constant Summary collapse

SENSITIVE =
[:model_invocation_input, :model_invocation_output]

Instance Attribute Summary collapse

Instance Attribute Details

#model_invocation_inputTypes::ModelInvocationInput

The input for the post-processing step.

  • The type is POST_PROCESSING.

  • The text contains the prompt.

  • The inferenceConfiguration, parserMode, and overrideLambda values are set in the PromptOverrideConfiguration object that was set when the agent was created or updated.



7833
7834
7835
7836
7837
7838
7839
7840
7841
7842
7843
7844
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7833

class PostProcessingTrace < Struct.new(
  :model_invocation_input,
  :model_invocation_output,
  :unknown)
  SENSITIVE = [:model_invocation_input, :model_invocation_output]
  include Aws::Structure
  include Aws::Structure::Union

  class ModelInvocationInput < PostProcessingTrace; end
  class ModelInvocationOutput < PostProcessingTrace; end
  class Unknown < PostProcessingTrace; end
end

#model_invocation_outputTypes::PostProcessingModelInvocationOutput

The foundation model output from the post-processing step.



7833
7834
7835
7836
7837
7838
7839
7840
7841
7842
7843
7844
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7833

class PostProcessingTrace < Struct.new(
  :model_invocation_input,
  :model_invocation_output,
  :unknown)
  SENSITIVE = [:model_invocation_input, :model_invocation_output]
  include Aws::Structure
  include Aws::Structure::Union

  class ModelInvocationInput < PostProcessingTrace; end
  class ModelInvocationOutput < PostProcessingTrace; end
  class Unknown < PostProcessingTrace; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



7833
7834
7835
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7833

def unknown
  @unknown
end