Class: Aws::BedrockAgentRuntime::Types::PostProcessingTrace
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::PostProcessingTrace
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
PostProcessingTrace is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of PostProcessingTrace corresponding to the set member.
Details about the post-processing step, in which the agent shapes the response.
Direct Known Subclasses
Defined Under Namespace
Classes: ModelInvocationInput, ModelInvocationOutput, Unknown
Constant Summary collapse
- SENSITIVE =
[:model_invocation_input, :model_invocation_output]
Instance Attribute Summary collapse
-
#model_invocation_input ⇒ Types::ModelInvocationInput
The input for the post-processing step.
-
#model_invocation_output ⇒ Types::PostProcessingModelInvocationOutput
The foundation model output from the post-processing step.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#model_invocation_input ⇒ Types::ModelInvocationInput
The input for the post-processing step.
-
The ‘type` is `POST_PROCESSING`.
-
The ‘text` contains the prompt.
-
The ‘inferenceConfiguration`, `parserMode`, and `overrideLambda` values are set in the [PromptOverrideConfiguration] object that was set when the agent was created or updated.
[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent_PromptOverrideConfiguration.html
6497 6498 6499 6500 6501 6502 6503 6504 6505 6506 6507 6508 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6497 class PostProcessingTrace < Struct.new( :model_invocation_input, :model_invocation_output, :unknown) SENSITIVE = [:model_invocation_input, :model_invocation_output] include Aws::Structure include Aws::Structure::Union class ModelInvocationInput < PostProcessingTrace; end class ModelInvocationOutput < PostProcessingTrace; end class Unknown < PostProcessingTrace; end end |
#model_invocation_output ⇒ Types::PostProcessingModelInvocationOutput
The foundation model output from the post-processing step.
6497 6498 6499 6500 6501 6502 6503 6504 6505 6506 6507 6508 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6497 class PostProcessingTrace < Struct.new( :model_invocation_input, :model_invocation_output, :unknown) SENSITIVE = [:model_invocation_input, :model_invocation_output] include Aws::Structure include Aws::Structure::Union class ModelInvocationInput < PostProcessingTrace; end class ModelInvocationOutput < PostProcessingTrace; end class Unknown < PostProcessingTrace; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
6497 6498 6499 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6497 def unknown @unknown end |