Class: Aws::BedrockAgentRuntime::Types::PreProcessingTrace
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::PreProcessingTrace
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
PreProcessingTrace is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of PreProcessingTrace corresponding to the set member.
Details about the pre-processing step, in which the agent contextualizes and categorizes user inputs.
Defined Under Namespace
Classes: ModelInvocationInput, ModelInvocationOutput, Unknown
Constant Summary collapse
- SENSITIVE =
[:model_invocation_input, :model_invocation_output]
Instance Attribute Summary collapse
-
#model_invocation_input ⇒ Types::ModelInvocationInput
The input for the pre-processing step.
-
#model_invocation_output ⇒ Types::PreProcessingModelInvocationOutput
The foundation model output from the pre-processing step.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#model_invocation_input ⇒ Types::ModelInvocationInput
The input for the pre-processing step.
-
The
typeisPRE_PROCESSING. -
The
textcontains the prompt. -
The
inferenceConfiguration,parserMode, andoverrideLambdavalues are set in the PromptOverrideConfiguration object that was set when the agent was created or updated.
7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7657 class PreProcessingTrace < Struct.new( :model_invocation_input, :model_invocation_output, :unknown) SENSITIVE = [:model_invocation_input, :model_invocation_output] include Aws::Structure include Aws::Structure::Union class ModelInvocationInput < PreProcessingTrace; end class ModelInvocationOutput < PreProcessingTrace; end class Unknown < PreProcessingTrace; end end |
#model_invocation_output ⇒ Types::PreProcessingModelInvocationOutput
The foundation model output from the pre-processing step.
7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7657 class PreProcessingTrace < Struct.new( :model_invocation_input, :model_invocation_output, :unknown) SENSITIVE = [:model_invocation_input, :model_invocation_output] include Aws::Structure include Aws::Structure::Union class ModelInvocationInput < PreProcessingTrace; end class ModelInvocationOutput < PreProcessingTrace; end class Unknown < PreProcessingTrace; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
7657 7658 7659 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7657 def unknown @unknown end |