Class: Aws::BedrockAgentRuntime::Types::PromptConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::PromptConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains configurations to override a prompt template in one part of an agent sequence. For more information, see [Advanced prompts][1].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/advanced-prompts.html
Constant Summary collapse
- SENSITIVE =
[:base_prompt_template]
Instance Attribute Summary collapse
-
#base_prompt_template ⇒ String
Defines the prompt template with which to replace the default prompt template.
-
#inference_configuration ⇒ Types::InferenceConfiguration
Contains inference parameters to use when the agent invokes a foundation model in the part of the agent sequence defined by the
promptType. -
#parser_mode ⇒ String
Specifies whether to override the default parser Lambda function when parsing the raw foundation model output in the part of the agent sequence defined by the
promptType. -
#prompt_creation_mode ⇒ String
Specifies whether to override the default prompt template for this
promptType. -
#prompt_state ⇒ String
Specifies whether to allow the inline agent to carry out the step specified in the
promptType. -
#prompt_type ⇒ String
The step in the agent sequence that this prompt configuration applies to.
Instance Attribute Details
#base_prompt_template ⇒ String
Defines the prompt template with which to replace the default prompt template. You can use placeholder variables in the base prompt template to customize the prompt. For more information, see [Prompt template placeholder variables][1]. For more information, see [Configure the prompt templates][2].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/prompt-placeholders.html [2]: docs.aws.amazon.com/bedrock/latest/userguide/advanced-prompts-configure.html
4263 4264 4265 4266 4267 4268 4269 4270 4271 4272 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4263 class PromptConfiguration < Struct.new( :base_prompt_template, :inference_configuration, :parser_mode, :prompt_creation_mode, :prompt_state, :prompt_type) SENSITIVE = [:base_prompt_template] include Aws::Structure end |
#inference_configuration ⇒ Types::InferenceConfiguration
Contains inference parameters to use when the agent invokes a foundation model in the part of the agent sequence defined by the promptType. For more information, see [Inference parameters for foundation models][1].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/model-parameters.html
4263 4264 4265 4266 4267 4268 4269 4270 4271 4272 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4263 class PromptConfiguration < Struct.new( :base_prompt_template, :inference_configuration, :parser_mode, :prompt_creation_mode, :prompt_state, :prompt_type) SENSITIVE = [:base_prompt_template] include Aws::Structure end |
#parser_mode ⇒ String
Specifies whether to override the default parser Lambda function when parsing the raw foundation model output in the part of the agent sequence defined by the promptType. If you set the field as OVERRIDEN, the overrideLambda field in the
- PromptOverrideConfiguration][1
-
must be specified with the ARN of a
Lambda function.
[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent_PromptOverrideConfiguration.html
4263 4264 4265 4266 4267 4268 4269 4270 4271 4272 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4263 class PromptConfiguration < Struct.new( :base_prompt_template, :inference_configuration, :parser_mode, :prompt_creation_mode, :prompt_state, :prompt_type) SENSITIVE = [:base_prompt_template] include Aws::Structure end |
#prompt_creation_mode ⇒ String
Specifies whether to override the default prompt template for this promptType. Set this value to OVERRIDDEN to use the prompt that you provide in the basePromptTemplate. If you leave it as DEFAULT, the agent uses a default prompt template.
4263 4264 4265 4266 4267 4268 4269 4270 4271 4272 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4263 class PromptConfiguration < Struct.new( :base_prompt_template, :inference_configuration, :parser_mode, :prompt_creation_mode, :prompt_state, :prompt_type) SENSITIVE = [:base_prompt_template] include Aws::Structure end |
#prompt_state ⇒ String
Specifies whether to allow the inline agent to carry out the step specified in the promptType. If you set this value to DISABLED, the agent skips that step. The default state for each promptType is as follows.
-
PRE_PROCESSING–ENABLED -
ORCHESTRATION–ENABLED -
KNOWLEDGE_BASE_RESPONSE_GENERATION–ENABLED -
POST_PROCESSING–DISABLED
4263 4264 4265 4266 4267 4268 4269 4270 4271 4272 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4263 class PromptConfiguration < Struct.new( :base_prompt_template, :inference_configuration, :parser_mode, :prompt_creation_mode, :prompt_state, :prompt_type) SENSITIVE = [:base_prompt_template] include Aws::Structure end |
#prompt_type ⇒ String
The step in the agent sequence that this prompt configuration applies to.
4263 4264 4265 4266 4267 4268 4269 4270 4271 4272 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4263 class PromptConfiguration < Struct.new( :base_prompt_template, :inference_configuration, :parser_mode, :prompt_creation_mode, :prompt_state, :prompt_type) SENSITIVE = [:base_prompt_template] include Aws::Structure end |