Class: Aws::BedrockAgentRuntime::Types::PromptOverrideConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::PromptOverrideConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains configurations to override prompts in different parts of an agent sequence. For more information, see [Advanced prompts][1].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/advanced-prompts.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#override_lambda ⇒ String
The ARN of the Lambda function to use when parsing the raw foundation model output in parts of the agent sequence.
-
#prompt_configurations ⇒ Array<Types::PromptConfiguration>
Contains configurations to override a prompt template in one part of an agent sequence.
Instance Attribute Details
#override_lambda ⇒ String
The ARN of the Lambda function to use when parsing the raw foundation model output in parts of the agent sequence. If you specify this field, at least one of the promptConfigurations must contain a parserMode value that is set to OVERRIDDEN. For more information, see [Parser Lambda function in Amazon Bedrock Agents][1].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/lambda-parser.html
4305 4306 4307 4308 4309 4310 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4305 class PromptOverrideConfiguration < Struct.new( :override_lambda, :prompt_configurations) SENSITIVE = [] include Aws::Structure end |
#prompt_configurations ⇒ Array<Types::PromptConfiguration>
Contains configurations to override a prompt template in one part of an agent sequence. For more information, see [Advanced prompts][1].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/advanced-prompts.html
4305 4306 4307 4308 4309 4310 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4305 class PromptOverrideConfiguration < Struct.new( :override_lambda, :prompt_configurations) SENSITIVE = [] include Aws::Structure end |