Class: Aws::BedrockAgentRuntime::Types::PromptTemplate
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::PromptTemplate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains the template for the prompt that’s sent to the model for response generation. For more information, see [Knowledge base prompt templates].
This data type is used in the following API operations:
- RetrieveAndGenerate request][2
-
– in the ‘filter` field
^
[1]: docs.aws.amazon.com/bedrock/latest/userguide/kb-test-config.html#kb-test-config-sysprompt [2]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_RetrieveAndGenerate.html#API_agent-runtime_RetrieveAndGenerate_RequestSyntax
Constant Summary collapse
- SENSITIVE =
[:text_prompt_template]
Instance Attribute Summary collapse
-
#text_prompt_template ⇒ String
The template for the prompt that’s sent to the model for response generation.
Instance Attribute Details
#text_prompt_template ⇒ String
The template for the prompt that’s sent to the model for response generation. You can include prompt placeholders, which become replaced before the prompt is sent to the model to provide instructions and context to the model. In addition, you can include XML tags to delineate meaningful sections of the prompt template.
For more information, see the following resources:
- Knowledge base prompt templates][1
- Use XML tags with Anthropic Claude models][2
[1]: docs.aws.amazon.com/bedrock/latest/userguide/kb-test-config.html#kb-test-config-sysprompt [2]: docs.claude.com/en/docs/build-with-claude/prompt-engineering/use-xml-tags
6818 6819 6820 6821 6822 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 6818 class PromptTemplate < Struct.new( :text_prompt_template) SENSITIVE = [:text_prompt_template] include Aws::Structure end |