Class: Aws::BedrockAgentRuntime::Types::QueryTransformationConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::QueryTransformationConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
To split up the prompt and retrieve multiple sources, set the transformation type to QUERY_DECOMPOSITION.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#type ⇒ String
The type of transformation to apply to the prompt.
Instance Attribute Details
#type ⇒ String
The type of transformation to apply to the prompt.
4397 4398 4399 4400 4401 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 4397 class QueryTransformationConfiguration < Struct.new( :type) SENSITIVE = [] include Aws::Structure end |