Class: Aws::BedrockAgentRuntime::Types::RerankResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::RerankResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If the total number of results is greater than can fit in the response, use this token in the
nextTokenfield when making another request to return the next batch of results. -
#results ⇒ Array<Types::RerankResult>
An array of objects, each of which contains information about the results of reranking.
Instance Attribute Details
#next_token ⇒ String
If the total number of results is greater than can fit in the
response, use this token in the nextToken field when making
another request to return the next batch of results.
8470 8471 8472 8473 8474 8475 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8470 class RerankResponse < Struct.new( :next_token, :results) SENSITIVE = [] include Aws::Structure end |
#results ⇒ Array<Types::RerankResult>
An array of objects, each of which contains information about the results of reranking.
8470 8471 8472 8473 8474 8475 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8470 class RerankResponse < Struct.new( :next_token, :results) SENSITIVE = [] include Aws::Structure end |