Class: Aws::BedrockAgentRuntime::Types::RerankingMetadataSelectiveModeConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::RerankingMetadataSelectiveModeConfiguration
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
RerankingMetadataSelectiveModeConfiguration is a union - when making an API calls you must set exactly one of the members.
Contains configurations for the metadata fields to include or exclude when considering reranking. If you include the ‘fieldsToExclude` field, the reranker ignores all the metadata fields that you specify. If you include the `fieldsToInclude` field, the reranker uses only the metadata fields that you specify and ignores all others. You can include only one of these fields.
Direct Known Subclasses
Defined Under Namespace
Classes: FieldsToExclude, FieldsToInclude, Unknown
Constant Summary collapse
- SENSITIVE =
[:fields_to_exclude, :fields_to_include]
Instance Attribute Summary collapse
-
#fields_to_exclude ⇒ Array<Types::FieldForReranking>
An array of objects, each of which specifies a metadata field to exclude from consideration when reranking.
-
#fields_to_include ⇒ Array<Types::FieldForReranking>
An array of objects, each of which specifies a metadata field to include in consideration when reranking.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#fields_to_exclude ⇒ Array<Types::FieldForReranking>
An array of objects, each of which specifies a metadata field to exclude from consideration when reranking.
8125 8126 8127 8128 8129 8130 8131 8132 8133 8134 8135 8136 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8125 class RerankingMetadataSelectiveModeConfiguration < Struct.new( :fields_to_exclude, :fields_to_include, :unknown) SENSITIVE = [:fields_to_exclude, :fields_to_include] include Aws::Structure include Aws::Structure::Union class FieldsToExclude < RerankingMetadataSelectiveModeConfiguration; end class FieldsToInclude < RerankingMetadataSelectiveModeConfiguration; end class Unknown < RerankingMetadataSelectiveModeConfiguration; end end |
#fields_to_include ⇒ Array<Types::FieldForReranking>
An array of objects, each of which specifies a metadata field to include in consideration when reranking. The remaining metadata fields are ignored.
8125 8126 8127 8128 8129 8130 8131 8132 8133 8134 8135 8136 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8125 class RerankingMetadataSelectiveModeConfiguration < Struct.new( :fields_to_exclude, :fields_to_include, :unknown) SENSITIVE = [:fields_to_exclude, :fields_to_include] include Aws::Structure include Aws::Structure::Union class FieldsToExclude < RerankingMetadataSelectiveModeConfiguration; end class FieldsToInclude < RerankingMetadataSelectiveModeConfiguration; end class Unknown < RerankingMetadataSelectiveModeConfiguration; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
8125 8126 8127 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8125 def unknown @unknown end |