Class: Aws::BedrockAgentRuntime::Types::ResponseStream
- Inherits:
-
Enumerator
- Object
- Enumerator
- Aws::BedrockAgentRuntime::Types::ResponseStream
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
The response from invoking the agent and associated citations and trace information.
EventStream is an Enumerator of Events.
#event_types #=> Array, returns all modeled event types in the stream
Instance Method Summary collapse
Instance Method Details
#event_types ⇒ Object
10321 10322 10323 10324 10325 10326 10327 10328 10329 10330 10331 10332 10333 10334 10335 10336 10337 10338 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10321 def event_types [ :access_denied_exception, :bad_gateway_exception, :chunk, :conflict_exception, :dependency_failed_exception, :files, :internal_server_exception, :model_not_ready_exception, :resource_not_found_exception, :return_control, :service_quota_exceeded_exception, :throttling_exception, :trace, :validation_exception ] end |