Class: Aws::BedrockAgentRuntime::Types::RetrievalResultContent

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains information about a chunk of text from a data source in the knowledge base. If the result is from a structured data source, the cell in the database and the type of the value is also identified.

This data type is used in the following API operations:

  • Retrieve response][1

    – in the ‘content` field

  • RetrieveAndGenerate response][2

    – in the ‘content` field

  • InvokeAgent response][3

    – in the ‘content` field

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_Retrieve.html#API_agent-runtime_Retrieve_ResponseSyntax [2]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_RetrieveAndGenerate.html#API_agent-runtime_RetrieveAndGenerate_ResponseSyntax [3]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_InvokeAgent.html#API_agent-runtime_InvokeAgent_ResponseSyntax

Constant Summary collapse

SENSITIVE =
[:row]

Instance Attribute Summary collapse

Instance Attribute Details

#audioTypes::AudioSegment

Audio segment information when the retrieval result contains audio content.

Returns:



7531
7532
7533
7534
7535
7536
7537
7538
7539
7540
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7531

class RetrievalResultContent < Struct.new(
  :audio,
  :byte_content,
  :row,
  :text,
  :type,
  :video)
  SENSITIVE = [:row]
  include Aws::Structure
end

#byte_contentString

A data URI with base64-encoded content from the data source. The URI is in the following format: returned in the following format: ‘data:image/jpeg;base64,$string`.

Returns:

  • (String)


7531
7532
7533
7534
7535
7536
7537
7538
7539
7540
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7531

class RetrievalResultContent < Struct.new(
  :audio,
  :byte_content,
  :row,
  :text,
  :type,
  :video)
  SENSITIVE = [:row]
  include Aws::Structure
end

#rowArray<Types::RetrievalResultContentColumn>

Specifies information about the rows with the cells to return in retrieval.



7531
7532
7533
7534
7535
7536
7537
7538
7539
7540
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7531

class RetrievalResultContent < Struct.new(
  :audio,
  :byte_content,
  :row,
  :text,
  :type,
  :video)
  SENSITIVE = [:row]
  include Aws::Structure
end

#textString

The cited text from the data source.

Returns:

  • (String)


7531
7532
7533
7534
7535
7536
7537
7538
7539
7540
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7531

class RetrievalResultContent < Struct.new(
  :audio,
  :byte_content,
  :row,
  :text,
  :type,
  :video)
  SENSITIVE = [:row]
  include Aws::Structure
end

#typeString

The type of content in the retrieval result.

Returns:

  • (String)


7531
7532
7533
7534
7535
7536
7537
7538
7539
7540
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7531

class RetrievalResultContent < Struct.new(
  :audio,
  :byte_content,
  :row,
  :text,
  :type,
  :video)
  SENSITIVE = [:row]
  include Aws::Structure
end

#videoTypes::VideoSegment

Video segment information when the retrieval result contains video content.

Returns:



7531
7532
7533
7534
7535
7536
7537
7538
7539
7540
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7531

class RetrievalResultContent < Struct.new(
  :audio,
  :byte_content,
  :row,
  :text,
  :type,
  :video)
  SENSITIVE = [:row]
  include Aws::Structure
end