Class: Aws::BedrockAgentRuntime::Types::RetrievalResultContent
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::RetrievalResultContent
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains information about a chunk of text from a data source in the knowledge base. If the result is from a structured data source, the cell in the database and the type of the value is also identified.
This data type is used in the following API operations:
- Retrieve response][1
-
– in the ‘content` field
- RetrieveAndGenerate response][2
-
– in the ‘content` field
- InvokeAgent response][3
-
– in the ‘content` field
[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_Retrieve.html#API_agent-runtime_Retrieve_ResponseSyntax [2]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_RetrieveAndGenerate.html#API_agent-runtime_RetrieveAndGenerate_ResponseSyntax [3]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_InvokeAgent.html#API_agent-runtime_InvokeAgent_ResponseSyntax
Constant Summary collapse
- SENSITIVE =
[:row]
Instance Attribute Summary collapse
-
#audio ⇒ Types::AudioSegment
Audio segment information when the retrieval result contains audio content.
-
#byte_content ⇒ String
A data URI with base64-encoded content from the data source.
-
#row ⇒ Array<Types::RetrievalResultContentColumn>
Specifies information about the rows with the cells to return in retrieval.
-
#text ⇒ String
The cited text from the data source.
-
#type ⇒ String
The type of content in the retrieval result.
-
#video ⇒ Types::VideoSegment
Video segment information when the retrieval result contains video content.
Instance Attribute Details
#audio ⇒ Types::AudioSegment
Audio segment information when the retrieval result contains audio content.
7531 7532 7533 7534 7535 7536 7537 7538 7539 7540 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7531 class RetrievalResultContent < Struct.new( :audio, :byte_content, :row, :text, :type, :video) SENSITIVE = [:row] include Aws::Structure end |
#byte_content ⇒ String
A data URI with base64-encoded content from the data source. The URI is in the following format: returned in the following format: ‘data:image/jpeg;base64,$string`.
7531 7532 7533 7534 7535 7536 7537 7538 7539 7540 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7531 class RetrievalResultContent < Struct.new( :audio, :byte_content, :row, :text, :type, :video) SENSITIVE = [:row] include Aws::Structure end |
#row ⇒ Array<Types::RetrievalResultContentColumn>
Specifies information about the rows with the cells to return in retrieval.
7531 7532 7533 7534 7535 7536 7537 7538 7539 7540 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7531 class RetrievalResultContent < Struct.new( :audio, :byte_content, :row, :text, :type, :video) SENSITIVE = [:row] include Aws::Structure end |
#text ⇒ String
The cited text from the data source.
7531 7532 7533 7534 7535 7536 7537 7538 7539 7540 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7531 class RetrievalResultContent < Struct.new( :audio, :byte_content, :row, :text, :type, :video) SENSITIVE = [:row] include Aws::Structure end |
#type ⇒ String
The type of content in the retrieval result.
7531 7532 7533 7534 7535 7536 7537 7538 7539 7540 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7531 class RetrievalResultContent < Struct.new( :audio, :byte_content, :row, :text, :type, :video) SENSITIVE = [:row] include Aws::Structure end |
#video ⇒ Types::VideoSegment
Video segment information when the retrieval result contains video content.
7531 7532 7533 7534 7535 7536 7537 7538 7539 7540 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7531 class RetrievalResultContent < Struct.new( :audio, :byte_content, :row, :text, :type, :video) SENSITIVE = [:row] include Aws::Structure end |