Class: Aws::BedrockAgentRuntime::Types::RetrieveAndGenerateConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains details about the resource being queried.

This data type is used in the following API operations:

  • RetrieveAndGenerate request][1

    – in the

    ‘retrieveAndGenerateConfiguration` field

^

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_RetrieveAndGenerate.html#API_agent-runtime_RetrieveAndGenerate_RequestSyntax

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#external_sources_configurationTypes::ExternalSourcesRetrieveAndGenerateConfiguration

The configuration for the external source wrapper object in the ‘retrieveAndGenerate` function.



7784
7785
7786
7787
7788
7789
7790
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7784

class RetrieveAndGenerateConfiguration < Struct.new(
  :external_sources_configuration,
  :knowledge_base_configuration,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#knowledge_base_configurationTypes::KnowledgeBaseRetrieveAndGenerateConfiguration

Contains details about the knowledge base for retrieving information and generating responses.



7784
7785
7786
7787
7788
7789
7790
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7784

class RetrieveAndGenerateConfiguration < Struct.new(
  :external_sources_configuration,
  :knowledge_base_configuration,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of resource that contains your data for retrieving information and generating responses.

<note markdown=“1”> If you choose to use ‘EXTERNAL_SOURCES`, then currently only Anthropic Claude 3 Sonnet models for knowledge bases are supported.

</note>

Returns:

  • (String)


7784
7785
7786
7787
7788
7789
7790
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7784

class RetrieveAndGenerateConfiguration < Struct.new(
  :external_sources_configuration,
  :knowledge_base_configuration,
  :type)
  SENSITIVE = []
  include Aws::Structure
end