Class: Aws::BedrockAgentRuntime::Types::RetrieveAndGenerateConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains details about the resource being queried.

This data type is used in the following API operations:

  • RetrieveAndGenerate request][1

    – in the

    retrieveAndGenerateConfiguration field

^

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_RetrieveAndGenerate.html#API_agent-runtime_RetrieveAndGenerate_RequestSyntax

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#external_sources_configurationTypes::ExternalSourcesRetrieveAndGenerateConfiguration

The configuration for the external source wrapper object in the retrieveAndGenerate function.



5193
5194
5195
5196
5197
5198
5199
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5193

class RetrieveAndGenerateConfiguration < Struct.new(
  :external_sources_configuration,
  :knowledge_base_configuration,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#knowledge_base_configurationTypes::KnowledgeBaseRetrieveAndGenerateConfiguration

Contains details about the knowledge base for retrieving information and generating responses.



5193
5194
5195
5196
5197
5198
5199
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5193

class RetrieveAndGenerateConfiguration < Struct.new(
  :external_sources_configuration,
  :knowledge_base_configuration,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of resource that contains your data for retrieving information and generating responses.

If you choose ot use EXTERNAL_SOURCES, then currently only Claude 3 Sonnet models for knowledge bases are supported.

Returns:

  • (String)


5193
5194
5195
5196
5197
5198
5199
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5193

class RetrieveAndGenerateConfiguration < Struct.new(
  :external_sources_configuration,
  :knowledge_base_configuration,
  :type)
  SENSITIVE = []
  include Aws::Structure
end