Class: Aws::BedrockAgentRuntime::Types::RetrieveAndGenerateOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains the response generated from querying the knowledge base.

This data type is used in the following API operations:

  • RetrieveAndGenerate response][1

    – in the ‘output` field

^

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_RetrieveAndGenerate.html#API_agent-runtime_RetrieveAndGenerate_ResponseSyntax

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#textString

The response generated from querying the knowledge base.

Returns:

  • (String)


7834
7835
7836
7837
7838
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 7834

class RetrieveAndGenerateOutput < Struct.new(
  :text)
  SENSITIVE = []
  include Aws::Structure
end