Class: Aws::BedrockAgentRuntime::Types::RetrieveAndGenerateOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::RetrieveAndGenerateOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains the response generated from querying the knowledge base.
This data type is used in the following API operations:
- RetrieveAndGenerate response][1
-
– in the
outputfield
^
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#text ⇒ String
The response generated from querying the knowledge base.
Instance Attribute Details
#text ⇒ String
The response generated from querying the knowledge base.
5243 5244 5245 5246 5247 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5243 class RetrieveAndGenerateOutput < Struct.new( :text) SENSITIVE = [] include Aws::Structure end |