Class: Aws::BedrockAgentRuntime::Types::RetrieveAndGenerateResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::RetrieveAndGenerateResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:output]
Instance Attribute Summary collapse
-
#citations ⇒ Array<Types::Citation>
A list of segments of the generated response that are based on sources in the knowledge base, alongside information about the sources.
-
#guardrail_action ⇒ String
Specifies if there is a guardrail intervention in the response.
-
#output ⇒ Types::RetrieveAndGenerateOutput
Contains the response generated from querying the knowledge base.
-
#session_id ⇒ String
The unique identifier of the session.
Instance Attribute Details
#citations ⇒ Array<Types::Citation>
A list of segments of the generated response that are based on sources in the knowledge base, alongside information about the sources.
9341 9342 9343 9344 9345 9346 9347 9348 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9341 class RetrieveAndGenerateResponse < Struct.new( :citations, :guardrail_action, :output, :session_id) SENSITIVE = [:output] include Aws::Structure end |
#guardrail_action ⇒ String
Specifies if there is a guardrail intervention in the response.
9341 9342 9343 9344 9345 9346 9347 9348 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9341 class RetrieveAndGenerateResponse < Struct.new( :citations, :guardrail_action, :output, :session_id) SENSITIVE = [:output] include Aws::Structure end |
#output ⇒ Types::RetrieveAndGenerateOutput
Contains the response generated from querying the knowledge base.
9341 9342 9343 9344 9345 9346 9347 9348 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9341 class RetrieveAndGenerateResponse < Struct.new( :citations, :guardrail_action, :output, :session_id) SENSITIVE = [:output] include Aws::Structure end |
#session_id ⇒ String
The unique identifier of the session. When you first make a
RetrieveAndGenerate request, Amazon Bedrock automatically
generates this value. You must reuse this value for all subsequent
requests in the same conversational session. This value allows
Amazon Bedrock to maintain context and knowledge from previous
interactions. You can't explicitly set the sessionId yourself.
9341 9342 9343 9344 9345 9346 9347 9348 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9341 class RetrieveAndGenerateResponse < Struct.new( :citations, :guardrail_action, :output, :session_id) SENSITIVE = [:output] include Aws::Structure end |