Class: Aws::BedrockAgentRuntime::Types::RetrieveAndGenerateResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:output]

Instance Attribute Summary collapse

Instance Attribute Details

#citationsArray<Types::Citation>

A list of segments of the generated response that are based on sources in the knowledge base, alongside information about the sources.

Returns:



8892
8893
8894
8895
8896
8897
8898
8899
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8892

class RetrieveAndGenerateResponse < Struct.new(
  :citations,
  :guardrail_action,
  :output,
  :session_id)
  SENSITIVE = [:output]
  include Aws::Structure
end

#guardrail_actionString

Specifies if there is a guardrail intervention in the response.

Returns:

  • (String)


8892
8893
8894
8895
8896
8897
8898
8899
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8892

class RetrieveAndGenerateResponse < Struct.new(
  :citations,
  :guardrail_action,
  :output,
  :session_id)
  SENSITIVE = [:output]
  include Aws::Structure
end

#outputTypes::RetrieveAndGenerateOutput

Contains the response generated from querying the knowledge base.



8892
8893
8894
8895
8896
8897
8898
8899
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8892

class RetrieveAndGenerateResponse < Struct.new(
  :citations,
  :guardrail_action,
  :output,
  :session_id)
  SENSITIVE = [:output]
  include Aws::Structure
end

#session_idString

The unique identifier of the session. When you first make a ‘RetrieveAndGenerate` request, Amazon Bedrock automatically generates this value. You must reuse this value for all subsequent requests in the same conversational session. This value allows Amazon Bedrock to maintain context and knowledge from previous interactions. You can’t explicitly set the ‘sessionId` yourself.

Returns:

  • (String)


8892
8893
8894
8895
8896
8897
8898
8899
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8892

class RetrieveAndGenerateResponse < Struct.new(
  :citations,
  :guardrail_action,
  :output,
  :session_id)
  SENSITIVE = [:output]
  include Aws::Structure
end