Class: Aws::BedrockAgentRuntime::Types::RetrieveAndGenerateSessionConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains configuration about the session with the knowledge base.

This data type is used in the following API operations:

  • RetrieveAndGenerate request][1

    – in the sessionConfiguration

    field

^

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_RetrieveAndGenerate.html#API_agent-runtime_RetrieveAndGenerate_RequestSyntax

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#kms_key_arnString

The ARN of the KMS key encrypting the session.

Returns:

  • (String)


5354
5355
5356
5357
5358
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5354

class RetrieveAndGenerateSessionConfiguration < Struct.new(
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end