Class: Aws::BedrockAgentRuntime::Types::RetrieveAndGenerateSessionConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::RetrieveAndGenerateSessionConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains configuration about the session with the knowledge base.
This data type is used in the following API operations:
- RetrieveAndGenerate request][1
-
– in the
sessionConfiguration
field
^
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#kms_key_arn ⇒ String
The ARN of the KMS key encrypting the session.
Instance Attribute Details
#kms_key_arn ⇒ String
The ARN of the KMS key encrypting the session.
5354 5355 5356 5357 5358 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5354 class RetrieveAndGenerateSessionConfiguration < Struct.new( :kms_key_arn) SENSITIVE = [] include Aws::Structure end |