Class: Aws::BedrockAgentRuntime::Types::RetrieveRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::RetrieveRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:retrieval_query, :user_context]
Instance Attribute Summary collapse
-
#guardrail_configuration ⇒ Types::GuardrailConfiguration
Guardrail settings.
-
#knowledge_base_id ⇒ String
The unique identifier of the knowledge base to query.
-
#next_token ⇒ String
If there are more results than can fit in the response, the response returns a
nextToken. -
#retrieval_configuration ⇒ Types::KnowledgeBaseRetrievalConfiguration
Contains configurations for the knowledge base query and retrieval process.
-
#retrieval_query ⇒ Types::KnowledgeBaseQuery
Contains the query to send the knowledge base.
-
#user_context ⇒ Types::UserContext
Contains information about the user making the request.
Instance Attribute Details
#guardrail_configuration ⇒ Types::GuardrailConfiguration
Guardrail settings.
9195 9196 9197 9198 9199 9200 9201 9202 9203 9204 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9195 class RetrieveRequest < Struct.new( :guardrail_configuration, :knowledge_base_id, :next_token, :retrieval_configuration, :retrieval_query, :user_context) SENSITIVE = [:retrieval_query, :user_context] include Aws::Structure end |
#knowledge_base_id ⇒ String
The unique identifier of the knowledge base to query.
9195 9196 9197 9198 9199 9200 9201 9202 9203 9204 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9195 class RetrieveRequest < Struct.new( :guardrail_configuration, :knowledge_base_id, :next_token, :retrieval_configuration, :retrieval_query, :user_context) SENSITIVE = [:retrieval_query, :user_context] include Aws::Structure end |
#next_token ⇒ String
If there are more results than can fit in the response, the response
returns a nextToken. Use this token in the nextToken field of
another request to retrieve the next batch of results.
9195 9196 9197 9198 9199 9200 9201 9202 9203 9204 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9195 class RetrieveRequest < Struct.new( :guardrail_configuration, :knowledge_base_id, :next_token, :retrieval_configuration, :retrieval_query, :user_context) SENSITIVE = [:retrieval_query, :user_context] include Aws::Structure end |
#retrieval_configuration ⇒ Types::KnowledgeBaseRetrievalConfiguration
Contains configurations for the knowledge base query and retrieval process. For more information, see Query configurations.
9195 9196 9197 9198 9199 9200 9201 9202 9203 9204 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9195 class RetrieveRequest < Struct.new( :guardrail_configuration, :knowledge_base_id, :next_token, :retrieval_configuration, :retrieval_query, :user_context) SENSITIVE = [:retrieval_query, :user_context] include Aws::Structure end |
#retrieval_query ⇒ Types::KnowledgeBaseQuery
Contains the query to send the knowledge base.
9195 9196 9197 9198 9199 9200 9201 9202 9203 9204 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9195 class RetrieveRequest < Struct.new( :guardrail_configuration, :knowledge_base_id, :next_token, :retrieval_configuration, :retrieval_query, :user_context) SENSITIVE = [:retrieval_query, :user_context] include Aws::Structure end |
#user_context ⇒ Types::UserContext
Contains information about the user making the request. This is used for access control filtering to ensure that retrieval results only include documents the user is authorized to access.
9195 9196 9197 9198 9199 9200 9201 9202 9203 9204 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9195 class RetrieveRequest < Struct.new( :guardrail_configuration, :knowledge_base_id, :next_token, :retrieval_configuration, :retrieval_query, :user_context) SENSITIVE = [:retrieval_query, :user_context] include Aws::Structure end |