Class: Aws::BedrockAgentRuntime::Types::RetrieveRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:retrieval_query]

Instance Attribute Summary collapse

Instance Attribute Details

#guardrail_configurationTypes::GuardrailConfiguration

Guardrail settings.



8034
8035
8036
8037
8038
8039
8040
8041
8042
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8034

class RetrieveRequest < Struct.new(
  :guardrail_configuration,
  :knowledge_base_id,
  :next_token,
  :retrieval_configuration,
  :retrieval_query)
  SENSITIVE = [:retrieval_query]
  include Aws::Structure
end

#knowledge_base_idString

The unique identifier of the knowledge base to query.

Returns:

  • (String)


8034
8035
8036
8037
8038
8039
8040
8041
8042
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8034

class RetrieveRequest < Struct.new(
  :guardrail_configuration,
  :knowledge_base_id,
  :next_token,
  :retrieval_configuration,
  :retrieval_query)
  SENSITIVE = [:retrieval_query]
  include Aws::Structure
end

#next_tokenString

If there are more results than can fit in the response, the response returns a ‘nextToken`. Use this token in the `nextToken` field of another request to retrieve the next batch of results.

Returns:

  • (String)


8034
8035
8036
8037
8038
8039
8040
8041
8042
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8034

class RetrieveRequest < Struct.new(
  :guardrail_configuration,
  :knowledge_base_id,
  :next_token,
  :retrieval_configuration,
  :retrieval_query)
  SENSITIVE = [:retrieval_query]
  include Aws::Structure
end

#retrieval_configurationTypes::KnowledgeBaseRetrievalConfiguration

Contains configurations for the knowledge base query and retrieval process. For more information, see [Query configurations].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/kb-test-config.html



8034
8035
8036
8037
8038
8039
8040
8041
8042
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8034

class RetrieveRequest < Struct.new(
  :guardrail_configuration,
  :knowledge_base_id,
  :next_token,
  :retrieval_configuration,
  :retrieval_query)
  SENSITIVE = [:retrieval_query]
  include Aws::Structure
end

#retrieval_queryTypes::KnowledgeBaseQuery

Contains the query to send the knowledge base.



8034
8035
8036
8037
8038
8039
8040
8041
8042
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8034

class RetrieveRequest < Struct.new(
  :guardrail_configuration,
  :knowledge_base_id,
  :next_token,
  :retrieval_configuration,
  :retrieval_query)
  SENSITIVE = [:retrieval_query]
  include Aws::Structure
end