Class: Aws::BedrockAgentRuntime::Types::RetrieveRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::RetrieveRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:retrieval_query]
Instance Attribute Summary collapse
-
#guardrail_configuration ⇒ Types::GuardrailConfiguration
Guardrail settings.
-
#knowledge_base_id ⇒ String
The unique identifier of the knowledge base to query.
-
#next_token ⇒ String
If there are more results than can fit in the response, the response returns a
nextToken. -
#retrieval_configuration ⇒ Types::KnowledgeBaseRetrievalConfiguration
Contains configurations for the knowledge base query and retrieval process.
-
#retrieval_query ⇒ Types::KnowledgeBaseQuery
Contains the query to send the knowledge base.
Instance Attribute Details
#guardrail_configuration ⇒ Types::GuardrailConfiguration
Guardrail settings.
5443 5444 5445 5446 5447 5448 5449 5450 5451 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5443 class RetrieveRequest < Struct.new( :guardrail_configuration, :knowledge_base_id, :next_token, :retrieval_configuration, :retrieval_query) SENSITIVE = [:retrieval_query] include Aws::Structure end |
#knowledge_base_id ⇒ String
The unique identifier of the knowledge base to query.
5443 5444 5445 5446 5447 5448 5449 5450 5451 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5443 class RetrieveRequest < Struct.new( :guardrail_configuration, :knowledge_base_id, :next_token, :retrieval_configuration, :retrieval_query) SENSITIVE = [:retrieval_query] include Aws::Structure end |
#next_token ⇒ String
If there are more results than can fit in the response, the response returns a nextToken. Use this token in the nextToken field of another request to retrieve the next batch of results.
5443 5444 5445 5446 5447 5448 5449 5450 5451 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5443 class RetrieveRequest < Struct.new( :guardrail_configuration, :knowledge_base_id, :next_token, :retrieval_configuration, :retrieval_query) SENSITIVE = [:retrieval_query] include Aws::Structure end |
#retrieval_configuration ⇒ Types::KnowledgeBaseRetrievalConfiguration
Contains configurations for the knowledge base query and retrieval process. For more information, see [Query configurations][1].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/kb-test-config.html
5443 5444 5445 5446 5447 5448 5449 5450 5451 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5443 class RetrieveRequest < Struct.new( :guardrail_configuration, :knowledge_base_id, :next_token, :retrieval_configuration, :retrieval_query) SENSITIVE = [:retrieval_query] include Aws::Structure end |
#retrieval_query ⇒ Types::KnowledgeBaseQuery
Contains the query to send the knowledge base.
5443 5444 5445 5446 5447 5448 5449 5450 5451 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5443 class RetrieveRequest < Struct.new( :guardrail_configuration, :knowledge_base_id, :next_token, :retrieval_configuration, :retrieval_query) SENSITIVE = [:retrieval_query] include Aws::Structure end |