Class: Aws::BedrockAgentRuntime::Types::RetrievedReference
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::RetrievedReference
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains metadata about a source cited for the generated response.
This data type is used in the following API operations:
- RetrieveAndGenerate response][1
-
– in the ‘retrievedReferences`
field
- InvokeAgent response][2
-
– in the ‘retrievedReferences` field
[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_RetrieveAndGenerate.html#API_agent-runtime_RetrieveAndGenerate_ResponseSyntax [2]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_InvokeAgent.html#API_agent-runtime_InvokeAgent_ResponseSyntax
Constant Summary collapse
- SENSITIVE =
[:content, :location, :metadata]
Instance Attribute Summary collapse
-
#content ⇒ Types::RetrievalResultContent
Contains the cited text from the data source.
-
#location ⇒ Types::RetrievalResultLocation
Contains information about the location of the data source.
-
#metadata ⇒ Hash<String,Hash,Array,String,Numeric,Boolean>
Contains metadata attributes and their values for the file in the data source.
Instance Attribute Details
#content ⇒ Types::RetrievalResultContent
Contains the cited text from the data source.
8101 8102 8103 8104 8105 8106 8107 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8101 class RetrievedReference < Struct.new( :content, :location, :metadata) SENSITIVE = [:content, :location, :metadata] include Aws::Structure end |
#location ⇒ Types::RetrievalResultLocation
Contains information about the location of the data source.
8101 8102 8103 8104 8105 8106 8107 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8101 class RetrievedReference < Struct.new( :content, :location, :metadata) SENSITIVE = [:content, :location, :metadata] include Aws::Structure end |
#metadata ⇒ Hash<String,Hash,Array,String,Numeric,Boolean>
Contains metadata attributes and their values for the file in the data source. For more information, see [Metadata and filtering].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/knowledge-base-ds.html#kb-ds-metadata
8101 8102 8103 8104 8105 8106 8107 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8101 class RetrievedReference < Struct.new( :content, :location, :metadata) SENSITIVE = [:content, :location, :metadata] include Aws::Structure end |