Class: Aws::BedrockAgentRuntime::Types::RetrievedReference

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains metadata about a source cited for the generated response.

This data type is used in the following API operations:

  • RetrieveAndGenerate response][1

    – in the retrievedReferences

    field

  • InvokeAgent response][2

    – in the retrievedReferences field

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_RetrieveAndGenerate.html#API_agent-runtime_RetrieveAndGenerate_ResponseSyntax [2]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_InvokeAgent.html#API_agent-runtime_InvokeAgent_ResponseSyntax

Constant Summary collapse

SENSITIVE =
[:content, :location, :metadata]

Instance Attribute Summary collapse

Instance Attribute Details

#contentTypes::RetrievalResultContent

Contains the cited text from the data source.



5510
5511
5512
5513
5514
5515
5516
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5510

class RetrievedReference < Struct.new(
  :content,
  :location,
  :metadata)
  SENSITIVE = [:content, :location, :metadata]
  include Aws::Structure
end

#locationTypes::RetrievalResultLocation

Contains information about the location of the data source.



5510
5511
5512
5513
5514
5515
5516
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5510

class RetrievedReference < Struct.new(
  :content,
  :location,
  :metadata)
  SENSITIVE = [:content, :location, :metadata]
  include Aws::Structure
end

#metadataHash<String,Hash,Array,String,Numeric,Boolean>

Contains metadata attributes and their values for the file in the data source. For more information, see [Metadata and filtering][1].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/knowledge-base-ds.html#kb-ds-metadata

Returns:

  • (Hash<String,Hash,Array,String,Numeric,Boolean>)


5510
5511
5512
5513
5514
5515
5516
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5510

class RetrievedReference < Struct.new(
  :content,
  :location,
  :metadata)
  SENSITIVE = [:content, :location, :metadata]
  include Aws::Structure
end