Class: Aws::BedrockAgentRuntime::Types::RetrieverConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Note:

RetrieverConfiguration is a union - when making an API calls you must set exactly one of the members.

Configuration for a retriever, specified as a union of retriever types.

Direct Known Subclasses

KnowledgeBase, Unknown

Defined Under Namespace

Classes: KnowledgeBase, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#knowledge_baseTypes::KnowledgeBaseRetrieverConfiguration

Configuration for a knowledge base retriever.



9111
9112
9113
9114
9115
9116
9117
9118
9119
9120
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9111

class RetrieverConfiguration < Struct.new(
  :knowledge_base,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class KnowledgeBase < RetrieverConfiguration; end
  class Unknown < RetrieverConfiguration; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



9111
9112
9113
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9111

def unknown
  @unknown
end