Class: Aws::BedrockAgentRuntime::Types::RetrieverConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::RetrieverConfiguration
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Note:
RetrieverConfiguration is a union - when making an API calls you must set exactly one of the members.
Configuration for a retriever, specified as a union of retriever types.
Direct Known Subclasses
Defined Under Namespace
Classes: KnowledgeBase, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#knowledge_base ⇒ Types::KnowledgeBaseRetrieverConfiguration
Configuration for a knowledge base retriever.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#knowledge_base ⇒ Types::KnowledgeBaseRetrieverConfiguration
Configuration for a knowledge base retriever.
9111 9112 9113 9114 9115 9116 9117 9118 9119 9120 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9111 class RetrieverConfiguration < Struct.new( :knowledge_base, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class KnowledgeBase < RetrieverConfiguration; end class Unknown < RetrieverConfiguration; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
9111 9112 9113 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9111 def unknown @unknown end |