Class: Aws::BedrockAgentRuntime::Types::SessionState
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::SessionState
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains parameters that specify various attributes that persist across a session or prompt. You can define session state attributes as key-value pairs when writing a [Lambda function] for an action group or pass them when making an [InvokeAgent] request. Use session state attributes to control and provide conversational context for your agent and to help customize your agent’s behavior. For more information, see [Control session context].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/agents-lambda.html [2]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_InvokeAgent.html [3]: docs.aws.amazon.com/bedrock/latest/userguide/agents-session-state.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#conversation_history ⇒ Types::ConversationHistory
The state’s conversation history.
-
#files ⇒ Array<Types::InputFile>
Contains information about the files used by code interpreter.
-
#invocation_id ⇒ String
The identifier of the invocation of an action.
-
#knowledge_base_configurations ⇒ Array<Types::KnowledgeBaseConfiguration>
An array of configurations, each of which applies to a knowledge base attached to the agent.
-
#prompt_session_attributes ⇒ Hash<String,String>
Contains attributes that persist across a prompt and the values of those attributes.
-
#return_control_invocation_results ⇒ Array<Types::InvocationResultMember>
Contains information about the results from the action group invocation.
-
#session_attributes ⇒ Hash<String,String>
Contains attributes that persist across a session and the values of those attributes.
Instance Attribute Details
#conversation_history ⇒ Types::ConversationHistory
The state’s conversation history.
8407 8408 8409 8410 8411 8412 8413 8414 8415 8416 8417 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8407 class SessionState < Struct.new( :conversation_history, :files, :invocation_id, :knowledge_base_configurations, :prompt_session_attributes, :return_control_invocation_results, :session_attributes) SENSITIVE = [] include Aws::Structure end |
#files ⇒ Array<Types::InputFile>
Contains information about the files used by code interpreter.
8407 8408 8409 8410 8411 8412 8413 8414 8415 8416 8417 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8407 class SessionState < Struct.new( :conversation_history, :files, :invocation_id, :knowledge_base_configurations, :prompt_session_attributes, :return_control_invocation_results, :session_attributes) SENSITIVE = [] include Aws::Structure end |
#invocation_id ⇒ String
The identifier of the invocation of an action. This value must match the ‘invocationId` returned in the `InvokeAgent` response for the action whose results are provided in the `returnControlInvocationResults` field. For more information, see
- Return control to the agent developer][1
-
and [Control session
[1]: docs.aws.amazon.com/bedrock/latest/userguide/agents-returncontrol.html [2]: docs.aws.amazon.com/bedrock/latest/userguide/agents-session-state.html
8407 8408 8409 8410 8411 8412 8413 8414 8415 8416 8417 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8407 class SessionState < Struct.new( :conversation_history, :files, :invocation_id, :knowledge_base_configurations, :prompt_session_attributes, :return_control_invocation_results, :session_attributes) SENSITIVE = [] include Aws::Structure end |
#knowledge_base_configurations ⇒ Array<Types::KnowledgeBaseConfiguration>
An array of configurations, each of which applies to a knowledge base attached to the agent.
8407 8408 8409 8410 8411 8412 8413 8414 8415 8416 8417 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8407 class SessionState < Struct.new( :conversation_history, :files, :invocation_id, :knowledge_base_configurations, :prompt_session_attributes, :return_control_invocation_results, :session_attributes) SENSITIVE = [] include Aws::Structure end |
#prompt_session_attributes ⇒ Hash<String,String>
Contains attributes that persist across a prompt and the values of those attributes.
-
In orchestration prompt template, these attributes replace the $prompt_session_attributes$ placeholder variable. For more information, see [Prompt template placeholder variables].
-
In [multi-agent collaboration], the ‘promptSessionAttributes` will only be used by supervisor agent when $prompt_session_attributes$ is present in prompt template.
[1]: docs.aws.amazon.com/bedrock/latest/userguide/prompt-placeholders.html [2]: docs.aws.amazon.com/bedrock/latest/userguide/agents-multi-agent-collaboration.html
8407 8408 8409 8410 8411 8412 8413 8414 8415 8416 8417 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8407 class SessionState < Struct.new( :conversation_history, :files, :invocation_id, :knowledge_base_configurations, :prompt_session_attributes, :return_control_invocation_results, :session_attributes) SENSITIVE = [] include Aws::Structure end |
#return_control_invocation_results ⇒ Array<Types::InvocationResultMember>
Contains information about the results from the action group invocation. For more information, see [Return control to the agent developer] and [Control session context].
<note markdown=“1”> If you include this field, the ‘inputText` field will be ignored.
</note>
[1]: docs.aws.amazon.com/bedrock/latest/userguide/agents-returncontrol.html [2]: docs.aws.amazon.com/bedrock/latest/userguide/agents-session-state.html
8407 8408 8409 8410 8411 8412 8413 8414 8415 8416 8417 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8407 class SessionState < Struct.new( :conversation_history, :files, :invocation_id, :knowledge_base_configurations, :prompt_session_attributes, :return_control_invocation_results, :session_attributes) SENSITIVE = [] include Aws::Structure end |
#session_attributes ⇒ Hash<String,String>
Contains attributes that persist across a session and the values of those attributes. If ‘sessionAttributes` are passed to a supervisor agent in [multi-agent collaboration], it will be forwarded to all agent collaborators.
[1]: docs.aws.amazon.com/bedrock/latest/userguide/agents-multi-agent-collaboration.html
8407 8408 8409 8410 8411 8412 8413 8414 8415 8416 8417 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8407 class SessionState < Struct.new( :conversation_history, :files, :invocation_id, :knowledge_base_configurations, :prompt_session_attributes, :return_control_invocation_results, :session_attributes) SENSITIVE = [] include Aws::Structure end |