Class: Aws::BedrockAgentRuntime::Types::SessionState
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::SessionState
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains parameters that specify various attributes that persist across a session or prompt. You can define session state attributes as key-value pairs when writing a [Lambda function][1] for an action group or pass them when making an [InvokeAgent][2] request. Use session state attributes to control and provide conversational context for your agent and to help customize your agent’s behavior. For more information, see [Control session context][3].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/agents-lambda.html [2]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_InvokeAgent.html [3]: docs.aws.amazon.com/bedrock/latest/userguide/agents-session-state.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#conversation_history ⇒ Types::ConversationHistory
The state’s conversation history.
-
#files ⇒ Array<Types::InputFile>
Contains information about the files used by code interpreter.
-
#invocation_id ⇒ String
The identifier of the invocation of an action.
-
#knowledge_base_configurations ⇒ Array<Types::KnowledgeBaseConfiguration>
An array of configurations, each of which applies to a knowledge base attached to the agent.
-
#prompt_session_attributes ⇒ Hash<String,String>
Contains attributes that persist across a prompt and the values of those attributes.
-
#return_control_invocation_results ⇒ Array<Types::InvocationResultMember>
Contains information about the results from the action group invocation.
-
#session_attributes ⇒ Hash<String,String>
Contains attributes that persist across a session and the values of those attributes.
Instance Attribute Details
#conversation_history ⇒ Types::ConversationHistory
The state’s conversation history.
5770 5771 5772 5773 5774 5775 5776 5777 5778 5779 5780 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5770 class SessionState < Struct.new( :conversation_history, :files, :invocation_id, :knowledge_base_configurations, :prompt_session_attributes, :return_control_invocation_results, :session_attributes) SENSITIVE = [] include Aws::Structure end |
#files ⇒ Array<Types::InputFile>
Contains information about the files used by code interpreter.
5770 5771 5772 5773 5774 5775 5776 5777 5778 5779 5780 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5770 class SessionState < Struct.new( :conversation_history, :files, :invocation_id, :knowledge_base_configurations, :prompt_session_attributes, :return_control_invocation_results, :session_attributes) SENSITIVE = [] include Aws::Structure end |
#invocation_id ⇒ String
The identifier of the invocation of an action. This value must match the invocationId returned in the InvokeAgent response for the action whose results are provided in the returnControlInvocationResults field. For more information, see
- Return control to the agent developer][1
-
and [Control session
context][2].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/agents-returncontrol.html [2]: docs.aws.amazon.com/bedrock/latest/userguide/agents-session-state.html
5770 5771 5772 5773 5774 5775 5776 5777 5778 5779 5780 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5770 class SessionState < Struct.new( :conversation_history, :files, :invocation_id, :knowledge_base_configurations, :prompt_session_attributes, :return_control_invocation_results, :session_attributes) SENSITIVE = [] include Aws::Structure end |
#knowledge_base_configurations ⇒ Array<Types::KnowledgeBaseConfiguration>
An array of configurations, each of which applies to a knowledge base attached to the agent.
5770 5771 5772 5773 5774 5775 5776 5777 5778 5779 5780 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5770 class SessionState < Struct.new( :conversation_history, :files, :invocation_id, :knowledge_base_configurations, :prompt_session_attributes, :return_control_invocation_results, :session_attributes) SENSITIVE = [] include Aws::Structure end |
#prompt_session_attributes ⇒ Hash<String,String>
Contains attributes that persist across a prompt and the values of those attributes. These attributes replace the $prompt_session_attributes$ placeholder variable in the orchestration prompt template. For more information, see [Prompt template placeholder variables][1].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/prompt-placeholders.html
5770 5771 5772 5773 5774 5775 5776 5777 5778 5779 5780 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5770 class SessionState < Struct.new( :conversation_history, :files, :invocation_id, :knowledge_base_configurations, :prompt_session_attributes, :return_control_invocation_results, :session_attributes) SENSITIVE = [] include Aws::Structure end |
#return_control_invocation_results ⇒ Array<Types::InvocationResultMember>
Contains information about the results from the action group invocation. For more information, see [Return control to the agent developer][1] and [Control session context][2].
<note markdown=“1”> If you include this field, the inputText field will be ignored.
</note>
[1]: docs.aws.amazon.com/bedrock/latest/userguide/agents-returncontrol.html [2]: docs.aws.amazon.com/bedrock/latest/userguide/agents-session-state.html
5770 5771 5772 5773 5774 5775 5776 5777 5778 5779 5780 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5770 class SessionState < Struct.new( :conversation_history, :files, :invocation_id, :knowledge_base_configurations, :prompt_session_attributes, :return_control_invocation_results, :session_attributes) SENSITIVE = [] include Aws::Structure end |
#session_attributes ⇒ Hash<String,String>
Contains attributes that persist across a session and the values of those attributes.
5770 5771 5772 5773 5774 5775 5776 5777 5778 5779 5780 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5770 class SessionState < Struct.new( :conversation_history, :files, :invocation_id, :knowledge_base_configurations, :prompt_session_attributes, :return_control_invocation_results, :session_attributes) SENSITIVE = [] include Aws::Structure end |