Class: Aws::BedrockAgentRuntime::Types::SessionSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains details about a session. For more information about sessions, see [Store and retrieve conversation history and context with Amazon Bedrock sessions].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/sessions.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp for when the session was created.

Returns:

  • (Time)


9462
9463
9464
9465
9466
9467
9468
9469
9470
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9462

class SessionSummary < Struct.new(
  :created_at,
  :last_updated_at,
  :session_arn,
  :session_id,
  :session_status)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_atTime

The timestamp for when the session was last modified.

Returns:

  • (Time)


9462
9463
9464
9465
9466
9467
9468
9469
9470
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9462

class SessionSummary < Struct.new(
  :created_at,
  :last_updated_at,
  :session_arn,
  :session_id,
  :session_status)
  SENSITIVE = []
  include Aws::Structure
end

#session_arnString

The Amazon Resource Name (ARN) of the session.

Returns:

  • (String)


9462
9463
9464
9465
9466
9467
9468
9469
9470
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9462

class SessionSummary < Struct.new(
  :created_at,
  :last_updated_at,
  :session_arn,
  :session_id,
  :session_status)
  SENSITIVE = []
  include Aws::Structure
end

#session_idString

The unique identifier for the session.

Returns:

  • (String)


9462
9463
9464
9465
9466
9467
9468
9469
9470
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9462

class SessionSummary < Struct.new(
  :created_at,
  :last_updated_at,
  :session_arn,
  :session_id,
  :session_status)
  SENSITIVE = []
  include Aws::Structure
end

#session_statusString

The current status of the session.

Returns:

  • (String)


9462
9463
9464
9465
9466
9467
9468
9469
9470
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9462

class SessionSummary < Struct.new(
  :created_at,
  :last_updated_at,
  :session_arn,
  :session_id,
  :session_status)
  SENSITIVE = []
  include Aws::Structure
end