Class: Aws::BedrockAgentRuntime::Types::SessionSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::SessionSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains details about a session. For more information about sessions, see [Store and retrieve conversation history and context with Amazon Bedrock sessions].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/sessions.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp for when the session was created.
-
#last_updated_at ⇒ Time
The timestamp for when the session was last modified.
-
#session_arn ⇒ String
The Amazon Resource Name (ARN) of the session.
-
#session_id ⇒ String
The unique identifier for the session.
-
#session_status ⇒ String
The current status of the session.
Instance Attribute Details
#created_at ⇒ Time
The timestamp for when the session was created.
8449 8450 8451 8452 8453 8454 8455 8456 8457 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8449 class SessionSummary < Struct.new( :created_at, :last_updated_at, :session_arn, :session_id, :session_status) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp for when the session was last modified.
8449 8450 8451 8452 8453 8454 8455 8456 8457 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8449 class SessionSummary < Struct.new( :created_at, :last_updated_at, :session_arn, :session_id, :session_status) SENSITIVE = [] include Aws::Structure end |
#session_arn ⇒ String
The Amazon Resource Name (ARN) of the session.
8449 8450 8451 8452 8453 8454 8455 8456 8457 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8449 class SessionSummary < Struct.new( :created_at, :last_updated_at, :session_arn, :session_id, :session_status) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
The unique identifier for the session.
8449 8450 8451 8452 8453 8454 8455 8456 8457 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8449 class SessionSummary < Struct.new( :created_at, :last_updated_at, :session_arn, :session_id, :session_status) SENSITIVE = [] include Aws::Structure end |
#session_status ⇒ String
The current status of the session.
8449 8450 8451 8452 8453 8454 8455 8456 8457 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8449 class SessionSummary < Struct.new( :created_at, :last_updated_at, :session_arn, :session_id, :session_status) SENSITIVE = [] include Aws::Structure end |