Class: Aws::BedrockAgentRuntime::Types::Span
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::Span
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains information about where the text with a citation begins and ends in the generated output.
This data type is used in the following API operations:
- RetrieveAndGenerate response][1
-
– in the ‘span` field
- InvokeAgent response][2
-
– in the ‘span` field
[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_RetrieveAndGenerate.html#API_agent-runtime_RetrieveAndGenerate_ResponseSyntax [2]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_InvokeAgent.html#API_agent-runtime_InvokeAgent_ResponseSyntax
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end ⇒ Integer
Where the text with a citation ends in the generated output.
-
#start ⇒ Integer
Where the text with a citation starts in the generated output.