Class: Aws::BedrockAgentRuntime::Types::StopFlowExecutionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#execution_identifierString

The unique identifier of the flow execution to stop.

Returns:

  • (String)


9566
9567
9568
9569
9570
9571
9572
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9566

class StopFlowExecutionRequest < Struct.new(
  :execution_identifier,
  :flow_alias_identifier,
  :flow_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#flow_alias_identifierString

The unique identifier of the flow alias used for the execution.

Returns:

  • (String)


9566
9567
9568
9569
9570
9571
9572
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9566

class StopFlowExecutionRequest < Struct.new(
  :execution_identifier,
  :flow_alias_identifier,
  :flow_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#flow_identifierString

The unique identifier of the flow.

Returns:

  • (String)


9566
9567
9568
9569
9570
9571
9572
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9566

class StopFlowExecutionRequest < Struct.new(
  :execution_identifier,
  :flow_alias_identifier,
  :flow_identifier)
  SENSITIVE = []
  include Aws::Structure
end