Class: Aws::BedrockAgentRuntime::Types::StopFlowExecutionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#execution_identifierString

The unique identifier of the flow execution to stop.

Returns:

  • (String)


8553
8554
8555
8556
8557
8558
8559
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8553

class StopFlowExecutionRequest < Struct.new(
  :execution_identifier,
  :flow_alias_identifier,
  :flow_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#flow_alias_identifierString

The unique identifier of the flow alias used for the execution.

Returns:

  • (String)


8553
8554
8555
8556
8557
8558
8559
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8553

class StopFlowExecutionRequest < Struct.new(
  :execution_identifier,
  :flow_alias_identifier,
  :flow_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#flow_identifierString

The unique identifier of the flow.

Returns:

  • (String)


8553
8554
8555
8556
8557
8558
8559
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 8553

class StopFlowExecutionRequest < Struct.new(
  :execution_identifier,
  :flow_alias_identifier,
  :flow_identifier)
  SENSITIVE = []
  include Aws::Structure
end