Class: Aws::BedrockAgentRuntime::Types::TextResponsePart

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains the part of the generated text that contains a citation, alongside where it begins and ends.

This data type is used in the following API operations:

  • RetrieveAndGenerate response][1

    – in the textResponsePart field

  • InvokeAgent response][2

    – in the textResponsePart field

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_RetrieveAndGenerate.html#API_agent-runtime_RetrieveAndGenerate_ResponseSyntax [2]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_InvokeAgent.html#API_agent-runtime_InvokeAgent_ResponseSyntax

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#spanTypes::Span

Contains information about where the text with a citation begins and ends in the generated output.

Returns:



5928
5929
5930
5931
5932
5933
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5928

class TextResponsePart < Struct.new(
  :span,
  :text)
  SENSITIVE = []
  include Aws::Structure
end

#textString

The part of the generated text that contains a citation.

Returns:

  • (String)


5928
5929
5930
5931
5932
5933
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 5928

class TextResponsePart < Struct.new(
  :span,
  :text)
  SENSITIVE = []
  include Aws::Structure
end