Class: Aws::BedrockAgentRuntime::Types::Trace
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::Trace
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Trace is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of Trace corresponding to the set member.
Contains one part of the agent's reasoning process and results from calling API actions and querying knowledge bases. You can use the trace to understand how the agent arrived at the response it provided the customer. For more information, see Trace enablement.
Defined Under Namespace
Classes: CustomOrchestrationTrace, FailureTrace, GuardrailTrace, OrchestrationTrace, PostProcessingTrace, PreProcessingTrace, RoutingClassifierTrace, Unknown
Constant Summary collapse
- SENSITIVE =
[:custom_orchestration_trace, :failure_trace, :guardrail_trace, :orchestration_trace, :post_processing_trace, :pre_processing_trace, :routing_classifier_trace]
Instance Attribute Summary collapse
-
#custom_orchestration_trace ⇒ Types::CustomOrchestrationTrace
Details about the custom orchestration step in which the agent determines the order in which actions are executed.
-
#failure_trace ⇒ Types::FailureTrace
Contains information about the failure of the interaction.
-
#guardrail_trace ⇒ Types::GuardrailTrace
The trace details for a trace defined in the Guardrail filter.
-
#orchestration_trace ⇒ Types::OrchestrationTrace
Details about the orchestration step, in which the agent determines the order in which actions are executed and which knowledge bases are retrieved.
-
#post_processing_trace ⇒ Types::PostProcessingTrace
Details about the post-processing step, in which the agent shapes the response..
-
#pre_processing_trace ⇒ Types::PreProcessingTrace
Details about the pre-processing step, in which the agent contextualizes and categorizes user inputs.
-
#routing_classifier_trace ⇒ Types::RoutingClassifierTrace
A routing classifier's trace.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#custom_orchestration_trace ⇒ Types::CustomOrchestrationTrace
Details about the custom orchestration step in which the agent determines the order in which actions are executed.
10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 10033 10034 10035 10036 10037 10038 10039 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10018 class Trace < Struct.new( :custom_orchestration_trace, :failure_trace, :guardrail_trace, :orchestration_trace, :post_processing_trace, :pre_processing_trace, :routing_classifier_trace, :unknown) SENSITIVE = [:custom_orchestration_trace, :failure_trace, :guardrail_trace, :orchestration_trace, :post_processing_trace, :pre_processing_trace, :routing_classifier_trace] include Aws::Structure include Aws::Structure::Union class CustomOrchestrationTrace < Trace; end class FailureTrace < Trace; end class GuardrailTrace < Trace; end class OrchestrationTrace < Trace; end class PostProcessingTrace < Trace; end class PreProcessingTrace < Trace; end class RoutingClassifierTrace < Trace; end class Unknown < Trace; end end |
#failure_trace ⇒ Types::FailureTrace
Contains information about the failure of the interaction.
10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 10033 10034 10035 10036 10037 10038 10039 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10018 class Trace < Struct.new( :custom_orchestration_trace, :failure_trace, :guardrail_trace, :orchestration_trace, :post_processing_trace, :pre_processing_trace, :routing_classifier_trace, :unknown) SENSITIVE = [:custom_orchestration_trace, :failure_trace, :guardrail_trace, :orchestration_trace, :post_processing_trace, :pre_processing_trace, :routing_classifier_trace] include Aws::Structure include Aws::Structure::Union class CustomOrchestrationTrace < Trace; end class FailureTrace < Trace; end class GuardrailTrace < Trace; end class OrchestrationTrace < Trace; end class PostProcessingTrace < Trace; end class PreProcessingTrace < Trace; end class RoutingClassifierTrace < Trace; end class Unknown < Trace; end end |
#guardrail_trace ⇒ Types::GuardrailTrace
The trace details for a trace defined in the Guardrail filter.
10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 10033 10034 10035 10036 10037 10038 10039 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10018 class Trace < Struct.new( :custom_orchestration_trace, :failure_trace, :guardrail_trace, :orchestration_trace, :post_processing_trace, :pre_processing_trace, :routing_classifier_trace, :unknown) SENSITIVE = [:custom_orchestration_trace, :failure_trace, :guardrail_trace, :orchestration_trace, :post_processing_trace, :pre_processing_trace, :routing_classifier_trace] include Aws::Structure include Aws::Structure::Union class CustomOrchestrationTrace < Trace; end class FailureTrace < Trace; end class GuardrailTrace < Trace; end class OrchestrationTrace < Trace; end class PostProcessingTrace < Trace; end class PreProcessingTrace < Trace; end class RoutingClassifierTrace < Trace; end class Unknown < Trace; end end |
#orchestration_trace ⇒ Types::OrchestrationTrace
Details about the orchestration step, in which the agent determines the order in which actions are executed and which knowledge bases are retrieved.
10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 10033 10034 10035 10036 10037 10038 10039 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10018 class Trace < Struct.new( :custom_orchestration_trace, :failure_trace, :guardrail_trace, :orchestration_trace, :post_processing_trace, :pre_processing_trace, :routing_classifier_trace, :unknown) SENSITIVE = [:custom_orchestration_trace, :failure_trace, :guardrail_trace, :orchestration_trace, :post_processing_trace, :pre_processing_trace, :routing_classifier_trace] include Aws::Structure include Aws::Structure::Union class CustomOrchestrationTrace < Trace; end class FailureTrace < Trace; end class GuardrailTrace < Trace; end class OrchestrationTrace < Trace; end class PostProcessingTrace < Trace; end class PreProcessingTrace < Trace; end class RoutingClassifierTrace < Trace; end class Unknown < Trace; end end |
#post_processing_trace ⇒ Types::PostProcessingTrace
Details about the post-processing step, in which the agent shapes the response..
10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 10033 10034 10035 10036 10037 10038 10039 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10018 class Trace < Struct.new( :custom_orchestration_trace, :failure_trace, :guardrail_trace, :orchestration_trace, :post_processing_trace, :pre_processing_trace, :routing_classifier_trace, :unknown) SENSITIVE = [:custom_orchestration_trace, :failure_trace, :guardrail_trace, :orchestration_trace, :post_processing_trace, :pre_processing_trace, :routing_classifier_trace] include Aws::Structure include Aws::Structure::Union class CustomOrchestrationTrace < Trace; end class FailureTrace < Trace; end class GuardrailTrace < Trace; end class OrchestrationTrace < Trace; end class PostProcessingTrace < Trace; end class PreProcessingTrace < Trace; end class RoutingClassifierTrace < Trace; end class Unknown < Trace; end end |
#pre_processing_trace ⇒ Types::PreProcessingTrace
Details about the pre-processing step, in which the agent contextualizes and categorizes user inputs.
10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 10033 10034 10035 10036 10037 10038 10039 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10018 class Trace < Struct.new( :custom_orchestration_trace, :failure_trace, :guardrail_trace, :orchestration_trace, :post_processing_trace, :pre_processing_trace, :routing_classifier_trace, :unknown) SENSITIVE = [:custom_orchestration_trace, :failure_trace, :guardrail_trace, :orchestration_trace, :post_processing_trace, :pre_processing_trace, :routing_classifier_trace] include Aws::Structure include Aws::Structure::Union class CustomOrchestrationTrace < Trace; end class FailureTrace < Trace; end class GuardrailTrace < Trace; end class OrchestrationTrace < Trace; end class PostProcessingTrace < Trace; end class PreProcessingTrace < Trace; end class RoutingClassifierTrace < Trace; end class Unknown < Trace; end end |
#routing_classifier_trace ⇒ Types::RoutingClassifierTrace
A routing classifier's trace.
10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 10033 10034 10035 10036 10037 10038 10039 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10018 class Trace < Struct.new( :custom_orchestration_trace, :failure_trace, :guardrail_trace, :orchestration_trace, :post_processing_trace, :pre_processing_trace, :routing_classifier_trace, :unknown) SENSITIVE = [:custom_orchestration_trace, :failure_trace, :guardrail_trace, :orchestration_trace, :post_processing_trace, :pre_processing_trace, :routing_classifier_trace] include Aws::Structure include Aws::Structure::Union class CustomOrchestrationTrace < Trace; end class FailureTrace < Trace; end class GuardrailTrace < Trace; end class OrchestrationTrace < Trace; end class PostProcessingTrace < Trace; end class PreProcessingTrace < Trace; end class RoutingClassifierTrace < Trace; end class Unknown < Trace; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
10018 10019 10020 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10018 def unknown @unknown end |