Class: Aws::BedrockAgentRuntime::Types::Trace

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Note:

Trace is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of Trace corresponding to the set member.

Contains one part of the agent’s reasoning process and results from calling API actions and querying knowledge bases. You can use the trace to understand how the agent arrived at the response it provided the customer. For more information, see [Trace enablement].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/agents-test.html#trace-enablement

Defined Under Namespace

Classes: CustomOrchestrationTrace, FailureTrace, GuardrailTrace, OrchestrationTrace, PostProcessingTrace, PreProcessingTrace, RoutingClassifierTrace, Unknown

Constant Summary collapse

SENSITIVE =
[:custom_orchestration_trace, :failure_trace, :guardrail_trace, :orchestration_trace, :post_processing_trace, :pre_processing_trace, :routing_classifier_trace]

Instance Attribute Summary collapse

Instance Attribute Details

#custom_orchestration_traceTypes::CustomOrchestrationTrace

Details about the custom orchestration step in which the agent determines the order in which actions are executed.



9847
9848
9849
9850
9851
9852
9853
9854
9855
9856
9857
9858
9859
9860
9861
9862
9863
9864
9865
9866
9867
9868
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9847

class Trace < Struct.new(
  :custom_orchestration_trace,
  :failure_trace,
  :guardrail_trace,
  :orchestration_trace,
  :post_processing_trace,
  :pre_processing_trace,
  :routing_classifier_trace,
  :unknown)
  SENSITIVE = [:custom_orchestration_trace, :failure_trace, :guardrail_trace, :orchestration_trace, :post_processing_trace, :pre_processing_trace, :routing_classifier_trace]
  include Aws::Structure
  include Aws::Structure::Union

  class CustomOrchestrationTrace < Trace; end
  class FailureTrace < Trace; end
  class GuardrailTrace < Trace; end
  class OrchestrationTrace < Trace; end
  class PostProcessingTrace < Trace; end
  class PreProcessingTrace < Trace; end
  class RoutingClassifierTrace < Trace; end
  class Unknown < Trace; end
end

#failure_traceTypes::FailureTrace

Contains information about the failure of the interaction.

Returns:



9847
9848
9849
9850
9851
9852
9853
9854
9855
9856
9857
9858
9859
9860
9861
9862
9863
9864
9865
9866
9867
9868
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9847

class Trace < Struct.new(
  :custom_orchestration_trace,
  :failure_trace,
  :guardrail_trace,
  :orchestration_trace,
  :post_processing_trace,
  :pre_processing_trace,
  :routing_classifier_trace,
  :unknown)
  SENSITIVE = [:custom_orchestration_trace, :failure_trace, :guardrail_trace, :orchestration_trace, :post_processing_trace, :pre_processing_trace, :routing_classifier_trace]
  include Aws::Structure
  include Aws::Structure::Union

  class CustomOrchestrationTrace < Trace; end
  class FailureTrace < Trace; end
  class GuardrailTrace < Trace; end
  class OrchestrationTrace < Trace; end
  class PostProcessingTrace < Trace; end
  class PreProcessingTrace < Trace; end
  class RoutingClassifierTrace < Trace; end
  class Unknown < Trace; end
end

#guardrail_traceTypes::GuardrailTrace

The trace details for a trace defined in the Guardrail filter.



9847
9848
9849
9850
9851
9852
9853
9854
9855
9856
9857
9858
9859
9860
9861
9862
9863
9864
9865
9866
9867
9868
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9847

class Trace < Struct.new(
  :custom_orchestration_trace,
  :failure_trace,
  :guardrail_trace,
  :orchestration_trace,
  :post_processing_trace,
  :pre_processing_trace,
  :routing_classifier_trace,
  :unknown)
  SENSITIVE = [:custom_orchestration_trace, :failure_trace, :guardrail_trace, :orchestration_trace, :post_processing_trace, :pre_processing_trace, :routing_classifier_trace]
  include Aws::Structure
  include Aws::Structure::Union

  class CustomOrchestrationTrace < Trace; end
  class FailureTrace < Trace; end
  class GuardrailTrace < Trace; end
  class OrchestrationTrace < Trace; end
  class PostProcessingTrace < Trace; end
  class PreProcessingTrace < Trace; end
  class RoutingClassifierTrace < Trace; end
  class Unknown < Trace; end
end

#orchestration_traceTypes::OrchestrationTrace

Details about the orchestration step, in which the agent determines the order in which actions are executed and which knowledge bases are retrieved.



9847
9848
9849
9850
9851
9852
9853
9854
9855
9856
9857
9858
9859
9860
9861
9862
9863
9864
9865
9866
9867
9868
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9847

class Trace < Struct.new(
  :custom_orchestration_trace,
  :failure_trace,
  :guardrail_trace,
  :orchestration_trace,
  :post_processing_trace,
  :pre_processing_trace,
  :routing_classifier_trace,
  :unknown)
  SENSITIVE = [:custom_orchestration_trace, :failure_trace, :guardrail_trace, :orchestration_trace, :post_processing_trace, :pre_processing_trace, :routing_classifier_trace]
  include Aws::Structure
  include Aws::Structure::Union

  class CustomOrchestrationTrace < Trace; end
  class FailureTrace < Trace; end
  class GuardrailTrace < Trace; end
  class OrchestrationTrace < Trace; end
  class PostProcessingTrace < Trace; end
  class PreProcessingTrace < Trace; end
  class RoutingClassifierTrace < Trace; end
  class Unknown < Trace; end
end

#post_processing_traceTypes::PostProcessingTrace

Details about the post-processing step, in which the agent shapes the response..



9847
9848
9849
9850
9851
9852
9853
9854
9855
9856
9857
9858
9859
9860
9861
9862
9863
9864
9865
9866
9867
9868
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9847

class Trace < Struct.new(
  :custom_orchestration_trace,
  :failure_trace,
  :guardrail_trace,
  :orchestration_trace,
  :post_processing_trace,
  :pre_processing_trace,
  :routing_classifier_trace,
  :unknown)
  SENSITIVE = [:custom_orchestration_trace, :failure_trace, :guardrail_trace, :orchestration_trace, :post_processing_trace, :pre_processing_trace, :routing_classifier_trace]
  include Aws::Structure
  include Aws::Structure::Union

  class CustomOrchestrationTrace < Trace; end
  class FailureTrace < Trace; end
  class GuardrailTrace < Trace; end
  class OrchestrationTrace < Trace; end
  class PostProcessingTrace < Trace; end
  class PreProcessingTrace < Trace; end
  class RoutingClassifierTrace < Trace; end
  class Unknown < Trace; end
end

#pre_processing_traceTypes::PreProcessingTrace

Details about the pre-processing step, in which the agent contextualizes and categorizes user inputs.



9847
9848
9849
9850
9851
9852
9853
9854
9855
9856
9857
9858
9859
9860
9861
9862
9863
9864
9865
9866
9867
9868
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9847

class Trace < Struct.new(
  :custom_orchestration_trace,
  :failure_trace,
  :guardrail_trace,
  :orchestration_trace,
  :post_processing_trace,
  :pre_processing_trace,
  :routing_classifier_trace,
  :unknown)
  SENSITIVE = [:custom_orchestration_trace, :failure_trace, :guardrail_trace, :orchestration_trace, :post_processing_trace, :pre_processing_trace, :routing_classifier_trace]
  include Aws::Structure
  include Aws::Structure::Union

  class CustomOrchestrationTrace < Trace; end
  class FailureTrace < Trace; end
  class GuardrailTrace < Trace; end
  class OrchestrationTrace < Trace; end
  class PostProcessingTrace < Trace; end
  class PreProcessingTrace < Trace; end
  class RoutingClassifierTrace < Trace; end
  class Unknown < Trace; end
end

#routing_classifier_traceTypes::RoutingClassifierTrace

A routing classifier’s trace.



9847
9848
9849
9850
9851
9852
9853
9854
9855
9856
9857
9858
9859
9860
9861
9862
9863
9864
9865
9866
9867
9868
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9847

class Trace < Struct.new(
  :custom_orchestration_trace,
  :failure_trace,
  :guardrail_trace,
  :orchestration_trace,
  :post_processing_trace,
  :pre_processing_trace,
  :routing_classifier_trace,
  :unknown)
  SENSITIVE = [:custom_orchestration_trace, :failure_trace, :guardrail_trace, :orchestration_trace, :post_processing_trace, :pre_processing_trace, :routing_classifier_trace]
  include Aws::Structure
  include Aws::Structure::Union

  class CustomOrchestrationTrace < Trace; end
  class FailureTrace < Trace; end
  class GuardrailTrace < Trace; end
  class OrchestrationTrace < Trace; end
  class PostProcessingTrace < Trace; end
  class PreProcessingTrace < Trace; end
  class RoutingClassifierTrace < Trace; end
  class Unknown < Trace; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



9847
9848
9849
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9847

def unknown
  @unknown
end