Class: Aws::BedrockAgentRuntime::Types::TraceElements
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::TraceElements
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Note:
TraceElements is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of TraceElements corresponding to the set member.
Contains trace elements for flow execution tracking.
Direct Known Subclasses
Defined Under Namespace
Classes: AgentTraces, Unknown
Constant Summary collapse
- SENSITIVE =
[:agent_traces]
Instance Attribute Summary collapse
-
#agent_traces ⇒ Array<Types::TracePart>
Agent trace information for the flow execution.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#agent_traces ⇒ Array<Types::TracePart>
Agent trace information for the flow execution.
9880 9881 9882 9883 9884 9885 9886 9887 9888 9889 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9880 class TraceElements < Struct.new( :agent_traces, :unknown) SENSITIVE = [:agent_traces] include Aws::Structure include Aws::Structure::Union class AgentTraces < TraceElements; end class Unknown < TraceElements; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
9880 9881 9882 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 9880 def unknown @unknown end |