Class: Aws::BedrockAgentRuntime::Types::TracePart

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains information about the agent and session, alongside the agent's reasoning process and results from calling API actions and querying knowledge bases and metadata about the trace. You can use the trace to understand how the agent arrived at the response it provided the customer. For more information, see Trace enablement.

Constant Summary collapse

SENSITIVE =
[:collaborator_name, :trace]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_alias_idString

The unique identifier of the alias of the agent.

Returns:

  • (String)


10114
10115
10116
10117
10118
10119
10120
10121
10122
10123
10124
10125
10126
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10114

class TracePart < Struct.new(
  :agent_alias_id,
  :agent_id,
  :agent_version,
  :caller_chain,
  :collaborator_name,
  :event_time,
  :session_id,
  :trace,
  :event_type)
  SENSITIVE = [:collaborator_name, :trace]
  include Aws::Structure
end

#agent_idString

The unique identifier of the agent.

Returns:

  • (String)


10114
10115
10116
10117
10118
10119
10120
10121
10122
10123
10124
10125
10126
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10114

class TracePart < Struct.new(
  :agent_alias_id,
  :agent_id,
  :agent_version,
  :caller_chain,
  :collaborator_name,
  :event_time,
  :session_id,
  :trace,
  :event_type)
  SENSITIVE = [:collaborator_name, :trace]
  include Aws::Structure
end

#agent_versionString

The version of the agent.

Returns:

  • (String)


10114
10115
10116
10117
10118
10119
10120
10121
10122
10123
10124
10125
10126
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10114

class TracePart < Struct.new(
  :agent_alias_id,
  :agent_id,
  :agent_version,
  :caller_chain,
  :collaborator_name,
  :event_time,
  :session_id,
  :trace,
  :event_type)
  SENSITIVE = [:collaborator_name, :trace]
  include Aws::Structure
end

#caller_chainArray<Types::Caller>

The part's caller chain.

Returns:



10114
10115
10116
10117
10118
10119
10120
10121
10122
10123
10124
10125
10126
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10114

class TracePart < Struct.new(
  :agent_alias_id,
  :agent_id,
  :agent_version,
  :caller_chain,
  :collaborator_name,
  :event_time,
  :session_id,
  :trace,
  :event_type)
  SENSITIVE = [:collaborator_name, :trace]
  include Aws::Structure
end

#collaborator_nameString

The part's collaborator name.

Returns:

  • (String)


10114
10115
10116
10117
10118
10119
10120
10121
10122
10123
10124
10125
10126
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10114

class TracePart < Struct.new(
  :agent_alias_id,
  :agent_id,
  :agent_version,
  :caller_chain,
  :collaborator_name,
  :event_time,
  :session_id,
  :trace,
  :event_type)
  SENSITIVE = [:collaborator_name, :trace]
  include Aws::Structure
end

#event_timeTime

The time of the trace.

Returns:

  • (Time)


10114
10115
10116
10117
10118
10119
10120
10121
10122
10123
10124
10125
10126
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10114

class TracePart < Struct.new(
  :agent_alias_id,
  :agent_id,
  :agent_version,
  :caller_chain,
  :collaborator_name,
  :event_time,
  :session_id,
  :trace,
  :event_type)
  SENSITIVE = [:collaborator_name, :trace]
  include Aws::Structure
end

#event_typeObject

Returns the value of attribute event_type

Returns:

  • (Object)

    the current value of event_type



10114
10115
10116
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10114

def event_type
  @event_type
end

#session_idString

The unique identifier of the session with the agent.

Returns:

  • (String)


10114
10115
10116
10117
10118
10119
10120
10121
10122
10123
10124
10125
10126
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10114

class TracePart < Struct.new(
  :agent_alias_id,
  :agent_id,
  :agent_version,
  :caller_chain,
  :collaborator_name,
  :event_time,
  :session_id,
  :trace,
  :event_type)
  SENSITIVE = [:collaborator_name, :trace]
  include Aws::Structure
end

#traceTypes::Trace

Contains one part of the agent's reasoning process and results from calling API actions and querying knowledge bases. You can use the trace to understand how the agent arrived at the response it provided the customer. For more information, see Trace enablement.

Returns:



10114
10115
10116
10117
10118
10119
10120
10121
10122
10123
10124
10125
10126
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10114

class TracePart < Struct.new(
  :agent_alias_id,
  :agent_id,
  :agent_version,
  :caller_chain,
  :collaborator_name,
  :event_time,
  :session_id,
  :trace,
  :event_type)
  SENSITIVE = [:collaborator_name, :trace]
  include Aws::Structure
end