Class: Aws::BedrockAgentRuntime::Types::UpdateSessionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::UpdateSessionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#session_identifier ⇒ String
The unique identifier of the session to modify.
-
#session_metadata ⇒ Hash<String,String>
A map of key-value pairs containing attributes to be persisted across the session.
Instance Attribute Details
#session_identifier ⇒ String
The unique identifier of the session to modify. You can specify
either the session's sessionId or its Amazon Resource Name (ARN).
10183 10184 10185 10186 10187 10188 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10183 class UpdateSessionRequest < Struct.new( :session_identifier, :session_metadata) SENSITIVE = [] include Aws::Structure end |
#session_metadata ⇒ Hash<String,String>
A map of key-value pairs containing attributes to be persisted across the session. For example the user's ID, their language preference, and the type of device they are using.
10183 10184 10185 10186 10187 10188 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10183 class UpdateSessionRequest < Struct.new( :session_identifier, :session_metadata) SENSITIVE = [] include Aws::Structure end |