Class: Aws::BedrockAgentRuntime::Types::UserContext
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::UserContext
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains information about the user making the request. Use this to pass user identity information for access control filtering, so that retrieval results only include documents the user is authorized to access.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#user_id ⇒ String
The identifier of the user making the retrieval request.
Instance Attribute Details
#user_id ⇒ String
The identifier of the user making the retrieval request.
10254 10255 10256 10257 10258 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10254 class UserContext < Struct.new( :user_id) SENSITIVE = [] include Aws::Structure end |