Class: Aws::BedrockAgentRuntime::Types::UserContext

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagentruntime/types.rb

Overview

Contains information about the user making the request. Use this to pass user identity information for access control filtering, so that retrieval results only include documents the user is authorized to access.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#user_idString

The identifier of the user making the retrieval request.

Returns:

  • (String)


10083
10084
10085
10086
10087
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10083

class UserContext < Struct.new(
  :user_id)
  SENSITIVE = []
  include Aws::Structure
end