Class: Aws::BedrockAgentRuntime::Types::VectorSearchBedrockRerankingConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgentRuntime::Types::VectorSearchBedrockRerankingConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagentruntime/types.rb
Overview
Contains configurations for reranking with an Amazon Bedrock reranker model.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#metadata_configuration ⇒ Types::MetadataConfigurationForReranking
Contains configurations for the metadata to use in reranking.
-
#model_configuration ⇒ Types::VectorSearchBedrockRerankingModelConfiguration
Contains configurations for the reranker model.
-
#number_of_reranked_results ⇒ Integer
The number of results to return after reranking.
Instance Attribute Details
#metadata_configuration ⇒ Types::MetadataConfigurationForReranking
Contains configurations for the metadata to use in reranking.
10121 10122 10123 10124 10125 10126 10127 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10121 class VectorSearchBedrockRerankingConfiguration < Struct.new( :metadata_configuration, :model_configuration, :number_of_reranked_results) SENSITIVE = [] include Aws::Structure end |
#model_configuration ⇒ Types::VectorSearchBedrockRerankingModelConfiguration
Contains configurations for the reranker model.
10121 10122 10123 10124 10125 10126 10127 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10121 class VectorSearchBedrockRerankingConfiguration < Struct.new( :metadata_configuration, :model_configuration, :number_of_reranked_results) SENSITIVE = [] include Aws::Structure end |
#number_of_reranked_results ⇒ Integer
The number of results to return after reranking.
10121 10122 10123 10124 10125 10126 10127 |
# File 'lib/aws-sdk-bedrockagentruntime/types.rb', line 10121 class VectorSearchBedrockRerankingConfiguration < Struct.new( :metadata_configuration, :model_configuration, :number_of_reranked_results) SENSITIVE = [] include Aws::Structure end |